@@ -7,12 +7,12 @@
 //
 
 #include "testremovegroupscommand.h"
-#include "catch.hpp"
-
+/*
 
 TEST_CASE("Testing RemoveGroupsCommand Class") {
     TestRemoveGroupsCommand tRemoveGroupsCommand;
     
     //how do we unit test this??
     //each private function reads files processes them and writes new ones.
-}
+}*/
+
