@@ -51,7 +51,7 @@ public:
 	void mergeFilter(string newFilter){
 		for(int i=0;i<alignmentLength;i++){
 			if(newFilter[i] == '0'){
-				filter[i] = 0;
+				filter[i] = '0';
 			}
 		}
 	}
@@ -89,7 +89,7 @@ public:
 	}
 
 	void doHard(string hard) {
-		ifstream fileHandle;
+        ifstream fileHandle; filter="";
         Utils util; util.openInputFile(hard, fileHandle);
 	
 		fileHandle >> filter;
