@@ -10,30 +10,26 @@
 #define metrologstudent_hpp
 
 #include "diversityutils.hpp"
-
+#include "diversitycalc.h"
 
 //MetroLogStudent - Samples the Poisson Log-Student distn to SADs
 /***********************************************************************/
 
-class MetroLogStudent  {
+class MetroLogStudent : public DiversityCalculator {
     
 public:
     
-    MetroLogStudent(double sigm, double sigv, double sign, double sigS, int n, string st) : sigmaM(sigm), sigmaV(sigv), sigmaN(sign), sigmaS(sigS), nIters(n), outFileStub(st) { m = MothurOut::getInstance(); }
+    MetroLogStudent(int fi, double sigm, double sigv, double sign, double sigS, int n, string st);
     ~MetroLogStudent() {}
     
     vector<string> getValues(SAbundVector* rank);
     
-    bool requiresSample() { return false; }
-    
+    string getTag() { return "ls"; }
     
 private:
     
-    Utils util;
-    MothurOut* m;
-    
     double sigmaM, sigmaV, sigmaN, sigmaS;
-    int nIters;
+    int nIters, fitIters;
     string outFileStub;
     
 };
