@@ -116,21 +116,34 @@ vector<int>  DeCalculator::findWindows(Sequence* query, int front, int back, int
 vector<float> DeCalculator::calcObserved(Sequence* query, Sequence* subject, vector<int> window, int size) {
 	try {
 		
+        if (query->getAligned().length() != subject->getAligned().length()) {
+            
+            m->mothurOut("[ERROR]: seqLengths must match. queryLength = " + toString(query->getAligned().length()) + ", subjectLength = " + toString(subject->getAligned().length()) +"\n");
+            m->setControl_pressed(true);
+        }
+        
+        
 		vector<float> temp;	
 		//int gaps = 0;		
 		for (int i = 0; i < window.size(); i++) {
-						
+					
+            if (m->getControl_pressed()) { break; }
+            
 			string seqFrag = query->getAligned().substr(window[i], size);
 			string seqFragsub = subject->getAligned().substr(window[i], size);
+            
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: seqLengths = " + toString(seqFrag.length()) + "," + toString(seqFragsub.length()) +  "\t" + toString(window[i]) + "\t" + toString(size) +"\n"); }
 				
 			int diff = 0;
 			for (int b = 0; b < seqFrag.length(); b++) {
 				//if at least one is a base and they are not equal
 				if( (isalpha(seqFrag[b]) || isalpha(seqFragsub[b])) && (seqFrag[b] != seqFragsub[b]) ) { diff++; }
             }
-               
+            
 			//percentage of mismatched bases
 			float dist = diff / (float) (seqFrag.length()) * 100;
+            
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: diffs = " + toString(diff) + ", dist = " + toString(dist) + "\n"); }
 			
 			temp.push_back(dist);
 		}
@@ -326,7 +339,7 @@ vector< vector<float> > DeCalculator::getQuantiles(vector<Sequence*> seqs, vecto
 		//for each sequence
 		for(int i = start; i < end; i++){
 		
-			m->mothurOut("Processing sequence " + toString(i)); m->mothurOutEndLine();
+			m->mothurOut("Processing sequence " + toString(i)+ "\n");
 			Sequence* query = new Sequence(seqs[i]->getName(), seqs[i]->getAligned());
 			
 			//compare to every other sequence in template
@@ -464,7 +477,7 @@ vector<Sequence> DeCalculator::findClosest(Sequence querySeq, vector<Sequence*>&
 		vector<SeqDist> distsLeft;
 		vector<SeqDist> distsRight;
 		
-		DistCalc* distcalculator = new eachGapDist();
+        DistCalc* distcalculator = new eachGapDist(1.0);
 		
 		string queryUnAligned = querySeq.getUnaligned();
 		int numBases = int(queryUnAligned.length() * 0.33);
@@ -624,7 +637,7 @@ Sequence* DeCalculator::findClosest(Sequence* querySeq, vector<Sequence*> db) {
 		
 		Sequence* seqsMatch;  
 		
-		DistCalc* distcalculator = new eachGapDist();
+        DistCalc* distcalculator = new eachGapDist(1.0);
 		int index = 0;
 		int smallest = 1000000;
 		
