@@ -31,10 +31,10 @@ ClusterClassic::ClusterClassic(float c, string f, bool s) : method(f),  nseqs(0)
 	}
 }
 /***********************************************************************/
-int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
+void ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 	try {
 		double distance;
-		int square;
+		bool square;
 		string name;
 		vector<string> matrixNames;
 		
@@ -44,7 +44,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
         string numTest;
 		fileHandle >> numTest >> name;
         
-        if (!util.isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ", quitting."); m->mothurOutEndLine(); exit(1); }
+        if (!util.isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ", quitting.\n");  exit(1); }
         else { convert(numTest, nseqs); }
 
 
@@ -56,7 +56,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 		}
 		else{
 				list = new ListVector(nameMap->getListVector());
-				if(nameMap->count(name)==0){        m->mothurOut("Error: Sequence '" + name + "' was not found in the names file, please correct"); m->mothurOutEndLine(); }
+				if(nameMap->count(name)==0){        m->mothurOut("Error: Sequence '" + name + "' was not found in the names file, please correct\n");  }
 		}
 		
 		//initialize distance matrix to cutoff
@@ -67,7 +67,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 		while((d=fileHandle.get()) != EOF){
 
 				if(isalnum(d)){
-						square = 1;
+						square = true;
 						fileHandle.putback(d);
 						for(int i=0;i<nseqs;i++){
 								fileHandle >> distance;
@@ -75,20 +75,20 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 						break;
 				}
 				if(d == '\n'){
-						square = 0;
+						square = false;
 						break;
 				}
 		}
 
 		
 
-		if(square == 0){
+		if(!square){
 
 
 				int        index = 0;
 
 				for(int i=1;i<nseqs;i++){
-						if (m->getControl_pressed()) {  fileHandle.close();   return 0; }
+						if (m->getControl_pressed()) {  fileHandle.close();   return; }
 						
 						fileHandle >> name;
 						matrixNames.push_back(name);
@@ -100,7 +100,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 						
 								for(int j=0;j<i;j++){
 								
-										if (m->getControl_pressed()) {  fileHandle.close(); return 0;  }
+										if (m->getControl_pressed()) {  fileHandle.close(); return;  }
 										
 										fileHandle >> distance;
 							
@@ -117,12 +117,12 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 				
 						}
 						else{
-								if(nameMap->count(name)==0){        m->mothurOut("Error: Sequence '" + name + "' was not found in the names file, please correct"); m->mothurOutEndLine(); }
+								if(nameMap->count(name)==0){        m->mothurOut("Error: Sequence '" + name + "' was not found in the names file, please correct\n");  }
 				
 								for(int j=0;j<i;j++){
 										fileHandle >> distance;
 										
-										if (m->getControl_pressed()) {  fileHandle.close(); return 0;  }
+										if (m->getControl_pressed()) {  fileHandle.close(); return;  }
 				
 										if (util.isEqual(distance,-1)) { distance = 1000000; }
 										else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
@@ -157,7 +157,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 								for(int j=0;j<nseqs;j++){
 										fileHandle >> distance;
 										
-										if (m->getControl_pressed()) {  fileHandle.close();  return 0; }
+										if (m->getControl_pressed()) {  fileHandle.close();  return; }
 										
 										if (util.isEqual(distance,-1)) { distance = 1000000; }
 										else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
@@ -173,12 +173,12 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 						
 						}
 						else{
-								if(nameMap->count(name)==0){        m->mothurOut("Error: Sequence '" + name + "' was not found in the names file, please correct"); m->mothurOutEndLine(); }
+								if(nameMap->count(name)==0){        m->mothurOut("Error: Sequence '" + name + "' was not found in the names file, please correct\n");  }
 				
 								for(int j=0;j<nseqs;j++){
 										fileHandle >> distance;
 										
-										if (m->getControl_pressed()) {  fileHandle.close();   return 0; }
+										if (m->getControl_pressed()) {  fileHandle.close();   return; }
 										
 									   if (distance == -1) { distance = 1000000; }
 										else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.                                                        
@@ -199,7 +199,7 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 				}
 		}
 		
-		if (m->getControl_pressed()) {  fileHandle.close();  return 0; }
+		if (m->getControl_pressed()) {  fileHandle.close();  return; }
 		
 		
 
@@ -207,8 +207,6 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 		rabund = new RAbundVector(list->getRAbundVector());
 		
 		fileHandle.close();
-		
-		return 0;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ClusterClassic", "readPhylipFile");
@@ -217,10 +215,10 @@ int ClusterClassic::readPhylipFile(string filename, NameAssignment* nameMap) {
 
 }
 /***********************************************************************/
-int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
+void ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
 	try {
 		double distance;
-		int square;
+		bool square;
 		string name;
 		vector<string> matrixNames;
 		
@@ -230,7 +228,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
         string numTest;
 		fileHandle >> numTest >> name;
         
-        if (!util.isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ", quitting."); m->mothurOutEndLine(); exit(1); }
+        if (!util.isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ", quitting.\n");  exit(1); }
         else { convert(numTest, nseqs); }
         
         
@@ -255,7 +253,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
 		while((d=fileHandle.get()) != EOF){
             
             if(isalnum(d)){
-                square = 1;
+                square = true;
                 fileHandle.putback(d);
                 for(int i=0;i<nseqs;i++){
                     fileHandle >> distance;
@@ -263,20 +261,20 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                 break;
             }
             if(d == '\n'){
-                square = 0;
+                square = false;
                 break;
             }
 		}
         
 		
         
-		if(square == 0){
+		if(!square){
             
             
             int        index = 0;
             
             for(int i=1;i<nseqs;i++){
-                if (m->getControl_pressed()) {  fileHandle.close(); return 0; }
+                if (m->getControl_pressed()) {  fileHandle.close(); return; }
                 
                 fileHandle >> name;
                 matrixNames.push_back(name);
@@ -288,7 +286,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                     
                     for(int j=0;j<i;j++){
                         
-                        if (m->getControl_pressed()) { fileHandle.close(); return 0;  }
+                        if (m->getControl_pressed()) { fileHandle.close(); return;  }
                         
                         fileHandle >> distance;
                         
@@ -307,7 +305,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                     for(int j=0;j<i;j++){
                         fileHandle >> distance;
                         
-                        if (m->getControl_pressed()) {  fileHandle.close(); return 0;  }
+                        if (m->getControl_pressed()) {  fileHandle.close(); return;  }
                         
                         if (util.isEqual(distance,-1)) { distance = 1000000; }
                         else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
@@ -340,7 +338,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                     for(int j=0;j<nseqs;j++){
                         fileHandle >> distance;
                         
-                        if (m->getControl_pressed()) {  fileHandle.close();   return 0; }
+                        if (m->getControl_pressed()) {  fileHandle.close();   return; }
                         
                         if (util.isEqual(distance,-1)) { distance = 1000000; }
                         else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.
@@ -359,7 +357,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
                     for(int j=0;j<nseqs;j++){
                         fileHandle >> distance;
                         
-                        if (m->getControl_pressed()) {  fileHandle.close();   return 0; }
+                        if (m->getControl_pressed()) {  fileHandle.close();   return; }
                         
                         if (util.isEqual(distance,-1)) { distance = 1000000; }
                         else if (sim) { distance = 1.0 - distance;  }  //user has entered a sim matrix that we need to convert.                                                        
@@ -379,7 +377,7 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
             }
 		}
 		
-		if (m->getControl_pressed()) {  fileHandle.close();   return 0; }
+		if (m->getControl_pressed()) {  fileHandle.close();   return; }
 		
 		
         
@@ -398,8 +396,6 @@ int ClusterClassic::readPhylipFile(string filename, CountTable* countTable) {
         }
 		
 		fileHandle.close();
-		
-		return 0;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ClusterClassic", "readPhylipFile");
@@ -424,13 +420,10 @@ double ClusterClassic::getSmallCell() {
 					mins.clear();
 					colDist temp(i, j, dMatrix[i][j]);
 					mins.push_back(temp);
-                    //cout << "adding " << i << '\t' << j << " to mins\n";
 					smallDist = dMatrix[i][j];
 				}else if (dMatrix[i][j] == smallDist) {
 					colDist temp(i, j, dMatrix[i][j]);
 					mins.push_back(temp);
-                    //cout << "adding " << i << '\t' << j << " to mins\n";
-
 				}
 			}
 		}
@@ -442,8 +435,6 @@ double ClusterClassic::getSmallCell() {
             smallCol = mins[0].col;
         }
         
-        //cout << "num mins = " << mins.size() << endl;
-        
 		//eliminate smallCell
 		if (smallRow < smallCol) { dMatrix[smallCol][smallRow] = aboveCutoff; }
 		else { dMatrix[smallRow][smallCol] = aboveCutoff; }
@@ -490,9 +481,7 @@ void ClusterClassic::update(double& cutOFF){
 		
 		int r, c;
 		r = smallRow; c = smallCol;
-        
-        //cout << "smallest row / col = " << smallRow << '\t' << smallCol << endl;
-				
+        				
 		for(int i=0;i<nseqs;i++){
 			if(i != r && i != c){
 				double distRow, distCol, newDist;
