@@ -34,7 +34,14 @@ vector<string> AlignCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["alignreport"] = tempOutNames;
+        outputTypes["accnos"] = tempOutNames;
 
+        abort = false; calledHelp = false;
+        
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
 		return myArray;
@@ -119,75 +126,18 @@ string AlignCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-AlignCommand::AlignCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-		outputTypes["alignreport"] = tempOutNames;
-		outputTypes["accnos"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "AlignCommand", "AlignCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 AlignCommand::AlignCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;
-		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true;}
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
+			OptionParser parser(option, setParameters());
+			map<string, string> parameters = parser.getParameters();
 			
-			OptionParser parser(option);
-			map<string, string> parameters = parser.getParameters(); 
-			
-			ValidParameters validParameter("align.seqs");
-			map<string, string>::iterator it;
-			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-			outputTypes["alignreport"] = tempOutNames;
-			outputTypes["accnos"] = tempOutNames;
-			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
-
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");
-			
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-
-				//user has given a template file
-                it = parameters.find("reference");
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["reference"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("fasta");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-                }
-			}
-
+            ValidParameters validParameter;
             templateFileName = validParameter.validFile(parameters, "reference");
             if (templateFileName == "not found") { m->mothurOut("[ERROR]: The reference parameter is a required for the align.seqs command, aborting.\n"); abort = true;
             }else if (templateFileName == "not open") { abort = true; }
@@ -200,7 +150,6 @@ AlignCommand::AlignCommand(string option)  {
             }
             else if (fastafile == "not open") { abort = true; }
             else { current->setFastaFile(fastafile); }
-
 		
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
@@ -230,11 +179,22 @@ AlignCommand::AlignCommand(string option)  {
 			util.mothurConvert(temp, threshold); 
 			
 			search = validParameter.valid(parameters, "search");		if (search == "not found"){	search = "kmer";		}
-			if ((search != "suffix") && (search != "kmer") && (search != "blast")) { m->mothurOut("invalid search option: choices are kmer, suffix or blast."); m->mothurOutEndLine(); abort=true; }
+			if ((search != "suffix") && (search != "kmer") && (search != "blast")) { m->mothurOut("invalid search option: choices are kmer, suffix or blast.\n");  abort=true; }
 			
 			align = validParameter.valid(parameters, "align");		if (align == "not found"){	align = "needleman";	}
-			if ((align != "needleman") && (align != "gotoh") && (align != "blast") && (align != "noalign")) { m->mothurOut("invalid align option: choices are needleman, gotoh, blast or noalign."); m->mothurOutEndLine(); abort=true; }
-
+			if ((align != "needleman") && (align != "gotoh") && (align != "blast") && (align != "noalign")) { m->mothurOut("invalid align option: choices are needleman, gotoh, blast or noalign.\n");  abort=true; }
+            
+            if ((search == "blast") || (align == "blast")) {
+                string blastlocation = "";
+                vector<string> locations = current->getLocations();
+                string path = current->getProgramPath();
+                
+                if (!util.findBlastLocation(blastlocation, path, locations)){
+                    m->mothurOut("[WARNING]: Unable to locate blast executables, cannot use blast as search or align method. Using defaults instead.\n");
+                    if (search == "blast") { search = "kmer"; }
+                    if (align == "blast") { align = "needleman"; }
+                }
+            }
 		}
 		
 	}
@@ -244,24 +204,26 @@ AlignCommand::AlignCommand(string option)  {
 	}
 }
 //**********************************************************************************************************************
-AlignCommand::~AlignCommand(){	
-	if (!abort) { delete templateDB; }
-}
+AlignCommand::~AlignCommand(){}
 //**********************************************************************************************************************
 
 int AlignCommand::execute(){
 	try {
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
-
-		templateDB = new AlignmentDB(templateFileName, search, kmerSize, gapOpen, gapExtend, match, misMatch, util.getRandomNumber(), true);
-		
+        
+        long long before = util.getRAMUsed(); long long total = util.getTotalRAM();
+        
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: RAM used before reading template " + toString(before) + " of total RAM available " + toString(total) + "\n"); }
+        
+        templateDB = new AlignmentDB(templateFileName, search, kmerSize, gapOpen, gapExtend, match, misMatch, util.getRandomNumber(), true);
+        
         if (m->getControl_pressed()) { outputTypes.clear(); return 0; }
         
         time_t start = time(NULL);
         m->mothurOut("\nAligning sequences from " + fastafile + " ...\n" );
         
-        if (outputDir == "") {  outputDir += util.hasPath(fastafile); }
-        map<string, string> variables; variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastafile));
+        if (outputdir == "") {  outputdir += util.hasPath(fastafile); }
+        map<string, string> variables; variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
         string alignFileName = getOutputFileName("fasta", variables);
         string reportFileName = getOutputFileName("alignreport", variables);
         string accnosFileName = getOutputFileName("accnos", variables);
@@ -273,6 +235,8 @@ int AlignCommand::execute(){
         
         long long numFastaSeqs = createProcesses(alignFileName, reportFileName, accnosFileName, fastafile, numFlipped);
         
+        delete templateDB;
+        
         if (m->getControl_pressed()) { util.mothurRemove(accnosFileName); util.mothurRemove(alignFileName); util.mothurRemove(reportFileName); outputTypes.clear();  return 0; }
         
         //delete accnos file if its blank else report to user
@@ -314,19 +278,21 @@ struct alignStruct {
     OutputWriter* reportWriter;
     OutputWriter* accnosWriter;
     string inputFilename;
-    string alignMethod, search;
+    string alignMethod, search, templateFileName;
     float match, misMatch, gapOpen, gapExtend, threshold;
     bool flip;
     long long numSeqs;
+    int kmerSize;
     
     vector<long long> flippedResults;
     linePair filePos;
     
     MothurOut* m;
-    AlignmentDB* templateDB;
     Utils util;
+    AlignmentDB* templateDB;
+    Alignment* alignment;
     
-       alignStruct (linePair fP, OutputWriter* aFName, OutputWriter* reFName, OutputWriter* ac, string fname, string al, float ma, float misMa, float gOpen, float gExtend, float thr, bool fl, AlignmentDB* tB, string se) {
+    alignStruct (linePair fP, OutputWriter* aFName, OutputWriter* reFName, OutputWriter* ac, string fname, AlignmentDB* tfn, string al, float ma, float misMa, float gOpen, float gExtend, float thr, bool fl, int ks, string se) {
         
         filePos.start = fP.start;
         filePos.end = fP.end;
@@ -336,17 +302,30 @@ struct alignStruct {
         inputFilename = fname;
         numSeqs = 0;
         m = MothurOut::getInstance();
-        alignMethod = al;
         match = ma;
         misMatch = misMa;
         gapOpen = gOpen;
         gapExtend = gExtend;
         threshold = thr;
         flip = fl;
-        templateDB = tB;
         search = se;
+        kmerSize = ks;
         flippedResults.resize(2, 0);
+        
+        templateDB = tfn;
+        
+        int longestBase = templateDB->getLongestBase();
+        if (m->getDebug()) { m->mothurOut("[DEBUG]: template longest base = "  + toString(longestBase) + " \n");            }
+        if(al == "gotoh")            {    alignment = new GotohOverlap(gapOpen, gapExtend, match, misMatch, longestBase);   }
+        else if(al == "needleman")    {    alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);         }
+        else if(al == "blast")        {    alignment = new BlastAlignment(gapOpen, gapExtend, match, misMatch);             }
+        else if(al == "noalign")        {    alignment = new NoAlign();                                                     }
+        else {
+            m->mothurOut(al + " is not a valid alignment option. I will run the command using needleman.\n");
+            alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);
+        }
     }
+    ~alignStruct() { delete alignment;  }
     
 };
 //**********************************************************************************************************************
@@ -365,20 +344,6 @@ void alignDriver(alignStruct* params) {
         long long numFlipped_0 = 0;
         long long numFlipped_1 = 0;
 		
-		//moved this into driver to avoid deep copies in windows paralellized version
-		Alignment* alignment;
-		int longestBase = params->templateDB->getLongestBase();
-        if (params->m->getDebug()) { params->m->mothurOut("[DEBUG]: template longest base = "  + toString(longestBase) + " \n"); }
-		if(params->alignMethod == "gotoh")			{	alignment = new GotohOverlap(params->gapOpen, params->gapExtend, params->match, params->misMatch, longestBase);			}
-		else if(params->alignMethod == "needleman")	{	alignment = new NeedlemanOverlap(params->gapOpen, params->match, params->misMatch, longestBase);				}
-		else if(params->alignMethod == "blast")		{	alignment = new BlastAlignment(params->gapOpen, params->gapExtend, params->match, params->misMatch);		}
-		else if(params->alignMethod == "noalign")		{	alignment = new NoAlign();													}
-		else {
-			params->m->mothurOut(params->alignMethod + " is not a valid alignment option. I will run the command using needleman.");
-			params->m->mothurOutEndLine();
-			alignment = new NeedlemanOverlap(params->gapOpen, params->match, params->misMatch, longestBase);
-		}
-	
 		while (!done) {
 			
 			if (params->m->getControl_pressed()) {  break; }
@@ -391,16 +356,16 @@ void alignDriver(alignStruct* params) {
 			int numBasesNeeded = origNumBases * params->threshold;
 	
 			if (candidateSeq->getName() != "") { //incase there is a commented sequence at the end of a file
-				if (candidateSeq->getUnaligned().length()+1 > alignment->getnRows()) {
-                    if (params->m->getDebug()) { params->m->mothurOut("[DEBUG]: " + candidateSeq->getName() + " " + toString(candidateSeq->getUnaligned().length()) + " " + toString(alignment->getnRows()) + " \n"); }
-					alignment->resize(candidateSeq->getUnaligned().length()+2);
+				if (candidateSeq->getUnaligned().length()+1 > params->alignment->getnRows()) {
+                    if (params->m->getDebug()) { params->m->mothurOut("[DEBUG]: " + candidateSeq->getName() + " " + toString(candidateSeq->getUnaligned().length()) + " " + toString(params->alignment->getnRows()) + " \n"); }
+					params->alignment->resize(candidateSeq->getUnaligned().length()+2);
 				}
                 
                 float searchScore;
 				Sequence temp = params->templateDB->findClosestSequence(candidateSeq, searchScore);
 				Sequence* templateSeq = new Sequence(temp.getName(), temp.getAligned());
 								
-				Nast* nast = new Nast(alignment, candidateSeq, templateSeq);
+				Nast* nast = new Nast(params->alignment, candidateSeq, templateSeq);
 		
 				Sequence* copy;
 				
@@ -413,7 +378,6 @@ void alignDriver(alignStruct* params) {
 				//if there is a possibility that this sequence should be reversed
 				if (candidateSeq->getNumBases() < numBasesNeeded) {
 					numFlipped_1++;
-					string wasBetter =  "";
 					//if the user wants you to try the reverse
 					if (params->flip) {
 				
@@ -429,7 +393,7 @@ void alignDriver(alignStruct* params) {
                         
                         if (params->m->getDebug()) { params->m->mothurOut("[DEBUG]: closest template "  + temp2.getName() + " \n"); }
 						
-						nast2 = new Nast(alignment, copy, templateSeq2);
+						nast2 = new Nast(params->alignment, copy, templateSeq2);
                         
                         if (params->m->getDebug()) { params->m->mothurOut("[DEBUG]: completed Nast2 "  + candidateSeq->getName() + " flipped numBases = " + toString(copy->getNumBases()) + " old numbases = " + toString(candidateSeq->getNumBases()) +" \n"); }
 			
@@ -441,24 +405,20 @@ void alignDriver(alignStruct* params) {
 							delete nast;
 							nast = nast2;
 							needToDeleteCopy = true;
-							wasBetter = "\treverse complement produced a better alignment, so mothur used the reverse complement.";
+                            params->accnosWriter->write(candidateSeq->getName()+ '\n');
                             numFlipped_0++;
-						}else{  
-							wasBetter = "\treverse complement did NOT produce a better alignment so it was not used, please check sequence.";
+						}else{
 							delete nast2;
                             delete templateSeq2;
 							delete copy;	
 						}
                         if (params->m->getDebug()) { params->m->mothurOut("[DEBUG]: done.\n"); }
 					}
-					
-					//create accnos file with names
-					params->accnosWriter->write(candidateSeq->getName() + wasBetter + "\n");
 				}
 				
 				report.setTemplate(templateSeq);
 				report.setSearchParameters(params->search, searchScore);
-				report.setAlignmentParameters(params->alignMethod, alignment);
+				report.setAlignmentParameters(params->alignMethod, params->alignment);
 				report.setNastParameters(*nast);
 	
 				params->alignWriter->write('>' + candidateSeq->getName() + '\n' + candidateSeq->getAligned() + '\n');
@@ -489,7 +449,6 @@ void alignDriver(alignStruct* params) {
         params->flippedResults[0] += numFlipped_0;
         params->flippedResults[1] += numFlipped_1;
         
-		delete alignment;
 		inFASTA.close();
 		
 	}
@@ -504,7 +463,7 @@ long long AlignCommand::createProcesses(string alignFileName, string reportFileN
 	try {
         
         vector<linePair> lines;
-        vector<unsigned long long> positions;
+        vector<double> positions;
 #if defined NON_WINDOWS
         positions = util.divideFile(filename, processors);
         for (int i = 0; i < (positions.size()-1); i++) {	lines.push_back(linePair(positions[i], positions[(i+1)]));	}
@@ -523,7 +482,7 @@ long long AlignCommand::createProcesses(string alignFileName, string reportFileN
 #endif
 
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<alignStruct*> data;
         
         long long num = 0;
@@ -546,19 +505,17 @@ long long AlignCommand::createProcesses(string alignFileName, string reportFileN
             OutputWriter* threadAccnosWriter = new OutputWriter(synchronizedOutputAccnosFile);
 
             
-            alignStruct* dataBundle = new alignStruct(lines[i+1], threadAlignWriter, threadReportWriter, threadAccnosWriter, filename,
-                                                        align, match, misMatch, gapOpen, gapExtend, threshold, flip, templateDB, search);
+            alignStruct* dataBundle = new alignStruct(lines[i+1], threadAlignWriter, threadReportWriter, threadAccnosWriter, filename, templateDB, align, match, misMatch, gapOpen, gapExtend, threshold, flip, kmerSize, search);
             data.push_back(dataBundle);
 
-            workerThreads.push_back(new thread(alignDriver, dataBundle));
+            workerThreads.push_back(new std::thread(alignDriver, dataBundle));
          }
         
         OutputWriter* threadAlignWriter = new OutputWriter(synchronizedOutputAlignFile);
         OutputWriter* threadReportWriter = new OutputWriter(synchronizedOutputReportFile);
         OutputWriter* threadAccnosWriter = new OutputWriter(synchronizedOutputAccnosFile);
         
-        alignStruct* dataBundle = new alignStruct(lines[0], threadAlignWriter, threadReportWriter, threadAccnosWriter, filename,
-                                                  align, match, misMatch, gapOpen, gapExtend, threshold, flip, templateDB, search);
+        alignStruct* dataBundle = new alignStruct(lines[0], threadAlignWriter, threadReportWriter, threadAccnosWriter, filename, templateDB, align, match, misMatch, gapOpen, gapExtend, threshold, flip, kmerSize, search);
         alignDriver(dataBundle);
         numFlipped[0] = dataBundle->flippedResults[0];
         numFlipped[1] = dataBundle->flippedResults[1];
