@@ -30,7 +30,6 @@ class AlignCommand : public Command {
     
 public:
 	AlignCommand(string);	
-	AlignCommand();
 	~AlignCommand();
 	
 	vector<string> setParameters();
@@ -47,17 +46,17 @@ public:
 	void help() { m->mothurOut(getHelpString()); }	
 	
 protected:
-	AlignmentDB* templateDB;
-
+	
 	long long createProcesses(string, string, string, string, vector<long long>&);
 	void appendReportFiles(string, string);
 		
-	string fastafile, templateFileName, distanceFileName, search, align, outputDir;
+	string fastafile, templateFileName, distanceFileName, search, align;
 	float match, misMatch, gapOpen, gapExtend, threshold;
 	int processors, kmerSize;
 	vector<string> outputNames;
 	
 	bool abort, flip, calledHelp, save;
+    AlignmentDB* templateDB;
 
 };
 
