@@ -22,6 +22,11 @@ vector<string> AnosimCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["anosim"] = tempOutNames;
 
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -66,71 +71,20 @@ string AnosimCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-AnosimCommand::AnosimCommand(){	
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["anosim"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "AnosimCommand", "AnosimCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 
 AnosimCommand::AnosimCommand(string option) {
 	try {
-		abort = false; calledHelp = false;   
-		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
-			ValidParameters validParameter;
-			
-			//check to make sure all parameters are valid for command
-			map<string,string>::iterator it;
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["anosim"] = tempOutNames;
-			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	}
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("design");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["design"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("phylip");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["phylip"] = inputDir + it->second;		}
-				}
-			}
 			
+            ValidParameters validParameter;
 			phylipFileName = validParameter.validFile(parameters, "phylip");
 			if (phylipFileName == "not open") { phylipFileName = ""; abort = true; }
 			else if (phylipFileName == "not found") { 
@@ -175,7 +129,7 @@ int AnosimCommand::execute(){
 		//read design file
 		designMap = new DesignMap(designFileName);
 		
-		if (outputDir == "") { outputDir = util.hasPath(phylipFileName); }
+		if (outputdir == "") { outputdir = util.hasPath(phylipFileName); }
 		
 		//read in distance matrix and square it
 		ReadPhylipVector readMatrix(phylipFileName);
@@ -193,7 +147,7 @@ int AnosimCommand::execute(){
 			string group = designMap->get(sampleNames[i]);
 			
 			if (group == "not found") {
-				m->mothurOut("[ERROR]: " + sampleNames[i] + " is not in your design file, please correct."); m->mothurOutEndLine(); m->setControl_pressed(true);
+				m->mothurOut("[ERROR]: " + sampleNames[i] + " is not in your design file, please correct.\n");  m->setControl_pressed(true);
 			}else { origGroupSampleMap[group].push_back(i); }
 		}
 		int numGroups = origGroupSampleMap.size();
@@ -202,7 +156,7 @@ int AnosimCommand::execute(){
 		
 		//create a new filename
 		ofstream ANOSIMFile;
-        map<string, string> variables; variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(phylipFileName));
+        map<string, string> variables; variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(phylipFileName));
 		string ANOSIMFileName = getOutputFileName("anosim", variables);	
         
 		util.openOutputFile(ANOSIMFileName, ANOSIMFile);
