@@ -22,6 +22,12 @@ vector<string> BinSeqCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
 	
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -68,102 +74,26 @@ string BinSeqCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-BinSeqCommand::BinSeqCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "BinSeqCommand", "BinSeqCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 BinSeqCommand::BinSeqCommand(string option) {
 	try {
-		abort = false; calledHelp = false;   
 		allLines = true;
-		labels.clear();
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+            OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters();
 			
-			ValidParameters validParameter;
-			map<string, string>::iterator it;
-		
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-            outputTypes["count"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("list");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["list"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-			}
-
-			
 			//check for required parameters
+            ValidParameters validParameter;
 			fastafile = validParameter.validFile(parameters, "fasta");
 			if (fastafile == "not found") { 				//if there is a current phylip file, use it
 				fastafile = current->getFastaFile(); 
-				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current fasta file and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter.\n");  }
+				else { 	m->mothurOut("You have no current fasta file and the fasta parameter is required.\n");  abort = true; }
 			}
 			else if (fastafile == "not open") { abort = true; }	
 			else { current->setFastaFile(fastafile); }
@@ -171,18 +101,13 @@ BinSeqCommand::BinSeqCommand(string option) {
 			listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not found") { 			
 				listfile = current->getListFile(); 
-				if (listfile != "") { m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current list file and the list parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (listfile != "") { m->mothurOut("Using " + listfile + " as input file for the list parameter.\n");  }
+				else { 	m->mothurOut("You have no current list file and the list parameter is required.\n");  abort = true; }
 			}
 			else if (listfile == "not open") { listfile = ""; abort = true; }	
 			else { current->setListFile(listfile); }
 			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){
-				outputDir = "";	
-				outputDir += util.hasPath(listfile); //if user entered a file with a path then preserve it	
-			}
-			
+            if (outputdir == "") { outputdir = util.hasPath(listfile); }
 		
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
@@ -212,13 +137,14 @@ BinSeqCommand::BinSeqCommand(string option) {
             if ((namesfile != "") && (countfile != "")) { m->mothurOut("[ERROR]: you may only use one of the following: name or count.\n");  abort = true; }
             if ((groupfile != "") && (countfile != "")) {  m->mothurOut("[ERROR]: you may only use one of the following: group or count.\n");  abort=true; }
             
+            if (!abort) {
             if ((namesfile != "") || (groupfile != "")) { //convert to count
                 
                 string rootFileName = namesfile;
                 if (rootFileName == "") { rootFileName = groupfile; }
                 
-                if (outputDir == "") { outputDir = util.hasPath(rootFileName); }
-                map<string, string> variables; variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(rootFileName));
+                if (outputdir == "") { outputdir = util.hasPath(rootFileName); }
+                map<string, string> variables; variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(rootFileName));
                 string outputFileName = getOutputFileName("count", variables);
 
                 CountTable ct; ct.createTable(namesfile, groupfile, nullVector); ct.printCompressedTable(outputFileName);
@@ -252,6 +178,7 @@ BinSeqCommand::BinSeqCommand(string option) {
                 
                 m->mothurOut("/******************************************/\n");
             }
+            }
 			
             if (countfile == "") {
                 if (namesfile == ""){
@@ -275,86 +202,31 @@ BinSeqCommand::~BinSeqCommand(){}
 int BinSeqCommand::execute(){
 	try {
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
-	
-		int error = 0;
-		
+
 		FastaMap fasta; fasta.readFastaFile(fastafile);
         
 		//if user gave a namesfile then use it
         if (countfile != "") {  ct.readTable(countfile, true, false);  }
 		
 		InputData input(listfile, "list", nullVector);
-		ListVector* list = input.getListVector();
-		string lastLabel = list->getLabel();
-		
-		if (m->getControl_pressed()) {  return 0; }
-		
-		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
-		set<string> processedLabels;
-		set<string> userLabels = labels;
+        set<string> processedLabels;
+        set<string> userLabels = labels;
+        string lastLabel = "";
+        int error = 0;
+        
+        ListVector* list = util.getNextList(input, allLines, userLabels, processedLabels, lastLabel);
+        
+        while (list != NULL) {
+            
+            if (m->getControl_pressed()) { delete list; break; }
+            
+            error = process(list, fasta); delete list;
+            if (error == 1)  { for (int i = 0; i < outputNames.size(); i++) {    util.mothurRemove(outputNames[i]);        }  return 0; }
+            
+            list = util.getNextList(input, allLines, userLabels, processedLabels, lastLabel);
+        }
 
-		while((list != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-			
-			if(m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);		}   return 0; }
-			
-			if(allLines == 1 || labels.count(list->getLabel()) == 1){
-				
-				error = process(list, fasta);
-				if (error == 1) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);		}  return 0; }
-							
-				processedLabels.insert(list->getLabel());
-				userLabels.erase(list->getLabel());
-			}
-			
-			if ((util.anyLabelsToProcess(list->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = list->getLabel();
-				
-				delete list;
-				list = input.getListVector(lastLabel);
-				
-				error = process(list, fasta);
-				if (error == 1) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);		}  return 0; }
-													
-				processedLabels.insert(list->getLabel());
-				userLabels.erase(list->getLabel());
-				
-				//restore real lastlabel to save below
-				list->setLabel(saveLabel);
-			}
-			
-			lastLabel = list->getLabel();			
-			
-			delete list;
-			list = input.getListVector();
-		}
-		
 		if(m->getControl_pressed())  { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);		}  return 0; }
-
-		//output error messages about any remaining user labels
-		set<string>::iterator it;
-		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {  
-			m->mothurOut("Your file does not include the label " + *it); 
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + ".");  m->mothurOutEndLine();
-			}
-		}
-		
-		//run last label if you need to
-		if (needToRun )  {
-			if (list != NULL) {		delete list;	}
-			list = input.getListVector(lastLabel);
-				
-			error = process(list, fasta);	
-			if (error == 1) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);		}   return 0; }
-			
-			delete list;  
-		}
-		
-		if(m->getControl_pressed())  { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);		}  return 0; }	
         
         //set align file as new current fastafile
 		string currentFasta = "";
@@ -366,7 +238,6 @@ int BinSeqCommand::execute(){
 		m->mothurOut("\nOutput File Names: \n"); 
 		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
 
-		
 		return 0;
 	}
 	catch(exception& e) {
@@ -379,7 +250,7 @@ int BinSeqCommand::execute(){
 int BinSeqCommand::process(ListVector* list, FastaMap& fasta) {
 	try {
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(listfile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(listfile));
         variables["[distance]"] = list->getLabel();
         string outputFileName = getOutputFileName("fasta", variables);
         
@@ -438,7 +309,6 @@ int BinSeqCommand::process(ListVector* list, FastaMap& fasta) {
         
         out.close();
         return 0;
-
 	}
 	catch(exception& e) {
 		m->errorOut(e, "BinSeqCommand", "process");
