@@ -23,7 +23,6 @@ class BinSeqCommand : public Command {
 	
 public:
 	BinSeqCommand(string);	
-	BinSeqCommand();
 	~BinSeqCommand();
 	
 	vector<string> setParameters();
@@ -42,7 +41,7 @@ private:
 	CountTable ct;
 	bool abort, allLines;
 	set<string> labels; //holds labels to be used
-	string filename, fastafile, listfile, countfile, label, outputDir;
+	string filename, fastafile, listfile, countfile, label;
 	vector<string> outputNames;
 	
 	int process(ListVector*, FastaMap&);
