@@ -24,6 +24,14 @@ vector<string> BiomInfoCommand::setParameters(){
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
         CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
         
+        abort = false; calledHelp = false; maxLevel = 0;
+        
+        vector<string> tempOutNames;
+        outputTypes["taxonomy"] = tempOutNames;
+        outputTypes["shared"] = tempOutNames;
+        outputTypes["constaxonomy"] = tempOutNames;
+        outputTypes["taxsummary"] = tempOutNames;
+        
         vector<string> myArray;
         for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
         return myArray;
@@ -98,68 +106,20 @@ string BiomInfoCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-BiomInfoCommand::BiomInfoCommand(){
-    try {
-        abort = true; calledHelp = true; maxLevel = 0;
-        setParameters();
-        vector<string> tempOutNames;
-        outputTypes["taxonomy"] = tempOutNames;
-        outputTypes["shared"] = tempOutNames;
-        outputTypes["constaxonomy"] = tempOutNames;
-        outputTypes["taxsummary"] = tempOutNames;
-    }
-    catch(exception& e) {
-        m->errorOut(e, "BiomInfoCommand", "BiomInfoCommand");
-        exit(1);
-    }
-}
-//**********************************************************************************************************************
 BiomInfoCommand::BiomInfoCommand(string option)  {
     try {
-        abort = false; calledHelp = false; maxLevel = 0;
+        maxLevel = 0;
         
         //allow user to run help
         if(option == "help") { help(); abort = true; calledHelp = true; }
         else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
         
         else {
-            
-            vector<string> myArray = setParameters();
-            
-            OptionParser parser(option);
+            OptionParser parser(option, setParameters());
             map<string, string> parameters = parser.getParameters();
             
             ValidParameters validParameter;
-            map<string, string>::iterator it;
-            
-            //check to make sure all parameters are valid for command
-            for (it = parameters.begin(); it != parameters.end(); it++) {
-                if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-            }
-            
-            //if the user changes the input directory command factory will send this info to us in the output parameter
-            string inputDir = validParameter.valid(parameters, "inputdir");
-            if (inputDir == "not found"){	inputDir = "";		}
-            else {
-                string path;
-                it = parameters.find("biom");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["biom"] = inputDir + it->second;		}
-                }
-            }
-            
-            vector<string> tempOutNames;
-            outputTypes["taxonomy"] = tempOutNames;
-            outputTypes["shared"] = tempOutNames;
-            outputTypes["constaxonomy"] = tempOutNames;
-            outputTypes["taxsummary"] = tempOutNames;
-            
-            //if the user changes the output directory command factory will send this info to us in the output parameter
-            outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	}
-            
             //check for required parameters
             biomfile = validParameter.validFile(parameters, "biom");
             if (biomfile == "not open") { biomfile = ""; abort = true; }
@@ -170,7 +130,7 @@ BiomInfoCommand::BiomInfoCommand(string option)  {
             if (label == "not found") { label = "userLabel"; }
             
             output = validParameter.valid(parameters, "output");		if(output == "not found"){	output = "detail"; }
-            if ((output != "simple") && (output != "detail")) { m->mothurOut(output + " is not a valid output form. Options are simple and detail. I will use detail."); m->mothurOutEndLine(); output = "detail"; }
+            if ((output != "simple") && (output != "detail")) { m->mothurOut(output + " is not a valid output form. Options are simple and detail. I will use detail.\n");  output = "detail"; }
             
             string temp = validParameter.valid(parameters, "relabund");		if (temp == "not found"){	temp = "false";			}
             relabund = util.isTrue(temp);
@@ -238,7 +198,7 @@ int BiomInfoCommand::execute(){
         }
         
         m->mothurOutEndLine();
-        m->mothurOut("Output File Names: "); m->mothurOutEndLine();
+        m->mothurOut("Output File Names: \n"); 
         for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
         m->mothurOutEndLine();
         
@@ -440,10 +400,10 @@ int BiomInfoCommand::extractFilesFromHDF5() {
     try {
         //getting output filename
         string filename = biomfile;
-        if (outputDir == "") { outputDir += util.hasPath(filename); }
+        if (outputdir == "") { outputdir += util.hasPath(filename); }
         
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(filename));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(filename));
         variables["[tag]"] = label;
         string sharedFilename = getOutputFileName("shared",variables);
         string taxFilename = getOutputFileName("constaxonomy",variables);
@@ -634,10 +594,10 @@ int BiomInfoCommand::createFilesFromBiom() {
     try {
         //getting output filename
         string filename = biomfile;
-        if (outputDir == "") { outputDir += util.hasPath(filename); }
+        if (outputdir == "") { outputdir += util.hasPath(filename); }
         
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(filename));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(filename));
         variables["[tag]"] = label;
         string sharedFilename = getOutputFileName("shared",variables);
         outputNames.push_back(sharedFilename); outputTypes["shared"].push_back(sharedFilename);
@@ -750,8 +710,8 @@ int BiomInfoCommand::createFilesFromBiom() {
             maxLevel = 0;
             string thisLine = it->second;
             if ((biomType == "Taxon table") || (biomType == "Taxontable")) {
-                string mapFilename = getOutputFileName("map",variables);
-                outputNames.push_back(mapFilename); outputTypes["map"].push_back(mapFilename);
+                string mapFilename = getOutputFileName("constaxonomy",variables);
+                outputNames.push_back(mapFilename); outputTypes["constaxonomy"].push_back(mapFilename);
                 ofstream outMap;
                 util.openOutputFile(mapFilename, outMap);
                 
@@ -798,7 +758,7 @@ int BiomInfoCommand::createFilesFromBiom() {
             if (hasTaxonomy) {
                 //write taxonomy file
                 map<string, string> variables;
-                variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(filename));
+                variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(filename));
                 variables["[tag]"] = label;
                 string taxFilename = getOutputFileName("taxonomy",variables);
                 outputNames.push_back(taxFilename); outputTypes["taxonomy"].push_back(taxFilename);
@@ -819,7 +779,7 @@ int BiomInfoCommand::createFilesFromBiom() {
                 outTax.close();
                 
                 //write taxonomy file
-                variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(filename));
+                variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(filename));
                 variables["[tag]"] = label;
                 variables["[tag2]"] = "";
                 string taxSumFilename = getOutputFileName("taxsummary",variables);
@@ -835,7 +795,7 @@ int BiomInfoCommand::createFilesFromBiom() {
             }
             
             //set fileroot
-            fileroot = outputDir + util.getRootName(util.getSimpleName(biomfile));
+            fileroot = outputdir + util.getRootName(util.getSimpleName(biomfile));
         }
         
         if (m->getControl_pressed()) {  out.close(); for (int j = 0; j < outputNames.size(); j++) {	util.mothurRemove(outputNames[j]);	} return 0; }
@@ -868,7 +828,7 @@ int BiomInfoCommand::createFilesFromBiom() {
                 if ((lookup->getNumBins() == conTaxonomy.size()) && (lookup->getNumBins() == otuNames.size())) {
                     //write taxonomy file
                     map<string, string> variables;
-                    variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(filename));
+                    variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(filename));
                     variables["[tag]"] = label;
                     string taxFilename = getOutputFileName("constaxonomy",variables);
                     outputNames.push_back(taxFilename); outputTypes["constaxonomy"].push_back(taxFilename);
@@ -918,7 +878,7 @@ int BiomInfoCommand::createFilesFromBiom() {
                     outTax.close();
                     
                     //write taxonomy file
-                    variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(filename));
+                    variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(filename));
                     variables["[tag]"] = label;
                     variables["[tag2]"] = "cons";
                     string taxSumFilename = getOutputFileName("taxsummary",variables);
