@@ -20,7 +20,6 @@
 class ChimeraBellerophonCommand : public Command {
 public:
 	ChimeraBellerophonCommand(string);
-	ChimeraBellerophonCommand();
 	~ChimeraBellerophonCommand(){}
 	
 	vector<string> setParameters();
@@ -39,7 +38,7 @@ public:
 private:
 
 	bool abort, filter, correction;
-	string fastafile, outputDir;
+	string fastafile;
 	int processors, window, increment, numSeqs;
 	vector<string> outputNames;
 
