@@ -20,7 +20,6 @@
 class ChimeraCcodeCommand : public Command {
 public:
 	ChimeraCcodeCommand(string);
-	ChimeraCcodeCommand();
 	~ChimeraCcodeCommand(){}
 	
 	vector<string> setParameters();
@@ -38,7 +37,7 @@ public:
 		
 private:
 	bool abort, filter, save;
-	string fastafile, templatefile, outputDir, maskfile;
+	string fastafile, templatefile, maskfile;
 	int window, numwanted, numSeqs, templateSeqsLength;
 	vector<string> outputNames;
     
