@@ -28,6 +28,13 @@ vector<string> ChimeraPerseusCommand::setParameters(){
 		CommandParameter pcutoff("cutoff", "Number", "", "0.5", "", "", "","",false,false); parameters.push_back(pcutoff);
 		CommandParameter palpha("alpha", "Number", "", "-5.54", "", "", "","",false,false); parameters.push_back(palpha);
 		CommandParameter pbeta("beta", "Number", "", "0.33", "", "", "","",false,false); parameters.push_back(pbeta);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["chimera"] = tempOutNames;
+        outputTypes["accnos"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
 			
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -81,86 +88,22 @@ string ChimeraPerseusCommand::getOutputPattern(string type) {
         exit(1);
     }
 }
-//**********************************************************************************************************************
-ChimeraPerseusCommand::ChimeraPerseusCommand(){	
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["chimera"] = tempOutNames;
-		outputTypes["accnos"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ChimeraPerseusCommand", "ChimeraPerseusCommand");
-		exit(1);
-	}
-}
 //***************************************************************************************************************
 ChimeraPerseusCommand::ChimeraPerseusCommand(string option)  {
 	try {
-		abort = false; calledHelp = false; 
         hasCount = false;
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
-			
-			ValidParameters validParameter("chimera.perseus");
-			map<string,string>::iterator it;
-			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			vector<string> tempOutNames;
-			outputTypes["chimera"] = tempOutNames;
-			outputTypes["accnos"] = tempOutNames;
-            outputTypes["count"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-            string inputDir = validParameter.valid(parameters, "inputdir");
-            if (inputDir == "not found"){	inputDir = "";		}
-            else {
-                string path;
-                it = parameters.find("count");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["count"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("fasta");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("name");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["name"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("group");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["group"] = inputDir + it->second;		}
-                }
-            }
-			
+
 			//check for required parameters
+            ValidParameters validParameter;
             fastafile = validParameter.validFile(parameters, "fasta");
             if (fastafile == "not found") {
                 fastafile = current->getFastaFile();
@@ -184,7 +127,7 @@ ChimeraPerseusCommand::ChimeraPerseusCommand(string option)  {
             if (countfile != "") { hasCount = true; }
             
 			//make sure there is at least one valid file left
-            if (hasName && hasCount) { m->mothurOut("[ERROR]: You must enter ONLY ONE of the following: count or name."); m->mothurOutEndLine(); abort = true; }
+            if (hasName && hasCount) { m->mothurOut("[ERROR]: You must enter ONLY ONE of the following: count or name.\n");  abort = true; }
             
             if (!hasName && !hasCount) { 
                 //if there is a current name file, use it, else look for current count file
@@ -205,9 +148,6 @@ ChimeraPerseusCommand::ChimeraPerseusCommand(string option)  {
 			
             if (hasGroup && hasCount) { m->mothurOut("[ERROR]: You must enter ONLY ONE of the following: count or group.\n");  abort = true; }
             
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	}
-			
 			string temp = validParameter.valid(parameters, "processors");	if (temp == "not found"){	temp = current->getProcessors();	}
 			processors = current->setProcessors(temp);
 			
@@ -230,8 +170,8 @@ ChimeraPerseusCommand::ChimeraPerseusCommand(string option)  {
                     string rootFileName = namefile;
                     if (rootFileName == "") { rootFileName = groupfile; }
                     
-                    if (outputDir == "") { outputDir = util.hasPath(rootFileName); }
-                    string outputFileName = outputDir + util.getRootName(util.getSimpleName(rootFileName)) + "count_table";
+                    if (outputdir == "") { outputdir = util.hasPath(rootFileName); }
+                    string outputFileName = outputdir + util.getRootName(util.getSimpleName(rootFileName)) + "count_table";
                     
                     CountTable ct; ct.createTable(namefile, groupfile, nullVector); ct.printCompressedTable(outputFileName);
                     outputNames.push_back(outputFileName); 
@@ -416,9 +356,9 @@ int ChimeraPerseusCommand::execute(){
         m->mothurOut("Checking sequences from " + fastafile + " ...\n" );
         
         long start = time(NULL);
-        if (outputDir == "") { outputDir = util.hasPath(fastafile);  }//if user entered a file with a path then preserve it
+        if (outputdir == "") { outputdir = util.hasPath(fastafile);  }
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastafile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
         string outputFileName = getOutputFileName("chimera", variables);
         string accnosFileName = getOutputFileName("accnos", variables);
         string newCountFile = "";
@@ -434,9 +374,20 @@ int ChimeraPerseusCommand::execute(){
             vector<string> groups;
             if (ct.testGroups(countfile, groups)) { //fills groups if count file has them
                 
-                variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(countfile));
+                variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(countfile));
                 newCountFile = getOutputFileName("count", variables);
                 
+                vector<string> groups;
+                map<string, vector<string> > group2Files;
+                if (hasCount) {
+                    current->setMothurCalling(true);
+                    SequenceCountParser cparser(countfile, fastafile, nullVector);
+                    current->setMothurCalling(false);
+                    groups = cparser.getNamesOfGroups();
+                    group2Files = cparser.getFiles();
+                    
+                }
+                
                 if (m->getControl_pressed()) { return 0; }
                 
                 //clears files
@@ -445,7 +396,7 @@ int ChimeraPerseusCommand::execute(){
                 util.openOutputFile(accnosFileName, out1); out1.close();
                 
                 string countlist = accnosFileName+".byCount";
-                numSeqs = createProcessesGroups(outputFileName, countlist, accnosFileName, newCountFile, groups, fastafile, countfile, numChimeras);
+                numSeqs = createProcessesGroups(group2Files, outputFileName, countlist, accnosFileName, newCountFile, groups, fastafile, countfile, numChimeras);
                 
                 if (m->getControl_pressed()) {  for (int j = 0; j < outputNames.size(); j++) {	util.mothurRemove(outputNames[j]);	}  return 0;	}
                 
@@ -572,6 +523,7 @@ struct perseusGroupsData {
     string chimeraFileName;
     string accnosFileName;
     string countlist;
+    map<string, vector<string> > parsedFiles;
     
     bool hasCount, dups;
     int threadID, count, numChimeras;
@@ -581,7 +533,7 @@ struct perseusGroupsData {
     MothurOut* m;
     
     perseusGroupsData(){}
-    perseusGroupsData(bool dps, bool hc, double a, double b, double c, string o,  string f, string n, string ac, string ctlist, vector<string> gr, int tid) {
+    perseusGroupsData(map<string, vector<string> >& g2f,bool dps, bool hc, double a, double b, double c, string o,  string f, string n, string ac, string ctlist, vector<string> gr, int tid) {
         alpha = a;
         beta = b;
         cutoff = c;
@@ -597,6 +549,7 @@ struct perseusGroupsData {
         dups = dps;
         count = 0;
         numChimeras = 0;
+        parsedFiles = g2f;
     }
 };
 //**********************************************************************************************************************
@@ -651,20 +604,11 @@ void driverGroups(perseusGroupsData* params){
         params->util.openOutputFile(params->chimeraFileName, out); out.close();
         params->util.openOutputFile(params->accnosFileName, out1); out1.close();
         
-        //Parse sequences by group
-        map<string, vector<string> > group2Files;
-        if (params->hasCount) {
-            SequenceCountParser cparser(params->dupsfile, params->fastafile, params->groups);
-            params->groups = cparser.getNamesOfGroups();
-            group2Files = cparser.getFiles();
-            
-        }
-        
 		int totalSeqs = 0;
         ofstream outCountList;
         if (params->hasCount && params->dups) { params->util.openOutputFile(params->countlist, outCountList); }
 		
-        for (map<string, vector<string> >::iterator it = group2Files.begin(); it != group2Files.end(); it++) {
+        for (map<string, vector<string> >::iterator it = params->parsedFiles.begin(); it != params->parsedFiles.end(); it++) {
             long start = time(NULL);	 if (params->m->getControl_pressed()) {  break; }
             
             
@@ -741,7 +685,7 @@ vector<seqData> ChimeraPerseusCommand::readFiles(string inputFile, map<string, i
 			Sequence temp(in); util.gobble(in);
 			
 			it = nameMap.find(temp.getName());
-			if (it == nameMap.end()) { error = true; m->mothurOut("[ERROR]: " + temp.getName() + " is in your fasta file and not in your namefile, please correct."); m->mothurOutEndLine(); }
+			if (it == nameMap.end()) { error = true; m->mothurOut("[ERROR]: " + temp.getName() + " is in your fasta file and not in your namefile, please correct.\n");  }
 			else {
                 temp.setAligned(util.removeNs(temp.getUnaligned()));
 				sequences.push_back(seqData(temp.getName(), temp.getUnaligned(), it->second));
@@ -765,7 +709,7 @@ vector<seqData> ChimeraPerseusCommand::readFiles(string inputFile, map<string, i
 /**************************************************************************************************/
 //perseusData(vector<seqData>& s, double a, double b, double c, string o, string ac, MothurOut* mout)
 //numSeqs = createProcessesGroups(outputFileName, countlist, accnosFileName, newCountFile, groups, fastafile, countfile, numChimeras);
-int ChimeraPerseusCommand::createProcessesGroups(string outputFName, string countlisttemp, string accnos, string newCountFile, vector<string> groups, string fasta, string dupsFile, int& numChimeras) {
+int ChimeraPerseusCommand::createProcessesGroups(map<string, vector<string> >& parsedFiles, string outputFName, string countlisttemp, string accnos, string newCountFile, vector<string> groups, string fasta, string dupsFile, int& numChimeras) {
 	try {
         numChimeras = 0;
         
@@ -785,7 +729,7 @@ int ChimeraPerseusCommand::createProcessesGroups(string outputFName, string coun
         }
 
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<perseusGroupsData*> data;
         
         long long num = 0;
@@ -796,16 +740,34 @@ int ChimeraPerseusCommand::createProcessesGroups(string outputFName, string coun
         for (int i = 0; i < processors-1; i++) {
             string extension = toString(i+1) + ".temp";
             vector<string> thisGroups;
-            for (int j = lines[i+1].start; j < lines[i+1].end; j++) { thisGroups.push_back(groups[j]); }
-            perseusGroupsData* dataBundle = new perseusGroupsData(dups, hasCount, alpha, beta, cutoff, (outputFName+extension), fasta, dupsFile,  (accnos+extension), (countlisttemp+extension), thisGroups, (i+1));
+            map<string, vector<string> > thisGroupsParsedFiles;
+            for (int j = lines[i+1].start; j < lines[i+1].end; j++) {
+                
+                map<string, vector<string> >::iterator it = parsedFiles.find(groups[j]);
+                if (it != parsedFiles.end()) {
+                    thisGroupsParsedFiles[groups[j]] = (it->second);
+                    thisGroups.push_back(groups[j]);
+                }
+                else { m->mothurOut("[ERROR]: missing files for group " + groups[j] + ", skipping\n"); }
+            }
+            perseusGroupsData* dataBundle = new perseusGroupsData(thisGroupsParsedFiles, dups, hasCount, alpha, beta, cutoff, (outputFName+extension), fasta, dupsFile,  (accnos+extension), (countlisttemp+extension), thisGroups, (i+1));
             data.push_back(dataBundle);
             
-            workerThreads.push_back(new thread(driverGroups, dataBundle));
+            workerThreads.push_back(new std::thread(driverGroups, dataBundle));
         }
         
         vector<string> thisGroups;
-        for (int j = lines[0].start; j < lines[0].end; j++) { thisGroups.push_back(groups[j]); }
-        perseusGroupsData* dataBundle = new perseusGroupsData(dups, hasCount, alpha, beta, cutoff, outputFName, fasta, dupsFile,  accnos, countlisttemp, thisGroups, 0);
+        map<string, vector<string> > thisGroupsParsedFiles;
+        for (int j = lines[0].start; j < lines[0].end; j++) {
+            
+            map<string, vector<string> >::iterator it = parsedFiles.find(groups[j]);
+            if (it != parsedFiles.end()) {
+                thisGroupsParsedFiles[groups[j]] = (it->second);
+                thisGroups.push_back(groups[j]);
+            }
+            else { m->mothurOut("[ERROR]: missing files for group " + groups[j] + ", skipping\n"); }
+        }
+        perseusGroupsData* dataBundle = new perseusGroupsData(thisGroupsParsedFiles, dups, hasCount, alpha, beta, cutoff, outputFName, fasta, dupsFile,  accnos, countlisttemp, thisGroups, 0);
         driverGroups(dataBundle);
         num = dataBundle->count;
         numChimeras = dataBundle->numChimeras;
