@@ -24,7 +24,6 @@
 class ChimeraPerseusCommand : public Command {
 public:
 	ChimeraPerseusCommand(string);
-	ChimeraPerseusCommand();
 	~ChimeraPerseusCommand() {}
 	
 	vector<string> setParameters();
@@ -41,7 +40,7 @@ public:
 	
 private:
 	bool abort, hasCount, dups;
-	string fastafile, countfile, outputDir;
+	string fastafile, countfile;
 	int processors, alignLength;
 	double cutoff, alpha, beta;
     vector<string> outputNames;
@@ -49,7 +48,7 @@ private:
 	string getCountFile(string&);
 	vector<seqData> readFiles(string, map<string, int>);
 	int deconvoluteResults(string, string);
-	int createProcessesGroups(string, string, string, string, vector<string>, string, string, int&);
+	int createProcessesGroups(map<string, vector<string> >&, string, string, string, string, vector<string>, string, string, int&);
 };
 /***********************************************************/
 
