@@ -42,6 +42,14 @@ vector<string> ChimeraSlayerCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["chimera"] = tempOutNames;
+        outputTypes["accnos"] = tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
 
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -112,87 +120,21 @@ string ChimeraSlayerCommand::getOutputPattern(string type) {
         exit(1);
     }
 }
-//**********************************************************************************************************************
-ChimeraSlayerCommand::ChimeraSlayerCommand(){	
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["chimera"] = tempOutNames;
-		outputTypes["accnos"] = tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ChimeraSlayerCommand", "ChimeraSlayerCommand");
-		exit(1);
-	}
-}
 //***************************************************************************************************************
 ChimeraSlayerCommand::ChimeraSlayerCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;
         hasCount = false;
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
-			
-			ValidParameters validParameter("chimera.slayer");
-			map<string,string>::iterator it;
-			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			vector<string> tempOutNames;
-			outputTypes["chimera"] = tempOutNames;
-			outputTypes["accnos"] = tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-            outputTypes["count"] = tempOutNames;
-		
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-            string inputDir = validParameter.valid(parameters, "inputdir");
-            if (inputDir == "not found"){	inputDir = "";		}
-            else {
-                string path;
-                it = parameters.find("count");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["count"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("fasta");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("name");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["name"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("group");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["group"] = inputDir + it->second;		}
-                }
-            }
-						
+        
+            ValidParameters validParameter;
             fastafile = validParameter.validFile(parameters, "fasta");
             if (fastafile == "not found") {
                 fastafile = current->getFastaFile();
@@ -227,19 +169,15 @@ ChimeraSlayerCommand::ChimeraSlayerCommand(string option)  {
 			
             if (hasGroup && hasCount) { m->mothurOut("[ERROR]: You must enter ONLY ONE of the following: count or group.\n");  abort = true; }
 			
-            //if the user changes the output directory command factory will send this info to us in the output parameter
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	}
+            
+			
 			
 			string path;
-			it = parameters.find("reference");
+			map<string, string>::iterator it = parameters.find("reference");
 			//user has given a template file
 			if(it != parameters.end()){ 
 				if (it->second == "self") {  templatefile = "self";  }
 				else {
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["reference"] = inputDir + it->second;		}
-					
 					templatefile = validParameter.validFile(parameters, "reference");
 					if (templatefile == "not open") { abort = true; }
 					else if (templatefile == "not found") { //check for saved reference sequences
@@ -303,9 +241,21 @@ ChimeraSlayerCommand::ChimeraSlayerCommand(string option)  {
 			if (temp == "not found") { temp = "false";			}
 			dups = util.isTrue(temp);
 			
+            bool foundTool = false;
+            path = current->getProgramPath();
+            
 			blastlocation = validParameter.valid(parameters, "blastlocation");	
-			if (blastlocation == "not found") { blastlocation = ""; }
-			else {
+			if (blastlocation == "not found") {
+                if (search == "blast") {
+                    blastlocation = "";
+                    vector<string> locations = current->getLocations();
+                    foundTool = util.findBlastLocation(blastlocation, path, locations);
+
+                    if (!foundTool){
+                        m->mothurOut("[WARNING]: Unable to locate blast executables, cannot use blast as search method. Using kmer instead.\n"); search = "kmer";
+                    }
+                }
+            }else {
 				//add / to name if needed
 				string lastChar = blastlocation.substr(blastlocation.length()-1);
                 if (lastChar != PATH_SEPARATOR) { blastlocation += PATH_SEPARATOR; }
@@ -325,7 +275,7 @@ ChimeraSlayerCommand::ChimeraSlayerCommand(string option)  {
 				ableToOpen = util.openInputFile(blastCommand, in2, "no error"); in2.close();
 				if(!ableToOpen) {	m->mothurOut("[ERROR]: " + blastCommand + " file does not exist. mothur requires blastall.exe to run chimera.slayer.\n");  abort = true; }
 			}
-
+            
 			if ((search != "blast") && (search != "kmer")) { m->mothurOut(search + " is not a valid search.\n");  abort = true;  }
 			
 			if ((hasName || hasCount) && (templatefile != "self")) { m->mothurOut("You have provided a namefile or countfile and the reference parameter is not set to self. I am not sure what reference you are trying to use, aborting.\n");  abort=true; }
@@ -335,8 +285,8 @@ ChimeraSlayerCommand::ChimeraSlayerCommand(string option)  {
                 string rootFileName = namefile;
                 if (rootFileName == "") { rootFileName = groupfile; }
                 
-                if (outputDir == "") { outputDir = util.hasPath(rootFileName); }
-                map<string, string> variables; variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(rootFileName));
+                if (outputdir == "") { outputdir = util.hasPath(rootFileName); }
+                map<string, string> variables; variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(rootFileName));
                 string outputFileName = getOutputFileName("count", variables);
                 
                 CountTable ct; ct.createTable(namefile, groupfile, nullVector); ct.printCompressedTable(outputFileName);
@@ -361,9 +311,9 @@ int ChimeraSlayerCommand::execute(){
         m->mothurOut("Checking sequences from " + fastafile + " ...\n" );
         
         long start = time(NULL);
-        if (outputDir == "") { outputDir = util.hasPath(fastafile);  }//if user entered a file with a path then preserve it
+        if (outputdir == "") { outputdir = util.hasPath(fastafile);  }
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastafile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
         string outputFileName = getOutputFileName("chimera", variables);
         string accnosFileName = getOutputFileName("accnos", variables);
         string trimFastaFileName = getOutputFileName("fasta", variables);
@@ -404,7 +354,7 @@ int ChimeraSlayerCommand::execute(){
             
         }else { //you have provided a groupfile
             if (hasCount) {
-                variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(countfile));
+                variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(countfile));
                 newCountFile = getOutputFileName("count", variables);
             }
             
@@ -649,7 +599,7 @@ int ChimeraSlayerCommand::setUpForSelfReference(map<string, string>& fileGroup,
 		
         if (!hasCount) {  countfile = getCountFile(fastafile);  }
         
-        string newFastaFile = outputDir + util.getRootName(util.getSimpleName(fastafile)) + "-sortedTemp.fasta";
+        string newFastaFile = outputdir + util.getRootName(util.getSimpleName(fastafile)) + "-sortedTemp.fasta";
         
 		if (countfile == "") { //no groups
             
@@ -673,16 +623,17 @@ int ChimeraSlayerCommand::setUpForSelfReference(map<string, string>& fileGroup,
                 fileGroup[fastafile] = "noGroup";
             }else { //using count file with groups
                 //Parse sequences by group
+                current->setMothurCalling(true);
                 SequenceCountParser parser(countfile, fastafile, nullVector);
                 vector<string> groups = parser.getNamesOfGroups();
-                
+                current->setMothurCalling(false);
                 for (int i = 0; i < groups.size(); i++) {
                     vector<string> thisGroupsFiles = parser.getFiles(groups[i]);
                     
                     string thisGroupsFastaFile = thisGroupsFiles[0];
                     string thisGroupsCountFile = thisGroupsFiles[1];
                     
-                    newFastaFile = outputDir + util.getRootName(util.getSimpleName(fastafile)) + groups[i] + "-sortedTemp.fasta";
+                    newFastaFile = outputdir + util.getRootName(util.getSimpleName(fastafile)) + groups[i] + "-sortedTemp.fasta";
                     priority = sortFastaFile(thisGroupsFastaFile, thisGroupsCountFile, newFastaFile);
                     fileToPriority[newFastaFile] = priority;
                     fileGroup[newFastaFile] = groups[i];
@@ -745,9 +696,9 @@ int ChimeraSlayerCommand::driverGroups(string outputFName, string accnos, string
 			long start = time(NULL);
 			string thisFastaName = itFile->first;
 			map<string, int> thisPriority = itFile->second;
-			string thisoutputFileName = outputDir + util.getRootName(util.getSimpleName(thisFastaName)) + fileGroup[thisFastaName] + "slayer.chimera";
-			string thisaccnosFileName = outputDir + util.getRootName(util.getSimpleName(thisFastaName)) + fileGroup[thisFastaName] + "slayer.accnos";
-			string thistrimFastaFileName = outputDir + util.getRootName(util.getSimpleName(thisFastaName)) + fileGroup[thisFastaName] + "slayer.fasta";
+			string thisoutputFileName = outputdir + util.getRootName(util.getSimpleName(thisFastaName)) + fileGroup[thisFastaName] + "slayer.chimera";
+			string thisaccnosFileName = outputdir + util.getRootName(util.getSimpleName(thisFastaName)) + fileGroup[thisFastaName] + "slayer.accnos";
+			string thistrimFastaFileName = outputdir + util.getRootName(util.getSimpleName(thisFastaName)) + fileGroup[thisFastaName] + "slayer.fasta";
 			
 			m->mothurOut("\nChecking sequences from group: " + fileGroup[thisFastaName] + ".\n");
 			
