@@ -22,7 +22,6 @@
 class ChimeraSlayerCommand : public Command {
 public:
 	ChimeraSlayerCommand(string);
-	ChimeraSlayerCommand();
 	~ChimeraSlayerCommand() {}
 	
 	vector<string> setParameters();
@@ -54,7 +53,7 @@ private:
 	int driverGroups(string, string, string, map<string, map<string, int> >&, map<string, string>&, string);
 
 	bool abort, realign, trim, trimera, hasCount, dups;
-	string fastafile, templatefile, outputDir, search, countfile, blastlocation;
+	string fastafile, templatefile, search, countfile, blastlocation;
 	int window, iters, increment, numwanted, ksize, match, mismatch, parents, minSimilarity, minCoverage, minBS, minSNP, templateSeqsLength;
     long long numSeqs;
 	float divR;
