@@ -21,6 +21,7 @@ vector<string> ChimeraUchimeCommand::setParameters(){
         CommandParameter pcount("count", "InputTypes", "", "", "NameCount-CountGroup", "none", "none","",false,false,true); parameters.push_back(pcount);
 		CommandParameter pgroup("group", "InputTypes", "", "", "CountGroup", "none", "none","",false,false,true); parameters.push_back(pgroup);
 		CommandParameter pprocessors("processors", "Number", "", "1", "", "", "","",false,false,true); parameters.push_back(pprocessors);
+        CommandParameter puchimelocation("uchime", "String", "", "", "", "", "","",false,false); parameters.push_back(puchimelocation);
         CommandParameter pstrand("strand", "String", "", "", "", "", "","",false,false); parameters.push_back(pstrand);
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
@@ -43,6 +44,14 @@ vector<string> ChimeraUchimeCommand::setParameters(){
 		CommandParameter pmaxlen("maxlen", "Number", "", "10000", "", "", "","",false,false); parameters.push_back(pmaxlen);
 		CommandParameter pucl("ucl", "Boolean", "", "F", "", "", "","",false,false); parameters.push_back(pucl);
 		CommandParameter pqueryfract("queryfract", "Number", "", "0.5", "", "", "","",false,false); parameters.push_back(pqueryfract);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["chimera"] = tempOutNames;
+        outputTypes["accnos"] = tempOutNames;
+        outputTypes["alns"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
 
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -67,6 +76,7 @@ string ChimeraUchimeCommand::getHelpString(){
         helpString += "If the dereplicate parameter is false, then if one group finds the sequence to be chimeric, then all groups find it to be chimeric, default=f.\n";
 		helpString += "The reference parameter allows you to enter a reference file containing known non-chimeric sequences, and is required. You may also set template=self, in this case the abundant sequences will be used as potential parents. \n";
 		helpString += "The processors parameter allows you to specify how many processors you would like to use.  The default is 1. \n";
+        helpString += "The uchime parameter allows you to specify the name and location of your uchime executable. By default mothur will look in your path and mothur's executable and mothur tools locations.  You can set the uchime location as follows, uchime=/usr/bin/uchime.\n";
 		helpString += "The abskew parameter can only be used with template=self. Minimum abundance skew. Default 1.9. Abundance skew is: min [ abund(parent1), abund(parent2) ] / abund(query).\n";
 		helpString += "The chimealns parameter allows you to indicate you would like a file containing multiple alignments of query sequences to parents in human readable format. Alignments show columns with differences that support or contradict a chimeric model.\n";
 		helpString += "The minh parameter - mininum score to report chimera. Default 0.3. Values from 0.1 to 5 might be reasonable. Lower values increase sensitivity but may report more false positives. If you decrease xn you may need to increase minh, and vice versa.\n";
@@ -114,86 +124,21 @@ string ChimeraUchimeCommand::getOutputPattern(string type) {
         exit(1);
     }
 }
-//**********************************************************************************************************************
-ChimeraUchimeCommand::ChimeraUchimeCommand(){	
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["chimera"] = tempOutNames;
-		outputTypes["accnos"] = tempOutNames;
-		outputTypes["alns"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ChimeraUchimeCommand", "ChimeraUchimeCommand");
-		exit(1);
-	}
-}
 //***************************************************************************************************************
 ChimeraUchimeCommand::ChimeraUchimeCommand(string option)  {
 	try {
-		abort = false; calledHelp = false; hasCount=false;
+		hasCount=false;
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
-			ValidParameters validParameter("chimera.uchime");
-			map<string,string>::iterator it;
-			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			vector<string> tempOutNames;
-			outputTypes["chimera"] = tempOutNames;
-			outputTypes["accnos"] = tempOutNames;
-			outputTypes["alns"] = tempOutNames;
-            outputTypes["count"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-            string inputDir = validParameter.valid(parameters, "inputdir");
-            if (inputDir == "not found"){	inputDir = "";		}
-            else {
-                string path;
-                it = parameters.find("count");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["count"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("fasta");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("name");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["name"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("group");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["group"] = inputDir + it->second;		}
-                }
-            }
-            
+            ValidParameters validParameter;
             fastafile = validParameter.validFile(parameters, "fasta");
             if (fastafile == "not found") {
                 fastafile = current->getFastaFile();
@@ -228,18 +173,14 @@ ChimeraUchimeCommand::ChimeraUchimeCommand(string option)  {
             
             if (hasGroup && hasCount) { m->mothurOut("[ERROR]: You must enter ONLY ONE of the following: count or group.\n");  abort = true; }
             
-            //if the user changes the output directory command factory will send this info to us in the output parameter
-            outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	}
             
-            it = parameters.find("reference");
+            
+            
+            map<string, string>::iterator it = parameters.find("reference");
             //user has given a template file
             if(it != parameters.end()){
                 if (it->second == "self") {  templatefile = "self";  }
                 else {
-                    string path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["reference"] = inputDir + it->second;		}
-                    
                     templatefile = validParameter.validFile(parameters, "reference");
                     if (templatefile == "not open") { abort = true; }
                     else if (templatefile == "not found") { //check for saved reference sequences
@@ -253,7 +194,7 @@ ChimeraUchimeCommand::ChimeraUchimeCommand(string option)  {
 			processors = current->setProcessors(temp);
 			
 			abskew = validParameter.valid(parameters, "abskew");	if (abskew == "not found"){	useAbskew = false;  abskew = "1.9";	}else{  useAbskew = true;  }
-			if (useAbskew && templatefile != "self") { m->mothurOut("The abskew parameter is only valid with template=self, ignoring."); m->mothurOutEndLine(); useAbskew = false; }
+			if (useAbskew && templatefile != "self") { m->mothurOut("The abskew parameter is only valid with template=self, ignoring.\n");  useAbskew = false; }
 			
 			temp = validParameter.valid(parameters, "chimealns");			if (temp == "not found") { temp = "f"; }
 			chimealns = util.isTrue(temp); 
@@ -276,7 +217,7 @@ ChimeraUchimeCommand::ChimeraUchimeCommand(string option)  {
 			ucl = util.isTrue(temp);
 			
 			queryfract = validParameter.valid(parameters, "queryfract");			if (queryfract == "not found")		{ useQueryfract = false; queryfract = "0.5";		}	else{ useQueryfract = true;		}
-			if (!ucl && useQueryfract) { m->mothurOut("queryfact may only be used when ucl=t, ignoring."); m->mothurOutEndLine(); useQueryfract = false; }
+			if (!ucl && useQueryfract) { m->mothurOut("queryfact may only be used when ucl=t, ignoring.\n");  useQueryfract = false; }
 			
 			temp = validParameter.valid(parameters, "skipgaps");					if (temp == "not found") { temp = "t"; }
 			skipgaps = util.isTrue(temp); 
@@ -294,26 +235,29 @@ ChimeraUchimeCommand::ChimeraUchimeCommand(string option)  {
             if (hasCount && (templatefile != "self")) { m->mothurOut("You have provided a countfile and the reference parameter is not set to self. I am not sure what reference you are trying to use, aborting.\n");  abort=true; }
 			if (hasGroup && (templatefile != "self")) { m->mothurOut("You have provided a group file and the reference parameter is not set to self. I am not sure what reference you are trying to use, aborting.\n");  abort=true; }
 			
-			//look for uchime exe
-			string path = current->getProgramPath();
-			string uchimeCommand = path + "uchime" + EXECUTABLE_EXT;
-			ifstream in;
-			uchimeCommand = util.getFullPathName(uchimeCommand);
-			bool ableToOpen = util.openInputFile(uchimeCommand, in, "no error"); in.close();
-			if(!ableToOpen) {	
-                m->mothurOut(uchimeCommand + " file does not exist. Checking path... \n");
-                //check to see if uchime is in the path??
-                ifstream in2;
-                string uName = "uchime"; uName += EXECUTABLE_EXT;
-                string uLocation = util.findProgramPath(uName);
-                uLocation += uName;
-                ableToOpen = util.openInputFile(uLocation, in2, "no error"); in2.close();
-
-                if(!ableToOpen) { m->mothurOut("[ERROR]: " + uLocation + " file does not exist. mothur requires the uchime executable.\n");  abort = true; }
-                else {  m->mothurOut("Found uchime in your path, using " + uLocation + "\n");uchimeLocation = uLocation; }
-            }else {  uchimeLocation = uchimeCommand; }
+            vector<string> versionOutputs;
+            bool foundTool = false;
+            string path = current->getProgramPath();
+            string programName = "uchime"; programName += EXECUTABLE_EXT;
             
+            uchimeLocation = validParameter.validFile(parameters, "uchime");
+            if (uchimeLocation == "not found") {
+                uchimeLocation = "";
+                foundTool = util.findTool(programName, uchimeLocation, path, versionOutputs, current->getLocations());
+            }
+            else {
+                //test to make sure uchime exists
+                ifstream in;
+                uchimeLocation = util.getFullPathName(uchimeLocation);
+                bool ableToOpen = util.openInputFile(uchimeLocation, in, "no error"); in.close();
+                if(!ableToOpen) {
+                    m->mothurOut(uchimeLocation + " file does not exist or cannot be opened, ignoring.\n"); uchimeLocation = "";
+                    foundTool = util.findTool(programName, uchimeLocation, path, versionOutputs, current->getLocations());
+                }
+            }
             uchimeLocation = util.getFullPathName(uchimeLocation);
+            m->mothurOut("[DEBUG]: uchime location using " + uchimeLocation + "\n");
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: uchime location using " + uchimeLocation + "\n"); }
             
             if (!abort) {
                 if ((namefile != "") || (groupfile != "")) { //convert to count
@@ -321,8 +265,8 @@ ChimeraUchimeCommand::ChimeraUchimeCommand(string option)  {
                     string rootFileName = namefile;
                     if (rootFileName == "") { rootFileName = groupfile; }
                     
-                    if (outputDir == "") { outputDir = util.hasPath(rootFileName); }
-                    map<string, string> variables; variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(rootFileName));
+                    if (outputdir == "") { outputdir = util.hasPath(rootFileName); }
+                    map<string, string> variables; variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(rootFileName));
                     string outputFileName = getOutputFileName("count", variables);
                     
                     CountTable ct; ct.createTable(namefile, groupfile, nullVector); ct.printCompressedTable(outputFileName);
@@ -344,8 +288,10 @@ struct uchimeData {
     string fastafile;
     string dupsfile;
     string outputFName;
-    string accnos, alns, formattedFastaFilename, templatefile, uchimeLocation, countlist;
+    string accnos, alns, formattedFastaFilename, templatefile, uchimeLocation;
     string driverAccnos, driverAlns, driverOutputFName;
+    map<string, vector<string> > parsedFiles;
+    map<string, vector<string> > seqs2RemoveByGroup;
     
     int count, numChimeras;
     vector<string> groups;
@@ -354,7 +300,7 @@ struct uchimeData {
     Utils util;
     
     uchimeData(){}
-    uchimeData(string o, string uloc, string t, string file, string f, string n, string ac,  string al, string nc, vector<string> gr, uchimeVariables* vs) {
+    uchimeData(map<string, vector<string> > g2f, string o, string uloc, string t, string file, string f, string n, string ac,  string al, vector<string> gr, uchimeVariables* vs) {
         fastafile = f;
         dupsfile = n;
         formattedFastaFilename = file;
@@ -367,11 +313,11 @@ struct uchimeData {
         count = 0;
         numChimeras = 0;
         uchimeLocation = uloc;
-        countlist = nc;
         vars = vs;
         driverAccnos = ac;
         driverAlns = al;
         driverOutputFName = o;
+        parsedFiles = g2f;
     }
     void setDriverNames(string o, string al, string ac) {
         driverAccnos = ac;
@@ -732,9 +678,9 @@ int ChimeraUchimeCommand::execute(){
         m->mothurOut("Checking sequences from " + fastafile + " ...\n" ); 
         
         long start = time(NULL);
-        if (outputDir == "") { outputDir = util.hasPath(fastafile);  }//if user entered a file with a path then preserve it
+        if (outputdir == "") { outputdir = util.hasPath(fastafile);  }
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastafile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
         variables["[tag]"] = "denovo";
         if (templatefile != "self") { variables["[tag]"] = "ref"; }
         string outputFileName = getOutputFileName("chimera", variables);
@@ -749,7 +695,7 @@ int ChimeraUchimeCommand::execute(){
         if (hasCount) {
             CountTable ct;
             if (ct.testGroups(countfile, groups)) { hasGroups = true; }
-            variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(countfile));
+            variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(countfile));
             newCountFile = getOutputFileName("count", variables);
         }
         
@@ -791,13 +737,37 @@ int ChimeraUchimeCommand::execute(){
         if (hasGroups) {
             if (m->getControl_pressed()) { for (int j = 0; j < outputNames.size(); j++) {	util.mothurRemove(outputNames[j]);	}  delete vars; return 0; }
             
+            vector<string> groups;
+            map<string, vector<string> > group2Files;
+            if (hasCount) {
+                current->setMothurCalling(true);
+                SequenceCountParser cparser(countfile, fastafile, nullVector);
+                current->setMothurCalling(false);
+                groups = cparser.getNamesOfGroups();
+                group2Files = cparser.getFiles();
+                
+            }
+            
             //clears files
             ofstream out, out1, out2;
             util.openOutputFile(outputFileName, out); out.close();
             util.openOutputFile(accnosFileName, out1); out1.close();
             if (chimealns) { util.openOutputFile(alnsFileName, out2); out2.close(); }
             
-            int totalSeqs = createProcessesGroups(outputFileName, newFasta, accnosFileName, alnsFileName, newCountFile, groups);
+            map<string, vector<string> > seqs2RemoveByGroup;
+            int totalSeqs = createProcessesGroups(group2Files, outputFileName, newFasta, accnosFileName, alnsFileName, groups, seqs2RemoveByGroup);
+            
+            if (hasCount && dups) {
+                CountTable newCount; newCount.readTable(countfile, true, false);
+                
+                for (map<string, vector<string> >::iterator it = seqs2RemoveByGroup.begin(); it != seqs2RemoveByGroup.end(); it++) {
+                    
+                    string group = it->first;
+                    for (int k = 0; k < it->second.size(); k++) { newCount.setAbund(it->second[k], group, 0); }
+                }
+                
+                newCount.printTable(newCountFile);
+            }
             
             if (m->getControl_pressed()) {  for (int j = 0; j < outputNames.size(); j++) {	util.mothurRemove(outputNames[j]);	} delete vars;  return 0;	}
             
@@ -829,8 +799,9 @@ int ChimeraUchimeCommand::execute(){
             
             int numSeqs = 0;
             int numChimeras = 0;
+            map<string, vector<string> > dummy;
             
-            uchimeData* dataBundle = new uchimeData(outputFileName, uchimeLocation, templatefile, fastafile, fastafile, countfile, accnosFileName, alnsFileName, accnosFileName+".byCount.temp", nullVector, vars);
+            uchimeData* dataBundle = new uchimeData(dummy, outputFileName, uchimeLocation, templatefile, fastafile, fastafile, countfile, accnosFileName, alnsFileName, nullVector, vars);
             
             numSeqs = driver(dataBundle);
             numChimeras = dataBundle->numChimeras;
@@ -1076,8 +1047,8 @@ int ChimeraUchimeCommand::deconvoluteResults(string outputFileName, string accno
 							else { out3 << line[i]; }
 						}
 						
-						if (spot == (line.length() - 1)) { m->mothurOut("[ERROR]: could not line sequence name in line " + line + "."); m->mothurOutEndLine(); m->setControl_pressed(true); }
-						else if ((spot+2) > (line.length() - 1)) { m->mothurOut("[ERROR]: could not line sequence name in line " + line + "."); m->mothurOutEndLine(); m->setControl_pressed(true); }
+						if (spot == (line.length() - 1)) { m->mothurOut("[ERROR]: could not line sequence name in line " + line + ".\n");  m->setControl_pressed(true); }
+						else if ((spot+2) > (line.length() - 1)) { m->mothurOut("[ERROR]: could not line sequence name in line " + line + ".\n");  m->setControl_pressed(true); }
 						else {
 							out << line[spot] << line[spot+1];
 							
@@ -1225,22 +1196,11 @@ int getSeqs(map<string, int>& nameMap, string thisGroupsFormattedOutputFilename,
 //**********************************************************************************************************************
 void driverGroups(uchimeData* params){
 	try {
-        //Parse sequences by group
-        map<string, vector<string> > group2Files;
-        if (params->vars->hasCount) {
-            SequenceCountParser cparser(params->dupsfile, params->fastafile, params->groups);
-            params->groups = cparser.getNamesOfGroups();
-            group2Files = cparser.getFiles();
-            
-        }
-
 		int totalSeqs = 0;
-        ofstream outCountList;
-        if (params->vars->hasCount && params->vars->dups) { params->util.openOutputFile(params->countlist, outCountList); }
         
-        for (map<string, vector<string> >::iterator it = group2Files.begin(); it != group2Files.end(); it++) {
+        for (map<string, vector<string> >::iterator it = params->parsedFiles.begin(); it != params->parsedFiles.end(); it++) {
             long start = time(NULL);
-            if (params->m->getControl_pressed()) {  outCountList.close(); params->util.mothurRemove(params->countlist); break; }
+            if (params->m->getControl_pressed()) {  break; }
             
             int error;
             long long numSeqs = 0;
@@ -1274,11 +1234,13 @@ void driverGroups(uchimeData* params){
                     params->util.openInputFile(params->accnos+thisGroup, in);
                     string name;
                     if (params->vars->hasCount) {
+                        vector<string> namesOfChimeras;
                         while (!in.eof()) {
                             in >> name; params->util.gobble(in);
-                            outCountList << name << '\t' << thisGroup << endl;
+                            namesOfChimeras.push_back(name);
                         }
                         in.close();
+                        params->seqs2RemoveByGroup[thisGroup] = namesOfChimeras;
                     }else {
                         map<string, string> thisnamemap; params->util.readNames(it->second[1], thisnamemap);
                         map<string, string>::iterator itN;
@@ -1307,8 +1269,7 @@ void driverGroups(uchimeData* params){
 			
 			params->m->mothurOut("\nIt took " + toString(time(NULL) - start) + " secs to check " + toString(numSeqs) + " sequences from group " + thisGroup + ".\n");
 		}
-        
-        if (!params->m->getControl_pressed()) { if (params->vars->hasCount && params->vars->dups) { outCountList.close(); } }
+    
         params->count = totalSeqs;
 		
 	}
@@ -1319,12 +1280,8 @@ void driverGroups(uchimeData* params){
 }	
 /**************************************************************************************************/
 
-int ChimeraUchimeCommand::createProcessesGroups(string outputFName, string filename, string accnos, string alns, string newCountFile, vector<string> groups) {
+int ChimeraUchimeCommand::createProcessesGroups(map<string, vector<string> >& groups2Files, string outputFName, string filename, string accnos, string alns, vector<string> groups, map<string, vector<string> >& seqs2RemoveByGroup) {
 	try {
-        CountTable newCount;
-        string dupsFileName = countfile;
-        if (hasCount && dups) { newCount.readTable(countfile, true, false); dupsFileName = countfile; }
-        
         //sanity check
         if (groups.size() < processors) { processors = groups.size(); m->mothurOut("Reducing processors to " + toString(groups.size()) + ".\n"); }
         
@@ -1341,7 +1298,7 @@ int ChimeraUchimeCommand::createProcessesGroups(string outputFName, string filen
         }
         
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<uchimeData*> data;
         
         long long num = 0;
@@ -1352,16 +1309,33 @@ int ChimeraUchimeCommand::createProcessesGroups(string outputFName, string filen
         for (int i = 0; i < processors-1; i++) {
             string extension = toString(i+1) + ".temp";
             vector<string> thisGroups;
-            for (int j = lines[i+1].start; j < lines[i+1].end; j++) { thisGroups.push_back(groups[j]); }
-            uchimeData* dataBundle = new uchimeData(outputFName+extension, uchimeLocation, templatefile, filename+extension, fastafile, dupsFileName,  accnos+extension, alns+extension, accnos+".byCount."+extension, thisGroups, vars);
+            map<string, vector<string> > thisGroupsParsedFiles;
+            for (int j = lines[i+1].start; j < lines[i+1].end; j++) {
+                
+                map<string, vector<string> >::iterator it = groups2Files.find(groups[j]);
+                if (it != groups2Files.end()) {
+                    thisGroupsParsedFiles[groups[j]] = (it->second);
+                    thisGroups.push_back(groups[j]);
+                }
+                else { m->mothurOut("[ERROR]: missing files for group " + groups[j] + ", skipping\n"); }
+            }
+            uchimeData* dataBundle = new uchimeData(thisGroupsParsedFiles, outputFName+extension, uchimeLocation, templatefile, filename+extension, fastafile, countfile,  accnos+extension, alns+extension, thisGroups, vars);
             data.push_back(dataBundle);
             
-            workerThreads.push_back(new thread(driverGroups, dataBundle));
+            workerThreads.push_back(new std::thread(driverGroups, dataBundle));
         }
         
         vector<string> thisGroups;
-        for (int j = lines[0].start; j < lines[0].end; j++) { thisGroups.push_back(groups[j]); }
-        uchimeData* dataBundle = new uchimeData(outputFName, uchimeLocation, templatefile, filename, fastafile, dupsFileName, accnos, alns, accnos+".byCount.temp", thisGroups, vars);
+        map<string, vector<string> > thisGroupsParsedFiles;
+        for (int j = lines[0].start; j < lines[0].end; j++) {
+            map<string, vector<string> >::iterator it = groups2Files.find(groups[j]);
+            if (it != groups2Files.end()) {
+                thisGroupsParsedFiles[groups[j]] = (it->second);
+                thisGroups.push_back(groups[j]);
+            }
+            else { m->mothurOut("[ERROR]: missing files for group " + groups[j] + ", skipping\n"); }
+        }
+        uchimeData* dataBundle = new uchimeData(thisGroupsParsedFiles, outputFName, uchimeLocation, templatefile, filename, fastafile, countfile, accnos, alns, thisGroups, vars);
         driverGroups(dataBundle);
         num = dataBundle->count;
         int numChimeras = dataBundle->numChimeras;
@@ -1370,6 +1344,22 @@ int ChimeraUchimeCommand::createProcessesGroups(string outputFName, string filen
             workerThreads[i]->join();
             num += data[i]->count;
             numChimeras += data[i]->numChimeras;
+            seqs2RemoveByGroup = dataBundle->seqs2RemoveByGroup;
+            
+            for (map<string, vector<string> >::iterator it = data[i]->seqs2RemoveByGroup.begin(); it != data[i]->seqs2RemoveByGroup.end(); it++) {
+                           
+                map<string, vector<string> >::iterator itSanity = seqs2RemoveByGroup.find(it->first);
+                if (itSanity == seqs2RemoveByGroup.end()) { //we haven't seen this group, should always be true
+                    seqs2RemoveByGroup[it->first] = it->second;
+                }
+            }
+            
+            string extension = toString(i+1) + ".temp";
+            util.appendFiles((outputFName+extension), outputFName);
+            util.mothurRemove((outputFName+extension));
+            
+            util.appendFiles((accnos+extension), accnos);
+            util.mothurRemove((accnos+extension));
             
             delete data[i];
             delete workerThreads[i];
@@ -1378,51 +1368,6 @@ int ChimeraUchimeCommand::createProcessesGroups(string outputFName, string filen
         time(&end);
         m->mothurOut("It took " + toString(difftime(end, start)) + " secs to check " + toString(num) + " sequences.\n\n");
         
-        //read my own
-        if (hasCount && dups) {
-            string countlisttemp = accnos+".byCount.temp";
-            if (!util.isBlank(countlisttemp)) {
-                ifstream in2;
-                util.openInputFile(countlisttemp, in2);
-                
-                string name, group;
-                while (!in2.eof()) {
-                    in2 >> name >> group; util.gobble(in2);
-                    newCount.setAbund(name, group, 0);
-                }
-                in2.close();
-            }
-            util.mothurRemove(countlisttemp);
-        }
-        
-        //append output files
-        for (int i = 0; i < processors-1; i++) {
-            string extension = toString(i+1) + ".temp";
-            util.appendFiles((outputFName+extension), outputFName);
-            util.mothurRemove((outputFName+extension));
-            
-            util.appendFiles((accnos+extension), accnos);
-            util.mothurRemove((accnos+extension));
-            
-            if (hasCount && dups) {
-                if (!util.isBlank(accnos+".byCount."+extension)) {
-                    ifstream in2;
-                    util.openInputFile(accnos+".byCount."+extension, in2);
-                    
-                    string name, group;
-                    while (!in2.eof()) {
-                        in2 >> name >> group; util.gobble(in2);
-                        newCount.setAbund(name, group, 0);
-                    }
-                    in2.close();
-                }
-                util.mothurRemove(accnos+".byCount."+extension);
-            }
-            
-        }
-        
-        //print new *.pick.count_table
-        if (hasCount && dups) {  newCount.printTable(newCountFile);   }
         
         return num;	
 	}
