@@ -69,7 +69,6 @@ struct uchimeVariables {
 class ChimeraUchimeCommand : public Command {
 public:
 	ChimeraUchimeCommand(string);
-	ChimeraUchimeCommand();
 	~ChimeraUchimeCommand() {}
 	
 	vector<string> setParameters();
@@ -86,7 +85,7 @@ public:
 	
 private:
 	bool abort, useAbskew, chimealns, useMinH, useMindiv, useXn, useDn, useXa, useChunks, useMinchunk, useIdsmoothwindow, useMinsmoothid, useMaxp, skipgaps, skipgaps2, useMinlen, useMaxlen, ucl, useQueryfract, hasCount, dups;
-	string fastafile, templatefile, outputDir, countfile, abskew, minh, mindiv, xn, dn, xa, chunks, minchunk, idsmoothwindow, minsmoothid, maxp, minlen, maxlen, queryfract, uchimeLocation, strand;
+	string fastafile, templatefile, countfile, abskew, minh, mindiv, xn, dn, xa, chunks, minchunk, idsmoothwindow, minsmoothid, maxp, minlen, maxlen, queryfract, uchimeLocation, strand;
 	int processors;
 	vector<string> outputNames;
     uchimeVariables* vars;
@@ -94,7 +93,7 @@ private:
 	string getCountFile(string&);
 	int readFasta(string, map<string, string>&);
 	int deconvoluteResults(string, string, string);
-	int createProcessesGroups(string, string, string, string, string, vector<string>);
+	int createProcessesGroups(map<string, vector<string> >&, string, string, string, string, vector<string>, map<string, vector<string> >&);
 };
 /**************************************************************************************************/
 
