@@ -20,10 +20,11 @@ vector<string> ClassifySeqsCommand::setParameters(){
         CommandParameter pname("name", "InputTypes", "", "", "NameCount", "none", "none","",false,false,true); parameters.push_back(pname);
         CommandParameter pcount("count", "InputTypes", "", "", "NameCount-CountGroup", "none", "none","",false,false,true); parameters.push_back(pcount);
 		CommandParameter pgroup("group", "InputTypes", "", "", "CountGroup", "none", "none","",false,false,true); parameters.push_back(pgroup);
+        CommandParameter phard("filter", "InputTypes", "", "", "none", "none", "none","",false,false); parameters.push_back(phard);
         CommandParameter poutput("output", "Multiple", "simple-detail", "detail", "", "", "","",false,false, true); parameters.push_back(poutput);
 		CommandParameter psearch("search", "Multiple", "kmer-blast-suffix-distance-align", "kmer", "", "", "","",false,false); parameters.push_back(psearch);
 		CommandParameter pksize("ksize", "Number", "", "8", "", "", "","",false,false); parameters.push_back(pksize);
-		CommandParameter pmethod("method", "Multiple", "wang-knn-zap", "wang", "", "", "","",false,false); parameters.push_back(pmethod);
+		CommandParameter pmethod("method", "Multiple", "wang-knn-zap-opti", "wang", "", "", "","",false,false); parameters.push_back(pmethod);
 		CommandParameter pprocessors("processors", "Number", "", "1", "", "", "","",false,false,true); parameters.push_back(pprocessors);
 		CommandParameter pmatch("match", "Number", "", "1.0", "", "", "","",false,false); parameters.push_back(pmatch);
         CommandParameter pprintlevel("printlevel", "Number", "", "-1", "", "", "","",false,false); parameters.push_back(pprintlevel);
@@ -39,6 +40,14 @@ vector<string> ClassifySeqsCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["taxonomy"] = tempOutNames;
+        outputTypes["accnos"] = tempOutNames;
+        outputTypes["taxsummary"] = tempOutNames;
+        outputTypes["matchdist"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -59,7 +68,7 @@ string ClassifySeqsCommand::getHelpString(){
 		helpString += "The name parameter allows you add a names file with your fasta file.\n";
 		helpString += "The group parameter allows you add a group file so you can have the summary totals broken up by group.\n";
         helpString += "The count parameter allows you add a count file so you can have the summary totals broken up by group.\n";
-		helpString += "The method parameter allows you to specify classification method to use.  Your options are: wang, knn and zap. The default is wang.\n";
+		helpString += "The method parameter allows you to specify classification method to use.  Your options are: wang, opti, knn and zap. The default is wang.\n";
 		helpString += "The ksize parameter allows you to specify the kmer size for finding most similar template to candidate.  The default is 8.\n";
 		helpString += "The processors parameter allows you to specify the number of processors to use. The default is all available.\n";
 		helpString += "The match parameter allows you to specify the bonus for having the same base. The default is 1.0.\n";
@@ -68,6 +77,7 @@ string ClassifySeqsCommand::getHelpString(){
 		helpString += "The gapextend parameter allows you to specify the penalty for extending a gap in an alignment.  The default is -1.0.\n";
 		helpString += "The numwanted parameter allows you to specify the number of sequence matches you want with the knn method.  The default is 10.\n";
 		helpString += "The cutoff parameter allows you to specify a bootstrap confidence threshold for your taxonomy.  The default is 80.\n";
+        helpString += "The filter parameter allows you to enter a file containing the filter created by filter.seqs. Aligned reads are expected when using the opti method, the filter is used to map the columns in the query reads to the columns in the template. \n";
 		helpString += "The probs parameter shuts off the bootstrapping results for the wang and zap method. The default is true, meaning you want the bootstrapping to be shown.\n";
         helpString += "The relabund parameter allows you to indicate you want the summary file values to be relative abundances rather than raw abundances. Default=F. \n";
 		helpString += "The iters parameter allows you to specify how many iterations to do when calculating the bootstrap confidence score for your taxonomy with the wang method.  The default is 100.\n";
@@ -94,7 +104,7 @@ string ClassifySeqsCommand::getCommonQuestions(){
         vector<string> questions, issues, qanswers, ianswers, howtos, hanswers;
         
         string question = "Does the reference need to be aligned?"; questions.push_back(question);
-        string qanswer = "\tNo, mothur does not require an aligned reference to assign a taxonomy. This is because it uses k-mers to find the probabilities of the taxonomic assignment.\n"; qanswers.push_back(qanswer);
+        string qanswer = "\tThat depends on the method. For the opti method, mothur uses the alignment to determine the probability a given base will be found in a given taxonomy at a given location in the alignment. For wang, knn and zap methods,  mothur does not require an aligned reference to assign a taxonomy. Wang use k-mers to find the probabilities of the taxonomic assignment. \n"; qanswers.push_back(qanswer);
         
         question = "What reference should I use to classify?"; questions.push_back(question);
         qanswer = "\tWe provide mothur formatted references on the wiki. https://www.mothur.org/wiki/RDP_reference_files https://mothur.org/wiki/Silva_reference_files https://www.mothur.org/wiki/Greengenes-formatted_databases Alternatively, mothur allows you to create your own references as long as they are in fasta and taxonomy file format. You can find mothur's files formats here, https://www.mothur.org/wiki/File_Types. \n"; qanswers.push_back(qanswer);
@@ -134,106 +144,21 @@ string ClassifySeqsCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-ClassifySeqsCommand::ClassifySeqsCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["taxonomy"] = tempOutNames;
-		outputTypes["accnos"] = tempOutNames;
-		outputTypes["taxsummary"] = tempOutNames;
-		outputTypes["matchdist"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ClassifySeqsCommand", "ClassifySeqsCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
 		hasName = false; hasCount=false;
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters(); 
 			
-			ValidParameters validParameter("classify.seqs");
-			map<string, string>::iterator it;
+			ValidParameters validParameter;
 			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["taxonomy"] = tempOutNames;
-			outputTypes["taxsummary"] = tempOutNames;
-			outputTypes["matchdist"] = tempOutNames;
-			outputTypes["accnos"] = tempOutNames;
-			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("reference");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["reference"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("taxonomy");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["taxonomy"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["count"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("fasta");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("name");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["name"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("group");
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["group"] = inputDir + it->second;		}
-                }
-            }
-
             fastafile = validParameter.validFile(parameters, "fasta");
             if (fastafile == "not found") {
                 fastafile = current->getFastaFile();
@@ -266,9 +191,6 @@ ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
             else { current->setGroupFile(groupfile); hasGroup = true; }
             
             if (hasGroup && hasCount) { m->mothurOut("[ERROR]: You must enter ONLY ONE of the following: count or group.\n");  abort = true; }
-            
-            //if the user changes the output directory command factory will send this info to us in the output parameter
-            outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	}
 			
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
@@ -287,6 +209,13 @@ ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 			taxonomyFileName = validParameter.validFile(parameters, "taxonomy");
 			if (taxonomyFileName == "not found") {  m->mothurOut("[ERROR]: The taxonomy parameter is a required for the classify.seqs command.\n"); abort = true;
 			}else if (taxonomyFileName == "not open") { abort = true; }
+            
+            temp = validParameter.validFile(parameters, "filter");     if (temp == "not found") { filter = ""; }
+            else if (temp == "not open") { filter = ""; abort = true; }
+            else {
+                ifstream in; util.openInputFile(temp, in);
+                in >> filter; in.close();
+            }
 			
 			search = validParameter.valid(parameters, "search");		if (search == "not found"){	search = "kmer";		}
 			
@@ -346,6 +275,17 @@ ClassifySeqsCommand::ClassifySeqsCommand(string option)  {
 				search = "kmer";
 			}
 			
+            if (search == "blast") {
+                string blastlocation = "";
+                vector<string> locations = current->getLocations();
+                string path = current->getProgramPath();
+                bool foundTool = util.findBlastLocation(blastlocation, path, locations);
+
+                if (!foundTool){
+                    m->mothurOut("[WARNING]: Unable to locate blast executables, cannot use blast as search method. Using kmer instead.\n"); search = "kmer";
+                }
+            }
+            
             if (!abort) {
                 if (!hasCount) {
                     if (namefile == ""){
@@ -374,15 +314,15 @@ int ClassifySeqsCommand::execute(){
         
         string outputMethodTag = method;
 		if(method == "wang"){	classify = new Bayesian(taxonomyFileName, templateFileName, search, kmerSize, cutoff, iters, util.getRandomNumber(), flip, writeShortcuts, current->getVersion());	}
-		else if(method == "knn"){	classify = new Knn(taxonomyFileName, templateFileName, search, kmerSize, gapOpen, gapExtend, match, misMatch, numWanted, util.getRandomNumber(), current->getVersion());				}
+		else if(method == "opti"){    classify = new OptiClassifier(taxonomyFileName, templateFileName, cutoff, iters, writeShortcuts, current->getVersion(), filter);    }
+        else if(method == "knn"){	classify = new Knn(taxonomyFileName, templateFileName, search, kmerSize, gapOpen, gapExtend, match, misMatch, numWanted, util.getRandomNumber(), current->getVersion());				}
         else if(method == "zap"){	
             outputMethodTag = search + "_" + outputMethodTag;
             if (search == "kmer") {   classify = new KmerTree(templateFileName, taxonomyFileName, kmerSize, cutoff); }
             else {  classify = new AlignTree(templateFileName, taxonomyFileName, cutoff);  }
         }
 		else {
-			m->mothurOut(search + " is not a valid method option. I will run the command using wang.");
-			m->mothurOutEndLine();
+			m->mothurOut(search + " is not a valid method option. I will run the command using wang.\n");
 			classify = new Bayesian(taxonomyFileName, templateFileName, search, kmerSize, cutoff, iters, util.getRandomNumber(), flip, writeShortcuts, current->getVersion());
 		}
 		
@@ -401,14 +341,14 @@ int ClassifySeqsCommand::execute(){
             else if (!foundDot && (baseTName[i] == '.')) {  foundDot = true; }
         }
         
-        if (outputDir == "") { outputDir += util.hasPath(fastafile); }
+        if (outputdir == "") { outputdir += util.hasPath(fastafile); }
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastafile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
         variables["[tag]"] = RippedTaxName;
         variables["[tag2]"] = outputMethodTag;
         string newTaxonomyFile = getOutputFileName("taxonomy", variables);
         string newaccnosFile = getOutputFileName("accnos", variables);
-        string tempTaxonomyFile = outputDir + util.getRootName(util.getSimpleName(fastafile)) + "taxonomy.temp";
+        string tempTaxonomyFile = outputdir + util.getRootName(util.getSimpleName(fastafile)) + "taxonomy.temp";
         string taxSummary = getOutputFileName("taxsummary", variables);
         
         if ((method == "knn") && (search == "distance")) {
@@ -494,7 +434,7 @@ int ClassifySeqsCommand::execute(){
         util.mothurRemove(newTaxonomyFile);
         util.renameFile(unclass, newTaxonomyFile);
         
-        if (m->getControl_pressed()) {  outputTypes.clear(); if (ct != NULL) { delete ct; } if (groupMap != NULL) { delete groupMap; } for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} delete classify; return 0; }
+        if (m->getControl_pressed()) {  outputTypes.clear(); if (ct != NULL) { delete ct; } if (groupMap != NULL) { delete groupMap; } for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} delete classify; delete taxaSum;  return 0; }
         
         //print summary file
         ofstream outTaxTree;
@@ -633,15 +573,12 @@ void driverClassifier(classifyData* params){
 int ClassifySeqsCommand::createProcesses(string taxFileName, string tempTaxFile, string accnos, string filename) {
 	try {
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<classifyData*> data;
         
         long long num = 0;
-        
-        time_t start, end;
-        time(&start);
 
-        vector<unsigned long long> positions;
+        vector<double> positions;
         vector<linePair> lines;
 #if defined NON_WINDOWS
         positions = util.divideFile(filename, processors);
@@ -671,7 +608,7 @@ int ClassifySeqsCommand::createProcesses(string taxFileName, string tempTaxFile,
             classifyData* dataBundle = new classifyData(threadAccnosWriter, probs, threadTaxWriter, threadTaxTWriter, filename, lines[i+1].start, lines[i+1].end, flip, classify);
             data.push_back(dataBundle);
             
-            workerThreads.push_back(new thread(driverClassifier, dataBundle));
+            workerThreads.push_back(new std::thread(driverClassifier, dataBundle));
         }
         
         OutputWriter* threadTaxWriter = new OutputWriter(synchronizedTaxFile);
@@ -696,8 +633,6 @@ int ClassifySeqsCommand::createProcesses(string taxFileName, string tempTaxFile,
         synchronizedTaxTFile->close(); synchronizedTaxFile->close(); synchronizedAccnosFile->close();
         delete threadTaxWriter; delete threadTaxTWriter; delete threadAccnosWriter;
         delete dataBundle;
-        time(&end);
-        m->mothurOut("It took " + toString(difftime(end, start)) + " secs to classify " + toString(num) + " sequences.\n\n");
         
         return num;
 	}
