@@ -18,9 +18,8 @@
 
 class ClassifySvmSharedCommand : public Command {
 public:
-  ClassifySvmSharedCommand();
+  
   ClassifySvmSharedCommand(string);
-  //~ClassifySvmSharedCommand() throw() {};
   ~ClassifySvmSharedCommand() {};
   
   vector<string> setParameters();
@@ -42,7 +41,6 @@ public:
 
 private:
     bool abort;
-    string outputDir;
     vector<string> outputNames, Groups;
 
     string sharedfile, designfile;
