@@ -23,6 +23,12 @@ vector<string> ClassifyTreeCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["tree"] = tempOutNames;
+        outputTypes["summary"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -71,93 +77,19 @@ string ClassifyTreeCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-ClassifyTreeCommand::ClassifyTreeCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["tree"] = tempOutNames;
-		outputTypes["summary"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ClassifyTreeCommand", "ClassifyTreeCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 ClassifyTreeCommand::ClassifyTreeCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string, string>::iterator it;
 			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			vector<string> tempOutNames;
-			outputTypes["tree"] = tempOutNames;
-			outputTypes["summary"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("tree");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["tree"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("taxonomy");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["taxonomy"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-			}
-			
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	}
             
 			//check for required parameters
 			treefile = validParameter.validFile(parameters, "tree");
@@ -202,7 +134,7 @@ ClassifyTreeCommand::ClassifyTreeCommand(string option)  {
             string temp = validParameter.valid(parameters, "cutoff");			if (temp == "not found") { temp = "51"; }
 			util.mothurConvert(temp, cutoff); 
 			
-			if ((cutoff < 51) || (cutoff > 100)) { m->mothurOut("cutoff must be above 50, and no greater than 100."); m->mothurOutEndLine(); abort = true;  }
+			if ((cutoff < 51) || (cutoff > 100)) { m->mothurOut("cutoff must be above 50, and no greater than 100.\n");  abort = true;  }
             
             output = validParameter.valid(parameters, "output");
             if (output == "not found") { output = "node"; }
@@ -268,7 +200,7 @@ int ClassifyTreeCommand::execute(){
 			}
 		}
 		
-		m->mothurOutEndLine(); m->mothurOutEndLine(); m->mothurOut("It took " + toString(time(NULL) - start) + " secs to find the concensus taxonomies."); m->mothurOutEndLine();
+		m->mothurOutEndLine(); m->mothurOutEndLine(); m->mothurOut("It took " + toString(time(NULL) - start) + " secs to find the concensus taxonomies.\n"); 
 		m->mothurOut("\nOutput File Names: \n"); 
 		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i] +"\n"); 	} m->mothurOutEndLine();
         
@@ -286,8 +218,8 @@ int ClassifyTreeCommand::execute(){
 int ClassifyTreeCommand::getClassifications(Tree*& T){
 	try {
 		
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(treefile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(treefile);  }
         map<string, string> variables; 
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(treefile));
 		string outputFileName = getOutputFileName("summary", variables);
@@ -302,8 +234,8 @@ int ClassifyTreeCommand::getClassifications(Tree*& T){
 		if (groupfile != "") { out << "Group\t"; } 
         out << "NumRep\tTaxonomy" << endl; 
 		
-		string treeOutputDir = outputDir;
-		if (outputDir == "") {  treeOutputDir += util.hasPath(treefile);  }
+		string treeOutputDir = outputdir;
+		if (outputdir == "") {  treeOutputDir += util.hasPath(treefile);  }
         variables["[filename]"] = treeOutputDir + util.getRootName(util.getSimpleName(treefile));
 		string outputTreeFileName = getOutputFileName("tree", variables);
 		
@@ -382,7 +314,7 @@ string ClassifyTreeCommand::getTaxonomy(set<string> names, int& size) {
 				map<string, string>::iterator it2 = nameMap.find(*it);
 				
 				if (it2 == nameMap.end()) { //this name is not in name file, skip it
-					m->mothurOut((*it) + " is not in your name file.  I will not include it in the consensus."); m->mothurOutEndLine();
+					m->mothurOut((*it) + " is not in your name file.  I will not include it in the consensus.\n"); 
 				}else{
 					
 					//is this sequence in the taxonomy file - look for repSeqName since we are assuming the taxonomy file is unique
@@ -390,8 +322,8 @@ string ClassifyTreeCommand::getTaxonomy(set<string> names, int& size) {
                     
 					if (itTax == taxMap.end()) { //this name is not in taxonomy file, skip it
                         
-						if ((*it) != (it2->second)) { m->mothurOut((*it) + " is represented by " +  it2->second + " and is not in your taxonomy file.  I will not include it in the consensus."); m->mothurOutEndLine(); }
-						else {  m->mothurOut((*it) + " is not in your taxonomy file.  I will not include it in the consensus."); m->mothurOutEndLine(); }
+						if ((*it) != (it2->second)) { m->mothurOut((*it) + " is represented by " +  it2->second + " and is not in your taxonomy file.  I will not include it in the consensus.\n");  }
+						else {  m->mothurOut((*it) + " is not in your taxonomy file.  I will not include it in the consensus.\n");  }
 					}else{
 						//add seq to tree
                         int num = nameCount[(*it)]; // we know its there since we found it in nameMap
@@ -405,7 +337,7 @@ string ClassifyTreeCommand::getTaxonomy(set<string> names, int& size) {
 				map<string, string>::iterator itTax = taxMap.find((*it));
                 
 				if (itTax == taxMap.end()) { //this name is not in taxonomy file, skip it
-					m->mothurOut((*it) + " is not in your taxonomy file.  I will not include it in the consensus."); m->mothurOutEndLine();
+					m->mothurOut((*it) + " is not in your taxonomy file.  I will not include it in the consensus.\n"); 
 				}else{
 					if (countfile != "") {
                         int numDups = ct->getNumSeqs((*it)); 
