@@ -53,11 +53,19 @@ vector<string> ClusterFitCommand::setParameters(){
         CommandParameter piters("iters", "Number", "", "100", "", "", "","",false,false,true); parameters.push_back(piters);
         CommandParameter pdenovoiters("denovoiters", "Number", "", "100", "", "", "","",false,false,true); parameters.push_back(pdenovoiters);
         CommandParameter pfitpercent("fitpercent", "Number", "", "10", "", "", "","",false,false,true); parameters.push_back(pfitpercent);
+        CommandParameter pprocessors("processors", "Number", "", "1", "", "", "","",false,false,true); parameters.push_back(pprocessors);
         CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter prefprint("printref", "Boolean", "", "F", "", "", "","",false,false); parameters.push_back(prefprint);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
         CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
         
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["list"] = tempOutNames;
+        outputTypes["sensspec"] = tempOutNames;
+        outputTypes["steps"] = tempOutNames;
+        
         vector<string> myArray;
         for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
         return myArray;
@@ -119,144 +127,22 @@ string ClusterFitCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-ClusterFitCommand::ClusterFitCommand(){
-    try {
-        abort = true; calledHelp = true;
-        setParameters();
-        vector<string> tempOutNames;
-        outputTypes["list"] = tempOutNames;
-        outputTypes["sensspec"] = tempOutNames;
-        outputTypes["steps"] = tempOutNames;
-    }
-    catch(exception& e) {
-        m->errorOut(e, "ClusterFitCommand", "ClusterFitCommand");
-        exit(1);
-    }
-}
-//**********************************************************************************************************************
 //This function checks to make sure the cluster command has no errors and then clusters based on the method chosen.
 ClusterFitCommand::ClusterFitCommand(string option)  {
     try{
-        abort = false; calledHelp = false;
-        
         //allow user to run help
         if(option == "help") { help(); abort = true; calledHelp = true; }
         else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
         
         else {
-            vector<string> myArray = setParameters();
-            
-            OptionParser parser(option);
+            OptionParser parser(option, setParameters());
             map<string,string> parameters = parser.getParameters();
-            map<string,string>::iterator it;
             
             ValidParameters validParameter;
             
-            //check to make sure all parameters are valid for command
-            for (it = parameters.begin(); it != parameters.end(); it++) {
-                if (!validParameter.isValidParameter(it->first, myArray, it->second)) {
-                    abort = true;
-                }
-            }
             
-            //initialize outputTypes
-            vector<string> tempOutNames;
-            outputTypes["list"] = tempOutNames;
-            outputTypes["sensspec"] = tempOutNames;
-            outputTypes["steps"] = tempOutNames;
-            
-            //if the user changes the output directory command factory will send this info to us in the output parameter
-            outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
-            
-            inputDir = validParameter.valid(parameters, "inputdir");
-            if (inputDir == "not found"){	inputDir = "";		}
-            else {
-                string path;
-                
-                it = parameters.find("refcolumn");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["refcolumn"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("column");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["column"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("name");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["name"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("count");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["count"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("fasta");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("reflist");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["reflist"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("refname");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["refname"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("refcount");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["refcount"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("reffasta");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["reffasta"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("accnos");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["accnos"] = inputDir + it->second;		}
-                }
-            }
-            
-            selfReference = true;
-            refdistfile = "";
-            distfile = "";
+            selfReference = true; createAccnos = false; refdistfile = ""; distfile = "";
             
             //check for required parameters
             reffastafile = validParameter.validFile(parameters, "reffasta");
@@ -269,10 +155,11 @@ ClusterFitCommand::ClusterFitCommand(string option)  {
             else if (refdistfile == "not found") { refdistfile = ""; }
             else {  refformat = "column"; selfReference = false; }
             
+            //allow ref list to be entered with denovo and accnos file
             reflistfile = validParameter.validFile(parameters, "reflist");
             if (reflistfile == "not open") { abort = true; }
             else if (reflistfile == "not found") { reflistfile = ""; }
-            else { selfReference = false; }
+            //else { selfReference = false; }
             
             refnamefile = validParameter.validFile(parameters, "refname");
             if (refnamefile == "not open") { abort = true; }
@@ -317,7 +204,12 @@ ClusterFitCommand::ClusterFitCommand(string option)  {
             accnosfile = validParameter.validFile(parameters, "accnos");
             if (accnosfile == "not open") { accnosfile = ""; abort = true; }
             else if (accnosfile == "not found") { accnosfile = ""; }
-            else {   current->setAccnosFile(accnosfile);	}
+            else {   current->setAccnosFile(accnosfile); createAccnos = false;	}
+            
+            //extract reference names from reflist instead of accnos fil
+            if (selfReference) {
+                if ((reflistfile != "") && (accnosfile == "")) { createAccnos = true; }
+            }
             
             method = validParameter.valid(parameters, "method");
             if (method == "not found") {  method = "open";}
@@ -404,6 +296,9 @@ ClusterFitCommand::ClusterFitCommand(string option)  {
             
             if ((fitPercent > 100) || (fitPercent < 0.01)) { abort=true; m->mothurOut("[ERROR]: fitpercent must be less than 100, and more than 0.01.\n"); }
             
+            temp = validParameter.valid(parameters, "processors");    if (temp == "not found"){    temp = current->getProcessors();    }
+            processors = current->setProcessors(temp);
+            
             adjust=-1.0;
             temp = validParameter.valid(parameters, "cutoff");
             if (temp == "not found") { temp = "0.03"; }
@@ -450,8 +345,8 @@ int ClusterFitCommand::execute(){
         if (namefile != "") { dupsFile = namefile; nameOrCount = "name"; }
         else { CountTable ct; ct.readTable(countfile, false, false); counts = ct.getNameMap();  }
         
-        if (outputDir == "") { outputDir += util.hasPath(distfile); }
-        fileroot = outputDir + util.getRootName(util.getSimpleName(distfile));
+        if (outputdir == "") { outputdir += util.hasPath(distfile); }
+        fileroot = outputdir + util.getRootName(util.getSimpleName(distfile));
         
         map<string, string> variables;
         variables["[filename]"] = fileroot;
@@ -460,46 +355,78 @@ int ClusterFitCommand::execute(){
         string listFile = "";
         string bestListFileName = "";
         
-        if ((selfReference) && (accnosfile == "")) { //denovo with mothur randomly assigning references
-        
-            //distfile, distFormat, dupsFile, dupsFormat, cutoff, percentage to be fitseqs - will randomly assign as fit
-            OptiData* matrix = new OptiRefMatrix(distfile, "column", dupsFile, nameOrCount, cutoff, fitPercent, refWeight);
+        if (selfReference) { //de novo
             
-            listFile = runDenovoOptiCluster(matrix, metric, counts, outputName);
-            
-            //evaluate results
-            bestListFileName = runSensSpec(columnfile, dupsFile, nameOrCount, metric, listFile);
-            
-            delete matrix;
-        }else if ((selfReference) && (accnosfile != "")) { //reference with accnos file assigning references
-            
-            //distfile, distFormat, dupsFile, dupsFormat, cutoff, accnos containing refseq name
-            OptiData* matrix = new OptiRefMatrix(distfile, "column", dupsFile, nameOrCount, cutoff, accnosfile);
-            
-            ListVector* list = runUserRefOptiCluster(matrix, metric, counts, outputName);
-            
-            if ((method == "open") && (printref)) { bestListFileName = runSensSpec(matrix, metric, list, counts); }
-            else {
-                ofstream listFile;
-                string listFileName = fileroot+ tag + ".list";
-                util.openOutputFile(listFileName,	listFile);
+            if ((accnosfile == "") && (!createAccnos)) { //denovo with mothur randomly assigning references
                 
-                if(countfile != "") { list->print(listFile, counts); }
-                else { list->print(listFile); }
-                listFile.close();
+                m->mothurOut("\nRandomly assigning reads from " + distfile + " as reference sequences\n");
                 
-                listFiles.push_back(listFileName);
+                //distfile, distFormat, dupsFile, dupsFormat, cutoff, percentage to be fitseqs - will randomly assign as fit
+                OptiData* matrix = new OptiRefMatrix(distfile, "column", dupsFile, nameOrCount, cutoff, fitPercent, refWeight);
                 
-                bestListFileName = runSensSpec(columnfile, dupsFile, nameOrCount, metric, listFileName);
+                listFile = runDenovoOptiCluster(matrix, metric, counts, outputName);
+                
+                //evaluate results
+                bestListFileName = runSensSpec(columnfile, dupsFile, nameOrCount, metric, listFile);
+                
+                delete matrix;
+                
+            }else { //reference with accnos file or reference list file assigning references
+                
+                set<string> refNames; vector<string> refLabels; vector< vector<string> > otus;
+                
+                if (accnosfile != "") { //use accnos file to assign references
+                    
+                    m->mothurOut("\nUsing sequences from " + accnosfile + " as reference sequences\n");
+                    
+                    refNames = util.readAccnos(accnosfile);
+                    
+                }else if (createAccnos) { //assign references based on reflist parameter
+                    
+                    m->mothurOut("\nUsing OTUs from " + reflistfile + " as reference OTUs\n");
+                    
+                    InputData input(reflistfile, "list", nullVector);
+                    set<string> processedLabels, userLabels;
+                    string lastLabel = "";
+                    
+                    ListVector* reflist = util.getNextList(input, true, userLabels, processedLabels, lastLabel);
+                    
+                    refLabels = reflist->getLabels();
+                    for (int i = 0; i < refLabels.size(); i++) { refLabels[i] = "Ref_" + refLabels[i];  }
+                    
+                    refNames = util.getSetFromList(reflist, otus); delete reflist;
+                }
+                
+                //distfile, distFormat, dupsFile, dupsFormat, cutoff, accnos containing refseq name
+                OptiData* matrix = new OptiRefMatrix(distfile, "column", dupsFile, nameOrCount, cutoff, refNames);
+                
+                //fit seqs
+                ListVector* list = runUserRefOptiCluster(matrix, metric, counts, outputName, refLabels, otus);
+                
+                if ((method == "open") && (printref)) { bestListFileName = runSensSpec(matrix, metric, list, counts); }
+                else {
+                    ofstream listFile;
+                    string listFileName = fileroot+ tag + ".list";
+                    util.openOutputFile(listFileName,    listFile);
+                    
+                    if(countfile != "") { list->print(listFile, counts); }
+                    else { list->print(listFile); }
+                    listFile.close();
+                    
+                    listFiles.push_back(listFileName);
+                    
+                    bestListFileName = runSensSpec(columnfile, dupsFile, nameOrCount, metric, listFileName);
+                }
+                delete list; delete matrix;
             }
-            delete list; delete matrix;
-            
-        }else if (!selfReference) { //reference with files containing reference seqs
+        }else { //reference with files containing reference seqs
             
             createReferenceNameCount(); //creates reference name or count file if needed
             
             calcDists();  //calc distance matrix for fasta file and distances between fasta file and reffasta file
             
+            m->mothurOut("\nUsing OTUs from " + reflistfile + " as reference OTUs\n");
+            
             //calc sens.spec values for reference
             InputData input(reflistfile, "list", nullVector);
             ListVector* list = input.getListVector();
@@ -609,10 +536,10 @@ string ClusterFitCommand::runDenovoOptiCluster(OptiData*& matrix, ClusterMetric*
             delete refList;
             
             long long numBins = cluster.getNumBins();
-            long long tp, tn, fp, fn;
+            double tp, tn, fp, fn;
             vector<double> results = cluster.getStats(tp, tn, fp, fn);
             
-            long long fittp, fittn, fitfp, fitfn;
+            double fittp, fittn, fitfp, fitfn;
             long long numFitBins = cluster.getNumFitBins();
             vector<double> fitresults = cluster.getFitStats(fittp, fittn, fitfp, fitfn);
             
@@ -676,9 +603,9 @@ string ClusterFitCommand::runDenovoOptiCluster(OptiData*& matrix, ClusterMetric*
     
 }
 //**********************************************************************************************************************
-ListVector* ClusterFitCommand::runUserRefOptiCluster(OptiData*& matrix, ClusterMetric*& metric, map<string, int>& counts, string outStepFile){
+ListVector* ClusterFitCommand::runUserRefOptiCluster(OptiData*& matrix, ClusterMetric*& metric, map<string, int>& counts, string outStepFile, vector<string> refListLabels, vector<vector<string> > otus){
     try {
-        m->mothurOut("\nClustering " + distfile + "\n");
+        
         bool printStepsHeader = true;
 
         OptiFitCluster cluster(matrix, metric, 0, criteria);
@@ -688,33 +615,37 @@ ListVector* ClusterFitCommand::runUserRefOptiCluster(OptiData*& matrix, ClusterM
         double listVectorMetric = 0; //worst state
         double delta = 1;
         
-        //get "ref" seqs for initialize inputs
-        OptiData* refMatrix = matrix->extractRefMatrix();
-        ListVector* refList = clusterRefs(refMatrix, metric); delete refMatrix;
-        
-        vector<vector<string> > otus;
-        for (int i = 0; i < refList->getNumBins(); i++) {
-            vector<string> binNames;
-            string bin = refList->get(i);
-            if (bin != "") {
-                util.splitAtComma(bin, binNames);
-                otus.push_back(binNames);
+        if (!createAccnos) {
+            
+            m->mothurOut("\nClustering references from " + distfile + "\n");
+            
+            //get "ref" seqs for initialize inputs
+            OptiData* refMatrix = matrix->extractRefMatrix();
+            ListVector* refList = clusterRefs(refMatrix, metric); delete refMatrix;
+            
+            for (int i = 0; i < refList->getNumBins(); i++) {
+                vector<string> binNames;
+                string bin = refList->get(i);
+                if (bin != "") {
+                    util.splitAtComma(bin, binNames);
+                    otus.push_back(binNames);
+                }
             }
+            
+            //add tag to OTULabels to indicate the reference
+            refListLabels = refList->getLabels();
+            for (int i = 0; i < refListLabels.size(); i++) { refListLabels[i] = "Ref_" + refListLabels[i];  }
+            refList->setLabels(refListLabels);
+            delete refList;
         }
         
-        //add tag to OTULabels to indicate the reference
-        vector<string> refListLabels = refList->getLabels();
-        for (int i = 0; i < refListLabels.size(); i++) { refListLabels[i] = "Ref_" + refListLabels[i];  }
-        refList->setLabels(refListLabels);
-        
-        cluster.initialize(listVectorMetric, true, otus, refList->getLabels(), method, true);
-        delete refList;
+        cluster.initialize(listVectorMetric, true, otus, refListLabels, method, true);
         
         long long numBins = cluster.getNumBins();
-        long long tp, tn, fp, fn;
+        double tp, tn, fp, fn;
         vector<double> results = cluster.getStats(tp, tn, fp, fn);
         
-        long long fittp, fittn, fitfp, fitfn;
+        double fittp, fittn, fitfp, fitfn;
         long long numFitBins = cluster.getNumFitBins();
         vector<double> fitresults = cluster.getFitStats(fittp, fittn, fitfp, fitfn);
         
@@ -774,7 +705,7 @@ ListVector* ClusterFitCommand::clusterRefs(OptiData*& refsMatrix, ClusterMetric*
         long long numBins = cluster.getNumBins();
         m->mothurOut("\n\niter\ttime\tlabel\tnum_otus\tcutoff\ttp\ttn\tfp\tfn\tsensitivity\tspecificity\tppv\tnpv\tfdr\taccuracy\tmcc\tf1score\n");
         
-        long long tp, tn, fp, fn;
+        double tp, tn, fp, fn;
         vector<double> results = cluster.getStats(tp, tn, fp, fn);
         m->mothurOut("0\t0\t" + toString(cutoff) + "\t" + toString(numBins) + "\t"+ toString(cutoff) + "\t" + toString(tp) + "\t" + toString(tn) + "\t" + toString(fp) + "\t" + toString(fn) + "\t");
         
@@ -851,10 +782,10 @@ string ClusterFitCommand::runRefOptiCluster(OptiData*& matrix, ClusterMetric*& m
         cluster.initialize(listVectorMetric, true, otus, refList->getLabels(), method, false);
         
         long long numBins = cluster.getNumBins();
-        long long tp, tn, fp, fn;
+        double tp, tn, fp, fn;
         vector<double> results = cluster.getStats(tp, tn, fp, fn);
         
-        long long fittp, fittn, fitfp, fitfn;
+        double fittp, fittn, fitfp, fitfn;
         long long numFitBins = cluster.getNumFitBins();
         vector<double> fitresults = cluster.getFitStats(fittp, fittn, fitfp, fitfn);
         
@@ -909,7 +840,7 @@ string ClusterFitCommand::runSensSpec(string distFName, string dupsfile, string
         
         ofstream sensSpecFile;
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(listFile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(listFile));
         string sensSpecFileName = getOutputFileName("sensspec",variables);
         util.openOutputFile(sensSpecFileName, sensSpecFile);
         outputNames.push_back(sensSpecFileName); outputTypes["sensspec"].push_back(sensSpecFileName);
@@ -935,13 +866,13 @@ string ClusterFitCommand::runSensSpec(string distFName, string dupsfile, string
                 int numBins = list->getNumBins();
                 
                 SensSpecCalc senscalc(matrix, list);
-                long long truePositives, trueNegatives, falsePositives, falseNegatives;
+                double truePositives, trueNegatives, falsePositives, falseNegatives;
                 senscalc.getResults(matrix, truePositives, trueNegatives, falsePositives, falseNegatives);
                 
-                long long tp =  truePositives;
-                long long fp =  falsePositives;
-                long long tn =  trueNegatives;
-                long long fn =  falseNegatives;
+                double tp =  truePositives;
+                double fp =  falsePositives;
+                double tn =  trueNegatives;
+                double fn =  falseNegatives;
                 
                 Sensitivity sens;   double sensitivity = sens.getValue(tp, tn, fp, fn);
                 Specificity spec;   double specificity = spec.getValue(tp, tn, fp, fn);
@@ -1031,13 +962,13 @@ string ClusterFitCommand::runSensSpec(string distFName, string dupsfile, string
                 
                 OptiMatrix matrix(thisDistFile, thisDupsFile, dupsFormat, "column", cutoff, false);
                 SensSpecCalc senscalc(matrix, list);
-                long long truePositives, trueNegatives, falsePositives, falseNegatives;
+                double truePositives, trueNegatives, falsePositives, falseNegatives;
                 senscalc.getResults(matrix, truePositives, trueNegatives, falsePositives, falseNegatives);
                 
-                long long tp =  truePositives;
-                long long fp =  falsePositives;
-                long long tn =  trueNegatives;
-                long long fn =  falseNegatives;
+                double tp =  truePositives;
+                double fp =  falsePositives;
+                double tn =  trueNegatives;
+                double fn =  falseNegatives;
                 
                 Sensitivity sens;   double sensitivity = sens.getValue(tp, tn, fp, fn);
                 Specificity spec;   double specificity = spec.getValue(tp, tn, fp, fn);
@@ -1082,7 +1013,7 @@ string ClusterFitCommand::runSensSpec(OptiData*& matrix, ClusterMetric*& userMet
 
         ofstream sensSpecFile;
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(listFileName));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(listFileName));
         string sensSpecFileName = getOutputFileName("sensspec",variables);
         util.openOutputFile(sensSpecFileName, sensSpecFile);
         outputNames.push_back(sensSpecFileName); outputTypes["sensspec"].push_back(sensSpecFileName);
@@ -1096,13 +1027,13 @@ string ClusterFitCommand::runSensSpec(OptiData*& matrix, ClusterMetric*& userMet
                 int numBins = list->getNumBins();
                 
                 SensSpecCalc senscalc(*matrix, list);
-                long long truePositives, trueNegatives, falsePositives, falseNegatives;
+                double truePositives, trueNegatives, falsePositives, falseNegatives;
                 senscalc.getResults(*matrix, truePositives, trueNegatives, falsePositives, falseNegatives);
                 
-                long long tp =  truePositives;
-                long long fp =  falsePositives;
-                long long tn =  trueNegatives;
-                long long fn =  falseNegatives;
+                double tp =  truePositives;
+                double fp =  falsePositives;
+                double tn =  trueNegatives;
+                double fn =  falseNegatives;
                 
                 Sensitivity sens;   double sensitivity = sens.getValue(tp, tn, fp, fn);
                 Specificity spec;   double specificity = spec.getValue(tp, tn, fp, fn);
@@ -1142,7 +1073,7 @@ string ClusterFitCommand::runSensSpec(OptiData*& matrix, ClusterMetric*& userMet
     }
 }
 //**********************************************************************************************************************
-void ClusterFitCommand::outputSteps(string outputName, bool& printHeaders, long long tp, long long tn, long long fp, long long fn, vector<double> results, long long numBins, long long fittp, long long fittn, long long fitfp, long long fitfn, vector<double> fitresults, long long numFitBins, int iter, bool printToFile, int denovoIter) {
+void ClusterFitCommand::outputSteps(string outputName, bool& printHeaders, double tp, double tn, double fp, double fn, vector<double> results, long long numBins, double fittp, double fittn, double fitfp, double fitfn, vector<double> fitresults, long long numFitBins, int iter, bool printToFile, int denovoIter) {
     try {
 
         if (!selfReference) { //writes to file as well
@@ -1227,7 +1158,6 @@ string ClusterFitCommand::calcDists() {
     try {
         if (columnfile == "") { //calc user distances
             string options = "fasta=" + fastafile + ", cutoff=" + toString(cutoff);
-            if (outputDir != "")                            { options += ", outputdir=" + outputDir;    }
             current->setMothurCalling(true);
             
             //calc dists for fastafile
@@ -1250,7 +1180,6 @@ string ClusterFitCommand::calcDists() {
         
         if (refAlignLength == alignLength) {
             string options = "fitcalc=t, fasta=" + reffastafile + ", oldfasta=" + fastafile + ", cutoff=" + toString(cutoff) + ", column=" + distfile;
-            if (outputDir != "")                            { options += ", outputdir=" + outputDir;    }
             
             //dists between reffasta and fastafile
             m->mothurOut("/******************************************/\n");
@@ -1267,7 +1196,6 @@ string ClusterFitCommand::calcDists() {
         }else {
             //filter each file to improve distance calc time
             string options = "fasta=" + reffastafile + ", vertical=t";
-            if (outputDir != "")                            { options += ", outputdir=" + outputDir;    }
             
             m->mothurOut("\nRunning vertical filter to improve distance calculation time\n\n");
             
@@ -1284,7 +1212,6 @@ string ClusterFitCommand::calcDists() {
             m->mothurOut("/******************************************/\n");
             
             options = "fasta=" + fastafile + ", reference=" + filteredRef;
-            if (outputDir != "")                            { options += ", outputdir=" + outputDir;    }
             
             //align fasta to refFasta
             m->mothurOut("/******************************************/\n");
@@ -1299,7 +1226,6 @@ string ClusterFitCommand::calcDists() {
             m->mothurOut("/******************************************/\n");
             
             options = "fitcalc=t, fasta=" + filteredRef + ", oldfasta=" + alignedFasta + ", cutoff=" + toString(cutoff) + ", column=" + distfile;
-            if (outputDir != "")                            { options += ", outputdir=" + outputDir;    }
             
             //dists between reffasta and fastafile
             m->mothurOut("/******************************************/\n");
