@@ -28,7 +28,6 @@ class ClusterFitCommand : public Command {
     
 public:
     ClusterFitCommand(string);
-    ClusterFitCommand();
     ~ClusterFitCommand();
     
     vector<string> setParameters();
@@ -44,19 +43,19 @@ public:
     void help() { m->mothurOut(getHelpString()); }
     
 private:
-    bool abort, sim, print_start, selfReference, printref;
+    bool abort, sim, print_start, selfReference, printref, createAccnos;
     string refdistfile, reffastafile, refnamefile, refcountfile, reflistfile, refNameOrCount;
     string namefile, refformat, distfile, countfile, fastafile, columnfile, nameOrCount, accnosfile;
     string comboDistFile;
     
-    string method, fileroot, tag, outputDir, inputDir, metric, initialize, metricName, criteria, refWeight;
+    string method, fileroot, tag,  inputDir, metric, initialize, metricName, criteria, refWeight;
     double cutoff, stableMetric;
     float adjust, fitPercent;
     int precision, length, maxIters, processors, denovoIters;
     vector<string> outputNames, listFiles;
     unsigned long loops;
     
-    ListVector* runUserRefOptiCluster(OptiData*&, ClusterMetric*&, map<string, int>&, string);
+    ListVector* runUserRefOptiCluster(OptiData*&, ClusterMetric*&, map<string, int>&, string, vector<string>, vector<vector<string> > );
     string runRefOptiCluster(OptiData*&, ClusterMetric*&, ListVector*&, map<string, int>&, string);
     string runDenovoOptiCluster(OptiData*&, ClusterMetric*&, map<string, int>&, string);
     ListVector* clusterRefs(OptiData*& refsMatrix, ClusterMetric*&);
@@ -64,7 +63,7 @@ private:
     string calcDists();
     string runSensSpec(OptiData*& matrix, ClusterMetric*& userMetric, ListVector*& list, map<string, int>& counts);
     string runSensSpec(string distFileName, string dupsFile, string dupsFormat, ClusterMetric*&, string);
-    void outputSteps(string outputName, bool& printHeaders, long long tp, long long tn, long long fp, long long fn, vector<double> results, long long numBins, long long fittp, long long fittn, long long fitfp, long long fitfn, vector<double> fitresults, long long numFitBins, int, bool, int);
+    void outputSteps(string outputName, bool& printHeaders, double tp, double tn, double fp, double fn, vector<double> results, long long numBins, double fittp, double fittn, double fitfp, double fitfn, vector<double> fitresults, long long numFitBins, int, bool, int);
 };
 
 #endif /* clusterfitcommand_hpp */
