@@ -36,6 +36,13 @@ vector<string> ClusterFragmentsCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["name"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -86,91 +93,29 @@ string ClusterFragmentsCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-ClusterFragmentsCommand::ClusterFragmentsCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-		outputTypes["name"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ClusterFragmentsCommand", "ClusterFragmentsCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 ClusterFragmentsCommand::ClusterFragmentsCommand(string option) {
 	try {
-		abort = false; calledHelp = false;   
-		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string, string>::iterator it;
-		
-			//check to make sure all parameters are valid for command
-			for (map<string, string>::iterator it2 = parameters.begin(); it2 != parameters.end(); it2++) { 
-				if (!validParameter.isValidParameter(it2->first, myArray, it2->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-			outputTypes["name"] = tempOutNames;
-            outputTypes["count"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-			}
-
-			//check for required parameters
 			fastafile = validParameter.validFile(parameters, "fasta");
 			if (fastafile == "not found") { 				
 				fastafile = current->getFastaFile(); 
-				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter.\n");  }
+				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required.\n");  abort = true; }
 			}
 			else if (fastafile == "not open") { fastafile = ""; abort = true; }	
 			else { current->setFastaFile(fastafile); }
 			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(fastafile); 	}
+			 
+			if (outputdir == ""){	outputdir = util.hasPath(fastafile); 	}
 
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
@@ -199,9 +144,7 @@ ClusterFragmentsCommand::ClusterFragmentsCommand(string option) {
                     if (!current->getMothurCalling())  {  parser.getNameFile(files);  }
                 }
             }
-			
 		}
-				
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ClusterFragmentsCommand", "ClusterFragmentsCommand");
@@ -221,7 +164,7 @@ int ClusterFragmentsCommand::execute(){
 		
 		if (m->getControl_pressed()) { return 0; }
 	
-		if (numSeqs == 0) { m->mothurOut("Error reading fasta file...please correct."); m->mothurOutEndLine(); return 0;  }
+		if (numSeqs == 0) { m->mothurOut("Error reading fasta file...please correct.\n");  return 0;  }
 		
 		//sort seqs by length of unaligned sequence
 		sort(alignSeqs.begin(), alignSeqs.end(), comparePriority);
@@ -269,7 +212,7 @@ int ClusterFragmentsCommand::execute(){
 		if(numSeqs % 100 != 0)	{ m->mothurOutJustToScreen(toString(numSeqs) + "\t" + toString(numSeqs - count) + "\t" + toString(count)+"\n");	}
 	
 		
-		string fileroot = outputDir + util.getRootName(util.getSimpleName(fastafile));
+		string fileroot = outputdir + util.getRootName(util.getSimpleName(fastafile));
         map<string, string> variables; 
         variables["[filename]"] = fileroot;
 		string newFastaFile = getOutputFileName("fasta", variables);
@@ -278,13 +221,12 @@ int ClusterFragmentsCommand::execute(){
 		
 		if (m->getControl_pressed()) { return 0; }
 		
-		m->mothurOutEndLine();
-		m->mothurOut("Total number of sequences before cluster.fragments was " + toString(alignSeqs.size()) + "."); m->mothurOutEndLine();
-		m->mothurOut("cluster.fragments removed " + toString(count) + " sequences."); m->mothurOutEndLine(); m->mothurOutEndLine(); 
+		m->mothurOut("\nTotal number of sequences before cluster.fragments was " + toString(alignSeqs.size()) + ".\n");
+		m->mothurOut("cluster.fragments removed " + toString(count) + " sequences.\n\n");   
 		
 		printData(newFastaFile, newNamesFile);
 		
-		m->mothurOut("It took " + toString(time(NULL) - start) + " secs to cluster " + toString(numSeqs) + " sequences."); m->mothurOutEndLine(); 
+		m->mothurOut("It took " + toString(time(NULL) - start) + " secs to cluster " + toString(numSeqs) + " sequences.\n");  
 		
 		if (m->getControl_pressed()) { util.mothurRemove(newFastaFile); util.mothurRemove(newNamesFile); return 0; }
 		
@@ -393,7 +335,7 @@ int ClusterFragmentsCommand::readFASTA(){
 				if (namefile != "") {
 					itSize = sizes.find(seq.getName());
 					
-					if (itSize == sizes.end()) { m->mothurOut(seq.getName() + " is not in your names file, please correct."); m->mothurOutEndLine(); exit(1); }
+					if (itSize == sizes.end()) { m->mothurOut(seq.getName() + " is not in your names file, please correct.\n");  exit(1); }
 					else{
 						seqRNode tempNode(itSize->second, seq, names[seq.getName()], seq.getUnaligned().length());
 						alignSeqs.push_back(tempNode);
