@@ -23,6 +23,11 @@ vector<string> CountSeqsCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+       
+        vector<string> tempOutNames;
+        outputTypes["count"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -66,86 +71,20 @@ string CountSeqsCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-CountSeqsCommand::CountSeqsCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["count"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "CountSeqsCommand", "CountSeqsCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 
 CountSeqsCommand::CountSeqsCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;
         allLines = true;
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string,string>::iterator it;
-			
-			//check to make sure all parameters are valid for command
-			for (map<string,string>::iterator it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["count"] = tempOutNames;
-			
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("shared");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["count"] = inputDir + it->second;		}
-                }
-			}
-			
-			//check for required parameters
 			namefile = validParameter.validFile(parameters, "name");
 			if (namefile == "not open") { namefile = ""; abort = true; }
 			else if (namefile == "not found"){	namefile = ""; }
@@ -186,8 +125,8 @@ CountSeqsCommand::CountSeqsCommand(string option)  {
             string temp = validParameter.valid(parameters, "compress");			if (temp == "not found") { temp = "t"; }
             compress = util.isTrue(temp);
 
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
+			 
+			
 		}
 		
 	}
@@ -209,8 +148,8 @@ int CountSeqsCommand::execute(){
             CountTable ct;
             ct.readTable(countfile, true, false, Groups);
             
-            if (outputDir == "") { outputDir = util.hasPath(countfile); }
-            variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(countfile));
+            if (outputdir == "") { outputdir = util.hasPath(countfile); }
+            variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(countfile));
             
             if (compress) {
                 variables["[distance]"] = "sparse";
@@ -226,8 +165,8 @@ int CountSeqsCommand::execute(){
                 ct.printTable(outputFileName, false);
             }
         }else if (namefile != "") {
-            if (outputDir == "") { outputDir = util.hasPath(namefile); }
-            variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(namefile));
+            if (outputdir == "") { outputdir = util.hasPath(namefile); }
+            variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(namefile));
             string outputFileName = getOutputFileName("count", variables);
             
             long start = time(NULL);
@@ -238,92 +177,28 @@ int CountSeqsCommand::execute(){
             m->mothurOut("\nIt took " + toString(time(NULL) - start) + " secs to create a table for " + toString(total) + " sequences.\n\n");
             m->mothurOut("Total number of sequences: " + toString(total) + "\n");
         }else {
-            if (outputDir == "") { outputDir = util.hasPath(sharedfile); }
-            variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile));
+            if (outputdir == "") { outputdir = util.hasPath(sharedfile); }
+            variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(sharedfile));
             
             InputData input(sharedfile, "sharedfile", Groups);
-            SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
-            Groups = lookup->getNamesGroups();
-            string lastLabel = lookup->getLabel();
-            vector<string> currentLabels = lookup->getOTUNames();
-            
-            //if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
             set<string> processedLabels;
             set<string> userLabels = labels;
+            string lastLabel = "";
             
-            //as long as you are not at the end of the file or done wih the lines you want
-            while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-                
-                if (m->getControl_pressed()) { delete lookup; for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
-                
-                if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
-                    
-                    m->mothurOut(lookup->getLabel()+"\n"); 
-                    vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
-                    processShared(data, variables, currentLabels);
-                    for(int i = 0; i < data.size(); i++) {  delete data[i]; } data.clear();
-                    
-                    processedLabels.insert(lookup->getLabel());
-                    userLabels.erase(lookup->getLabel());
-                }
-                
-                if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-                    string saveLabel = lookup->getLabel();
-                    
-                    delete lookup;
-                    lookup = input.getSharedRAbundVectors(lastLabel);
-                    m->mothurOut(lookup->getLabel()+"\n"); 
-                    
-                    vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
-                    processShared(data, variables, currentLabels);
-                    for(int i = 0; i < data.size(); i++) {  delete data[i]; } data.clear();
-                    
-                    processedLabels.insert(lookup->getLabel());
-                    userLabels.erase(lookup->getLabel());
-                    
-                    //restore real lastlabel to save below
-                    lookup->setLabels(saveLabel);
-                }
-                
-                lastLabel = lookup->getLabel();
-                //prevent memory leak
-                delete lookup;
-                
-                if (m->getControl_pressed()) { return 0; }
-                
-                //get next line to process
-                lookup = input.getSharedRAbundVectors();
-            }
+            SharedRAbundVectors* lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
+            vector<string> currentLabels = lookup->getOTUNames();
+            Groups = lookup->getNamesGroups();
             
-            if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); }  return 0; }
-            
-            //output error messages about any remaining user labels
-            set<string>::iterator it;
-            bool needToRun = false;
-            for (it = userLabels.begin(); it != userLabels.end(); it++) {
-                m->mothurOut("Your file does not include the label " + *it);
-                if (processedLabels.count(lastLabel) != 1) {
-                    m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-                    needToRun = true;
-                }else {
-                    m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-                }
-            }
-            
-            //run last label if you need to
-            if (needToRun )  {
-                delete lookup;
-                lookup = input.getSharedRAbundVectors(lastLabel);
+            while (lookup != NULL) {
                 
-                m->mothurOut(lookup->getLabel()+"\n"); 
+                if (m->getControl_pressed()) { delete lookup; break; }
                 
                 vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
                 processShared(data, variables, currentLabels);
-                for(int i = 0; i < data.size(); i++) {  delete data[i]; } data.clear();
+                for(int i = 0; i < data.size(); i++) {  delete data[i]; } data.clear(); delete lookup;
                 
-               delete lookup;
+                lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
             }
-            
         }
         
         //set rabund file as new current rabundfile
