@@ -20,6 +20,13 @@ vector<string> DeconvoluteCommand::setParameters(){
         CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+       
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["name"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -65,95 +72,30 @@ string DeconvoluteCommand::getOutputPattern(string type) {
         exit(1);
     }
 }
-
-//**********************************************************************************************************************
-DeconvoluteCommand::DeconvoluteCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-		outputTypes["name"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "DeconvoluteCommand", "DeconvoluteCommand");
-		exit(1);
-	}
-}
 /**************************************************************************************/
 DeconvoluteCommand::DeconvoluteCommand(string option)  {	
 	try {
-		abort = false; calledHelp = false;   
-		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string, string>::iterator it;
-		
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-			outputTypes["name"] = tempOutNames;
-            outputTypes["count"] = tempOutNames;
-		
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-			}
-
-			
-			//check for required parameters
 			fastafile = validParameter.validFile(parameters, "fasta");
 			if (fastafile == "not open") { abort = true; }
 			else if (fastafile == "not found") {
 				fastafile = current->getFastaFile();
-				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter.\n");  }
+				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required.\n");  abort = true; }
 			}else { current->setFastaFile(fastafile); }
 			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	
-				outputDir = "";	
-				outputDir += util.hasPath(fastafile); //if user entered a file with a path then preserve it
+			 
+            if (outputdir == ""){
+				outputdir += util.hasPath(fastafile); 
 			}
 			
 			namefile = validParameter.validFile(parameters, "name");
@@ -166,7 +108,7 @@ DeconvoluteCommand::DeconvoluteCommand(string option)  {
 			else if (countfile == "not found") { countfile = ""; }
 			else { current->setCountFile(countfile); }
 			
-            if ((countfile != "") && (namefile != "")) { m->mothurOut("When executing a unique.seqs command you must enter ONLY ONE of the following: count or name."); m->mothurOutEndLine(); abort = true; }
+            if ((countfile != "") && (namefile != "")) { m->mothurOut("When executing a unique.seqs command you must enter ONLY ONE of the following: count or name.\n");  abort = true; }
 			
             format = validParameter.valid(parameters, "format");
             if(format == "not found"){
@@ -203,7 +145,7 @@ int DeconvoluteCommand::execute() {
         
 		//prepare filenames and open files
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastafile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
         string outNameFile = getOutputFileName("name", variables);
         string outCountFile = getOutputFileName("count", variables);
         variables["[extension]"] = util.getExtension(fastafile);
@@ -216,7 +158,7 @@ int DeconvoluteCommand::execute() {
             if (namefile == outNameFile){
                 //prepare filenames and open files
                 map<string, string> mvariables;
-                mvariables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastafile));
+                mvariables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
                 mvariables["[tag]"] = "unique";
                 outNameFile = getOutputFileName("name", mvariables);
             }
@@ -227,7 +169,7 @@ int DeconvoluteCommand::execute() {
             if (countfile == outCountFile){
                 //prepare filenames and open files
                 map<string, string> mvariables;
-                mvariables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastafile));
+                mvariables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
                 mvariables["[tag]"] = "unique";
                 outCountFile = getOutputFileName("count", mvariables);   }
         }
@@ -258,7 +200,7 @@ int DeconvoluteCommand::execute() {
 				//sanity checks
 				itname = nameInFastaFile.find(seq.getName());
 				if (itname == nameInFastaFile.end()) { nameInFastaFile.insert(seq.getName());  }
-				else { m->mothurOut("[ERROR]: You already have a sequence named " + seq.getName() + " in your fasta file, sequence names must be unique, please correct."); m->mothurOutEndLine(); }
+				else { m->mothurOut("[ERROR]: You already have a sequence named " + seq.getName() + " in your fasta file, sequence names must be unique, please correct.\n");  }
 
 				itStrings = sequenceStrings.find(seq.getAligned());
 				
@@ -270,7 +212,7 @@ int DeconvoluteCommand::execute() {
 						itNames = nameMap.find(seq.getName());
 						
 						if (itNames == nameMap.end()) { //namefile and fastafile do not match
-							m->mothurOut("[ERROR]: " + seq.getName() + " is in your fasta file, and not in your namefile, please correct."); m->mothurOutEndLine();
+							m->mothurOut("[ERROR]: " + seq.getName() + " is in your fasta file, and not in your namefile, please correct.\n"); 
 						}else {
                             if (format == "name") { sequenceStrings[seq.getAligned()] = itNames->second;  nameFileOrder.push_back(seq.getAligned());
                             }else {  newCt.push_back(seq.getName(), util.getNumNames(itNames->second)); sequenceStrings[seq.getAligned()] = seq.getName();	nameFileOrder.push_back(seq.getAligned()); }
@@ -294,7 +236,7 @@ int DeconvoluteCommand::execute() {
 						itNames = nameMap.find(seq.getName());
 						
 						if (itNames == nameMap.end()) { //namefile and fastafile do not match
-							m->mothurOut("[ERROR]: " + seq.getName() + " is in your fasta file, and not in your namefile, please correct."); m->mothurOutEndLine();
+							m->mothurOut("[ERROR]: " + seq.getName() + " is in your fasta file, and not in your namefile, please correct.\n"); 
 						}else {
                             if (format == "name") { sequenceStrings[seq.getAligned()] += "," + itNames->second;  }
                             else {  int currentReps = newCt.getNumSeqs(itStrings->second);  newCt.setNumSeqs(itStrings->second, currentReps+(util.getNumNames(itNames->second)));  }
@@ -358,7 +300,7 @@ int DeconvoluteCommand::execute() {
                     if (countfile != "") {  ct.printSeq(outNames, itStrings->second);  }
                     else if (format == "count")  {  newCt.printSeq(outNames, itStrings->second);  }
                 }
-			}else{ m->mothurOut("[ERROR]: mismatch in namefile print."); m->mothurOutEndLine(); m->setControl_pressed(true); }
+			}else{ m->mothurOut("[ERROR]: mismatch in namefile print.\n");  m->setControl_pressed(true); }
 		}
 		outNames.close();
 		
