@@ -21,7 +21,6 @@ class DeconvoluteCommand : public Command {
 
 public:
 	DeconvoluteCommand(string);
-	DeconvoluteCommand();
 	~DeconvoluteCommand() {}
 	
 	vector<string> setParameters();
@@ -39,7 +38,7 @@ public:
 	
 	
 private:
-	string fastafile, namefile, outputDir, countfile, format;
+	string fastafile, namefile,  countfile, format;
 	vector<string> outputNames;
 
 	bool abort;
