@@ -18,7 +18,6 @@
 class DegapSeqsCommand : public Command {
 public:
 	DegapSeqsCommand(string);
-	DegapSeqsCommand();
 	~DegapSeqsCommand(){}
 	
 	vector<string> setParameters();
@@ -37,7 +36,7 @@ private:
     
     int processors;
 	bool abort;
-	string fastafile, outputDir;
+	string fastafile;
 	vector<string> outputNames;
     
     long long createProcesses(string, string);
