@@ -26,6 +26,12 @@ vector<string> DistanceCommand::setParameters(){
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
 		
+        abort = false; calledHelp = false;
+       
+        vector<string> tempOutNames;
+        outputTypes["phylip"] = tempOutNames;
+        outputTypes["column"] = tempOutNames;
+        
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
 		return myArray;
@@ -76,92 +82,29 @@ string DistanceCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-DistanceCommand::DistanceCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["phylip"] = tempOutNames;
-		outputTypes["column"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "DistanceCommand", "DistanceCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 DistanceCommand::DistanceCommand(string option) {
 	try {
-		abort = false; calledHelp = false;   
-		Estimators.clear();
-				
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters();
 			
-			ValidParameters validParameter("dist.seqs");
-			map<string, string>::iterator it2;
-		
-			//check to make sure all parameters are valid for command
-			for (it2 = parameters.begin(); it2 != parameters.end(); it2++) { 
-				if (validParameter.isValidParameter(it2->first, myArray, it2->second) != true) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["phylip"] = tempOutNames;
-			outputTypes["column"] = tempOutNames;
-		
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it2 = parameters.find("fasta");
-				//user has given a template file
-				if(it2 != parameters.end()){ 
-					path = util.hasPath(it2->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it2->second;		}
-				}
-				
-				it2 = parameters.find("oldfasta");
-				//user has given a template file
-				if(it2 != parameters.end()){ 
-					path = util.hasPath(it2->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["oldfasta"] = inputDir + it2->second;		}
-				}
-				
-				it2 = parameters.find("column");
-				//user has given a template file
-				if(it2 != parameters.end()){ 
-					path = util.hasPath(it2->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["column"] = inputDir + it2->second;		}
-				}
-			}
-
-			//check for required parameters
+			ValidParameters validParameter;
 			fastafile = validParameter.validFile(parameters, "fasta");
 			if (fastafile == "not found") { 				
 				fastafile = current->getFastaFile(); 
-				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter."); m->mothurOutEndLine(); 
-					ifstream inFASTA;
-					util.openInputFile(fastafile, inFASTA);
+				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter.\n");
+					ifstream inFASTA; util.openInputFile(fastafile, inFASTA);
 					alignDB = SequenceDB(inFASTA); 
 					inFASTA.close();
-				}else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
+				}else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required.\n"); abort = true; }
 			}else if (fastafile == "not open") { abort = true; }	
 			else{
-				ifstream inFASTA;
-				util.openInputFile(fastafile, inFASTA);
+				ifstream inFASTA; util.openInputFile(fastafile, inFASTA);
 				alignDB = SequenceDB(inFASTA); 
 				inFASTA.close();
 				current->setFastaFile(fastafile);
@@ -176,10 +119,8 @@ DistanceCommand::DistanceCommand(string option) {
 			else if (column == "not open") { abort = true; }	
 			else { current->setColumnFile(column); }
 			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	
-				outputDir = "";	
-				outputDir += util.hasPath(fastafile); //if user entered a file with a path then preserve it	
+            if (outputdir == ""){
+				outputdir += util.hasPath(fastafile); 
 			}
 
 			//check for optional parameter and set defaults
@@ -189,7 +130,6 @@ DistanceCommand::DistanceCommand(string option) {
 			else { 
 				 if (calc == "default")  {  calc = "onegap";  }
 			}
-			util.splitAtDash(calc, Estimators);
 
 			string temp;
 			temp = validParameter.valid(parameters, "countends");	if(temp == "not found"){	temp = "T";	}
@@ -210,14 +150,15 @@ DistanceCommand::DistanceCommand(string option) {
 			output = validParameter.valid(parameters, "output");		if(output == "not found"){	output = "column"; }
             if (output == "phylip") { output = "lt";  }
 			
-			if (((column != "") && (oldfastafile == "")) || ((column == "") && (oldfastafile != ""))) { m->mothurOut("If you provide column or oldfasta, you must provide both."); m->mothurOutEndLine(); abort=true; }
+			if (((column != "") && (oldfastafile == "")) || ((column == "") && (oldfastafile != ""))) { m->mothurOut("If you provide column or oldfasta, you must provide both.\n");  abort=true; }
 			
-			if ((column != "") && (oldfastafile != "") && (output != "column")) { m->mothurOut("You have provided column and oldfasta, indicating you want to append distances to your column file. Your output must be in column format to do so."); m->mothurOutEndLine(); abort=true; }
+			if ((column != "") && (oldfastafile != "") && (output != "column")) { m->mothurOut("You have provided column and oldfasta, indicating you want to append distances to your column file. Your output must be in column format to do so.\n"); abort=true; }
 			
-			if ((output != "column") && (output != "lt") && (output != "square")) { m->mothurOut(output + " is not a valid output form. Options are column, lt and square. I will use column."); m->mothurOutEndLine(); output = "column"; }
+			if ((output != "column") && (output != "lt") && (output != "square")) { m->mothurOut(output + " is not a valid output form. Options are column, lt and square. I will use column.\n");  output = "column"; }
+            
+            if ((calc != "onegap") && (calc != "eachgap") && (calc != "nogaps")) { m->mothurOut(calc + " is not a valid output form. Options are eachgap, onegap and nogaps. I'll use onegap.\n");  calc = "onegap";  }
 
 		}
-				
 	}
 	catch(exception& e) {
 		m->errorOut(e, "DistanceCommand", "DistanceCommand");
@@ -235,7 +176,70 @@ int DistanceCommand::execute(){
 		
 		//save number of new sequence
 		numNewFasta = alignDB.getNumSeqs();
-		
+        
+        if (false) {
+            DistCalc* distCalculator;
+            if (countends) {
+                if (calc == "nogaps")            {    distCalculator = new ignoreGaps(cutoff);    }
+                else if (calc == "eachgap")    {    distCalculator = new eachGapDist(cutoff);    }
+                else if (calc == "onegap")        {    distCalculator = new oneGapDist(cutoff);    }
+            }else {
+                if (calc == "nogaps")        {    distCalculator = new ignoreGaps(cutoff);                    }
+                else if (calc == "eachgap"){    distCalculator = new eachGapIgnoreTermGapDist(cutoff);    }
+                else if (calc == "onegap")    {    distCalculator = new oneGapIgnoreTermGapDist(cutoff);        }
+            }
+            
+            Sequence seqI = alignDB.get(0);
+            vector<int> colsToUse;
+            for (int i = 0; i < seqI.getAligned().length(); i++) {
+                if (i % 8 == 0){ colsToUse.push_back(i); cout << i << endl; }
+            }
+            for(int i=0;i<numNewFasta;i++){
+                
+                Sequence seqI = alignDB.get(i);
+                
+                for(int j=0;j<i;j++){
+                    
+                    if (m->getControl_pressed()) { break;  }
+                    
+                    Sequence seqJ = alignDB.get(j);
+                    double dist = distCalculator->calcDist(seqI, seqJ);
+                    
+                    cout << "seq2seq Dist = "  << dist << endl;
+                    
+                    string seqISampledAligned = ""; string seqJSampledAligned = "";
+                    for (int k = 0; k < colsToUse.size(); k++) {
+                        seqISampledAligned += seqI.getAligned()[colsToUse[k]];
+                        seqJSampledAligned += seqJ.getAligned()[colsToUse[k]];
+                    }
+                    Sequence sampledI("sampledI", seqISampledAligned);
+                    Sequence sampledJ("sampledJ", seqJSampledAligned);
+                    
+                    classifierOTU seqJOTU(seqJ.getAligned());
+                    vector<double> distOTU = distCalculator->calcDist(seqI, seqJOTU, nullIntVector);
+                    
+                    cout << "seq2OTU Dist = " << distOTU[0] << endl;
+                    
+                    vector<string> thisAligned; thisAligned.push_back(seqJ.getAligned());  thisAligned.push_back(seqI.getAligned());
+                    
+                    classifierOTU seqAOTU(thisAligned);
+                    
+                    //cout << seqISampledAligned << endl << seqJSampledAligned << endl;
+                    
+                    dist = distCalculator->calcDist(sampledI, sampledJ);
+                    
+                    cout << "sampled seq2seq dist = " << dist << endl;
+                    
+                    distOTU = distCalculator->calcDist(seqI, seqAOTU, colsToUse);
+                    
+                    for (int k = 0; k < distOTU.size(); k++) {
+                        cout << "sampled seq2OTU dist = "  << distOTU[k] << endl;
+                    }
+                }
+            }
+            
+            delete distCalculator;
+        }
 		//sanity check the oldfasta and column file as well as add oldfasta sequences to alignDB
         if ((oldfastafile != "") && (column != ""))  {	if (!(sanityCheck())) { return 0; }  }
 		
@@ -243,12 +247,12 @@ int DistanceCommand::execute(){
 		
 		numSeqs = alignDB.getNumSeqs();
 		
-		if (!alignDB.sameLength()) {  m->mothurOut("[ERROR]: your sequences are not the same length, aborting."); m->mothurOutEndLine(); return 0; }
+		if (!alignDB.sameLength()) {  m->mothurOut("[ERROR]: your sequences are not the same length, aborting.\n");  return 0; }
 		
 		string outputFile;
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastafile));
-        if ((oldfastafile != "") && (column != ""))  { variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(oldfastafile)); }
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
+        if ((oldfastafile != "") && (column != ""))  { variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(oldfastafile)); }
             
 		if (output == "lt") { //does the user want lower triangle phylip formatted file 
             variables["[outputtag]"] = "phylip";
@@ -323,8 +327,8 @@ int DistanceCommand::execute(){
 		m->mothurOut(outputFile+"\n\n");
 		
 		if (util.isTrue(compress)) {
-			m->mothurOut("Compressing..."); m->mothurOutEndLine();
-			m->mothurOut("(Replacing " + outputFile + " with " + outputFile + ".gz)"); m->mothurOutEndLine();
+			m->mothurOut("Compressing...\n"); 
+			m->mothurOut("(Replacing " + outputFile + " with " + outputFile + ".gz)\n"); 
 			system(("gzip -v " + outputFile).c_str());
 			outputNames.push_back(outputFile + ".gz");
 		}else { outputNames.push_back(outputFile); }
@@ -343,21 +347,21 @@ void driverColumn(distanceData* params){
         ValidCalculators validCalculator;
         DistCalc* distCalculator;
         if (params->countends) {
-            if (validCalculator.isValidCalculator("distance", params->Estimator) ) {
-                if (params->Estimator == "nogaps")			{	distCalculator = new ignoreGaps();	}
-                else if (params->Estimator == "eachgap")	{	distCalculator = new eachGapDist();	}
-                else if (params->Estimator == "onegap")		{	distCalculator = new oneGapDist();	}
+            if (validCalculator.isValidCalculator("distance", params->calc) ) {
+                if (params->calc == "nogaps")			{	distCalculator = new ignoreGaps(params->cutoff);	}
+                else if (params->calc == "eachgap")	{	distCalculator = new eachGapDist(params->cutoff);	}
+                else if (params->calc == "onegap")		{	distCalculator = new oneGapDist(params->cutoff);	}
             }
         }else {
-            if (validCalculator.isValidCalculator("distance", params->Estimator) ) {
-                if (params->Estimator == "nogaps")		{	distCalculator = new ignoreGaps();					}
-                else if (params->Estimator == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-                else if (params->Estimator == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
+            if (validCalculator.isValidCalculator("distance", params->calc) ) {
+                if (params->calc == "nogaps")		{	distCalculator = new ignoreGaps(params->cutoff);					}
+                else if (params->calc == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist(params->cutoff);	}
+                else if (params->calc == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist(params->cutoff);		}
             }
         }
         
         int startTime = time(NULL);
-        
+       
         params->count = 0;
         string buffer = "";
         for(int i=params->startLine;i<params->endLine;i++){
@@ -383,6 +387,8 @@ void driverColumn(distanceData* params){
         }
         params->threadWriter->write(buffer);
         
+        if((params->endLine-1) % 100 != 0){ params->m->mothurOutJustToScreen(toString(params->endLine-1) + "\t" + toString(time(NULL) - startTime) + "\t" + toString(params->count) +"\n"); }
+        
         delete distCalculator;
     }
     catch(exception& e) {
@@ -395,17 +401,18 @@ void driverLt(distanceData* params){
     try {
         ValidCalculators validCalculator;
         DistCalc* distCalculator;
+        double cutoff = 1.0;
         if (params->countends) {
-            if (validCalculator.isValidCalculator("distance", params->Estimator) ) {
-                if (params->Estimator == "nogaps")			{	distCalculator = new ignoreGaps();	}
-                else if (params->Estimator == "eachgap")	{	distCalculator = new eachGapDist();	}
-                else if (params->Estimator == "onegap")		{	distCalculator = new oneGapDist();	}
+            if (validCalculator.isValidCalculator("distance", params->calc) ) {
+                if (params->calc == "nogaps")			{	distCalculator = new ignoreGaps(cutoff);	}
+                else if (params->calc == "eachgap")	{	distCalculator = new eachGapDist(cutoff);	}
+                else if (params->calc == "onegap")		{	distCalculator = new oneGapDist(cutoff);	}
             }
         }else {
-            if (validCalculator.isValidCalculator("distance", params->Estimator) ) {
-                if (params->Estimator == "nogaps")		{	distCalculator = new ignoreGaps();					}
-                else if (params->Estimator == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-                else if (params->Estimator == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
+            if (validCalculator.isValidCalculator("distance", params->calc) ) {
+                if (params->calc == "nogaps")		{	distCalculator = new ignoreGaps(cutoff);					}
+                else if (params->calc == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist(cutoff);	}
+                else if (params->calc == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist(cutoff);		}
             }
         }
         
@@ -446,6 +453,8 @@ void driverLt(distanceData* params){
             
         }
         
+        if((params->endLine-1) % 100 != 0){ params->m->mothurOutJustToScreen(toString(params->endLine-1) + "\t" + toString(time(NULL) - startTime) + "\t" + toString(params->count) +"\n"); }
+        
         outFile.close();
         delete distCalculator;
     }
@@ -459,17 +468,18 @@ void driverSquare(distanceData* params){
     try {
         ValidCalculators validCalculator;
         DistCalc* distCalculator;
+        double cutoff = 1.0;
         if (params->countends) {
-            if (validCalculator.isValidCalculator("distance", params->Estimator) ) {
-                if (params->Estimator == "nogaps")			{	distCalculator = new ignoreGaps();	}
-                else if (params->Estimator == "eachgap")	{	distCalculator = new eachGapDist();	}
-                else if (params->Estimator == "onegap")		{	distCalculator = new oneGapDist();	}
+            if (validCalculator.isValidCalculator("distance", params->calc) ) {
+                if (params->calc == "nogaps")			{	distCalculator = new ignoreGaps(cutoff);	}
+                else if (params->calc == "eachgap")	{	distCalculator = new eachGapDist(cutoff);	    }
+                else if (params->calc == "onegap")		{	distCalculator = new oneGapDist(cutoff);	}
             }
         }else {
-            if (validCalculator.isValidCalculator("distance", params->Estimator) ) {
-                if (params->Estimator == "nogaps")		{	distCalculator = new ignoreGaps();					}
-                else if (params->Estimator == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-                else if (params->Estimator == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
+            if (validCalculator.isValidCalculator("distance", params->calc) ) {
+                if (params->calc == "nogaps")		{	distCalculator = new ignoreGaps(cutoff);					}
+                else if (params->calc == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist(cutoff);	}
+                else if (params->calc == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist(cutoff);		}
             }
         }
         int startTime = time(NULL);
@@ -508,6 +518,8 @@ void driverSquare(distanceData* params){
             if(i % 100 == 0){ params->m->mothurOutJustToScreen(toString(i) + "\t" + toString(time(NULL) - startTime) + "\t" + toString(params->count) +"\n");  }
         }
         
+        if((params->endLine-1) % 100 != 0){ params->m->mothurOutJustToScreen(toString(params->endLine-1) + "\t" + toString(time(NULL) - startTime) + "\t" + toString(params->count) +"\n"); }
+        
         outFile.close();
         delete distCalculator;
     }
@@ -522,16 +534,16 @@ void driverFitCalc(distanceData* params){
         ValidCalculators validCalculator;
         DistCalc* distCalculator;
         if (params->countends) {
-            if (validCalculator.isValidCalculator("distance", params->Estimator) ) {
-                if (params->Estimator == "nogaps")			{	distCalculator = new ignoreGaps();	}
-                else if (params->Estimator == "eachgap")	{	distCalculator = new eachGapDist();	}
-                else if (params->Estimator == "onegap")		{	distCalculator = new oneGapDist();	}
+            if (validCalculator.isValidCalculator("distance", params->calc) ) {
+                if (params->calc == "nogaps")			{	distCalculator = new ignoreGaps(params->cutoff);	}
+                else if (params->calc == "eachgap")	{	distCalculator = new eachGapDist(params->cutoff);	}
+                else if (params->calc == "onegap")		{	distCalculator = new oneGapDist(params->cutoff);	}
             }
         }else {
-            if (validCalculator.isValidCalculator("distance", params->Estimator) ) {
-                if (params->Estimator == "nogaps")		{	distCalculator = new ignoreGaps();					}
-                else if (params->Estimator == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-                else if (params->Estimator == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
+            if (validCalculator.isValidCalculator("distance", params->calc) ) {
+                if (params->calc == "nogaps")		{	distCalculator = new ignoreGaps(params->cutoff);					}
+                else if (params->calc == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist(params->cutoff);	}
+                else if (params->calc == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist(params->cutoff);		}
             }
         }
         
@@ -559,6 +571,8 @@ void driverFitCalc(distanceData* params){
         }
         params->threadWriter->write(buffer);
         
+        if((params->endLine-1) % 100 != 0){ params->m->mothurOutJustToScreen(toString(params->endLine-1) + "\t" + toString(time(NULL) - startTime) + "\t" + toString(params->count) +"\n"); }
+        
         delete distCalculator;
 
     }
@@ -576,10 +590,10 @@ void DistanceCommand::createProcesses(string filename) {
         time(&start);
         
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<distanceData*> data;
         
-        unsigned long long numDists = 0;
+        double numDists = 0;
         
         if (output == "square") { numDists = numSeqs * numSeqs; }
         else { for(int i=0;i<numSeqs;i++){ for(int j=0;j<i;j++){ numDists++; if (numDists > processors) { break; } } } }
@@ -630,16 +644,16 @@ void DistanceCommand::createProcesses(string filename) {
                 threadWriter = new OutputWriter(synchronizedOutputFile);
                 dataBundle = new distanceData(threadWriter);
             }else { dataBundle = new distanceData(filename+extension); }
-            dataBundle->setVariables(lines[i+1].start, lines[i+1].end, cutoff, alignDB, oldFastaDB, Estimators[0], numNewFasta, countends);
+            dataBundle->setVariables(lines[i+1].start, lines[i+1].end, cutoff, alignDB, oldFastaDB, calc, numNewFasta, countends);
             data.push_back(dataBundle);
             
-            thread* thisThread = NULL;
+            std::thread* thisThread = NULL;
             if (output == "column")     {
-                if (fitCalc)    { thisThread = new thread(driverFitCalc, dataBundle);   }
-                else            {  thisThread = new thread(driverColumn, dataBundle);   }
+                if (fitCalc)    { thisThread = new std::thread(driverFitCalc, dataBundle);   }
+                else            {  thisThread = new std::thread(driverColumn, dataBundle);   }
             }
-            else if (output == "lt")    { thisThread = new thread(driverLt, dataBundle);            }
-            else                        { thisThread = new thread(driverSquare, dataBundle);        }
+            else if (output == "lt")    { thisThread = new std::thread(driverLt, dataBundle);            }
+            else                        { thisThread = new std::thread(driverSquare, dataBundle);        }
             workerThreads.push_back(thisThread);
         }
         
@@ -649,7 +663,7 @@ void DistanceCommand::createProcesses(string filename) {
             threadWriter = new OutputWriter(synchronizedOutputFile);
             dataBundle = new distanceData(threadWriter);
         }else { dataBundle = new distanceData(filename); }
-        dataBundle->setVariables(lines[0].start, lines[0].end, cutoff, alignDB, oldFastaDB, Estimators[0], numNewFasta, countends);
+        dataBundle->setVariables(lines[0].start, lines[0].end, cutoff, alignDB, oldFastaDB, calc, numNewFasta, countends);
         
         if (output == "column")     {
             if (fitCalc)    { driverFitCalc(dataBundle);    }
@@ -712,7 +726,7 @@ bool DistanceCommand::sanityCheck() {
 		}
 		in2.close();
 		
-		if (fastaAlignLength != oldfastaAlignLength) { m->mothurOut("fasta files do not have the same alignment length."); m->mothurOutEndLine(); return false;  }
+		if (fastaAlignLength != oldfastaAlignLength) { m->mothurOut("fasta files do not have the same alignment length.\n");  return false;  }
 		
         //read fasta file and save names as well as adding them to the alignDB
         set<string> namesOldFasta;
