@@ -23,6 +23,12 @@ vector<string> FilterSeqsCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["filter"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -39,8 +45,8 @@ string FilterSeqsCommand::getHelpString(){
 		string helpString = "";
 		helpString += "The filter.seqs command reads a file containing sequences and creates a .filter and .filter.fasta file.\n";
 		helpString += "The filter.seqs command parameters are fasta, trump, soft, hard, processors and vertical. \n";
-		helpString += "The fasta parameter is required, unless you have a valid current fasta file. You may enter several fasta files to build the filter from and filter, by separating their names with -'s.\n";
-		helpString += "For example: fasta=abrecovery.fasta-amazon.fasta \n";
+		helpString += "The fasta parameter is required, unless you have a valid current fasta file. You may enter several fasta files to build the filter from and filter, by separating their names with |'s.\n";
+		helpString += "For example: fasta=abrecovery.fasta|amazon.fasta \n";
 		helpString += "The trump option will remove a column if the trump character is found at that position in any sequence of the alignment. Default=*, meaning no trump. \n";
 		helpString += "A soft mask removes any column where the dominant base (i.e. A, T, G, C, or U) does not occur in at least a designated percentage of sequences. Default=0.\n";
 		helpString += "The hard parameter allows you to enter a file containing the filter you want to use.\n";
@@ -73,85 +79,34 @@ string FilterSeqsCommand::getOutputPattern(string type) {
         exit(1);
     }
 }
-//**********************************************************************************************************************
-FilterSeqsCommand::FilterSeqsCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-		outputTypes["filter"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "FilterSeqsCommand", "FilterSeqsCommand");
-		exit(1);
-	}
-}
 /**************************************************************************************/
 FilterSeqsCommand::FilterSeqsCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;  recalced = false;
-		filterFileName = "";
+		recalced = false; filterFileName = "";
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
-			ValidParameters validParameter("filter.seqs");
-			map<string,string>::iterator it;
-			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-			outputTypes["filter"] = tempOutNames;
-		
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("hard");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["hard"] = inputDir + it->second;		}
-				}
-			}
-			
-			//check for required parameters
+			ValidParameters validParameter;
 			fasta = validParameter.valid(parameters, "fasta");
 			if (fasta == "not found") { 				
 				fasta = current->getFastaFile(); 
 				if (fasta != "") { 
                     fastafileNames.push_back(fasta);  
-                    m->mothurOut("Using " + fasta + " as input file for the fasta parameter."); m->mothurOutEndLine();
+                    m->mothurOut("Using " + fasta + " as input file for the fasta parameter.\n");
                     string simpleName = util.getSimpleName(fasta);
                     filterFileName += simpleName.substr(0, simpleName.find_first_of('.'));
                 }
-				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
+				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required.\n");  abort = true; }
 			}
 			else { 
-				util.splitAtDash(fasta, fastafileNames);
+				util.splitAtChar(fasta, fastafileNames, '|');
 				
 				//go through files and make sure they are good, if not, then disregard them
 				for (int i = 0; i < fastafileNames.size(); i++) {
@@ -159,9 +114,9 @@ FilterSeqsCommand::FilterSeqsCommand(string option)  {
 					bool ignore = false;
 					if (fastafileNames[i] == "current") { 
 						fastafileNames[i] = current->getFastaFile(); 
-						if (fastafileNames[i] != "") {  m->mothurOut("Using " + fastafileNames[i] + " as input file for the fasta parameter where you had given current."); m->mothurOutEndLine(); }
+						if (fastafileNames[i] != "") {  m->mothurOut("Using " + fastafileNames[i] + " as input file for the fasta parameter where you had given current.\n");  }
 						else { 	
-							m->mothurOut("You have no current fastafile, ignoring current."); m->mothurOutEndLine(); ignore=true; 
+							m->mothurOut("You have no current fastafile, ignoring current.\n"); ignore=true;
 							//erase from file list
 							fastafileNames.erase(fastafileNames.begin()+i);
 							i--;
@@ -179,19 +134,17 @@ FilterSeqsCommand::FilterSeqsCommand(string option)  {
                 }
 				
 				//make sure there is at least one valid file left
-				if (fastafileNames.size() == 0) { m->mothurOut("no valid files."); m->mothurOutEndLine(); abort = true; }
+				if (fastafileNames.size() == 0) { m->mothurOut("no valid files.\n");  abort = true; }
 			}
 			
 			if (!abort) {
-				//if the user changes the output directory command factory will send this info to us in the output parameter 
-				outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	
-					outputDir = "";	
-					outputDir += util.hasPath(fastafileNames[0]); //if user entered a file with a path then preserve it	
+				 
+                if (outputdir == ""){
+					outputdir += util.hasPath(fastafileNames[0]);
 				}
 			}
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
-			
 			string temp;
 			hard = validParameter.validFile(parameters, "hard");				if (hard == "not found") { hard = ""; }
 			else if (hard == "not open") { hard = ""; abort = true; }	
@@ -235,7 +188,7 @@ int FilterSeqsCommand::execute() {
 		inFASTA.close();
 		
 		////////////create filter/////////////////
-		m->mothurOut("Creating Filter... "); m->mothurOutEndLine();
+		m->mothurOut("Creating Filter...\n");
 		
 		filter = createFilter();
 		
@@ -247,8 +200,8 @@ int FilterSeqsCommand::execute() {
 		
 		//prevent giantic file name
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + filterFileName + ".";
-		if (fastafileNames.size() > 3) { variables["[filename]"] = outputDir + "merge."; }
+        variables["[filename]"] = outputdir + filterFileName + ".";
+		if (fastafileNames.size() > 3) { variables["[filename]"] = outputdir + "merge."; }
 		string filterFile = getOutputFileName("filter", variables);  
 		
 		util.openOutputFile(filterFile, outFilter);
@@ -258,7 +211,7 @@ int FilterSeqsCommand::execute() {
 				
 		////////////run filter/////////////////
 		
-		m->mothurOut("Running Filter... "); m->mothurOutEndLine();
+		m->mothurOut("Running Filter...\n"); 
 		
 		filterSequences();
 		
@@ -306,10 +259,10 @@ int FilterSeqsCommand::filterSequences() {
 		for (int s = 0; s < fastafileNames.size(); s++) {
 			
             map<string, string> variables;
-            variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastafileNames[s]));
+            variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafileNames[s]));
             string filteredFasta = getOutputFileName("fasta", variables);
             
-            vector<unsigned long long> positions;
+            vector<double> positions;
             if (savedPositions.size() != 0) { positions = savedPositions[s]; }
             else {
 #if defined NON_WINDOWS
@@ -410,7 +363,7 @@ long long FilterSeqsCommand::createProcessesRunFilter(string F, string filename,
         long long num = 0;
         
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<filterRunData*> data;
     
         time_t start, end;
@@ -425,7 +378,7 @@ long long FilterSeqsCommand::createProcessesRunFilter(string F, string filename,
             filterRunData* dataBundle = new filterRunData(filter, filename, threadWriter, lines[i+1].start, lines[i+1].end, alignmentLength);
             data.push_back(dataBundle);
             
-            workerThreads.push_back(new thread(driverRunFilter, dataBundle));
+            workerThreads.push_back(new std::thread(driverRunFilter, dataBundle));
         }
         
         OutputWriter* threadWriter = new OutputWriter(synchronizedOutputFile);
@@ -561,7 +514,7 @@ void driverCreateFilter(filterData* params) {
 long long FilterSeqsCommand::createProcessesCreateFilter(Filters& F, string filename) {
 	try {
         vector<linePair> lines;
-        vector<unsigned long long> positions;
+        vector<double> positions;
         
 #if defined NON_WINDOWS
         positions = util.divideFile(filename, processors);
@@ -587,7 +540,7 @@ long long FilterSeqsCommand::createProcessesCreateFilter(Filters& F, string file
         bool doVertical = util.isTrue(vertical);
 
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<filterData*> data;
         
         time_t start, end;
@@ -597,7 +550,7 @@ long long FilterSeqsCommand::createProcessesCreateFilter(Filters& F, string file
             filterData* dataBundle = new filterData(filename, lines[i+1].start, lines[i+1].end, alignmentLength, trump, doVertical, soft, hard, i+1);
             data.push_back(dataBundle);
             
-            workerThreads.push_back(new thread(driverCreateFilter, dataBundle));
+            workerThreads.push_back(new std::thread(driverCreateFilter, dataBundle));
         }
         
         filterData* dataBundle = new filterData(filename, lines[0].start, lines[0].end, alignmentLength, trump, doVertical, soft, hard, 0);
@@ -626,7 +579,6 @@ long long FilterSeqsCommand::createProcessesCreateFilter(Filters& F, string file
             for (int k = 0; k < alignmentLength; k++) {	 F.c[k] += data[i]->F.c[k];       }
             for (int k = 0; k < alignmentLength; k++) {	 F.gap[k] += data[i]->F.gap[k];   }
             
-            
             delete data[i];
             delete workerThreads[i];
         }
