@@ -19,7 +19,6 @@
 class GetCoreMicroBiomeCommand : public Command {
 public:
     GetCoreMicroBiomeCommand(string);
-    GetCoreMicroBiomeCommand();
     ~GetCoreMicroBiomeCommand(){}
     
     vector<string> setParameters();
@@ -41,7 +40,6 @@ private:
     vector<string> Groups;
     set<string> labels;
     bool abort;
-    string outputDir;
     vector<string> outputNames;
     float abund;
     int samples, factor;
