@@ -16,6 +16,11 @@ vector<string> GetCurrentCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["summary"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -43,19 +48,6 @@ string GetCurrentCommand::getHelpString(){
 	}
 }
 //**********************************************************************************************************************
-GetCurrentCommand::GetCurrentCommand(){	
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-        vector<string> tempOutNames;
-        outputTypes["summary"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "GetCurrentCommand", "GetCurrentCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 string GetCurrentCommand::getOutputPattern(string type) {
     try {
         string pattern = "";
@@ -73,33 +65,19 @@ string GetCurrentCommand::getOutputPattern(string type) {
 //**********************************************************************************************************************
 GetCurrentCommand::GetCurrentCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			//check to make sure all parameters are valid for command
-			for (map<string,string>::iterator it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-            vector<string> tempOutNames;
-            outputTypes["summary"] = tempOutNames;
-            
 			clearTypes = validParameter.valid(parameters, "clear");
 			if (clearTypes == "not found") { clearTypes = ""; }
 			else { util.splitAtDash(clearTypes, types);	}
-            
-            //if the user changes the output directory command factory will send this info to us in the output parameter
-            outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){  outputDir = ""; }
 		}
 		
 	}
@@ -150,9 +128,11 @@ int GetCurrentCommand::execute(){
 					current->setTreeFile("");
 				}else if (types[i] == "shared") {
 					current->setSharedFile("");
-				}else if (types[i] == "relabund") {
-					current->setRelAbundFile("");
-				}else if (types[i] == "design") {
+                }else if (types[i] == "relabund") {
+                    current->setRelAbundFile("");
+                }else if (types[i] == "clr") {
+                    current->setCLRFile("");
+                }else if (types[i] == "design") {
 					current->setDesignFile("");
 				}else if (types[i] == "sff") {
 					current->setSFFFile("");
@@ -176,6 +156,8 @@ int GetCurrentCommand::execute(){
 					current->setSummaryFile("");
                 }else if (types[i] == "file") {
                     current->setFileFile("");
+                }else if (types[i] == "file") {
+                    current->setSampleFile("");
 				}else if (types[i] == "processors") {
 					current->setProcessors("1");
 				}else if (types[i] == "all") {
@@ -192,10 +174,10 @@ int GetCurrentCommand::execute(){
         
 		if (current->hasCurrentFiles()) {
             map<string, string> variables;
-            variables["[filename]"] = util.getFullPathName(outputDir);
+            variables["[filename]"] = util.getFullPathName(outputdir);
             string filename = getOutputFileName("summary", variables);
             
-			m->mothurOutEndLine(); m->mothurOut("Current files saved by mothur:"); m->mothurOutEndLine();
+			m->mothurOutEndLine(); m->mothurOut("Current files saved by mothur:\n"); 
 			current->printCurrentFiles(filename);
             outputNames.push_back(filename); outputTypes["summary"].push_back(filename);
 		}
@@ -205,9 +187,9 @@ int GetCurrentCommand::execute(){
             m->mothurOutEndLine(); m->mothurOut("Current input directory saved by mothur: " + inputDir); m->mothurOutEndLine();
         }
         
-        string outputDir = current->getOutputDir();
-        if (outputDir != "") {
-            m->mothurOutEndLine(); m->mothurOut("Current output directory saved by mothur: " + outputDir); m->mothurOutEndLine();
+        string outputdir = current->getOutputDir();
+        if (outputdir != "") {
+            m->mothurOutEndLine(); m->mothurOut("Current output directory saved by mothur: " + outputdir); m->mothurOutEndLine();
         }
         string defaultPath = current->getDefaultPath();
         if (defaultPath != "") {
@@ -222,7 +204,7 @@ int GetCurrentCommand::execute(){
         
         if (current->hasCurrentFiles()) {
             m->mothurOutEndLine();
-            m->mothurOut("Output File Names: "); m->mothurOutEndLine();
+            m->mothurOut("Output File Names: \n"); 
             for (int i = 0; i < outputNames.size(); i++) { m->mothurOut(outputNames[i]); m->mothurOutEndLine(); }
             m->mothurOutEndLine();
         }
