@@ -17,7 +17,6 @@ class GetCurrentCommand : public Command {
 
 	public:
 		GetCurrentCommand(string);
-		GetCurrentCommand();
 		~GetCurrentCommand() {}
 	
 		vector<string> setParameters();
@@ -38,7 +37,7 @@ class GetCurrentCommand : public Command {
 		vector<string> outputNames;
 		bool abort;
 	
-		string clearTypes, outputDir;
+		string clearTypes;
 		vector<string> types;
 		
 };
