@@ -16,7 +16,6 @@ class GetDistsCommand : public Command {
 public:
 	
 	GetDistsCommand(string);	
-	GetDistsCommand();
 	~GetDistsCommand(){}
 	
 	vector<string> setParameters();
@@ -35,7 +34,7 @@ public:
 	
 private:
 	set<string> names;
-	string accnosfile, phylipfile, columnfile, outputDir;
+	string accnosfile, phylipfile, columnfile;
 	bool abort;
 	vector<string> outputNames;
 	
