@@ -18,6 +18,8 @@ vector<string> GetgroupCommand::setParameters(){
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
 		
+        abort = false; calledHelp = false;
+        
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
 		return myArray;
@@ -43,53 +45,20 @@ string GetgroupCommand::getHelpString(){
 		exit(1);
 	}
 }
-
-//**********************************************************************************************************************
-GetgroupCommand::GetgroupCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-	}
-	catch(exception& e) {
-		m->errorOut(e, "GetgroupCommand", "GetgroupCommand");
-		exit(1);
-	}
-}
 //**********************************************************************************************************************
 GetgroupCommand::GetgroupCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			map<string,string>::iterator it;
 			
 			ValidParameters validParameter;
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("shared");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
-				}
-			}
 			
 			//get shared file
 			sharedfile = validParameter.validFile(parameters, "shared");
@@ -102,8 +71,8 @@ GetgroupCommand::GetgroupCommand(string option)  {
 			}else { current->setSharedFile(sharedfile); }
 			
 			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(sharedfile);		}
+			 
+					if (outputdir == ""){    outputdir = util.hasPath(sharedfile);		}
 		}
 	}
 	catch(exception& e) {
