@@ -15,7 +15,6 @@
 class GetgroupCommand : public Command {
 public:
 	GetgroupCommand(string);
-	GetgroupCommand();
 	~GetgroupCommand() {}
 	
 	vector<string> setParameters();
@@ -33,7 +32,7 @@ public:
 	
 private:
 	
-	string outputFile, sharedfile, outputDir;
+	string outputFile, sharedfile;
 	vector<string> outputNames;
 	ofstream out;
 	ifstream in;
