@@ -31,6 +31,19 @@ vector<string> GetLineageCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["taxonomy"] = tempOutNames;
+        outputTypes["name"] = tempOutNames;
+        outputTypes["group"] = tempOutNames;
+        outputTypes["alignreport"] = tempOutNames;
+        outputTypes["list"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
+        outputTypes["constaxonomy"] = tempOutNames;
+        outputTypes["shared"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -89,142 +102,18 @@ string GetLineageCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-GetLineageCommand::GetLineageCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-		outputTypes["taxonomy"] = tempOutNames;
-		outputTypes["name"] = tempOutNames;
-		outputTypes["group"] = tempOutNames;
-		outputTypes["alignreport"] = tempOutNames;
-		outputTypes["list"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-        outputTypes["constaxonomy"] = tempOutNames;
-        outputTypes["shared"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "GetLineageCommand", "GetLineageCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 GetLineageCommand::GetLineageCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-				
-		//allow user to run help
-		if(option == "help") { help(); abort = true; calledHelp = true; }
+        if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string,string>::iterator it;
 			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-			outputTypes["taxonomy"] = tempOutNames;
-			outputTypes["name"] = tempOutNames;
-			outputTypes["group"] = tempOutNames;
-			outputTypes["alignreport"] = tempOutNames;
-			outputTypes["list"] = tempOutNames;
-            outputTypes["count"] = tempOutNames;
-            outputTypes["constaxonomy"] = tempOutNames;
-            outputTypes["shared"] = tempOutNames;
-
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("alignreport");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["alignreport"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("list");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["list"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("taxonomy");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["taxonomy"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("constaxonomy");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["constaxonomy"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("shared");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
-				}
-			}
-
 			
 			//check for required parameters			
 			fastafile = validParameter.validFile(parameters, "fasta");
@@ -268,9 +157,9 @@ GetLineageCommand::GetLineageCommand(string option)  {
     
             if ((constaxonomy == "") && (taxfile == "")) {
                 taxfile = current->getTaxonomyFile();
-                if (taxfile != "") { m->mothurOut("Using " + taxfile + " as input file for the taxonomy parameter."); m->mothurOutEndLine(); }
+                if (taxfile != "") { m->mothurOut("Using " + taxfile + " as input file for the taxonomy parameter.\n");  }
                 else {
-                    m->mothurOut("You have no current taxonomy file and did not provide a constaxonomy file. The taxonomy or constaxonomy parameter is required."); m->mothurOutEndLine(); abort = true; }
+                    m->mothurOut("You have no current taxonomy file and did not provide a constaxonomy file. The taxonomy or constaxonomy parameter is required.\n");  abort = true; }
 			}
             
 			string usedDups = "true";
@@ -287,15 +176,15 @@ GetLineageCommand::GetLineageCommand(string option)  {
             else { current->setCountFile(countfile); }
             
             if ((namefile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: name or count."); m->mothurOutEndLine(); abort = true;
+                m->mothurOut("[ERROR]: you may only use one of the following: name or count.\n");  abort = true;
             }
             
             if ((groupfile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: group or count."); m->mothurOutEndLine(); abort=true;
+                m->mothurOut("[ERROR]: you may only use one of the following: group or count.\n");  abort=true;
             }
 			
 			taxons = validParameter.valid(parameters, "taxon");
-			if (taxons == "not found") { taxons = "";  m->mothurOut("No taxons given, please correct."); m->mothurOutEndLine();  abort = true;  }
+			if (taxons == "not found") { taxons = "";  m->mothurOut("No taxons given, please correct.\n");   abort = true;  }
 			else { 
 				//rip off quotes
 				if (taxons[0] == '\'') {  taxons = taxons.substr(1); }
@@ -303,7 +192,7 @@ GetLineageCommand::GetLineageCommand(string option)  {
 			}
 			util.splitAtChar(taxons, listOfTaxons, '-');
 			
-			if ((fastafile == "") && (constaxonomy == "") && (namefile == "") && (groupfile == "") && (alignfile == "") && (listfile == "") && (taxfile == "") && (countfile == ""))  { m->mothurOut("You must provide one of the following: fasta, name, group, count, alignreport, taxonomy, constaxonomy, shared or listfile."); m->mothurOutEndLine(); abort = true; }
+			if ((fastafile == "") && (constaxonomy == "") && (namefile == "") && (groupfile == "") && (alignfile == "") && (listfile == "") && (taxfile == "") && (countfile == ""))  { m->mothurOut("You must provide one of the following: fasta, name, group, count, alignreport, taxonomy, constaxonomy, shared or listfile.\n");  abort = true; }
             
             if ((constaxonomy != "") && ((fastafile != "") || (namefile != "") || (groupfile != "") || (alignfile != "") || (taxfile != "") || (countfile != ""))) {
                 m->mothurOut("[ERROR]: can only use constaxonomy file with a list or shared file, aborting.\n");  abort = true;
@@ -319,7 +208,7 @@ GetLineageCommand::GetLineageCommand(string option)  {
             
             if ((sharedfile != "") || (listfile != "")) {
                 label = validParameter.valid(parameters, "label");
-                if (label == "not found") { label = ""; m->mothurOut("[WARNING]: You did not provide a label, I will use the first label in your inputfile."); m->mothurOutEndLine(); }
+                if (label == "not found") { label = ""; m->mothurOut("[WARNING]: You did not provide a label, I will use the first label in your inputfile.\n");  }
             }
             
             if (countfile == "") {
@@ -347,7 +236,7 @@ int GetLineageCommand::execute(){
         
         if (countfile != "") {
             if ((fastafile != "") || (listfile != "") || (taxfile != "")) { 
-                m->mothurOut("\n[NOTE]: The count file should contain only unique names, so mothur assumes your fasta, list and taxonomy files also contain only uniques.\n\n");
+                //m->mothurOut("\n[NOTE]: The count file should contain only unique names, so mothur assumes your fasta, list and taxonomy files also contain only uniques.\n\n");
             }
         }
         
@@ -358,8 +247,7 @@ int GetLineageCommand::execute(){
             if (!util.isBlank(accnosFileName)) {
                 outputNames.push_back(accnosFileName); outputTypes["accnos"].push_back(accnosFileName);
                 runGetSeqs(accnosFileName);
-            }
-            util.mothurRemove(accnosFileName);
+            }else { util.mothurRemove(accnosFileName); }
             
         }else {
             string accnosFileName = readConsTax();
@@ -367,8 +255,7 @@ int GetLineageCommand::execute(){
             if (!util.isBlank(accnosFileName)) {
                 outputNames.push_back(accnosFileName); outputTypes["accnos"].push_back(accnosFileName);
                 runGetOTUs(accnosFileName);
-            }
-            util.mothurRemove(accnosFileName);
+            } else { util.mothurRemove(accnosFileName); }
         }
 				
 		
@@ -512,7 +399,7 @@ int GetLineageCommand::runGetOTUs(string accnosFileName){
             m->mothurOut("Running command: get.otus(" + inputString + ")\n");
             current->setMothurCalling(true);
             
-            Command* getCommand = new GetOtuLabelsCommand(inputString);
+            Command* getCommand = new GetOtusCommand(inputString);
             getCommand->execute();
             
             map<string, vector<string> > filenames = getCommand->getOutputFiles();
@@ -543,8 +430,8 @@ int GetLineageCommand::runGetOTUs(string accnosFileName){
 //**********************************************************************************************************************
 string GetLineageCommand::readTax(){
 	try {
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(taxfile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(taxfile);  }
 		map<string, string> variables; 
 		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(taxfile));
         variables["[extension]"] = util.getExtension(taxfile);
@@ -561,15 +448,12 @@ string GetLineageCommand::readTax(){
 		
 		bool wroteSomething = false;
 		vector<bool> taxonsHasConfidence; taxonsHasConfidence.resize(listOfTaxons.size(), false);
-		vector< vector< map<string, float> > > searchTaxons; searchTaxons.resize(listOfTaxons.size());
-		vector<string> noConfidenceTaxons; noConfidenceTaxons.resize(listOfTaxons.size(), "");
+		vector< vector<Taxon> > searchTaxons; searchTaxons.resize(listOfTaxons.size());
 		
 		for (int i = 0; i < listOfTaxons.size(); i++) {
-			noConfidenceTaxons[i] = listOfTaxons[i];
             bool hasCon = false;
-            searchTaxons[i] = util.getTaxons(listOfTaxons[i], hasCon);  taxonsHasConfidence[i] = hasCon;
-            noConfidenceTaxons[i] = listOfTaxons[i];
-            if (hasCon) { util.removeConfidences(noConfidenceTaxons[i]); }
+            searchTaxons[i] = util.getTaxons(listOfTaxons[i], hasCon);
+            taxonsHasConfidence[i] = hasCon;
 		}
 		
 		while(!in.eof()){
@@ -578,10 +462,12 @@ string GetLineageCommand::readTax(){
 
             in >> name; util.gobble(in);
             tax = util.getline(in); util.gobble(in);
-			
-            string noQuotesTax = util.removeQuotes(tax);
             
-			if (util.searchTax(noQuotesTax, listOfTaxons, taxonsHasConfidence, noConfidenceTaxons, searchTaxons)) {
+            Taxonomy thisSeq(name, tax);
+			vector<Taxon> otuTax = thisSeq.getTaxons();
+            util.removeQuotes(otuTax);
+            
+			if (util.searchTax(otuTax, taxonsHasConfidence, searchTaxons)) {
                 out << name << '\t' << tax << endl;
                 outAccnos << name << endl; wroteSomething = true;
             }
@@ -604,8 +490,8 @@ string GetLineageCommand::readTax(){
 //**********************************************************************************************************************
 string GetLineageCommand::readConsTax(){
 	try {
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(constaxonomy);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(constaxonomy);  }
 		map<string, string> variables;
 		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(constaxonomy));
         variables["[extension]"] = util.getExtension(constaxonomy);
@@ -618,8 +504,6 @@ string GetLineageCommand::readConsTax(){
 		
 		ifstream in;
 		util.openInputFile(constaxonomy, in);
-		string otuLabel, tax;
-        int numReps;
         
         //read headers
         string headers = util.getline(in);
@@ -627,30 +511,25 @@ string GetLineageCommand::readConsTax(){
 		
 		bool wroteSomething = false;
 		vector<bool> taxonsHasConfidence; taxonsHasConfidence.resize(listOfTaxons.size(), false);
-		vector< vector< map<string, float> > > searchTaxons; searchTaxons.resize(listOfTaxons.size());
-		vector<string> noConfidenceTaxons; noConfidenceTaxons.resize(listOfTaxons.size(), "");
+		vector< vector<Taxon> > searchTaxons; searchTaxons.resize(listOfTaxons.size());
 		
 		for (int i = 0; i < listOfTaxons.size(); i++) {
-            noConfidenceTaxons[i] = listOfTaxons[i];
             bool hasCon = false;
-            searchTaxons[i] = util.getTaxons(listOfTaxons[i], hasCon);  taxonsHasConfidence[i] = hasCon;
-            noConfidenceTaxons[i] = listOfTaxons[i];
-            if (hasCon) { util.removeConfidences(noConfidenceTaxons[i]); }
+            searchTaxons[i] = util.getTaxons(listOfTaxons[i], hasCon);
+            taxonsHasConfidence[i] = hasCon;
         }
         
 		while(!in.eof()){
             
 			if (m->getControl_pressed()) { break; }
             
-			in >> otuLabel;	 		util.gobble(in);
-            in >> numReps;          util.gobble(in);
-            tax = util.getline(in);   util.gobble(in);
-			
-            string noQuotesTax = util.removeQuotes(tax);
+            Taxonomy thisOtu(in);
+            vector<Taxon> otuTax = thisOtu.getTaxons();
+            util.removeQuotes(otuTax);
             
-            if (util.searchTax(noQuotesTax, listOfTaxons, taxonsHasConfidence, noConfidenceTaxons, searchTaxons)) {
-                wroteSomething = true; outAccnos << otuLabel << endl;
-                out << otuLabel << '\t' << numReps << '\t' << tax << endl;
+            if (util.searchTax(otuTax, taxonsHasConfidence, searchTaxons)) {
+                wroteSomething = true; outAccnos << thisOtu.getName() << endl;
+                thisOtu.printConsTax(out);
             }
         }
 		in.close();
