@@ -14,14 +14,14 @@
 #include "sharedrabundvectors.hpp"
 #include "listvector.hpp"
 #include "getseqscommand.h"
-#include "getotulabelscommand.h"
+#include "getotuscommand.h"
+#include "taxonomy.hpp"
 
 class GetLineageCommand : public Command {
 	
 	public:
 	
 		GetLineageCommand(string);
-		GetLineageCommand();
 		~GetLineageCommand(){}
 	
 		vector<string> setParameters();
@@ -40,7 +40,7 @@ class GetLineageCommand : public Command {
 	
 	private:
 		vector<string> outputNames, listOfTaxons;
-		string fastafile, namefile, groupfile, alignfile, countfile, listfile, taxfile, outputDir, taxons, sharedfile, constaxonomy, label;
+		string fastafile, namefile, groupfile, alignfile, countfile, listfile, taxfile,  taxons, sharedfile, constaxonomy, label;
 		bool abort, dups;
 		
 		string readTax();
