@@ -10,10 +10,6 @@
 #include "getoturepcommand.h"
 #include "readphylip.h"
 #include "readcolumn.h"
-#include "formatphylip.h"
-#include "formatcolumn.h"
-
-
 
 //********************************************************************************************************************
 //sorts lowest to highest
@@ -46,7 +42,6 @@ vector<string> GetOTURepCommand::setParameters(){
         CommandParameter pcount("count", "InputTypes", "", "", "NameCount-CountGroup", "none", "ColumnName","count",false,false, true); parameters.push_back(pcount);
 		CommandParameter pgroup("group", "InputTypes", "", "", "CountGroup", "none", "none","",false,false, true); parameters.push_back(pgroup);
 		CommandParameter pcolumn("column", "InputTypes", "", "", "PhylipColumn", "PhylipColumn", "ColumnName","",false,false, true); parameters.push_back(pcolumn);
-		CommandParameter plabel("label", "String", "", "", "", "", "","",false,false); parameters.push_back(plabel);
 		CommandParameter pgroups("groups", "String", "", "", "", "", "","",false,false); parameters.push_back(pgroups);
 		CommandParameter pcutoff("cutoff", "Number", "", "10", "", "", "","",false,false); parameters.push_back(pcutoff);
 		CommandParameter pprecision("precision", "Number", "", "100", "", "", "","",false,false); parameters.push_back(pprecision);
@@ -57,6 +52,13 @@ vector<string> GetOTURepCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false; allLines = true;
+        
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["name"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -71,12 +73,12 @@ vector<string> GetOTURepCommand::setParameters(){
 string GetOTURepCommand::getHelpString(){	
 	try {
 		string helpString = "";
-		helpString += "The get.oturep command parameters are phylip, column, list, fasta, name, group, count, large, weighted, cutoff, precision, groups, sorted, method, label and rename.  The list parameter is required, as well as phylip or column and name if you are using method=distance. If method=abundance a name or count file is required.\n";
-        helpString += "The label parameter allows you to select what distance you would like a output files created for. Example label=0.03. If no label is provided the first label is used.\n";
+		helpString += "The get.oturep command parameters are phylip, column, list, fasta, name, group, count, large, weighted, cutoff, precision, groups, sorted, method and rename.  The list parameter is required, as well as phylip or column and name if you are using method=distance. If method=abundance a name or count file is required.\n";
 		helpString += "The rename parameter allows you to indicate you want the OTU label to replace the representative sequence name. Default=F. \n";
 		helpString += "The phylip or column parameter is required for method=distance, but only one may be used.  If you use a column file the name or count filename is required. \n";
         helpString += "The method parameter allows you to select the method of selecting the representative sequence. Choices are distance and abundance.  The distance method finds the sequence with the largest number of close sequences in the OTU. If tie occurs, a sequence is randomly selected from the ties.  The abundance method chooses the most abundant sequence in the OTU as the representative.\n";
 		helpString += "If you do not provide a cutoff value 0.03 is assumed. If you do not provide a precision value then 100 is assumed.\n";
+        helpString += "Multiple cutoffs can be entered as follows cutoff=0.01-0.03. \n";
 		helpString += "The get.oturep command should be in the following format: get.oturep(phylip=yourDistanceMatrix, fasta=yourFastaFile, list=yourListFile, name=yourNamesFile, group=yourGroupFile).\n";
 		helpString += "Example get.oturep(phylip=amazon.dist, fasta=amazon.fasta, list=amazon.fn.list, group=amazon.groups).\n";
 		helpString += "The sorted parameter allows you to indicate you want the output sorted. You can sort by sequence name, bin number, bin size or group. The default is no sorting, but your options are name, number, size, or group.\n";
@@ -115,115 +117,19 @@ string GetOTURepCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-GetOTURepCommand::GetOTURepCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-		outputTypes["name"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "GetOTURepCommand", "GetOTURepCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 GetOTURepCommand::GetOTURepCommand(string option)  {
 	try{
-		abort = false; calledHelp = false;   
-		allLines = true;
-				
 		//allow user to run help
 		if (option == "help") { 
 			help(); abort = true; calledHelp = true;
 		}else if(option == "citation") { citation(); abort = true; calledHelp = true;
-		} else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+		} else if(option == "category") {  abort = true; calledHelp = true;  }
+        else {
+			OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string, string>::iterator it;
-		
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
 			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-			outputTypes["name"] = tempOutNames;
-            outputTypes["count"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("list");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["list"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("phylip");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["phylip"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("column");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["column"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-			}
-
-			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
 			
 			//check for required parameters
 			fastafile = validParameter.validFile(parameters, "fasta");
@@ -234,8 +140,8 @@ GetOTURepCommand::GetOTURepCommand(string option)  {
 			listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not found") { 			
 				listfile = current->getListFile(); 
-				if (listfile != "") { m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current list file and the list parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (listfile != "") { m->mothurOut("Using " + listfile + " as input file for the list parameter.\n");  }
+				else { 	m->mothurOut("You have no current list file and the list parameter is required.\n");  abort = true; }
 			}
 			else if (listfile == "not open") { abort = true; }	
 			else { current->setListFile(listfile); }
@@ -272,33 +178,33 @@ GetOTURepCommand::GetOTURepCommand(string option)  {
 			
             method = validParameter.valid(parameters, "method");		if (method == "not found"){	method = "distance";	}
 			if ((method != "distance") && (method != "abundance")) {
-				m->mothurOut(method + " is not a valid option for the method parameter. The only options are: distance and abundance, aborting."); m->mothurOutEndLine(); abort = true;
+				m->mothurOut(method + " is not a valid option for the method parameter. The only options are: distance and abundance, aborting.\n");  abort = true;
 			}
             
             if (method == "distance") {
                 if ((phylipfile == "") && (columnfile == "")) { //is there are current file available for either of these?
                     //give priority to column, then phylip
                     columnfile = current->getColumnFile();
-                    if (columnfile != "") {  distFile = columnfile; format = "column"; m->mothurOut("Using " + columnfile + " as input file for the column parameter."); m->mothurOutEndLine(); }
+                    if (columnfile != "") {  distFile = columnfile; format = "column"; m->mothurOut("Using " + columnfile + " as input file for the column parameter.\n");  }
                     else {
                         phylipfile = current->getPhylipFile();
-                        if (phylipfile != "") {  distFile = phylipfile; format = "phylip"; m->mothurOut("Using " + phylipfile + " as input file for the phylip parameter."); m->mothurOutEndLine(); }
+                        if (phylipfile != "") {  distFile = phylipfile; format = "phylip"; m->mothurOut("Using " + phylipfile + " as input file for the phylip parameter.\n");  }
                         else {
-                            m->mothurOut("No valid current files. You must provide a phylip or column file before you can use the get.oturep command."); m->mothurOutEndLine();
+                            m->mothurOut("No valid current files. You must provide a phylip or column file before you can use the get.oturep command.\n"); 
                             abort = true;
                         }
                     }
-                }else if ((phylipfile != "") && (columnfile != "")) { m->mothurOut("When executing a get.oturep command you must enter ONLY ONE of the following: phylip or column."); m->mothurOutEndLine(); abort = true; }
+                }else if ((phylipfile != "") && (columnfile != "")) { m->mothurOut("When executing a get.oturep command you must enter ONLY ONE of the following: phylip or column.\n");  abort = true; }
                 
                 if (columnfile != "") {
                     if ((namefile == "") && (countfile == "")) {
                         namefile = current->getNameFile();
-                        if (namefile != "") {  m->mothurOut("Using " + namefile + " as input file for the name parameter."); m->mothurOutEndLine(); }
+                        if (namefile != "") {  m->mothurOut("Using " + namefile + " as input file for the name parameter.\n");  }
                         else {
                             countfile = current->getCountFile();
-                            if (countfile != "") {  m->mothurOut("Using " + countfile + " as input file for the count parameter."); m->mothurOutEndLine(); }
+                            if (countfile != "") {  m->mothurOut("Using " + countfile + " as input file for the count parameter.\n");  }
                             else {
-                                m->mothurOut("You need to provide a namefile or countfile if you are going to use the column format."); m->mothurOutEndLine();
+                                m->mothurOut("You need to provide a namefile or countfile if you are going to use the column format.\n"); 
                                 abort = true; 
                             }	
                         }	
@@ -307,47 +213,50 @@ GetOTURepCommand::GetOTURepCommand(string option)  {
             }else if (method == "abundance") {
                 if ((namefile == "") && (countfile == "")) {
 					namefile = current->getNameFile();
-					if (namefile != "") {  m->mothurOut("Using " + namefile + " as input file for the name parameter."); m->mothurOutEndLine(); }
+					if (namefile != "") {  m->mothurOut("Using " + namefile + " as input file for the name parameter.\n");  }
 					else {
 						countfile = current->getCountFile();
-                        if (countfile != "") {  m->mothurOut("Using " + countfile + " as input file for the count parameter."); m->mothurOutEndLine(); }
+                        if (countfile != "") {  m->mothurOut("Using " + countfile + " as input file for the count parameter.\n");  }
                         else {
-                            m->mothurOut("You need to provide a namefile or countfile if you are going to use the abundance method."); m->mothurOutEndLine();
+                            m->mothurOut("You need to provide a namefile or countfile if you are going to use the abundance method.\n"); 
                             abort = true;
                         }
 					}
 				}
                 if ((phylipfile != "") || (columnfile != "")) {
-                    m->mothurOut("[WARNING]: A phylip or column file is not needed to use the abundance method, ignoring."); m->mothurOutEndLine();
+                    m->mothurOut("[WARNING]: A phylip or column file is not needed to use the abundance method, ignoring.\n"); 
                     phylipfile = ""; columnfile = "";
                 }
             }
             
             if ((namefile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: name or count."); m->mothurOutEndLine(); abort = true;
+                m->mothurOut("[ERROR]: you may only use one of the following: name or count.\n");  abort = true;
             }
             
             if ((groupfile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: group or count."); m->mothurOutEndLine(); abort=true;
+                m->mothurOut("[ERROR]: you may only use one of the following: group or count.\n");  abort=true;
             }
 
-        
-			//check for optional parameter and set defaults
-			// ...at some point should added some additional type checking...
-			label = validParameter.valid(parameters, "label");			
-			if (label == "not found") { label = "";   }
+            cutoffSet = false;
+            string temp = validParameter.valid(parameters, "cutoff");
+            if (temp == "not found") {  temp = "0.03"; }
+            else { cutoffSet = true; }
+            
+            int pos = temp.find('-');
+            if (pos != string::npos) { //multiple cutoffs given
+                util.splitAtDash(temp, cutoffs);  temp = *cutoffs.begin();
+            }else {     cutoffs.insert(temp);  }
+            util.mothurConvert(temp, cutoff);
 						
 			sorted = validParameter.valid(parameters, "sorted");		if (sorted == "not found"){	sorted = "";	}
 			if (sorted == "none") { sorted=""; }
 			if ((sorted != "") && (sorted != "name") && (sorted != "bin") && (sorted != "size") && (sorted != "group")) {
-				m->mothurOut(sorted + " is not a valid option for the sorted parameter. The only options are: name, bin, size and group. I will not sort."); m->mothurOutEndLine();
+				m->mothurOut(sorted + " is not a valid option for the sorted parameter. The only options are: name, bin, size and group. I will not sort.\n"); 
 				sorted = "";
 			}
             
-            
-			
 			if ((sorted == "group") && ((groupfile == "")&& !hasGroups)) {
-				m->mothurOut("You must provide a groupfile or have a count file with group info to sort by group. I will not sort."); m->mothurOutEndLine();
+				m->mothurOut("You must provide a groupfile or have a count file with group info to sort by group. I will not sort.\n"); 
 				sorted = "";
 			}
 			
@@ -363,7 +272,7 @@ GetOTURepCommand::GetOTURepCommand(string option)  {
 				}
 			}
 			
-			string temp = validParameter.valid(parameters, "weighted");		if (temp == "not found") {	 temp = "f"; 	} weighted = util.isTrue(temp);
+			temp = validParameter.valid(parameters, "weighted");		if (temp == "not found") {	 temp = "f"; 	} weighted = util.isTrue(temp);
             
             temp = validParameter.valid(parameters, "rename");		if (temp == "not found") {	 temp = "f"; 	} rename = util.isTrue(temp);
             
@@ -375,7 +284,7 @@ GetOTURepCommand::GetOTURepCommand(string option)  {
 			
 			temp = validParameter.valid(parameters, "precision");			if (temp == "not found") { temp = "100"; } util.mothurConvert(temp, precision);
 			
-			temp = validParameter.valid(parameters, "cutoff");			if (temp == "not found") { temp = "0.03"; } util.mothurConvert(temp, cutoff);
+            matrix = NULL;
 			
 		}
 	}
@@ -391,81 +300,55 @@ int GetOTURepCommand::execute(){
 	try {
 	
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
-		
-		list = NULL;
         
         if (method == "distance") {
-            if ((namefile != "") && (groupfile != "")) { //create count file for simplicity
-                
-                CountTable ct; ct.createTable(namefile, groupfile, nullVector);
-                
-                if (outputDir == "") { outputDir = util.hasPath(namefile); }
-                map<string, string> variables; variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(namefile));
-                countfile = getOutputFileName("count", variables);
-                
-                ct.printCompressedTable(countfile);
-                
-                current->setCountFile(countfile);
-                if (ct.hasGroupInfo()) { hasGroups = true; }
-                
-                vector<string> uniqueNames = ct.getNamesOfSeqs();
-                util.printAccnos("temp.accnos", uniqueNames);
-                
-                string inputString = "list=" + listfile + ", accnos=temp.accnos";
-                
-                m->mothurOut("/******************************************/\n");
-                m->mothurOut("\nRunning command: get.seqs(" + inputString + ")\n");
-                current->setMothurCalling(true);
-                
-                Command* getSeqsCommand = new GetSeqsCommand(inputString);
-                getSeqsCommand->execute();
-                
-                string templistfile = getSeqsCommand->getOutputFiles()["list"][0];
-                string newName = util.getRootName(listfile) + "unique.list";
-                util.renameFile(templistfile, newName);  listfile = newName;
-                namefile = ""; groupfile = ""; util.mothurRemove("temp.accnos");
-                
-                delete getSeqsCommand;
-                current->setMothurCalling(false);
-                
-                m->mothurOut("/******************************************/\n");
-            }
-            readDist();
+            if ((namefile != "") && (groupfile != "")) { createCount();  } //create count file for simplicity
         }
        
         if (namefile != "") { nameMap = util.readNames(namefile); }
         
         if (m->getControl_pressed()) { return 0; }
         
+        GroupMap groupMap;
         if (groupfile != "") {
             //read in group map info.
-            groupMap = new GroupMap(groupfile);
-            int error = groupMap->readMap();
-            if (error == 1) { delete groupMap; m->mothurOut("Error reading your groupfile. Proceeding without groupfile.\n");  groupfile = "";  }
+            GroupMap groupMap(groupfile);
+            int error = groupMap.readMap();
+            if (error == 1) { m->mothurOut("Error reading your groupfile. Proceeding without groupfile.\n");  groupfile = "";  }
         }
         
-        InputData input(listfile, "list", Groups);
-        list = input.getListVector();
-        string lastLabel = list->getLabel();
-        
-        if (label == "") { m->mothurOut("You did not provide a label, using " + lastLabel + ".\n");  }
-        else if ( lastLabel == label) {} //do nothing, this is the list we want
-        else {
-            delete list;
-            list = input.getListVector(label);
-            lastLabel = list->getLabel();
+        if (!cutoffSet) {
+            InputData input(listfile, "list", Groups);
+            ListVector* list = input.getListVector();
+            string lastLabel = list->getLabel();
+            m->mothurOut("You did not provide a label, using " + lastLabel + ".\n");
+            if (lastLabel == "unique") { cutoff = 0.0; }
+            
+            if (method == "distance") { readDist(); }
+            process(list, groupMap); delete list;
         }
-        if (list == NULL) { m->mothurOut("[ERROR]: Unable to read list file, aborting.\n");  m->setControl_pressed(true); }
-        else {
-            m->mothurOut(lastLabel + "\t" + toString(list->getNumBins()) + "\n");
-            process(list);
-            delete list;
+        else { //multiple cutoffs
+            for (set<string>::iterator it = cutoffs.begin(); it != cutoffs.end(); it++) {
+                if (*it == "unique") { cutoff = 0.0; }
+                else { util.mothurConvert(*it, cutoff); }
+                
+                if (method == "distance") { readDist(); }
+                
+                InputData input(listfile, "list", Groups);
+                ListVector* list = input.getListVector(*it);
+                if (list != NULL) {
+                    string lastLabel = list->getLabel();
+                
+                    process(list, groupMap); delete list;
+                }
+            }
         }
         
+        //handles multiple labels
         if (fastafile != "") {
             //read fastafile
-            FastaMap* fasta = new FastaMap();
-            fasta->readFastaFile(fastafile);
+            FastaMap fasta;
+            fasta.readFastaFile(fastafile);
             
             //if user gave a namesfile then use it
             if (namefile != "") {	readNamesFile(fasta);	}
@@ -473,9 +356,8 @@ int GetOTURepCommand::execute(){
             //output create and output the .rep.fasta files
             map<string, string>::iterator itNameFile;
             for (itNameFile = outputNameFiles.begin(); itNameFile != outputNameFiles.end(); itNameFile++) {
-                processFastaNames(itNameFile->first, itNameFile->second, fasta);
+                processFastaNames(itNameFile->first, itNameFile->second, fasta, groupMap);
             }
-            delete fasta;
         }else {
             //output create and output the .rep.fasta files
             map<string, string>::iterator itNameFile;
@@ -484,9 +366,6 @@ int GetOTURepCommand::execute(){
             }
         }
         
-        
-        if (groupfile != "") { delete groupMap; }
-		
 		if (m->getControl_pressed()) {  return 0; }
 		
 		//set fasta file as new current fastafile - use first one??
@@ -528,6 +407,8 @@ int GetOTURepCommand::readDist() {
         string distfile = columnfile;
         if (format == "phylip") { distfile = phylipfile; }
         
+        if (matrix != NULL) { delete matrix; }
+        
         matrix = new OptiMatrix(distfile, thisNamefile, nameOrCount, format, cutoff, false);
         
         if (m->getControl_pressed()) { return 0; }
@@ -540,7 +421,48 @@ int GetOTURepCommand::readDist() {
 	}
 }
 //**********************************************************************************************************************
-void GetOTURepCommand::readNamesFile(FastaMap*& fasta) {
+void GetOTURepCommand::createCount() {
+    try {
+        CountTable ct; ct.createTable(namefile, groupfile, nullVector);
+        
+        if (outputdir == "") { outputdir = util.hasPath(namefile); }
+        map<string, string> variables; variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(namefile));
+        countfile = getOutputFileName("count", variables);
+        
+        ct.printCompressedTable(countfile);
+        
+        current->setCountFile(countfile);
+        if (ct.hasGroupInfo()) { hasGroups = true; }
+        
+        vector<string> uniqueNames = ct.getNamesOfSeqs();
+        util.printAccnos("temp.accnos", uniqueNames);
+        
+        string inputString = "list=" + listfile + ", accnos=temp.accnos";
+        
+        m->mothurOut("/******************************************/\n");
+        m->mothurOut("\nRunning command: get.seqs(" + inputString + ")\n");
+        current->setMothurCalling(true);
+        
+        Command* getSeqsCommand = new GetSeqsCommand(inputString);
+        getSeqsCommand->execute();
+        
+        string templistfile = getSeqsCommand->getOutputFiles()["list"][0];
+        string newName = util.getRootName(listfile) + "unique.list";
+        util.renameFile(templistfile, newName);  listfile = newName;
+        namefile = ""; groupfile = ""; util.mothurRemove("temp.accnos");
+        
+        delete getSeqsCommand;
+        current->setMothurCalling(false);
+        
+        m->mothurOut("/******************************************/\n");
+    }
+    catch(exception& e) {
+        m->errorOut(e, "GetOTURepCommand", "readDist");
+        exit(1);
+    }
+}
+//**********************************************************************************************************************
+void GetOTURepCommand::readNamesFile(FastaMap& fasta) {
 	try {
 		ifstream in;
 		vector<string> dupNames;
@@ -558,9 +480,9 @@ void GetOTURepCommand::readNamesFile(FastaMap*& fasta) {
 			util.splitAtComma(names, dupNames);
 			
 			//store names in fasta map
-			sequence = fasta->getSequence(name);
+            sequence = fasta.getSequence(name);
 			for (int i = 0; i < dupNames.size(); i++) {
-				fasta->push_back(dupNames[i], sequence);
+                fasta.push_back(dupNames[i], sequence);
 			}
 		
 			util.gobble(in);
@@ -739,20 +661,23 @@ string GetOTURepCommand::findRep(vector<string> names, map<string, long long>& m
 }
 
 //**********************************************************************************************************************
-int GetOTURepCommand::process(ListVector* processList) {
+int GetOTURepCommand::process(ListVector* processList, GroupMap& groupMap) {
 	try{
+        
+        m->mothurOut(processList->getLabel() + "\t" + toString(processList->getNumBins()) + "\n");
+        
 		string name, sequence;
 		string nameRep;
 
 		//create output file
-		if (outputDir == "") { outputDir += util.hasPath(listfile); }
+		if (outputdir == "") { outputdir += util.hasPath(listfile); }
 				
 		ofstream newNamesOutput;
 		string outputNamesFile;
 		map<string, string> files; //group -> filenameAW
 		
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(listfile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(listfile));
         
 		if (Groups.size() == 0) { //you don't want to use groups
             variables["[tag]"] = processList->getLabel();
@@ -770,7 +695,7 @@ int GetOTURepCommand::process(ListVector* processList) {
 			for (int i=0; i<Groups.size(); i++) {
                 variables["[tag]"] = processList->getLabel();
                 variables["[group]"] = Groups[i];
-				outputNamesFile = outputDir + util.getRootName(util.getSimpleName(listfile)) + processList->getLabel() + "." + Groups[i] + ".";
+				outputNamesFile = outputdir + util.getRootName(util.getSimpleName(listfile)) + processList->getLabel() + "." + Groups[i] + ".";
                 if (countfile == "") { 
                     outputNamesFile = getOutputFileName("name", variables);
                     outputNames.push_back(outputNamesFile); outputTypes["name"].push_back(outputNamesFile); 
@@ -791,7 +716,7 @@ int GetOTURepCommand::process(ListVector* processList) {
         
 		//for each bin in the list vector
         vector<string> binLabels = processList->getLabels();
-		for (int i = 0; i < processList->size(); i++) {
+		for (int i = 0; i < processList->getNumBins(); i++) {
         
             
 			if (m->getControl_pressed()) { out.close(); if (Groups.size() == 0) { newNamesOutput.close(); } return 0; }
@@ -825,8 +750,8 @@ int GetOTURepCommand::process(ListVector* processList) {
 				
 				for (int j=0; j<namesInBin.size(); j++) {
                     if (groupfile != "") {
-                        string thisgroup = groupMap->getGroup(namesInBin[j]);
-                        if (thisgroup == "not found") { m->mothurOut(namesInBin[j] + " is not in your groupfile, please correct."); m->mothurOutEndLine(); m->setControl_pressed(true); }
+                        string thisgroup = groupMap.getGroup(namesInBin[j]);
+                        if (thisgroup == "not found") { m->mothurOut(namesInBin[j] + " is not in your groupfile, please correct.\n");  m->setControl_pressed(true); }
                         
                         //add this name to correct group
                         if (util.inUsersGroups(thisgroup, Groups)) { NamesInGroup[thisgroup].push_back(namesInBin[j]);  }
@@ -879,13 +804,13 @@ int GetOTURepCommand::process(ListVector* processList) {
 	}
 }
 //**********************************************************************************************************************
-int GetOTURepCommand::processFastaNames(string filename, string label, FastaMap*& fasta) {
+int GetOTURepCommand::processFastaNames(string filename, string label, FastaMap& fasta, GroupMap& groupMap) {
 	try{
 
 		//create output file
-		if (outputDir == "") { outputDir += util.hasPath(listfile); }
+		if (outputdir == "") { outputdir += util.hasPath(listfile); }
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(listfile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(listfile));
         variables["[tag]"] = label;
 		string outputFileName = getOutputFileName("fasta",variables);
 		util.openOutputFile(outputFileName, out);
@@ -943,7 +868,7 @@ int GetOTURepCommand::processFastaNames(string filename, string label, FastaMap*
 			if (groupfile != "") {
 				//find the groups that are in this bin
 				for (int i = 0; i < names.size(); i++) {
-					string groupName = groupMap->getGroup(names[i]);
+                    string groupName = groupMap.getGroup(names[i]);
 					if (groupName == "not found") {  
 						m->mothurOut(names[i] + " is missing from your group file. Please correct.\n");
 						groupError = true;
@@ -975,7 +900,7 @@ int GetOTURepCommand::processFastaNames(string filename, string label, FastaMap*
 
 			
 			//print out name and sequence for that bin
-			string sequence = fasta->getSequence(rep);
+            string sequence = fasta.getSequence(rep);
 
 			if (sequence != "not found") {
 				if (sorted == "") { //print them out
@@ -1042,7 +967,7 @@ int GetOTURepCommand::processNames(string filename, string label) {
 	try{
 		
 		//create output file
-		if (outputDir == "") { outputDir += util.hasPath(listfile); }
+		if (outputdir == "") { outputdir += util.hasPath(listfile); }
 		
 		ofstream out2;
 		string tempNameFile = filename + ".temp";
