@@ -26,6 +26,14 @@ vector<string> GetSharedOTUCommand::setParameters(){
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
 
+        abort = false; calledHelp = false;
+        userGroups = ""; unique = true; allLines = true;
+        
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["accnos"] = tempOutNames;
+        outputTypes["sharedseqs"] = tempOutNames;
+        
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
 		return myArray;
@@ -79,101 +87,18 @@ string GetSharedOTUCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-GetSharedOTUCommand::GetSharedOTUCommand(){	
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-		outputTypes["accnos"] = tempOutNames;
-		outputTypes["sharedseqs"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "GetSharedOTUCommand", "GetSharedOTUCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 GetSharedOTUCommand::GetSharedOTUCommand(string option)  {
 	try {
-	
-		abort = false; calledHelp = false;   userGroups = "";
-		unique = true;
-		allLines = true;
-		
-		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string,string>::iterator it;
 			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-			outputTypes["accnos"] = tempOutNames;
-			outputTypes["sharedseqs"] = tempOutNames;
-			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("list");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["list"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("shared");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["count"] = inputDir + it->second;		}
-                }
-			}
-
 			
 			//check for required parameters
 			listfile = validParameter.validFile(parameters, "list");
@@ -209,35 +134,35 @@ GetSharedOTUCommand::GetSharedOTUCommand(string option)  {
                 //is there are current file available for either of these?
 				//give priority to shared, then list
 				sharedfile = current->getSharedFile();
-				if (sharedfile != "") {  m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
+				if (sharedfile != "") {  m->mothurOut("Using " + sharedfile + " as input file for the shared parameter.\n");  }
 				else {
 					listfile = current->getListFile();
-					if (listfile != "") {  m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
+					if (listfile != "") {  m->mothurOut("Using " + listfile + " as input file for the list parameter.\n");  }
 					else {
-						m->mothurOut("No valid current files. You must provide a shared or list file."); m->mothurOutEndLine();
+						m->mothurOut("No valid current files. You must provide a shared or list file.\n"); 
 						abort = true;
 					}
 				}
             }else if ((sharedfile != "") && (listfile != "")) {
-                m->mothurOut("You may enter ONLY ONE of the following: shared or list."); m->mothurOutEndLine(); abort = true;
+                m->mothurOut("You may enter ONLY ONE of the following: shared or list.\n");  abort = true;
             }
 			
             if (listfile != "") {
                 if ((groupfile == "") && (countfile == "")) {
                     groupfile = current->getGroupFile();
-                    if (groupfile != "") {  m->mothurOut("Using " + groupfile + " as input file for the group parameter."); m->mothurOutEndLine(); }
+                    if (groupfile != "") {  m->mothurOut("Using " + groupfile + " as input file for the group parameter.\n");  }
                     else {
                         countfile = current->getCountFile();
-                        if (countfile != "") {  m->mothurOut("Using " + countfile + " as input file for the count parameter."); m->mothurOutEndLine(); }
+                        if (countfile != "") {  m->mothurOut("Using " + countfile + " as input file for the count parameter.\n");  }
                         else {
-                            m->mothurOut("You need to provide a groupfile or countfile if you are going to use the list format."); m->mothurOutEndLine();
+                            m->mothurOut("You need to provide a groupfile or countfile if you are going to use the list format.\n"); 
                             abort = true;
                         }
                     }
                 }
 			}
 
-			if ((sharedfile != "") && (fastafile != "")) { m->mothurOut("You cannot use the fasta file with the shared file."); m->mothurOutEndLine(); abort = true; }
+			if ((sharedfile != "") && (fastafile != "")) { m->mothurOut("You cannot use the fasta file with the shared file.\n");  abort = true; }
             
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
@@ -329,71 +254,19 @@ int GetSharedOTUCommand::execute(){
             }
             
             InputData input(listfile, "list", nullVector);
-            ListVector* list = input.getListVector();
-            string lastLabel = "";
-            
-            //if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
             set<string> processedLabels;
             set<string> userLabels = labels;
+            string lastLabel = "";
             
+            ListVector* list = util.getNextList(input, allLines, userLabels, processedLabels, lastLabel);
             
-            while((list != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
+            while (list != NULL) {
                 
-                if (m->getControl_pressed()) {
-                    for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); }  outputTypes.clear();
-                    if (groupfile != "") { delete groupMap; }else { delete ct; } return 0;
-                }
+                if (m->getControl_pressed()) { delete list; break; }
                 
-                if(allLines == 1 || labels.count(list->getLabel()) == 1){
-                    m->mothurOut(list->getLabel());
-                    process(list);
+                process(list); delete list;
                 
-                    processedLabels.insert(list->getLabel());
-                    userLabels.erase(list->getLabel());
-                }
-                
-                if ((util.anyLabelsToProcess(list->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-                    string saveLabel = list->getLabel();
-                    
-                    delete list;
-                    list = input.getListVector(lastLabel);
-                    
-                    m->mothurOut(list->getLabel());
-                    process(list);
-                    
-                    processedLabels.insert(list->getLabel());
-                    userLabels.erase(list->getLabel());
-                    
-                    //restore real lastlabel to save below
-                    list->setLabel(saveLabel);
-                }
-                
-                lastLabel = list->getLabel();			
-                
-                delete list;
-                list = input.getListVector();
-            }
-
-            //output error messages about any remaining user labels
-            set<string>::iterator it;
-            bool needToRun = false;
-            for (it = userLabels.begin(); it != userLabels.end(); it++) {  
-                m->mothurOut("Your file does not include the label " + *it); 
-                if (processedLabels.count(lastLabel) != 1) {
-                    m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-                    needToRun = true;
-                }else {
-                    m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-                }
-            }
-            
-            //run last label if you need to
-            if (needToRun )  {
-                if (list != NULL) {		delete list;	}
-                list = input.getListVector(lastLabel);
-                
-                process(list);
-                delete list;
+                list = util.getNextList(input, allLines, userLabels, processedLabels, lastLabel);
             }
             
             if (m->getControl_pressed()) { outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); }  if (groupfile != "") { delete groupMap; }else { delete ct; } return 0; } 
@@ -433,9 +306,9 @@ int GetSharedOTUCommand::process(ListVector* shared) {
 		ofstream outNames;
 		string outputFileNames;
 		
-		if (outputDir == "") { outputDir += util.hasPath(listfile); }
+		if (outputdir == "") { outputdir += util.hasPath(listfile); }
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(listfile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(listfile));
         variables["[distance]"] = shared->getLabel();
         variables["[group]"] = userGroups;
 		if (output != "accnos") { outputFileNames = getOutputFileName("sharedseqs", variables); }
@@ -476,7 +349,7 @@ int GetSharedOTUCommand::process(ListVector* shared) {
 					namesOfSeqsInThisBin.push_back((name + "|" + seqGroup + "|" + binLabels[i]));
 				}else {  namesOfSeqsInThisBin.push_back(name);	}
 				
-				if (seqGroup == "not found") { m->mothurOut(name + " is not in your groupfile. Please correct."); m->mothurOutEndLine(); exit(1);  }
+				if (seqGroup == "not found") { m->mothurOut(name + " is not in your groupfile. Please correct.\n");  exit(1);  }
 				
                 if (groupfile != "") {
                     //is this seq in one of hte groups we care about
@@ -546,8 +419,8 @@ int GetSharedOTUCommand::process(ListVector* shared) {
 		
 		//if fasta file provided output new fasta file
 		if ((fastafile != "") && wroteSomething) {
-			if (outputDir == "") { outputDir += util.hasPath(fastafile); }
-            variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastafile));
+			if (outputdir == "") { outputdir += util.hasPath(fastafile); }
+            variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
 			string outputFileFasta = getOutputFileName("fasta", variables);
 			ofstream outFasta;
 			util.openOutputFile(outputFileFasta, outFasta);
@@ -585,9 +458,12 @@ int GetSharedOTUCommand::process(ListVector* shared) {
 int GetSharedOTUCommand::runShared() {
 	try {
         InputData input(sharedfile, "sharedfile", Groups);
-		SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
+		set<string> processedLabels;
+        set<string> userLabels = labels;
+        string lastLabel = "";
+        
+        SharedRAbundVectors* lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
         Groups = lookup->getNamesGroups();
-		string lastLabel = lookup->getLabel();
         
         if (userGroups == "") {
             //make string for outputfile name
@@ -599,80 +475,18 @@ int GetSharedOTUCommand::runShared() {
         
         //put groups in map to find easier
         for(int i = 0; i < Groups.size(); i++) { groupFinder[Groups[i]] = Groups[i];}
-
-		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
-		set<string> processedLabels;
-		set<string> userLabels = labels;
         
-		//as long as you are not at the end of the file or done wih the lines you want
-		while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-			if (m->getControl_pressed()) {
-                outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); }
-                delete lookup;  return 0;
-			}
+        while (lookup != NULL) {
             
+            if (m->getControl_pressed()) { delete lookup; break; }
             
-			if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
-				m->mothurOut(lookup->getLabel());
-				process(lookup);
-				
-				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
-			}
-			
-			if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-                string saveLabel = lookup->getLabel();
-                
-                delete lookup;
-                lookup = input.getSharedRAbundVectors(lastLabel);
-                
-                m->mothurOut(lookup->getLabel());
-                process(lookup);
-                
-                processedLabels.insert(lookup->getLabel());
-                userLabels.erase(lookup->getLabel());
-                
-                //restore real lastlabel to save below
-                lookup->setLabels(saveLabel);
-			}
-			
-			lastLabel = lookup->getLabel();
+            process(lookup); delete lookup;
             
-			//get next line to process
-			//prevent memory leak
-			delete lookup;
-			lookup = input.getSharedRAbundVectors();
-		}
-		
-		if (m->getControl_pressed()) {
-            outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); }
-            delete lookup;  return 0;
+            lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
         }
         
-		//output error messages about any remaining user labels
-		set<string>::iterator it;
-		bool needToRun = false;
-		for (it = userLabels.begin(); it != userLabels.end(); it++) {
-			m->mothurOut("Your file does not include the label " + *it);
-			if (processedLabels.count(lastLabel) != 1) {
-				m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-				needToRun = true;
-			}else {
-				m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-			}
-		}
-		
-		//run last label if you need to
-		if (needToRun )  {
-            delete lookup;
-            lookup = input.getSharedRAbundVectors(lastLabel);
-            
-            m->mothurOut(lookup->getLabel());
-            process(lookup);
-            delete lookup;
-		}
+		if (m->getControl_pressed()) { outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
         
-		//reset groups parameter
-		  
 		
 		return 0;
 
@@ -687,9 +501,9 @@ int GetSharedOTUCommand::process(SharedRAbundVectors*& lookup) {
 	try {
 		
 		string outputFileNames;
-		if (outputDir == "") { outputDir += util.hasPath(sharedfile); }
+		if (outputdir == "") { outputdir += util.hasPath(sharedfile); }
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(sharedfile));
         variables["[distance]"] = lookup->getLabel();
         variables["[group]"] = userGroups;
 		if (output != "accnos") { outputFileNames = getOutputFileName("sharedseqs", variables); }
