@@ -14,7 +14,8 @@
 vector<string> LefseCommand::setParameters(){
 	try {
         CommandParameter pdesign("design", "InputTypes", "", "", "none", "none", "none","",false,true,true); parameters.push_back(pdesign);
-        CommandParameter pshared("shared", "InputTypes", "", "", "none", "none", "none","summary",false,true,true); parameters.push_back(pshared);
+        CommandParameter pshared("shared", "InputTypes", "", "", "shared-clr", "none", "none","metastats",false,false,true); parameters.push_back(pshared);
+        //CommandParameter pclr("clr", "InputTypes", "", "", "shared-clr", "none", "none","metastats",false,false,true); parameters.push_back(pclr);
         CommandParameter pclass("class", "String", "", "", "", "", "","",false,false); parameters.push_back(pclass);
         CommandParameter psubclass("subclass", "String", "", "", "", "", "","",false,false); parameters.push_back(psubclass);
 		CommandParameter plabel("label", "String", "", "", "", "", "","",false,false); parameters.push_back(plabel);
@@ -45,6 +46,11 @@ vector<string> LefseCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false; allLines = true;
+        
+        vector<string> tempOutNames;
+        outputTypes["summary"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -102,77 +108,33 @@ string LefseCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-LefseCommand::LefseCommand(){
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-        vector<string> tempOutNames;
-		outputTypes["summary"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "LefseCommand", "LefseCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 LefseCommand::LefseCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;
-        allLines = true;
-		
-		//allow user to run help
+
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			//valid paramters for this command
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string,string>::iterator it;
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) {
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			vector<string> tempOutNames;
-            outputTypes["summary"] = tempOutNames;
+            sharedfile = validParameter.validFile(parameters, "shared");
+            if (sharedfile == "not open") { abort = true; }
+            else if (sharedfile == "not found") { sharedfile = "";  }
+            else { current->setSharedFile(sharedfile); inputfile = sharedfile; format = "sharedfile";  }
             
-			//if the user changes the input directory command factory will send this info to us in the output parameter
-			string inputDir = validParameter.valid(parameters, "inputdir");
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-                
-                string path;
-				it = parameters.find("design");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["design"] = inputDir + it->second;		}
-				}
-				
-                it = parameters.find("shared");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
-				}
+            if ((sharedfile == "")) {
+                //is there are current file available for any of these?
+                //give priority to shared, then list, then rabund, then sabund
+                //if there is a current shared file, use it
+                sharedfile = current->getSharedFile();
+                if (sharedfile != "") { inputfile = sharedfile; format = "sharedfile"; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter.\n"); }
+                else {
+                    m->mothurOut("No valid current files. You must provide a shared file.\n"); abort = true;
+                }
             }
-                    
-            //get shared file, it is required
-			sharedfile = validParameter.validFile(parameters, "shared");
-			if (sharedfile == "not open") { sharedfile = ""; abort = true; }
-			else if (sharedfile == "not found") {
-				//if there is a current shared file, use it
-				sharedfile = current->getSharedFile();
-				if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current sharedfile and the shared parameter is required."); m->mothurOutEndLine(); abort = true; }
-			}else { current->setSharedFile(sharedfile); }
             
             //get shared file, it is required
 			designfile = validParameter.validFile(parameters, "design");
@@ -180,13 +142,13 @@ LefseCommand::LefseCommand(string option)  {
 			else if (designfile == "not found") {
 				//if there is a current shared file, use it
 				designfile = current->getDesignFile();
-				if (designfile != "") { m->mothurOut("Using " + designfile + " as input file for the design parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current design file and the design parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (designfile != "") { m->mothurOut("Using " + designfile + " as input file for the design parameter.\n");  }
+				else { 	m->mothurOut("You have no current design file and the design parameter is required.\n");  abort = true; }
 			}else { current->setDesignFile(designfile); }
             
-            //if the user changes the output directory command factory will send this info to us in the output parameter
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){
-				outputDir = util.hasPath(sharedfile); //if user entered a file with a path then preserve it
+            
+            if (outputdir == ""){
+				outputdir = util.hasPath(inputfile); 
 			}
             
             string label = validParameter.valid(parameters, "label");
@@ -251,7 +213,7 @@ LefseCommand::LefseCommand(string option)  {
             
             multiClassStrat = validParameter.valid(parameters, "multiclass");
             if (multiClassStrat == "not found"){	multiClassStrat = "onevall";		}
-			if ((multiClassStrat != "onevall") && (multiClassStrat != "onevone")) { m->mothurOut("Invalid multiclass option: choices are onevone or onevall."); m->mothurOutEndLine(); abort=true; }
+			if ((multiClassStrat != "onevall") && (multiClassStrat != "onevone")) { m->mothurOut("Invalid multiclass option: choices are onevone or onevall.\n");  abort=true; }
 		}
 		
 	}
@@ -279,82 +241,26 @@ int LefseCommand::execute(){
             Groups = designMap.getNamesGroups(Sets);
         }
         
-        InputData input(sharedfile, "sharedfile", Groups);
-        SharedRAbundFloatVectors* lookup = input.getSharedRAbundFloatVectors();
-        string lastLabel = lookup->getLabel();
-        Groups = lookup->getNamesGroups();
-        
-        //if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
+        InputData input(inputfile, format, Groups);
         set<string> processedLabels;
         set<string> userLabels = labels;
+        string lastLabel = "";
         
-        //as long as you are not at the end of the file or done wih the lines you want
-        while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-            
-            if (m->getControl_pressed()) { delete lookup;  return 0; }
-            
-            if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
-                
-                m->mothurOut(lookup->getLabel()+"\n"); 
-                
-                process(lookup, designMap);
-                
-                processedLabels.insert(lookup->getLabel());
-                userLabels.erase(lookup->getLabel());
-            }
-            
-            if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-                string saveLabel = lookup->getLabel();
-                
-                delete lookup;
-                lookup = input.getSharedRAbundFloatVectors(lastLabel);
-                m->mothurOut(lookup->getLabel()+"\n"); 
-                
-                process(lookup, designMap);
-                
-                processedLabels.insert(lookup->getLabel());
-                userLabels.erase(lookup->getLabel());
-                
-                //restore real lastlabel to save below
-                lookup->setLabels(saveLabel);
-            }
-            
-            lastLabel = lookup->getLabel();
-            //prevent memory leak
-            delete lookup;
-            
-            if (m->getControl_pressed()) { return 0; }
-            
-            //get next line to process
-            lookup = input.getSharedRAbundFloatVectors();
+        SharedRAbundFloatVectors* lookup = NULL; SharedCLRVectors* clr = NULL;
+        
+        if (format == "sharedfile") {
+            lookup = util.getNextRelabund(input, allLines, userLabels, processedLabels, lastLabel);
+            Groups = lookup->getNamesGroups();
         }
         
-        if (m->getControl_pressed()) {  return 0; }
-        
-        //output error messages about any remaining user labels
-        set<string>::iterator it;
-        bool needToRun = false;
-        for (it = userLabels.begin(); it != userLabels.end(); it++) {
-            m->mothurOut("Your file does not include the label " + *it);
-            if (processedLabels.count(lastLabel) != 1) {
-                m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-                needToRun = true;
-            }else {
-                m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-            }
-        }
-        
-        //run last label if you need to
-        if (needToRun )  {
-            delete lookup;
-            lookup = input.getSharedRAbundFloatVectors(lastLabel);
+        while ((lookup != NULL) || (clr != NULL)){
             
-            m->mothurOut(lookup->getLabel()+"\n"); 
-            process(lookup, designMap);
+            if (m->getControl_pressed()) { if (lookup != NULL) { delete lookup; } if (clr != NULL) { delete clr; }break; }
             
-            delete lookup;
+            process(lookup, clr, designMap);
+            
+            if (format == "sharedfile") { delete lookup; lookup = util.getNextRelabund(input, allLines, userLabels, processedLabels, lastLabel); }
         }
-                
 		
         //output files created by command
 		m->mothurOut("\nOutput File Names: \n"); 
@@ -369,8 +275,7 @@ int LefseCommand::execute(){
 	}
 }
 //**********************************************************************************************************************
-
-int LefseCommand::process(SharedRAbundFloatVectors*& lookup, DesignMap& designMap) {
+int LefseCommand::process(SharedRAbundFloatVectors*& lookup, SharedCLRVectors*& clr, DesignMap& designMap) {
 	try {
         vector<string> classes;
         vector<string> subclasses;
@@ -378,8 +283,11 @@ int LefseCommand::process(SharedRAbundFloatVectors*& lookup, DesignMap& designMa
         map<string, set<string> > class2SubClasses; //maps class name to vector of its subclasses
         map<string, vector<int> > subClass2GroupIndex; //maps subclass name to vector of indexes in lookup from that subclass. old -> 1,2,3 means groups in location 1,2,3 of lookup are from old.  Saves time below.
         map<string, vector<int> > class2GroupIndex; //maps subclass name to vector of indexes in lookup from that class. old -> 1,2,3 means groups in location 1,2,3 of lookup are from old.  Saves time below.
-        if (normMillion) {  normalize(lookup);  }
-        vector<string> namesOfGroups = lookup->getNamesGroups();
+        if (normMillion) {  normalize(lookup, clr);  }
+        vector<string> namesOfGroups;
+        if (lookup != NULL) { namesOfGroups = lookup->getNamesGroups();  }
+        else                { namesOfGroups = clr->getNamesGroups();     }
+        
         for (int j = 0; j < namesOfGroups.size(); j++) {
             string group = namesOfGroups[j];
             string treatment = designMap.get(group, mclass); //get value for this group in this category
@@ -414,10 +322,10 @@ int LefseCommand::process(SharedRAbundFloatVectors*& lookup, DesignMap& designMa
         //sort classes so order is right
         sort(classes.begin(), classes.end());
         
-        vector< vector<double> > means = getMeans(lookup, class2GroupIndex); //[numOTUs][classes] - classes in same order as class2GroupIndex
+        vector< vector<double> > means = getMeans(lookup, clr, class2GroupIndex); //[numOTUs][classes] - classes in same order as class2GroupIndex
         
         //run kruskal wallis on each otu
-        map<int, double> significantOtuLabels = runKruskalWallis(lookup, designMap);
+        map<int, double> significantOtuLabels = runKruskalWallis(lookup, clr, designMap);
         
         int numSigBeforeWilcox = significantOtuLabels.size();
         
@@ -425,7 +333,7 @@ int LefseCommand::process(SharedRAbundFloatVectors*& lookup, DesignMap& designMa
         
         //check for subclass
         string wilcoxString = "";
-        if ((subclass != "") && wilc) {  significantOtuLabels = runWilcoxon(lookup, designMap, significantOtuLabels, class2SubClasses, subClass2GroupIndex, subclass2Class);  wilcoxString += " ( " + toString(numSigBeforeWilcox) + " ) before internal wilcoxon"; }
+        if ((subclass != "") && wilc) {  significantOtuLabels = runWilcoxon(lookup, clr, designMap, significantOtuLabels, class2SubClasses, subClass2GroupIndex, subclass2Class);  wilcoxString += " ( " + toString(numSigBeforeWilcox) + " ) before internal wilcoxon"; }
         
         int numSigAfterWilcox = significantOtuLabels.size();
         
@@ -435,14 +343,19 @@ int LefseCommand::process(SharedRAbundFloatVectors*& lookup, DesignMap& designMa
         
         map<int, double> sigOTUSLDA;
         if (numSigAfterWilcox > 0) {
-            sigOTUSLDA = testLDA(lookup, significantOtuLabels, class2GroupIndex, subClass2GroupIndex);
+            sigOTUSLDA = testLDA(lookup, clr, significantOtuLabels, class2GroupIndex, subClass2GroupIndex);
             m->mothurOut("Number of discriminative features with abs LDA score > " + toString(ldaThreshold) + " : " + toString(significantOtuLabels.size()) + ".\n");
         }
         else { m->mothurOut("No features with significant differences between the classes.\n"); }
         
         if (m->getDebug()) { m->mothurOut("[DEBUG]: completed lda\n"); } 
         
-        printResults(means, significantOtuLabels, sigOTUSLDA, lookup->getLabel(), classes, lookup->getOTUNames());
+        string label;
+        vector<string> otuNames;
+        if (lookup != NULL) {   label = lookup->getLabel();  otuNames = lookup->getOTUNames(); }
+        else                {   label = clr->getLabel();  otuNames = clr->getOTUNames();       }
+        
+        printResults(means, significantOtuLabels, sigOTUSLDA, label, classes, otuNames);
         
         return 0;
     }
@@ -452,18 +365,34 @@ int LefseCommand::process(SharedRAbundFloatVectors*& lookup, DesignMap& designMa
 	}
 }
 //**********************************************************************************************************************
-int LefseCommand::normalize(SharedRAbundFloatVectors*& lookup) {
+int LefseCommand::normalize(SharedRAbundFloatVectors*& lookup, SharedCLRVectors*& clr) {
 	try {
         vector<double> mul;
-        vector<string> namesOfGroups = lookup->getNamesGroups();
-        for (int i = 0; i < lookup->size(); i++) {
-            double sum = lookup->getNumSeqs(namesOfGroups[i]);
+        vector<string> namesOfGroups;
+        int numBins = 0;
+        int numSamples = 0;
+        
+        if (lookup != NULL) {
+            namesOfGroups = lookup->getNamesGroups();
+            numBins = lookup->getNumBins();
+            numSamples = lookup->size();
+        }else {
+            namesOfGroups = clr->getNamesGroups();
+            numBins = clr->getNumBins();
+            numSamples = clr->size();
+        }
+        
+        for (int i = 0; i < numSamples; i++) {
+            double sum = 0;
+            if (lookup != NULL) {  sum = lookup->getNumSeqs(namesOfGroups[i]);    }
+            else                {  sum = clr->getNumSeqs(namesOfGroups[i]);       }
             mul.push_back(1000000.0/sum);
         }
         
-        for (int i = 0; i < lookup->size(); i++) {
-            for (int j = 0; j < lookup->getNumBins(); j++) {
-                lookup->set(j, lookup->get(j, namesOfGroups[i])*mul[i], namesOfGroups[i]);
+        for (int i = 0; i < numSamples; i++) {
+            for (int j = 0; j < numBins; j++) {
+                if (lookup != NULL) { lookup->set(j, lookup->get(j, namesOfGroups[i])*mul[i], namesOfGroups[i]);    }
+                else                { clr->set(j, clr->get(j, namesOfGroups[i])*mul[i], namesOfGroups[i]);       }
             }
         }
         
@@ -475,13 +404,22 @@ int LefseCommand::normalize(SharedRAbundFloatVectors*& lookup) {
 	}
 }
 //**********************************************************************************************************************
-map<int, double> LefseCommand::runKruskalWallis(SharedRAbundFloatVectors*& lookup, DesignMap& designMap) {
-	try {        
+map<int, double> LefseCommand::runKruskalWallis(SharedRAbundFloatVectors*& lookup, SharedCLRVectors*& clr, DesignMap& designMap) {
+	try {
+        vector<string> namesOfGroups;
+        int numBins = 0;
+        
+        if (lookup != NULL) {
+            namesOfGroups = lookup->getNamesGroups();
+            numBins = lookup->getNumBins();
+        }else {
+            namesOfGroups = clr->getNamesGroups();
+            numBins = clr->getNumBins();
+        }
         map<int, double> significantOtuLabels;
-        int numBins = lookup->getNumBins();
+        
         //sanity check to make sure each treatment has a group in the shared file
         set<string> treatments;
-        vector<string> namesOfGroups = lookup->getNamesGroups();
         for (int j = 0; j < namesOfGroups.size(); j++) {
             string group = namesOfGroups[j];
             string treatment = designMap.get(group, mclass); //get value for this group in this category
@@ -494,7 +432,10 @@ map<int, double> LefseCommand::runKruskalWallis(SharedRAbundFloatVectors*& looku
             if (m->getControl_pressed()) { break; }
             
             vector<spearmanRank> values;
-            vector<float> abunds = lookup->getOTU(i);
+            vector<float> abunds;
+            if (lookup != NULL) { abunds = lookup->getOTU(i);   }
+            else                { abunds = clr->getOTU(i);      }
+            
             for (int j = 0; j < namesOfGroups.size(); j++) {
                 string group = namesOfGroups[j];
                 string treatment = designMap.get(group, mclass); //get value for this group in this category
@@ -517,7 +458,7 @@ map<int, double> LefseCommand::runKruskalWallis(SharedRAbundFloatVectors*& looku
 }
 //**********************************************************************************************************************
 //assumes not neccessarily paired
-map<int, double> LefseCommand::runWilcoxon(SharedRAbundFloatVectors*& lookup, DesignMap& designMap, map<int, double> bins, map<string, set<string> >& class2SubClasses, map<string, vector<int> >& subClass2GroupIndex, map<string, string> subclass2Class) {
+map<int, double> LefseCommand::runWilcoxon(SharedRAbundFloatVectors*& lookup, SharedCLRVectors*& clr, DesignMap& designMap, map<int, double> bins, map<string, set<string> >& class2SubClasses, map<string, vector<int> >& subClass2GroupIndex, map<string, string> subclass2Class) {
     try {
         map<int, double> significantOtuLabels;
         map<int, double>::iterator it;
@@ -526,15 +467,19 @@ map<int, double> LefseCommand::runWilcoxon(SharedRAbundFloatVectors*& lookup, De
          1. Subclass members all belong to same main class
          anything else
         */
+        int numBins = 0;
+        if (lookup != NULL) { numBins = lookup->getNumBins();   }
+        else                { numBins = clr->getNumBins();      }
         
-        int numBins = lookup->getNumBins();
         for (int i = 0; i < numBins; i++) {
             if (m->getControl_pressed()) { break; }
             
             it = bins.find(i);
             if (it != bins.end()) { //flagged in Kruskal Wallis
                 
-                vector<float> abunds = lookup->getOTU(i);
+                vector<float> abunds;
+                if (lookup != NULL) { abunds = lookup->getOTU(i);   }
+                else                { abunds = clr->getOTU(i);      }
                 
                 bool sig = testOTUWilcoxon(class2SubClasses, abunds, subClass2GroupIndex, subclass2Class);
                 if (sig) { significantOtuLabels[i] = it->second;  }
@@ -706,13 +651,21 @@ bool LefseCommand::testOTUWilcoxon(map<string, set<string> >& class2SubClasses,
 }
 //**********************************************************************************************************************
 //modelled after lefse.py test_lda_r function
-map<int, double> LefseCommand::testLDA(SharedRAbundFloatVectors*& lookup, map<int, double> bins, map<string, vector<int> >& class2GroupIndex, map<string, vector<int> >& subClass2GroupIndex) {
+map<int, double> LefseCommand::testLDA(SharedRAbundFloatVectors*& lookup, SharedCLRVectors*& clr, map<int, double> bins, map<string, vector<int> >& class2GroupIndex, map<string, vector<int> >& subClass2GroupIndex) {
     try {
         map<int, double> sigOTUS;
         map<int, double>::iterator it;
         LinearAlgebra linear;
     
-        int numBins = lookup->getNumBins();
+        int numBins = 0;
+        int numGroups = 0;
+        if (lookup != NULL) {
+            numBins = lookup->getNumBins();
+            numGroups = lookup->size(); //lfk
+        }else                {
+            numBins = clr->getNumBins();
+            numGroups = clr->size(); //lfk
+        }
         vector< vector<double> > adjustedLookup;
         
         for (int i = 0; i < numBins; i++) {
@@ -726,7 +679,9 @@ map<int, double> LefseCommand::testLDA(SharedRAbundFloatVectors*& lookup, map<in
                 if (m->getDebug()) { m->mothurOut("[DEBUG]:flagged bin = " + toString(i) + "\n."); }
                 
                 //fill x with this OTUs abundances
-                vector<float> tempx = lookup->getOTU(i);
+                vector<float> tempx;
+                if (lookup != NULL) { tempx = lookup->getOTU(i);   }
+                else                { tempx = clr->getOTU(i);      }
                 vector<double> x; for (int h = 0; h < tempx.size(); h++) { x.push_back((double)tempx[h]); }
                 
                 //go through classes
@@ -767,7 +722,7 @@ map<int, double> LefseCommand::testLDA(SharedRAbundFloatVectors*& lookup, map<in
             classes.push_back(it->first);
         }
         
-        int numGroups = lookup->size(); //lfk
+        
         int fractionNumGroups = numGroups * fBoots; //rfk
         minCl = (int)((float)(minCl*fBoots*fBoots*0.05));
         minCl = max(minCl, 1);
@@ -836,9 +791,12 @@ map<int, double> LefseCommand::testLDA(SharedRAbundFloatVectors*& lookup, map<in
     }
 }
 //**********************************************************************************************************************
-vector< vector<double> > LefseCommand::getMeans(SharedRAbundFloatVectors*& lookup, map<string, vector<int> >& class2GroupIndex) {
+vector< vector<double> > LefseCommand::getMeans(SharedRAbundFloatVectors*& lookup, SharedCLRVectors*& clr, map<string, vector<int> >& class2GroupIndex) {
     try {
-        int numBins = lookup->getNumBins();
+        int numBins = 0;
+        if (lookup != NULL) {  numBins = lookup->getNumBins();   }
+        else                {  numBins = clr->getNumBins();      }
+        
         int numClasses = class2GroupIndex.size();
         vector< vector<double> > means; //[numOTUS][classes]
         means.resize(numBins);
@@ -856,7 +814,10 @@ vector< vector<double> > LefseCommand::getMeans(SharedRAbundFloatVectors*& looku
         }
         
         for (int i = 0; i < numBins; i++) {
-            vector<float> abunds = lookup->getOTU(i);
+            vector<float> abunds;
+            if (lookup != NULL) { abunds = lookup->getOTU(i);   }
+            else                { abunds = clr->getOTU(i);      }
+            
             for (int j = 0; j < abunds.size(); j++) {
                 if (m->getControl_pressed()) { return means; }
                 means[i][quickIndex[indexToClass[j]]] += abunds[j];
@@ -1004,7 +965,7 @@ bool LefseCommand::contastWithinClassesOrFewPerClass(vector< vector<double> >& l
 int LefseCommand::printResults(vector< vector<double> > means, map<int, double> sigKW, map<int, double> sigLDA, string label, vector<string> classes, vector<string> currentLabels) {
     try {
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(inputfile));
         variables["[distance]"] = label;
         string outputFileName = getOutputFileName("summary",variables);
 		ofstream out;
