@@ -34,6 +34,12 @@ vector<string> LibShuffCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["coverage"] = tempOutNames;
+        outputTypes["libshuffsummary"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -80,78 +86,27 @@ string LibShuffCommand::getOutputPattern(string type) {
         exit(1);
     }
 }
-//**********************************************************************************************************************
-LibShuffCommand::LibShuffCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["coverage"] = tempOutNames;
-		outputTypes["libshuffsummary"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "LibShuffCommand", "LibShuffCommand");
-		exit(1);
-	}
-}
-
 //**********************************************************************************************************************
 LibShuffCommand::LibShuffCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-		
-		//allow user to run help
+
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters();
 			map<string,string>::iterator it;
 			
 			ValidParameters validParameter;
-		
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["coverage"] = tempOutNames;
-			outputTypes["libshuffsummary"] = tempOutNames;
-			
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("phylip");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["phylip"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-			}
-			
-			//check for required parameters
 			phylipfile = validParameter.validFile(parameters, "phylip");
 			if (phylipfile == "not open") { phylipfile = ""; abort = true; }
 			else if (phylipfile == "not found") { 
 				phylipfile = current->getPhylipFile(); 
-				if (phylipfile != "") {  m->mothurOut("Using " + phylipfile + " as input file for the phylip parameter."); m->mothurOutEndLine(); }
+				if (phylipfile != "") {  m->mothurOut("Using " + phylipfile + " as input file for the phylip parameter.\n");  }
 				else { 
-					m->mothurOut("You must provide a phylip file."); m->mothurOutEndLine(); 
+					m->mothurOut("You must provide a phylip file.\n");  
 					abort = true;
 				} 
 			}else { current->setPhylipFile(phylipfile); }	
@@ -161,18 +116,14 @@ LibShuffCommand::LibShuffCommand(string option)  {
 			if (groupfile == "not open") { groupfile = ""; abort = true; }
 			else if (groupfile == "not found") { 
 				groupfile = current->getGroupFile(); 
-				if (groupfile != "") {  m->mothurOut("Using " + groupfile + " as input file for the group parameter."); m->mothurOutEndLine(); }
+				if (groupfile != "") {  m->mothurOut("Using " + groupfile + " as input file for the group parameter.\n");  }
 				else { 
-					m->mothurOut("You must provide a group file."); m->mothurOutEndLine(); 
+					m->mothurOut("You must provide a group file.\n");  
 					abort = true;
 				} 
 			}else { current->setGroupFile(groupfile); }	
 			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	
-				outputDir = "";	
-				outputDir += util.hasPath(phylipfile); //if user entered a file with a path then preserve it	
-			}
+			if (outputdir == ""){ outputdir += util.hasPath(phylipfile);  }
 						
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
@@ -230,9 +181,9 @@ int LibShuffCommand::execute(){
 		if (matrix->getNumSeqs() < groupMap->getNumSeqs()) {  
 			m->mothurOut("Your distance file contains " + toString(matrix->getNumSeqs()) + " sequences, and your group file contains " + toString(groupMap->getNumSeqs()) + " sequences.");  m->mothurOutEndLine();				
 			//create new group file
-			if(outputDir == "") { outputDir += util.hasPath(groupfile); }
+			if(outputdir == "") { outputdir += util.hasPath(groupfile); }
 			
-			string newGroupFile = outputDir + util.getRootName(util.getSimpleName(groupfile)) + "editted.groups";
+			string newGroupFile = outputdir + util.getRootName(util.getSimpleName(groupfile)) + "editted.groups";
 			outputNames.push_back(newGroupFile);
 			ofstream outGroups;
 			util.openOutputFile(newGroupFile, outGroups);
@@ -245,7 +196,7 @@ int LibShuffCommand::execute(){
 			}
 			outGroups.close();
 			
-			m->mothurOut(newGroupFile + " is a new group file containing only the sequence that are in your distance file. I will read this file instead."); m->mothurOutEndLine();
+			m->mothurOut(newGroupFile + " is a new group file containing only the sequence that are in your distance file. I will read this file instead.\n"); 
 			
 			//read new groupfile
 			delete groupMap; 
@@ -260,7 +211,7 @@ int LibShuffCommand::execute(){
 			
 		setGroups();								//set the groups to be analyzed and sorts them
 		
-		if (numGroups < 2) { m->mothurOut("[ERROR]: libshuff requires at least 2 groups, you only have " + toString(numGroups) + ", aborting."); m->mothurOutEndLine(); m->setControl_pressed(true); }
+		if (numGroups < 2) { m->mothurOut("[ERROR]: libshuff requires at least 2 groups, you only have " + toString(numGroups) + ", aborting.\n");  m->setControl_pressed(true); }
 		
 		if (m->getControl_pressed()) { delete groupMap; delete matrix; return 0; }
 		
@@ -344,12 +295,11 @@ int LibShuffCommand::printCoverageFile() {
 
 		ofstream outCov;
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(phylipfile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(phylipfile));
 		summaryFile = getOutputFileName("coverage", variables);
 		util.openOutputFile(summaryFile, outCov);
 		outputNames.push_back(summaryFile); outputTypes["coverage"].push_back(summaryFile);
 		outCov.setf(ios::fixed, ios::floatfield); outCov.setf(ios::showpoint);
-		//cout.setf(ios::fixed, ios::floatfield); cout.setf(ios::showpoint);
 		
 		map<double,vector<int> > allDistances;
 		map<double,vector<int> >::iterator it;
@@ -440,7 +390,7 @@ int LibShuffCommand::printSummaryFile() {
 
 		ofstream outSum;
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(phylipfile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(phylipfile));
 		summaryFile = getOutputFileName("libshuffsummary",variables);
 		util.openOutputFile(summaryFile, outSum);
 		outputNames.push_back(summaryFile); outputTypes["libshuffsummary"].push_back(summaryFile);
@@ -449,7 +399,7 @@ int LibShuffCommand::printSummaryFile() {
 		cout.setf(ios::fixed, ios::floatfield); cout.setf(ios::showpoint);
 		
 		cout << setw(20) << left << "Comparison" << '\t' << setprecision(8) << "dCXYScore" << '\t' << "Significance" << endl;
-		m->mothurOutJustToLog("Comparison\tdCXYScore\tSignificance"); m->mothurOutEndLine();
+		m->mothurOutJustToLog("Comparison\tdCXYScore\tSignificance\n"); 
 		outSum << setw(20) << left << "Comparison" << '\t' << setprecision(8) << "dCXYScore" << '\t' << "Significance" << endl;
 	
 		int precision = (int)log10(iters);
@@ -506,7 +456,7 @@ void LibShuffCommand::setGroups() {
 				//check that groups are valid
 				for (int i = 0; i < myGroups.size(); i++) {
 					if (groupMap->isValidGroup(myGroups[i]) != true) {
-						m->mothurOut(myGroups[i] + " is not a valid group, and will be disregarded."); m->mothurOutEndLine();
+						m->mothurOut(myGroups[i] + " is not a valid group, and will be disregarded.\n"); 
 						// erase the invalid group from globaldata->Groups
 						myGroups.erase(myGroups.begin()+i);
 					}
@@ -516,7 +466,7 @@ void LibShuffCommand::setGroups() {
 				if ((myGroups.size() == 0) || (myGroups.size() == 1)) { 
 					numGroups = groupMap->getNumGroups();
 					for (int i=0; i < numGroups; i++) {  myGroups.push_back((groupMap->getNamesOfGroups())[i]); }
-					m->mothurOut("When using the groups parameter you must have at least 2 valid groups. I will run the command using all the groups in your groupfile."); m->mothurOutEndLine();
+					m->mothurOut("When using the groups parameter you must have at least 2 valid groups. I will run the command using all the groups in your groupfile.\n"); 
 				} else { numGroups = myGroups.size(); }
 			} else { //users wants all groups
 				numGroups = groupMap->getNumGroups();
