@@ -17,35 +17,28 @@ class ListSeqsCommand : public Command {
 	public:
 	
 		ListSeqsCommand(string);
-		ListSeqsCommand();	
 		~ListSeqsCommand(){}
 	
 		vector<string> setParameters();
 		string getCommandName()			{ return "list.seqs";				}
 		string getCommandCategory()		{ return "Sequence Processing";		}
 		
-	string getHelpString();	
-    string getOutputPattern(string);	
+        string getHelpString();	
+        string getOutputPattern(string);
 		string getCitation() { return "http://www.mothur.org/wiki/List.seqs"; }
-		string getDescription()		{ return "lists sequences from a list, fasta, name, group, alignreport or taxonomy file"; }
+		string getDescription()		{ return "lists sequences from a list, fasta, name, group, count, fastq, taxonomy, alignreport or contigsreport file"; }
 
 		int execute(); 
 		void help() { m->mothurOut(getHelpString()); }	
 	
 	
 	private:
-		vector<string> names, outputNames;
-		string fastafile, namefile, groupfile, countfile, alignfile, inputFileName, outputDir, listfile, taxfile, fastqfile, format;
-		bool abort;
-		
-		int readFasta();
-		int readName();
-		int readGroup();
-		int readAlign();
-		int readList();
-		int readTax();
-        int readCount();
-        int readFastq();
+		vector<string> outputNames;
+		vector<string> fastafiles, namefiles, groupfiles, countfiles, alignfiles, listfiles, taxfiles, fastqfiles, contigsreportfiles;
+        string  format, inputFileName;
+        bool abort;
+        
+        void process(vector<string> files, set<string>&, void f(set<string>&, ifstream&, MothurOut*&));
 };
 
 #endif
