@@ -19,6 +19,11 @@ vector<string> MakeFileCommand::setParameters(){
         CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
         CommandParameter pdelim("delim", "String", "", "_", "", "", "","",false,false); parameters.push_back(pdelim);
         
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["file"] = tempOutNames;
+        
         vector<string> myArray;
         for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
         return myArray;
@@ -65,68 +70,34 @@ string MakeFileCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-MakeFileCommand::MakeFileCommand(){
-    try {
-        abort = true; calledHelp = true;
-        setParameters();
-        vector<string> tempOutNames;
-        outputTypes["file"] = tempOutNames;
-    }
-    catch(exception& e) {
-        m->errorOut(e, "MakeFileCommand", "MakeFileCommand");
-        exit(1);
-    }
-}
-
-//**********************************************************************************************************************
-
 MakeFileCommand::MakeFileCommand(string option)  {
     try {
-        
-        abort = false; calledHelp = false;
-        
-        //allow user to run help
-        if(option == "help") { help(); abort = true; calledHelp = true; }
+         if(option == "help") { help(); abort = true; calledHelp = true; }
         else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
         
         else {
-            vector<string> myArray = setParameters();
-            
-            OptionParser parser(option);
+            OptionParser parser(option, setParameters());
             map<string, string> parameters = parser.getParameters();
             
             ValidParameters validParameter;
-            map<string, string>::iterator it;
-            
-            //check to make sure all parameters are valid for command
-            for (it = parameters.begin(); it != parameters.end(); it++) {
-                if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-            }
-            
-            //initialize outputTypes
-            vector<string> tempOutNames;
-            outputTypes["file"] = tempOutNames;
-            
-            //if the user changes the input directory command factory will send this info to us in the output parameter
             inputDir = validParameter.valid(parameters, "inputdir");
-            if (inputDir == "not found"){	inputDir = "";	m->mothurOut("[ERROR]: The inputdir parameter is required, aborting."); m->mothurOutEndLine(); abort = true;	}
+            if (inputDir == "not found"){	inputDir = "";	m->mothurOut("[ERROR]: The inputdir parameter is required, aborting.\n");  abort = true;	}
             else {
                 if (util.dirCheck(inputDir)) {} // all set
                 else { abort = true; }
             }
             
-            //if the user changes the output directory command factory will send this info to us in the output parameter
-            outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = inputDir;		}
-            
+            		if (outputdir == ""){    outputdir = inputDir;		}
             
             //if the user changes the input directory command factory will send this info to us in the output parameter
             typeFile = validParameter.valid(parameters, "type");
             if (typeFile == "not found"){	typeFile = "fastq";		}
             
-            if ((typeFile != "fastq") && (typeFile != "gz")) { m->mothurOut(typeFile + " is not a valid type. Options are fastq or gz. I will use fastq."); m->mothurOutEndLine(); typeFile = "fastq"; }
+            if ((typeFile != "fastq") && (typeFile != "gz")) { m->mothurOut(typeFile + " is not a valid type. Options are fastq or gz. I will use fastq.\n");  typeFile = "fastq"; }
             
             string temp = validParameter.valid(parameters, "numcols");		if(temp == "not found"){	temp = "3"; }
-            if ((temp != "2") && (temp != "3")) { m->mothurOut(temp + " is not a valid numcols. Options are 2 or 3. I will use 3."); m->mothurOutEndLine(); temp = "3";  }
+            if ((temp != "2") && (temp != "3")) { m->mothurOut(temp + " is not a valid numcols. Options are 2 or 3. I will use 3.\n");  temp = "3";  }
             util.mothurConvert(temp, numCols);
             
             prefix = validParameter.valid(parameters, "prefix");		if (prefix == "not found") { prefix = "stability"; }
@@ -172,7 +143,6 @@ int MakeFileCommand::execute(){
             string lastFile = "";
             for (int i = 0; i < fastqFiles.size()-1; i++) {
                 
-                if (m->getDebug()) { m->mothurOut("[DEBUG]: " + toString(i) + ".\n"); }
                 if (m->getDebug()) { m->mothurOut("[DEBUG]: File " + toString(i) + " = " + fastqFiles[i] + ".\n"); }
                 
                 if (m->getControl_pressed()) { break; }
@@ -196,23 +166,29 @@ int MakeFileCommand::execute(){
                         i++;
                     }
                 }else{
+                    if (m->getDebug()) { m->mothurOut("[DEBUG]: Adding single " + fastqFiles[i] + ".\n"); }
                     singles.push_back(util.getSimpleName(fastqFiles[i])); lastFile = fastqFiles[i];
                 }
             }
-            if (lastFile != fastqFiles[fastqFiles.size()-1]) { singles.push_back(util.getSimpleName(fastqFiles[fastqFiles.size()-1])); }
+            if (lastFile != fastqFiles[fastqFiles.size()-1]) {
+                if (m->getDebug()) { m->mothurOut("[DEBUG]: Adding single " + fastqFiles[fastqFiles.size()-1] + ".\n"); }
+                singles.push_back(util.getSimpleName(fastqFiles[fastqFiles.size()-1])); }
             
             if (singles.size() != 0) {
                 map<string, string> variables;
-                variables["[filename]"] = outputDir + prefix + ".";
+                variables["[filename]"] = outputdir + prefix + ".";
                 if (paired.size() != 0) { variables["[tag]"] = "single"; }
                 string filename = getOutputFileName("file",variables);
-                ofstream out;
-                util.openOutputFile(filename, out);
-                outputNames.push_back(filename); outputTypes["file"].push_back(filename);
-                current->setFileFile(filename);
                 
-                for (int i = 0; i < singles.size(); i++) { out << singles[i] << endl; }
-                out.close();
+                ofstream out; util.openOutputFile(filename, out);
+                
+                for (int i = 0; i < singles.size(); i++) { out << singles[i] << endl; } out.close();
+                
+                if (util.isBlank(filename)) {  util.mothurRemove(filename); }
+                else {
+                    outputNames.push_back(filename); outputTypes["file"].push_back(filename);
+                    m->mothurOut("\n[WARNNG]: mothur found unpaired files in your input directory. Outputting list of filenames to " + filename + " for your review.\n\n");
+                }
             }
             
             //generates unique group names
@@ -220,19 +196,15 @@ int MakeFileCommand::execute(){
 
             if (paired.size() != 0) {
                 map<string, string> variables;
-                variables["[filename]"] = outputDir + prefix + ".";
-                if (singles.size() != 0) { variables["[tag]"] = "paired"; }
+                variables["[filename]"] = outputdir + prefix + ".";
                 string filename = getOutputFileName("file",variables);
-                ofstream out;
-                util.openOutputFile(filename, out);
+                
+                ofstream out; util.openOutputFile(filename, out);
                 outputNames.push_back(filename); outputTypes["file"].push_back(filename);
                 current->setFileFile(filename);
                 
                 for (int i = 0; i < paired.size(); i++) {
-                    for (int j = 0; j < paired[i].size(); j++) {
-                        out << paired[i][j] << '\t';
-                    }
-                    out << endl;
+                    for (int j = 0; j < paired[i].size(); j++) { out << paired[i][j] << '\t'; } out << endl;
                 }
                 out.close();
             }
@@ -322,7 +294,7 @@ vector< vector<string> > MakeFileCommand::findGroupNames(vector< vector<string>
                 }
                 
                 if (groupName != "") { groupName = groupName.substr(0, groupName.length()-1); }
-                
+               
                 //is this name unique
                 if (groups.count(groupName) == 0) {  groups.insert(groupName);  }
                 else { groupName = "Group_"+ toString(i); groups.insert(groupName); }
@@ -331,6 +303,7 @@ vector< vector<string> > MakeFileCommand::findGroupNames(vector< vector<string>
             }
             
         }else { //separate by the user selected deliminator. default='_'
+            set<string> groups;
             for (int i = 0; i < paired.size(); i++) {
                 
                 string groupName = "Group_" + toString(i);
@@ -339,6 +312,19 @@ vector< vector<string> > MakeFileCommand::findGroupNames(vector< vector<string>
                 
                 if (pos != string::npos) { groupName = filename.substr(0, pos); }
                 
+                if (groups.count(groupName) == 0) {  groups.insert(groupName);  }
+                else {
+                    //look for another delim
+                    string tempFilename = filename.substr(pos+1); //grab rest of name
+                    pos = tempFilename.find(delim);
+                    if (pos != string::npos) {
+                        groupName += "_" + tempFilename.substr(0, pos);
+                        if (groups.count(groupName) != 0) {  groupName += "_"+ toString(i);  } //already have this name
+                    }
+                    else { groupName += "_"+ toString(i); }
+                    groups.insert(groupName);
+                }
+                
                 results[i].push_back(groupName); results[i].push_back(paired[i][0]); results[i].push_back(paired[i][1]);
             }
         }
@@ -354,20 +340,22 @@ vector< vector<string> > MakeFileCommand::findGroupNames(vector< vector<string>
 
 int MakeFileCommand::fillAccnosFile(string tempFile){
     try {
-        
         string findCommand = "";
         string tempOut = tempFile;
         tempFile = "\"" + tempFile + "\"";
+        string wrappedInput = "\"" + inputDir + "\"";
         
 #if defined NON_WINDOWS
 
-        findCommand = "find \"" + inputDir.substr(0, inputDir.length()-1) + "\" -maxdepth 1 -name \"*." + typeFile + "\" > " + tempFile;
+        findCommand = "ls " + wrappedInput + "*." + typeFile + " > " + tempFile;
+        //findCommand = "find \"" + inputDir.substr(0, inputDir.length()-1) + "\" -maxdepth 1 -name \"*." + typeFile + "\" > " + tempFile;
         if (m->getDebug()) { m->mothurOut(findCommand + "\n"); }
         system(findCommand.c_str());
         
 #else
         //use ls command
-        findCommand = "find \"\" "  + inputDir.substr(0, inputDir.length()-1) + "\\*." + typeFile + " > " + tempFile;
+        findCommand = "dir /B "  + wrappedInput + "*." + typeFile + " > " + tempFile;
+        //findCommand = "dir /B \""  + inputDir.substr(0, inputDir.length()-1) + "\\*.\"" + typeFile + " > " + tempFile + "\"";
         if (m->getDebug()) { m->mothurOut(findCommand + "\n"); }
         system(findCommand.c_str());
 
@@ -384,10 +372,12 @@ int MakeFileCommand::fillAccnosFile(string tempFile){
         string junk, filename;
         while (!in.eof()) {
             if (m->getControl_pressed()) { break; }
-            in >> junk; util.gobble(in);
+           
             in >> filename; util.gobble(in);
-            
-            out << filename << endl;
+
+            if (m->getDebug()) { m->mothurOut("[DEBUG]: Found file " + filename + ".\n"); }
+            //ignore hidden files
+            if (filename[0] != '.') { out << filename << endl; }
         }
         in.close();
         out.close();
