@@ -21,6 +21,11 @@ vector<string> MantelCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["mantel"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -65,84 +70,34 @@ string MantelCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-MantelCommand::MantelCommand(){	
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["mantel"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "MantelCommand", "MantelCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 MantelCommand::MantelCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
 		
-		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string, string>::iterator it;
-			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			vector<string> tempOutNames;
-			outputTypes["mantel"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("phylip1");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["phylip1"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("phylip2");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["phylip2"] = inputDir + it->second;		}
-				}
-			}
-			
-			
-			//check for required parameters
 			phylipfile1 = validParameter.validFile(parameters, "phylip1");
 			if (phylipfile1 == "not open") { phylipfile1 = ""; abort = true; }
-			else if (phylipfile1 == "not found") { phylipfile1 = ""; m->mothurOut("phylip1 is a required parameter for the mantel command."); m->mothurOutEndLine(); abort = true;  }	
+			else if (phylipfile1 == "not found") { phylipfile1 = ""; m->mothurOut("phylip1 is a required parameter for the mantel command.\n");  abort = true;  }
 			
 			phylipfile2 = validParameter.validFile(parameters, "phylip2");
 			if (phylipfile2 == "not open") { phylipfile2 = ""; abort = true; }
-			else if (phylipfile2 == "not found") { phylipfile2 = ""; m->mothurOut("phylip2 is a required parameter for the mantel command."); m->mothurOutEndLine(); abort = true;  }	
+			else if (phylipfile2 == "not found") { phylipfile2 = ""; m->mothurOut("phylip2 is a required parameter for the mantel command.\n"); abort = true;  }
 			
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(phylipfile1);	}
+					if (outputdir == ""){    outputdir = util.hasPath(phylipfile1);	}
 			
 			method = validParameter.valid(parameters, "method");		if (method == "not found"){	method = "pearson";		}
 			
 			string temp = validParameter.valid(parameters, "iters");			if (temp == "not found") { temp = "1000"; }
 			util.mothurConvert(temp, iters);
 			
-			if ((method != "pearson") && (method != "spearman") && (method != "kendall")) { m->mothurOut(method + " is not a valid method. Valid methods are pearson, spearman, and kendall."); m->mothurOutEndLine(); abort = true; }
+			if ((method != "pearson") && (method != "spearman") && (method != "kendall")) { m->mothurOut(method + " is not a valid method. Valid methods are pearson, spearman, and kendall.\n"); abort = true; }
 		}
 	}
 	catch(exception& e) {
@@ -178,10 +133,10 @@ int MantelCommand::execute(){
 		//make sure matrix2 and matrix1 are in the same order
 		if (names1 == names2) { //then everything is in same order and same size
 		}else if (names1.size() != names2.size()) { //wrong size no need to order, abort
-			m->mothurOut("[ERROR]: distance matrices are not the same size, aborting."); m->mothurOutEndLine();
+			m->mothurOut("[ERROR]: distance matrices are not the same size, aborting.\n"); 
 			m->setControl_pressed(true);
 		}else { //sizes are the same, but either the names are different or they are in different order
-			m->mothurOut("[WARNING]: Names do not match between distance files. Comparing based on order in files."); m->mothurOutEndLine();
+			m->mothurOut("[WARNING]: Names do not match between distance files. Comparing based on order in files.\n"); 
 		}	
 		
 		if (m->getControl_pressed()) { return 0; }
@@ -222,7 +177,7 @@ int MantelCommand::execute(){
 		if (m->getControl_pressed()) { return 0; }
 		
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(phylipfile1));
+		variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(phylipfile1));
 		string outputFile = getOutputFileName("mantel",variables);
 		outputNames.push_back(outputFile); outputTypes["mantel"].push_back(outputFile);
 		ofstream out;
