@@ -13,6 +13,7 @@
 #include "command.hpp"
 #include "inputdata.h"
 #include "sharedrabundvectors.hpp"
+#include "sharedclrvectors.hpp"
 #include "mothurmetastats.h"
 #include "designmap.h"
 
@@ -23,7 +24,6 @@ class MetaStatsCommand : public Command {
 
 public:
 	MetaStatsCommand(string);
-	MetaStatsCommand();
 	~MetaStatsCommand() {}
 	
 	vector<string> setParameters();
@@ -39,18 +39,17 @@ public:
 	void help() { m->mothurOut(getHelpString()); }	
 	
 private:
-    DesignMap* designMap;
-	SharedRAbundVectors* lookup;
-		
+    
 	bool abort, allLines, pickedGroups;
 	set<string> labels; //holds labels to be used
-	string groups, label, outputDir, inputDir, designfile, sets, sharedfile;
+	string groups, label,  inputDir, designfile, sets, sharedfile, clrfile, inputfile, format;
 	vector<string> Groups, outputNames, Sets;
 	vector< vector<string> > namesOfGroupCombos;
 	int iters, processors;
 	float threshold;
 	
-	int process(SharedRAbundVectors*&);
+	int process(SharedRAbundVectors*&, DesignMap*&);
+    int process(SharedCLRVectors*&, DesignMap*&);
 };
 
 /**************************************************************************************************/
