@@ -22,7 +22,12 @@ vector<string> NormalizeSharedCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
-		
+        
+        abort = false; calledHelp = false;  allLines = true;
+        
+		vector<string> tempOutNames;
+        outputTypes["shared"] = tempOutNames;
+        
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
 		return myArray;
@@ -70,69 +75,17 @@ string NormalizeSharedCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-NormalizeSharedCommand::NormalizeSharedCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["shared"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "NormalizeSharedCommand", "NormalizeSharedCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
-
 NormalizeSharedCommand::NormalizeSharedCommand(string option) {
 	try {
-		abort = false; calledHelp = false;   
-		allLines = true;
-		
-		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
-			map<string,string>::iterator it;
 			
 			ValidParameters validParameter;
-			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["shared"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("shared");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("relabund");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["relabund"] = inputDir + it->second;		}
-				}
-			}
-			
 			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }	
 			else if (sharedfile == "not found") { sharedfile = ""; }
@@ -149,20 +102,20 @@ NormalizeSharedCommand::NormalizeSharedCommand(string option) {
 				//give priority to shared, then list, then rabund, then sabund
 				//if there is a current shared file, use it
 				sharedfile = current->getSharedFile(); 
-				if (sharedfile != "") { inputfile = sharedfile; format = "sharedfile"; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
+				if (sharedfile != "") { inputfile = sharedfile; format = "sharedfile"; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter.\n");  }
 				else { 
 					relabundfile = current->getRelAbundFile(); 
-					if (relabundfile != "") { inputfile = relabundfile; format = "relabund"; m->mothurOut("Using " + relabundfile + " as input file for the relabund parameter."); m->mothurOutEndLine(); }
+					if (relabundfile != "") { inputfile = relabundfile; format = "relabund"; m->mothurOut("Using " + relabundfile + " as input file for the relabund parameter.\n");  }
 					else { 
-						m->mothurOut("No valid current files. You must provide a list, sabund, rabund, relabund or shared file."); m->mothurOutEndLine(); 
+						m->mothurOut("No valid current files. You must provide a list, sabund, rabund, relabund or shared file.\n");  
 						abort = true;
 					}
 				}
 			}
 			
 			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(inputfile);		}
+			 
+					if (outputdir == ""){    outputdir = util.hasPath(inputfile);		}
 			
 			
 
@@ -184,14 +137,14 @@ NormalizeSharedCommand::NormalizeSharedCommand(string option) {
 			}
 			
 			method = validParameter.valid(parameters, "method");				if (method == "not found") { method = "totalgroup"; }
-			if ((method != "totalgroup") && (method != "zscore")) {  m->mothurOut(method + " is not a valid scaling option for the normalize.shared command. The options are totalgroup and zscore. We hope to add more ways to normalize in the future, suggestions are welcome!"); m->mothurOutEndLine(); abort = true; }
+			if ((method != "totalgroup") && (method != "zscore")) {  m->mothurOut(method + " is not a valid scaling option for the normalize.shared command. The options are totalgroup and zscore. We hope to add more ways to normalize in the future, suggestions are welcome!\n");  abort = true; }
 		
 			string temp = validParameter.valid(parameters, "norm");
 			if (temp == "not found") {  
 				norm = 0;  //once you have read, set norm to smallest group number
 			}else { 
 				util.mothurConvert(temp, norm);
-				if (norm < 0) { m->mothurOut("norm must be positive."); m->mothurOutEndLine(); abort=true; }
+				if (norm < 0) { m->mothurOut("norm must be positive.\n");  abort=true; }
 			}
 			
 			temp = validParameter.valid(parameters, "makerelabund");	if (temp == "") { temp = "f"; }
@@ -212,193 +165,63 @@ int NormalizeSharedCommand::execute(){
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
 		InputData input(inputfile, format, Groups);
+        set<string> processedLabels;
+        set<string> userLabels = labels;
+        string lastLabel = "";
         
 		//you are reading a sharedfile and you do not want to make relabund
 		if ((format == "sharedfile") && (!makeRelabund)) {
-			SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
-			string lastLabel = lookup->getLabel();
+			SharedRAbundVectors* lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
+            Groups = lookup->getNamesGroups();
 			
 			//look for groups whose numseqs is below norm and remove them, warning the user
-			if (norm != 0) {
-                lookup->removeGroups(norm);
-                Groups = lookup->getNamesGroups();
-			}
-			
-			//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
-			set<string> processedLabels;
-			set<string> userLabels = labels;
+			if (norm != 0) { lookup->removeGroups(norm); Groups = lookup->getNamesGroups(); }
 			
 			if (method == "totalgroup") {
 				//set norm to smallest group number
 				if (norm == 0) { norm = lookup->getNumSeqsSmallestGroup(); }
 				
-				m->mothurOut("Normalizing to " + toString(norm) + "."); m->mothurOutEndLine();
+				m->mothurOut("Normalizing to " + toString(norm) + ".\n");
 			}
 			
 			bool printHeaders = true;
-			//as long as you are not at the end of the file or done wih the lines you want
-			while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-				
-                if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} outputTypes.clear();  delete lookup;    return 0; }
-				
-				if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
-					
-					m->mothurOut(lookup->getLabel()+"\n"); 
-					normalize(lookup, printHeaders);
-					
-					processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
-				}
-				
-				if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-					string saveLabel = lookup->getLabel();
-					
-					delete lookup;
-					lookup = input.getSharedRAbundVectors(lastLabel);
-					m->mothurOut(lookup->getLabel()+"\n"); 
-					
-					normalize(lookup, printHeaders);
-					
-					processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
-					
-					//restore real lastlabel to save below
-					lookup->setLabels(saveLabel);
-				}
-				
-				lastLabel = lookup->getLabel();
-				//prevent memory leak
-				delete lookup;
-				
-				if (m->getControl_pressed()) {  for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} outputTypes.clear();   return 0; }
-				
-				//get next line to process
-				lookup = input.getSharedRAbundVectors();
-			}
-			
-			if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} outputTypes.clear();    return 0; }
-			
-			//output error messages about any remaining user labels
-			set<string>::iterator it;
-			bool needToRun = false;
-			for (it = userLabels.begin(); it != userLabels.end(); it++) {  
-				m->mothurOut("Your file does not include the label " + *it); 
-				if (processedLabels.count(lastLabel) != 1) {
-					m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-					needToRun = true;
-				}else {
-					m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-				}
-			}
-			
-			//run last label if you need to
-			if (needToRun )  {
-				delete lookup;
-				lookup = input.getSharedRAbundVectors(lastLabel);
-				m->mothurOut(lookup->getLabel()+"\n"); 
-				normalize(lookup, printHeaders);
-				delete lookup;
-			}
+            while (lookup != NULL) {
+                
+                if (m->getControl_pressed()) { delete lookup; break; }
+                
+                normalize(lookup, printHeaders); delete lookup;
+                
+                lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
+            }
 			
 		}else{ //relabund values
-			SharedRAbundFloatVectors* lookupFloat = input.getSharedRAbundFloatVectors();
-			string lastLabel = lookupFloat->getLabel();
-			
-			//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
-			set<string> processedLabels;
-			set<string> userLabels = labels;
+			SharedRAbundFloatVectors* lookupFloat = util.getNextRelabund(input, allLines, userLabels, processedLabels, lastLabel);
+            Groups = lookupFloat->getNamesGroups();
 			
 			//look for groups whose numseqs is below norm and remove them, warning the user
-			if (norm != 0) { 
-                lookupFloat->removeGroups(norm);
-                Groups = lookupFloat->getNamesGroups();
-			}
+			if (norm != 0) {  lookupFloat->removeGroups(norm); Groups = lookupFloat->getNamesGroups(); }
 			
 			//set norm to smallest group number
 			if (method == "totalgroup") {
                 if (norm == 0) {
-                    vector<string> lookupGroups = lookupFloat->getNamesGroups();
-                    norm = lookupFloat->getNumSeqs(lookupGroups[0]);
-                    for (int i = 1; i < lookupGroups.size(); i++) {
-                        if (lookupFloat->getNumSeqs(lookupGroups[i]) < norm) { norm = lookupFloat->getNumSeqs(lookupGroups[i]);  }
-                    }  
+                    norm = lookupFloat->getNumSeqsSmallestGroup();
+                    Groups = lookupFloat->getNamesGroups();
                 }
 				
-				m->mothurOut("Normalizing to " + toString(norm) + "."); m->mothurOutEndLine();
+				m->mothurOut("Normalizing to " + toString(norm) + ".\n");
 			}
 			
             bool printHeaders = true;
-			//as long as you are not at the end of the file or done wih the lines you want
-			while((lookupFloat != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-				
-                if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} outputTypes.clear();  delete lookupFloat;   return 0; }
-				
-				if(allLines == 1 || labels.count(lookupFloat->getLabel()) == 1){
-					
-					m->mothurOut(lookupFloat->getLabel()); m->mothurOutEndLine();
-					
-					normalize(lookupFloat, printHeaders);
-					
-					processedLabels.insert(lookupFloat->getLabel());
-					userLabels.erase(lookupFloat->getLabel());
-				}
-				
-				if ((util.anyLabelsToProcess(lookupFloat->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-					string saveLabel = lookupFloat->getLabel();
-					
-					delete lookupFloat;
-					lookupFloat = input.getSharedRAbundFloatVectors(lastLabel);
-					
-					m->mothurOut(lookupFloat->getLabel()); m->mothurOutEndLine();
-		
-					normalize(lookupFloat, printHeaders);
-					
-					processedLabels.insert(lookupFloat->getLabel());
-					userLabels.erase(lookupFloat->getLabel());
-					
-					//restore real lastlabel to save below
-					lookupFloat->setLabels(saveLabel);
-				}
-				
-				lastLabel = lookupFloat->getLabel();
-				//prevent memory leak
-				delete lookupFloat;
-				
-				if (m->getControl_pressed()) {  for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} outputTypes.clear();    return 0; }
-				
-				//get next line to process
-				lookupFloat = input.getSharedRAbundFloatVectors();
-			}
-			
-			if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} outputTypes.clear();    return 0; }
-			
-			//output error messages about any remaining user labels
-			set<string>::iterator it;
-			bool needToRun = false;
-			for (it = userLabels.begin(); it != userLabels.end(); it++) {  
-				m->mothurOut("Your file does not include the label " + *it); 
-				if (processedLabels.count(lastLabel) != 1) {
-					m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-					needToRun = true;
-				}else {
-					m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-				}
-			}
-			
-			//run last label if you need to
-			if (needToRun )  {
-				delete lookupFloat;
-				lookupFloat = input.getSharedRAbundFloatVectors(lastLabel);
-				
-				m->mothurOut(lookupFloat->getLabel()); m->mothurOutEndLine();
-				
-				normalize(lookupFloat, printHeaders);
-				
-				delete lookupFloat;
-			}
-			
-		}
-		//reset groups parameter
-		
-		
+            while (lookupFloat != NULL) {
+                    
+                if (m->getControl_pressed()) { delete lookupFloat; break; }
+
+                normalize(lookupFloat, printHeaders); delete lookupFloat;
+                    
+                lookupFloat = util.getNextRelabund(input, allLines, userLabels, processedLabels, lastLabel);
+            }
+        }
+        
 		if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]);	} outputTypes.clear(); return 0;}
 		
 		m->mothurOut("\nOutput File Names: \n"); 
@@ -425,7 +248,7 @@ int NormalizeSharedCommand::normalize(SharedRAbundVectors*& thisLookUp, bool& pr
 	try {
         vector<string> lookupGroups = thisLookUp->getNamesGroups();
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputfile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(inputfile));
         variables["[distance]"] = thisLookUp->getLabel();
 		string outputFileName = getOutputFileName("shared",variables);
         
@@ -487,7 +310,7 @@ int NormalizeSharedCommand::normalize(SharedRAbundVectors*& thisLookUp, bool& pr
 				}
 			}
 						
-		}else{ m->mothurOut(method + " is not a valid scaling option."); m->mothurOutEndLine(); m->setControl_pressed(true); return 0; }
+		}else{ m->mothurOut(method + " is not a valid scaling option.\n");  m->setControl_pressed(true); return 0; }
 				
 		thisLookUp->eliminateZeroOTUS();
         thisLookUp->print(out, printHeaders);
@@ -506,7 +329,7 @@ int NormalizeSharedCommand::normalize(SharedRAbundFloatVectors*& thisLookUp, boo
 	try {
         vector<string> lookupGroups = thisLookUp->getNamesGroups();
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(inputfile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(inputfile));
         variables["[distance]"] = thisLookUp->getLabel();
 		string outputFileName = getOutputFileName("shared",variables);
 		ofstream out;
@@ -560,7 +383,7 @@ int NormalizeSharedCommand::normalize(SharedRAbundFloatVectors*& thisLookUp, boo
                 }
 			}			
 			
-		}else{ m->mothurOut(method + " is not a valid scaling option."); m->mothurOutEndLine(); m->setControl_pressed(true); return 0; }
+		}else{ m->mothurOut(method + " is not a valid scaling option.\n");  m->setControl_pressed(true); return 0; }
 		
 		
         thisLookUp->eliminateZeroOTUS();
