@@ -20,7 +20,6 @@ class PCACommand : public Command {
 	
 public:
 	PCACommand(string);	
-	PCACommand();
 	~PCACommand() {}
 	
 	vector<string> setParameters();
@@ -39,7 +38,7 @@ public:
 private:
 
 	bool abort, metric;
-	string outputDir, mode, inputFile, label, groups, sharedfile, relabundfile;
+	string  mode, inputFile, label, groups, sharedfile, relabundfile;
 	vector<string> outputNames, Groups;
 	set<string> labels;
 	LinearAlgebra linearCalc;
