@@ -30,6 +30,16 @@ vector<string> PcrSeqsCommand::setParameters(){
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
         
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["taxonomy"] = tempOutNames;
+        outputTypes["group"] = tempOutNames;
+        outputTypes["name"] = tempOutNames;
+        outputTypes["accnos"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
+        
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
 		return myArray;
@@ -83,134 +93,28 @@ string PcrSeqsCommand::getOutputPattern(string type) {
         exit(1);
     }
 }
-//**********************************************************************************************************************
-
-PcrSeqsCommand::PcrSeqsCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-		outputTypes["taxonomy"] = tempOutNames;
-		outputTypes["group"] = tempOutNames;
-		outputTypes["name"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-        outputTypes["accnos"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "PcrSeqsCommand", "PcrSeqsCommand");
-		exit(1);
-	}
-}
 //***************************************************************************************************************
-
 PcrSeqsCommand::PcrSeqsCommand(string option)  {
 	try {
-		
-		abort = false; calledHelp = false;   
-		
-		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string,string>::iterator it;
-			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-			outputTypes["taxonomy"] = tempOutNames;
-			outputTypes["group"] = tempOutNames;
-			outputTypes["name"] = tempOutNames;
-            outputTypes["accnos"] = tempOutNames;
-            outputTypes["count"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("oligos");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["oligos"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("ecoli");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["ecoli"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("taxonomy");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["taxonomy"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-				
-			}
-            
-			
-			//check for required parameters
 			fastafile = validParameter.validFile(parameters, "fasta");
 			if (fastafile == "not found") { 				
 				fastafile = current->getFastaFile(); 
-				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter.\n");  }
+				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required.\n"); abort = true; }
 			}else if (fastafile == "not open") { fastafile = ""; abort = true; }	
 			else { current->setFastaFile(fastafile); }
 			
-            //if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(fastafile);	}
+             
+					if (outputdir == ""){    outputdir = util.hasPath(fastafile);	}
 
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
@@ -246,11 +150,11 @@ PcrSeqsCommand::PcrSeqsCommand(string option)  {
 			else { current->setCountFile(countfile); }
             
             if ((namefile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: name or count."); m->mothurOutEndLine(); abort = true;
+                m->mothurOut("[ERROR]: you may only use one of the following: name or count.\n"); abort = true;
             }
 			
             if ((groupfile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: group or count."); m->mothurOutEndLine(); abort=true;
+                m->mothurOut("[ERROR]: you may only use one of the following: group or count.\n"); abort = true;
             }
             
             taxfile = validParameter.validFile(parameters, "taxonomy");
@@ -318,8 +222,8 @@ int PcrSeqsCommand::execute(){
         long start = time(NULL);
         fileAligned = true; pairedOligos = false;
         
-        string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(fastafile);  }
+        string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(fastafile);  }
         map<string, string> variables; 
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(fastafile));
         variables["[extension]"] = util.getExtension(fastafile);
@@ -336,8 +240,8 @@ int PcrSeqsCommand::execute(){
 		
 		if (m->getControl_pressed()) {  return 0; }
         
-        thisOutputDir = outputDir;
-        if (outputDir == "") {  thisOutputDir += util.hasPath(fastafile);  }
+        thisOutputDir = outputdir;
+        if (outputdir == "") {  thisOutputDir += util.hasPath(fastafile);  }
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(fastafile));
         string outputFileName = getOutputFileName("accnos",variables);
 
@@ -373,8 +277,8 @@ int PcrSeqsCommand::execute(){
                 current->setMothurCalling(false);
                 
                 if (groupfile != "") {
-                    thisOutputDir = outputDir;
-                    if (outputDir == "") {  thisOutputDir += util.hasPath(groupfile);  }
+                    thisOutputDir = outputdir;
+                    if (outputdir == "") {  thisOutputDir += util.hasPath(groupfile);  }
                     variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(groupfile));
                     variables["[extension]"] = util.getExtension(groupfile);
                     string outGroup = getOutputFileName("group", variables);
@@ -383,8 +287,8 @@ int PcrSeqsCommand::execute(){
                 }
                 
                 if (namefile != "") {
-                    thisOutputDir = outputDir;
-                    if (outputDir == "") {  thisOutputDir += util.hasPath(namefile);  }
+                    thisOutputDir = outputdir;
+                    if (outputdir == "") {  thisOutputDir += util.hasPath(namefile);  }
                     variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(namefile));
                     variables["[extension]"] = util.getExtension(namefile);
                     string outName = getOutputFileName("name", variables);
@@ -393,8 +297,8 @@ int PcrSeqsCommand::execute(){
                 }
                 
                 if (countfile != "") {
-                    thisOutputDir = outputDir;
-                    if (outputDir == "") {  thisOutputDir += util.hasPath(countfile);  }
+                    thisOutputDir = outputdir;
+                    if (outputdir == "") {  thisOutputDir += util.hasPath(countfile);  }
                     variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(countfile));
                     variables["[extension]"] = util.getExtension(countfile);
                     string outCount = getOutputFileName("count", variables);
@@ -403,8 +307,8 @@ int PcrSeqsCommand::execute(){
                 }
                 
                 if (taxfile != "")              {
-                    thisOutputDir = outputDir;
-                    if (outputDir == "") {  thisOutputDir += util.hasPath(taxfile);  }
+                    thisOutputDir = outputdir;
+                    if (outputdir == "") {  thisOutputDir += util.hasPath(taxfile);  }
                     variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(taxfile));
                     variables["[extension]"] = util.getExtension(taxfile);
                     string outputFileName = getOutputFileName("taxonomy", variables);
@@ -718,23 +622,35 @@ int driverPcr(pcrData* params){
                     //make sure the seqs are aligned
                     if (!params->fileAligned) { params->m->mothurOut("[ERROR]: seqs are not aligned. When using start and end your sequences must be aligned.\n"); params->m->setControl_pressed(true); break; }
                     else {
-                        if (params->end != -1) {
-                            if (params->end > currSeq.getAligned().length()) {  params->m->mothurOut("[ERROR]: end is longer than your sequence length, aborting.\n"); params->m->setControl_pressed(true); break; }
-                            else {
-                                if (params->keepdots)   { currSeq.filterFromPos(params->end); }
+                        string alignedString = currSeq.getAligned();
+                        //cout << currSeq.getName() << '\t' << alignedString[params->start] << '\t' << alignedString[params->end] << endl;
+                        if ((currSeq.getStartPos() > params->start) || (currSeq.getEndPos() < params->end)) {
+                            goodSeq = false;
+                            if (params->m->getDebug()) {
+                                params->m->mothurOut("[DEBUG]: " + currSeq.getName()+ " values at locations (" + toString(params->start) + "," + toString(params->end) + ") = (" + alignedString[params->start] + "," + alignedString[params->end] + ")\n");
+                                
+                            }
+                        }
+                        else {
+                            if (params->end != -1) {
+                                if (params->end > currSeq.getAligned().length()) {  params->m->mothurOut("[ERROR]: end of " +toString(params->end)  + " is longer than " + currSeq.getName() + " length of " +toString(currSeq.getAligned().length()) + ", aborting.\n"); params->m->setControl_pressed(true); break; }
                                 else {
-                                    string seqString = currSeq.getAligned().substr(0, (params->end));
+                                    if (params->keepdots)   { currSeq.filterFromPos(params->end); }
+                                    else {
+                                        string seqString = currSeq.getAligned().substr(0, (params->end));
+                                        currSeq.setAligned(seqString);
+                                    }
+                                }
+                            }
+                            
+                            if (params->start != -1) {
+                                if (params->keepdots)   {  currSeq.filterToPos(params->start-1);  }
+                                else {
+                                    string seqString = currSeq.getAligned().substr(params->start);
                                     currSeq.setAligned(seqString);
                                 }
                             }
-                        }
-                        
-                        if (params->start != -1) {
-                            if (params->keepdots)   {  currSeq.filterToPos(params->start-1);  }
-                            else {
-                                string seqString = currSeq.getAligned().substr(params->start);
-                                currSeq.setAligned(seqString);
-                            }
+                       
                         }
                     }
                 }
@@ -746,8 +662,8 @@ int driverPcr(pcrData* params){
                 
                 if (totalDiffs > (params->pdiffs + params->rdiffs)) { trashCode += "t"; goodSeq = false; }
                 
-                //trimming removed all bases
-                if (currSeq.getUnaligned() == "") { goodSeq = false; }
+                //remove super short reads
+                if (currSeq.getUnaligned() == "") { goodSeq = false;  currSeq.setAligned("NNNNNNN"); }
                 
                 if(goodSeq)    {
                     currSeq.printSequence(params->goodFasta);
@@ -807,7 +723,7 @@ long long PcrSeqsCommand::createProcesses(string filename, string goodFileName,
         Sequence ecoliSeq("filler","NNNN");
         if(ecolifile != "") {    ecoliSeq = readEcoli();      }  if (m->getControl_pressed()) {  return 0; }
         
-        vector<unsigned long long> positions;
+        vector<double> positions;
         vector<linePair> lines;
         long long numFastaSeqs = 0;
 #if defined NON_WINDOWS
@@ -829,7 +745,7 @@ long long PcrSeqsCommand::createProcesses(string filename, string goodFileName,
 #endif
         
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<pcrData*> data;
         
         auto synchronizedGoodFastaFile = make_shared<SynchronizedOutputFile>(goodFileName);
@@ -843,7 +759,7 @@ long long PcrSeqsCommand::createProcesses(string filename, string goodFileName,
             pcrData* dataBundle = new pcrData(filename, oligosfile, threadFastaWriter, threadFastaScrapWriter, ecoliSeq, nomatch, keepprimer, keepdots, pdiffs, rdiffs, lines[i+1].start, lines[i+1].end, start, end);
             data.push_back(dataBundle);
             
-            workerThreads.push_back(new thread(driverPcr, dataBundle));
+            workerThreads.push_back(new std::thread(driverPcr, dataBundle));
         }
         
         OutputWriter* threadFastaWriter = new OutputWriter(synchronizedGoodFastaFile);
