@@ -30,6 +30,13 @@ vector<string> PhyloDiversityCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["phylodiv"] = tempOutNames;
+        outputTypes["rarefy"] = tempOutNames;
+        outputTypes["summary"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -83,96 +90,25 @@ string PhyloDiversityCommand::getOutputPattern(string type) {
     }
 }
 
-//**********************************************************************************************************************
-PhyloDiversityCommand::PhyloDiversityCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["phylodiv"] = tempOutNames;
-		outputTypes["rarefy"] = tempOutNames;
-		outputTypes["summary"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "PhyloDiversityCommand", "PhyloDiversityCommand");
-		exit(1);
-	}
-}
 //**********************************************************************************************************************
 PhyloDiversityCommand::PhyloDiversityCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-		
-		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();;
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
-			map<string,string>::iterator it;
 			
 			ValidParameters validParameter;
-		
-			//check to make sure all parameters are valid for command
-			for (map<string,string>::iterator it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["phylodiv"] = tempOutNames;
-			outputTypes["rarefy"] = tempOutNames;
-			outputTypes["summary"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("tree");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["tree"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-			}
-			
-			//check for required parameters
 			treefile = validParameter.validFile(parameters, "tree");
 			if (treefile == "not open") { treefile = ""; abort = true; }
 			else if (treefile == "not found") { 				
 				//if there is a current design file, use it
 				treefile = current->getTreeFile(); 
-				if (treefile != "") { m->mothurOut("Using " + treefile + " as input file for the tree parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current tree file and the tree parameter is required."); m->mothurOutEndLine(); abort = true; }								
+				if (treefile != "") { m->mothurOut("Using " + treefile + " as input file for the tree parameter.\n");  }
+				else { 	m->mothurOut("You have no current tree file and the tree parameter is required.\n");  abort = true; }								
 			}else { current->setTreeFile(treefile); }	
 			
 			//check for required parameters
@@ -192,14 +128,14 @@ PhyloDiversityCommand::PhyloDiversityCommand(string option)  {
 			else { current->setCountFile(countfile); }
             
             if ((namefile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: name or count."); m->mothurOutEndLine(); abort = true;
+                m->mothurOut("[ERROR]: you may only use one of the following: name or count.\n");  abort = true;
             }
 			
             if ((groupfile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: group or count."); m->mothurOutEndLine(); abort=true;
+                m->mothurOut("[ERROR]: you may only use one of the following: group or count.\n");  abort=true;
             }
 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(treefile);	}
+					if (outputdir == ""){    outputdir = util.hasPath(treefile);	}
 			
 			string temp;
 			temp = validParameter.valid(parameters, "freq");			if (temp == "not found") { temp = "100"; }
@@ -215,7 +151,7 @@ PhyloDiversityCommand::PhyloDiversityCommand(string option)  {
                 else { subsample = true; }
             }else {
                 subsample = false;
-                m->mothurOut("[ERROR]: sampledepth must be numeric, aborting.\n"); m->mothurOutEndLine(); abort=true;
+                m->mothurOut("[ERROR]: sampledepth must be numeric, aborting.\n\n");  abort=true;
             }
             if (subsample) { rarefy = true;  }
             
@@ -332,7 +268,7 @@ int PhyloDiversityCommand::execute(){
             //check that groups are valid
             for (int i = 0; i < Groups.size(); i++) {
                 if (!util.inUsersGroups(Groups[i], tGroups)) {
-                    m->mothurOut(Groups[i] + " is not a valid group, and will be disregarded."); m->mothurOutEndLine();
+                    m->mothurOut(Groups[i] + " is not a valid group, and will be disregarded.\n"); 
                     // erase the invalid group from userGroups
                     Groups.erase(Groups.begin()+i);
                     i--;
@@ -351,7 +287,7 @@ int PhyloDiversityCommand::execute(){
 			
 			ofstream outRare;
             map<string, string> variables; 
-            variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(treefile));
+            variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(treefile));
             variables["[tag]"] = toString(i+1);
 			string outSumFile = getOutputFileName("summary",variables);
 			string outRareFile = getOutputFileName("rarefy",variables);
@@ -688,7 +624,7 @@ int PhyloDiversityCommand::createProcesses(Tree* t, CountTable* ct, map< string,
         }
         
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<phylodivData*> data;
         
         //Lauch worker threads
@@ -712,7 +648,7 @@ int PhyloDiversityCommand::createProcesses(Tree* t, CountTable* ct, map< string,
             
             data.push_back(dataBundle);
 
-            workerThreads.push_back(new thread(driverPhylo, dataBundle));
+            workerThreads.push_back(new std::thread(driverPhylo, dataBundle));
         }
         
         vector< vector<int> > thisRandomLeaf;
