@@ -38,6 +38,13 @@ vector<string> PreClusterCommand::setParameters(){
         CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
         CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["map"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
 
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -101,92 +108,19 @@ string PreClusterCommand::getOutputPattern(string type) {
         exit(1);
     }
 }
-//**********************************************************************************************************************
-PreClusterCommand::PreClusterCommand(){
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-		//outputTypes["name"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-		outputTypes["map"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "PreClusterCommand", "PreClusterCommand");
-		exit(1);
-	}
-}
 //**************************************************************************************************
-
 PreClusterCommand::PreClusterCommand(string option) {
 	try {
-		abort = false; calledHelp = false;
 
-		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 
 		else {
-			vector<string> myArray = setParameters();
-
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters();
 
 			ValidParameters validParameter;
-			map<string, string>::iterator it;
-
-			//check to make sure all parameters are valid for command
-			for (map<string, string>::iterator it2 = parameters.begin(); it2 != parameters.end(); it2++) {
-				if (validParameter.isValidParameter(it2->first, myArray, it2->second) != true) {  abort = true;  }
-			}
-
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-			//outputTypes["name"] = tempOutNames;
-			outputTypes["map"] = tempOutNames;
-            outputTypes["count"] = tempOutNames;
-
-			//if the user changes the input directory command factory will send this info to us in the output parameter
-			string inputDir = validParameter.valid(parameters, "inputdir");
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-
-                it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-			}
-
-			//check for required parameters
 			fastafile = validParameter.validFile(parameters, "fasta");
 			if (fastafile == "not found") {
 				fastafile = current->getFastaFile();
@@ -196,11 +130,7 @@ PreClusterCommand::PreClusterCommand(string option) {
 			else if (fastafile == "not open") { abort = true; }
 			else { current->setFastaFile(fastafile); }
 
-			//if the user changes the output directory command factory will send this info to us in the output parameter
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){
-				outputDir = "";
-				outputDir += util.hasPath(fastafile); //if user entered a file with a path then preserve it
-			}
+			 if (outputdir == ""){ outputdir += util.hasPath(fastafile); }
 
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
@@ -292,6 +222,16 @@ PreClusterCommand::PreClusterCommand(string option) {
             
             
             align = validParameter.valid(parameters, "align");		if (align == "not found"){	align = "needleman";	}
+            if (align == "blast") {
+                string blastlocation = "";
+                vector<string> locations = current->getLocations();
+                string path = current->getProgramPath();
+                bool foundTool = util.findBlastLocation(blastlocation, path, locations);
+
+                if (!foundTool){
+                    m->mothurOut("[WARNING]: Unable to locate blast executables, cannot use blast as align method. Using needleman instead.\n"); align = "needleman";
+                }
+            }
             
             align_method = "unaligned";
             
@@ -301,8 +241,8 @@ PreClusterCommand::PreClusterCommand(string option) {
                     string rootFileName = namefile;
                     if (rootFileName == "") { rootFileName = groupfile; }
                     
-                    if (outputDir == "") { outputDir = util.hasPath(rootFileName); }
-                    string outputFileName = outputDir + util.getRootName(util.getSimpleName(rootFileName)) + "count_table";
+                    if (outputdir == "") { outputdir = util.hasPath(rootFileName); }
+                    string outputFileName = outputdir + util.getRootName(util.getSimpleName(rootFileName)) + "count_table";
                     
                     CountTable ct; ct.createTable(namefile, groupfile, nullVector); ct.printCompressedTable(outputFileName);
                     outputNames.push_back(outputFileName);
@@ -401,7 +341,7 @@ struct preClusterData {
   string fastafile, countfile, pc_method, align_method, align, newMName;
   OutputWriter* newNName;
   MothurOut* m;
-  int start, end, count, diffs, length;
+  int start, end, count, diffs, length, numGroups;
   vector<string> groups;
   bool hasCount;
   float match, misMatch, gapOpen, gapExtend, alpha, delta, error_rate, indel_prob, max_indels;
@@ -411,6 +351,7 @@ struct preClusterData {
   map<string, vector<string> > outputTypes;
   vector<seqPNode*> alignSeqs; //maps the number of identical seqs to a sequence. filled and freed by functions
   Alignment* alignment;
+    map<string, vector<string> > parsedFiles;
 
 				// double error_rate = 0.005;error_rate
 				// double indel_prob = 0.01;indel_prob
@@ -420,7 +361,7 @@ struct preClusterData {
 
   preClusterData(){}
 
-  preClusterData(string f, string c, string pcm, string am,  OutputWriter* nnf, string nmf, vector<string> gr) {
+  preClusterData(map<string, vector<string> > g2f, string f, string c, string pcm, string am,  OutputWriter* nnf, string nmf, vector<string> gr) {
     fastafile = f;
     pc_method = pcm;
     align_method = am;
@@ -431,11 +372,12 @@ struct preClusterData {
     countfile = c; if (countfile != "") { hasCount = true; }
     count=0;
     m = MothurOut::getInstance();
+      parsedFiles = g2f;
   }
 
-  void setVariables(int st, int en, int d, string pcm, string am, string al, float ma, float misma, float gpOp, float gpEx, float a, float del, float me, float ip, float mi, vector<float> ed) {
-    start = st;
-    end = en;
+  void setVariables(int d, string pcm, string am, string al, float ma, float misma, float gpOp, float gpEx, float a, float del, float me, float ip, float mi, vector<float> ed) {
+    
+      numGroups = groups.size();
     diffs = d;
 		pc_method = pcm;
     align_method = am;
@@ -617,7 +559,7 @@ int process(string group, string newMapFile, preClusterData* params){
                         
                         if (params->m->getControl_pressed()) { out.close(); return 0; }
                         
-                        if ((params->alignSeqs[i]->numIdentical != 0) && (originalCount[j] < originalCount[i])) {  //this sequence has not been merged yet
+                        if ((params->alignSeqs[j]->numIdentical != 0) && (originalCount[j] < originalCount[i])) {  //this sequence has not been merged yet //
                             //are you within "diff" bases
                             int mismatch = calcMisMatches(params->alignSeqs[i]->sequence, params->alignSeqs[j]->sequence, params);
                             
@@ -907,7 +849,7 @@ void print(string newfasta, string newname, preClusterData* params){
         params->m->mothurOut("/******************************************/\n");
         params->m->mothurOut("Running command: get.seqs(" + inputString + ")\n");
         
-        Command* getCommand = new GetSeqsCommand(inputString);
+        GetSeqsCommand* getCommand = new GetSeqsCommand(inputString);
         getCommand->execute();
         
         map<string, vector<string> > filenames = getCommand->getOutputFiles();
@@ -935,7 +877,9 @@ int PreClusterCommand::execute(){
         
         long start = time(NULL);
         
-        string fileroot = outputDir + util.getRootName(util.getSimpleName(fastafile));
+        string numProcessors = current->getProcessors();
+        
+        string fileroot = outputdir + util.getRootName(util.getSimpleName(fastafile));
         map<string, string> variables;
         variables["[filename]"] = fileroot;
         
@@ -956,7 +900,17 @@ int PreClusterCommand::execute(){
             newMapFile = fileroot + "precluster.";
             string convolutedNamesFile = newCountFile + ".temp";
             
-            createProcessesGroups(convolutedNamesFile, newMapFile);
+            vector<string> groups;
+            map<string, vector<string> > group2Files;
+            
+            current->setMothurCalling(true);
+            SequenceCountParser cparser(countfile, fastafile, nullVector);
+            current->setMothurCalling(false);
+            cout << " groups = "<< cparser.getNamesOfGroups().size() << endl;
+            groups = cparser.getNamesOfGroups();
+            group2Files = cparser.getFiles();
+            
+            createProcessesGroups(group2Files, groups, convolutedNamesFile, newMapFile);
             
             string accnosFile;
             if (countfile != "") {  accnosFile = mergeGroupCounts(newCountFile, convolutedNamesFile); }
@@ -971,8 +925,10 @@ int PreClusterCommand::execute(){
         }else {
             if (processors != 1) { m->mothurOut("When using running without group information mothur can only use 1 processor, continuing.\n");  processors = 1; }
             
-            preClusterData* params = new preClusterData(fastafile, countfile, pc_method, align_method, NULL, newMapFile, nullVector);
-            params->setVariables(0,0, diffs, pc_method, align_method, align, match, misMatch, gapOpen, gapExtend, alpha, delta, error_rate, indel_prob, max_indels, error_dist);
+            vector<string> groups;
+            map<string, vector<string> > group2Files;
+            preClusterData* params = new preClusterData(group2Files, fastafile, countfile, pc_method, align_method, NULL, newMapFile, nullVector);
+            params->setVariables(diffs, pc_method, align_method, align, match, misMatch, gapOpen, gapExtend, alpha, delta, error_rate, indel_prob, max_indels, error_dist);
             
             //reads fasta file and return number of seqs
             long long numSeqs = 0; params->alignSeqs = readFASTA(params, numSeqs); //fills alignSeqs and makes all seqs active
@@ -998,6 +954,8 @@ int PreClusterCommand::execute(){
             m->mothurOut("It took " + toString(time(NULL) - start) + " secs to cluster " + toString(numSeqs) + " sequences.\n");
         }
         
+        current->setProcessors(numProcessors);
+        
         if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	}  return 0; }
         
         m->mothurOut("\nOutput File Names: \n");
@@ -1164,53 +1122,29 @@ bool fillWeighted(preClusterData* params, string fastafileName, string groupOrCo
 
 long long driverGroups(preClusterData* params){
     try {
-        vector<string> subsetGroups;
-        for (int i = params->start; i < params->end; i++) {  subsetGroups.push_back(params->groups[i]);  }
-        
-        //run splitGroups command to parse files
-        string inputString = "groups=" + params->util.getStringFromVector(subsetGroups, "-");
-        inputString += ", fasta=" + params->fastafile;
-        
-        if (params->hasCount) {  inputString += ", count=" + params->countfile;  }
-        
-        params->m->mothurOut("\n/******************************************/\n");
-        params->m->mothurOut("Running command: split.groups(" + inputString + ")\n");
-        
-        Command* splitCommand = new SplitGroupCommand(inputString);
-        splitCommand->execute();
-        
-        //type -> files in groups order. fasta -> vector<string>. fastaFileForGroup1 stored in filenames["fasta"][1]
-        map<string, vector<string> > filenames = splitCommand->getOutputFiles();
-        
-        delete splitCommand;
-        params->m->mothurOut("/******************************************/\n");
-    
-        if (params->m->getControl_pressed()) { return 0; }
-        
         long long numSeqs = 0;
     
         //precluster each group
-        int fileIndex = 0;
-        for (int i = params->start; i < params->end; i++) {
+        for (map<string, vector<string> >::iterator it = params->parsedFiles.begin(); it != params->parsedFiles.end(); it++) {
             if (params->m->getControl_pressed()) { return numSeqs; }
             
-            params->m->mothurOut("\nProcessing group " + params->groups[i] + ":\n");
+            string thisGroup = it->first;
+            params->m->mothurOut("\nProcessing group " + thisGroup + ":\n");
             
             time_t start = time(NULL);
             bool aligned = false;
             
-            string thisGroupsFasta = filenames["fasta"][fileIndex];
+            string thisGroupsFasta = it->second[0];
             
             map<string, string> thisGroupsNameMap;
             if (params->hasCount)          {
-                string thisGroupsCount = filenames["count"][fileIndex];
+                string thisGroupsCount = it->second[1];
                 
                 aligned = fillWeighted(params, thisGroupsFasta, thisGroupsCount);
                 
                 params->util.mothurRemove(thisGroupsCount);
             }
             params->util.mothurRemove(thisGroupsFasta);
-            fileIndex++;
             
             //sort seqs by number of identical seqs
             sort(params->alignSeqs.begin(), params->alignSeqs.end(), comparePriorityTopDown);
@@ -1228,8 +1162,8 @@ long long driverGroups(preClusterData* params){
                 }
             }
             
-            string extension = params->groups[i]+".map";
-            long long count = process(params->groups[i]+"\t", params->newMName+extension, params);
+            string extension = thisGroup+".map";
+            long long count = process(thisGroup+"\t", params->newMName+extension, params);
             
             if(params->pc_method != "deblur"){
                 params->outputNames.push_back(params->newMName+extension);
@@ -1241,7 +1175,7 @@ long long driverGroups(preClusterData* params){
             params->m->mothurOut("Total number of sequences before pre.cluster was " + toString(num) + ".\n");
             params->m->mothurOut("pre.cluster removed " + toString(count) + " sequences.\n\n");
                 
-            printData(params->groups[i], params, thisGroupsNameMap);
+            printData(thisGroup, params, thisGroupsNameMap);
             
             for (int i = 0; i < params->alignSeqs.size(); i++) {  delete params->alignSeqs[i]; } params->alignSeqs.clear();
             
@@ -1271,6 +1205,17 @@ string PreClusterCommand::mergeGroupCounts(string newcount, string newname){
         ifstream inNames;
         util.openInputFile(newname, inNames);
         
+        /*
+         newname looks like:
+         
+        groupName seqName seqCountForGroup
+         
+         FDF6  seq1  35
+         
+         seq1 has an abundance of 35 in group FDF6
+         
+         */
+        
         time_t start = time(NULL);
         long long count = 0;
         
@@ -1307,7 +1252,7 @@ string PreClusterCommand::mergeGroupCounts(string newcount, string newname){
         ofstream outAccnos; util.openOutputFile(newname, outAccnos);
         for (int i = 0; i < namesOfSeqs.size(); i++) { outAccnos << namesOfSeqs[i] << endl; }
         outAccnos.close();
-        
+
 		return newname;
 	}
 	catch(exception& e) {
@@ -1317,12 +1262,9 @@ string PreClusterCommand::mergeGroupCounts(string newcount, string newname){
 }
 /**************************************************************************************************/
 
-void PreClusterCommand::createProcessesGroups(string newNName, string newMFile) {
+void PreClusterCommand::createProcessesGroups(map<string, vector<string> >& parsedFiles, vector<string> groups, string newNName, string newMFile) {
   try {
-    //parse fasta and name file by group
-    vector<string> groups;
-    if (countfile != "") { CountTable ct; ct.testGroups(countfile, groups); }
-
+    
     //sanity check
     if (groups.size() < processors) { processors = groups.size(); m->mothurOut("Reducing processors to " + toString(groups.size()) + ".\n"); }
 
@@ -1339,7 +1281,7 @@ void PreClusterCommand::createProcessesGroups(string newNName, string newMFile)
     }
 
     //create array of worker threads
-    vector<thread*> workerThreads;
+    vector<std::thread*> workerThreads;
     vector<preClusterData*> data;
       
     auto synchronizedNameFile = std::make_shared<SynchronizedOutputFile>(newNName);
@@ -1347,22 +1289,47 @@ void PreClusterCommand::createProcessesGroups(string newNName, string newMFile)
     //Lauch worker threads
     for (int i = 0; i < processors-1; i++) {
       OutputWriter* threadNameWriter = new OutputWriter(synchronizedNameFile);
-
-      preClusterData* dataBundle = new preClusterData(fastafile, countfile, pc_method, align_method, threadNameWriter, newMFile, groups);
-      dataBundle->setVariables(lines[i+1].start, lines[i+1].end, diffs, pc_method, align_method, align, match, misMatch, gapOpen, gapExtend, alpha, delta, error_rate, indel_prob, max_indels, error_dist);
+        
+        vector<string> thisGroups;
+        map<string, vector<string> > thisGroupsParsedFiles;
+        for (int j = lines[i+1].start; j < lines[i+1].end; j++) {
+            
+            map<string, vector<string> >::iterator it = parsedFiles.find(groups[j]);
+            if (it != parsedFiles.end()) {
+                thisGroupsParsedFiles[groups[j]] = (it->second);
+                thisGroups.push_back(groups[j]);
+            }
+            else { m->mothurOut("[ERROR]: missing files for group " + groups[j] + ", skipping\n"); }
+        }
+        
+      preClusterData* dataBundle = new preClusterData(thisGroupsParsedFiles, fastafile, countfile, pc_method, align_method, threadNameWriter, newMFile, thisGroups);
+      dataBundle->setVariables(diffs, pc_method, align_method, align, match, misMatch, gapOpen, gapExtend, alpha, delta, error_rate, indel_prob, max_indels, error_dist);
       data.push_back(dataBundle);
 
-      workerThreads.push_back(new thread(driverGroups, dataBundle));
+      workerThreads.push_back(new std::thread(driverGroups, dataBundle));
     }
     OutputWriter* threadNameWriter = new OutputWriter(synchronizedNameFile);
-
-    preClusterData* dataBundle = new preClusterData(fastafile, countfile, pc_method, align_method, threadNameWriter, newMFile, groups);
-    dataBundle->setVariables(lines[0].start, lines[0].end, diffs, pc_method, align_method, align, match, misMatch, gapOpen, gapExtend, alpha, delta, error_rate, indel_prob, max_indels, error_dist);
+      
+      vector<string> thisGroups;
+      map<string, vector<string> > thisGroupsParsedFiles;
+      for (int j = lines[0].start; j < lines[0].end; j++) {
+          
+          map<string, vector<string> >::iterator it = parsedFiles.find(groups[j]);
+          if (it != parsedFiles.end()) {
+              thisGroupsParsedFiles[groups[j]] = (it->second);
+              thisGroups.push_back(groups[j]);
+          }
+          else { m->mothurOut("[ERROR]: missing files for group " + groups[j] + ", skipping\n"); }
+      }
+    preClusterData* dataBundle = new preClusterData(thisGroupsParsedFiles, fastafile, countfile, pc_method, align_method, threadNameWriter, newMFile, thisGroups);
+    dataBundle->setVariables(diffs, pc_method, align_method, align, match, misMatch, gapOpen, gapExtend, alpha, delta, error_rate, indel_prob, max_indels, error_dist);
 
     driverGroups(dataBundle);
 
     outputNames.insert(outputNames.end(), dataBundle->outputNames.begin(), dataBundle->outputNames.end());
-    outputTypes.insert(dataBundle->outputTypes.begin(), dataBundle->outputTypes.end());
+    for (itTypes = dataBundle->outputTypes.begin(); itTypes != dataBundle->outputTypes.end(); itTypes++) {
+        outputTypes[itTypes->first].insert(outputTypes[itTypes->first].end(), itTypes->second.begin(), itTypes->second.end());
+    }
 
     for (int i = 0; i < processors-1; i++) {
       workerThreads[i]->join();
@@ -1370,7 +1337,9 @@ void PreClusterCommand::createProcessesGroups(string newNName, string newMFile)
       delete data[i]->newNName;
 
       outputNames.insert(outputNames.end(), data[i]->outputNames.begin(), data[i]->outputNames.end());
-      outputTypes.insert(data[i]->outputTypes.begin(), data[i]->outputTypes.end());
+      for (itTypes = data[i]->outputTypes.begin(); itTypes != data[i]->outputTypes.end(); itTypes++) {
+          outputTypes[itTypes->first].insert(outputTypes[itTypes->first].end(), itTypes->second.begin(), itTypes->second.end());
+      }
 
       delete data[i];
       delete workerThreads[i];
