@@ -26,6 +26,13 @@ vector<string> PrimerDesignCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["summary"] = tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["list"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -81,88 +88,18 @@ string PrimerDesignCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-PrimerDesignCommand::PrimerDesignCommand(){	
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-        vector<string> tempOutNames;
-		outputTypes["summary"] = tempOutNames; 
-        outputTypes["fasta"] = tempOutNames;
-        outputTypes["list"] = tempOutNames;
-        
-	}
-	catch(exception& e) {
-		m->errorOut(e, "PrimerDesignCommand", "PrimerDesignCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 PrimerDesignCommand::PrimerDesignCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-		
-		//allow user to run help
+
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			//valid paramters for this command
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string,string>::iterator it;
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-            vector<string> tempOutNames;
-            outputTypes["summary"] = tempOutNames; 
-            outputTypes["fasta"] = tempOutNames;
-            outputTypes["list"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
- 				string path;
-				it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-                
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("list");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["list"] = inputDir + it->second;		}
-				}
-            }
-                        
-			//check for parameters
 			namefile = validParameter.validFile(parameters, "name");
 			if (namefile == "not open") { abort = true; }	
 			else if (namefile == "not found") { namefile = ""; }
@@ -178,8 +115,8 @@ PrimerDesignCommand::PrimerDesignCommand(string option)  {
 			if (fastafile == "not open") { fastafile = ""; abort=true;  }
 			else if (fastafile == "not found") {  
                 fastafile = current->getFastaFile(); 
-				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter.\n");  }
+				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required.\n");  abort = true; }
             }else  { current->setFastaFile(fastafile); }
             
             //get listfile - it is required
@@ -187,20 +124,16 @@ PrimerDesignCommand::PrimerDesignCommand(string option)  {
 			if (listfile == "not open") { listfile = ""; abort=true;  }
 			else if (listfile == "not found") {  
                 listfile = current->getListFile(); 
-				if (listfile != "") { m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current listfile and the list parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (listfile != "") { m->mothurOut("Using " + listfile + " as input file for the list parameter.\n");  }
+				else { 	m->mothurOut("You have no current listfile and the list parameter is required.\n");  abort = true; }
             }else  { current->setListFile(listfile); }
 
             
 			if ((namefile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: name or count."); m->mothurOutEndLine(); abort = true;
+                m->mothurOut("[ERROR]: you may only use one of the following: name or count.\n");  abort = true;
             }
 			
-            
-            //if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	
-				outputDir = util.hasPath(listfile); //if user entered a file with a path then preserve it	
-			}
+            if (outputdir == ""){	 outputdir = util.hasPath(listfile);  }
             
             string temp = validParameter.valid(parameters, "cutoff");  if (temp == "not found") { temp = "100"; }
 			util.mothurConvert(temp, cutoff); 
@@ -224,7 +157,7 @@ PrimerDesignCommand::PrimerDesignCommand(string option)  {
 			processors = current->setProcessors(temp);
             
             label = validParameter.valid(parameters, "label");			
-			if (label == "not found") { label = ""; m->mothurOut("You did not provide a label, I will use the first label in your inputfile."); m->mothurOutEndLine(); label=""; }
+			if (label == "not found") { label = ""; m->mothurOut("You did not provide a label, I will use the first label in your inputfile.\n");  label=""; }
         
             if (countfile == "") { 
                 if (namefile == "") {
@@ -288,7 +221,7 @@ int PrimerDesignCommand::execute(){
         vector<Sequence> conSeqs = createProcessesConSeqs(nameMap, seq2Bin, binLabels);
         
         map<string, string> variables; 
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(listfile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(listfile));
         variables["[distance]"] = list->getLabel();
         string consFastaFile = getOutputFileName("fasta", variables);
         outputNames.push_back(consFastaFile); outputTypes["fasta"].push_back(consFastaFile);
@@ -351,7 +284,7 @@ int PrimerDesignCommand::execute(){
         
         //print new list file
         map<string, string> mvariables; 
-        mvariables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(listfile));
+        mvariables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(listfile));
         mvariables["[extension]"] = util.getExtension(listfile);
         string newListFile = getOutputFileName("list", mvariables);
         ofstream outListTemp;
@@ -667,7 +600,7 @@ void driverPDesign(primerDesignData* params){
 set<int> PrimerDesignCommand::createProcesses(string newSummaryFile, vector<double>& minTms, vector<double>& maxTms, set<string>& primers, vector<Sequence>& conSeqs, int binIndex, vector<string>& binLabels) {
 	try {
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<primerDesignData*> data;
 		
 		//sanity check
@@ -694,7 +627,7 @@ set<int> PrimerDesignCommand::createProcesses(string newSummaryFile, vector<doub
             
             data.push_back(dataBundle);
             
-            workerThreads.push_back(new thread(driverPDesign, dataBundle));
+            workerThreads.push_back(new std::thread(driverPDesign, dataBundle));
         }
         
         OutputWriter* threadSummaryWriter = new OutputWriter(synchronizedOutputSummaryFile);
@@ -874,11 +807,11 @@ vector<Sequence> PrimerDesignCommand::createProcessesConSeqs(map<string, int>& n
         int numBins = binLabels.size();
         vector<linePair> lines;
 #if defined NON_WINDOWS
-        vector<unsigned long long> positions;  positions = util.divideFile(fastafile, processors);
+        vector<double> positions;  positions = util.divideFile(fastafile, processors);
         for (int i = 0; i < (positions.size()-1); i++) {	lines.push_back(linePair(positions[i], positions[(i+1)]));	}
 #else
         long long numSeqs;
-        vector<unsigned long long> positions = util.setFilePosFasta(fastafile, numSeqs);
+        vector<double> positions = util.setFilePosFasta(fastafile, numSeqs);
         if (numSeqs < processors) { processors = numSeqs; m->mothurOut("Reducing processors to " + toString(numSeqs) + ".\n");  }
         
         //figure out how many sequences you have to process
@@ -891,7 +824,7 @@ vector<Sequence> PrimerDesignCommand::createProcessesConSeqs(map<string, int>& n
 #endif
         
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<primerCountsData*> data;
 
         //Lauch worker threads
@@ -901,7 +834,7 @@ vector<Sequence> PrimerDesignCommand::createProcessesConSeqs(map<string, int>& n
             primerCountsData* dataBundle = new primerCountsData(fastafile, nameMap, lines[i+1].start, lines[i+1].end, seq2Bin, numBins);
             data.push_back(dataBundle);
             
-            workerThreads.push_back(new thread(driverGetCounts, dataBundle));
+            workerThreads.push_back(new std::thread(driverGetCounts, dataBundle));
         }
         
         primerCountsData* dataBundle = new primerCountsData(fastafile, nameMap, lines[0].start, lines[0].end, seq2Bin, numBins);
@@ -1049,7 +982,7 @@ char PrimerDesignCommand::getBase(vector<unsigned int> counts, int size){  //A,T
 		else if ((counts[0] == 0) && (counts[1] == 0) && (counts[2] == 0) && (counts[3] == 0) && (counts[4] != 0)) {  conBase = '-'; }
 		//cutoff removed all counts
 		else if ((counts[0] == 0) && (counts[1] == 0) && (counts[2] == 0) && (counts[3] == 0) && (counts[4] == 0)) {  conBase = 'N'; }
-		else{ m->mothurOut("[ERROR]: cannot find consensus base."); m->mothurOutEndLine(); }
+		else{ m->mothurOut("[ERROR]: cannot find consensus base.\n");  }
 		
 		return conBase;
 		
