@@ -45,6 +45,26 @@ vector<string> RareFactCommand::setParameters(){
         CommandParameter pprocessors("processors", "Number", "", "1", "", "", "","",false,false,true); parameters.push_back(pprocessors);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;    allLines = true;
+        
+        vector<string> tempOutNames;
+        outputTypes["rarefaction"] = tempOutNames;
+        outputTypes["r_chao"] = tempOutNames;
+        outputTypes["r_ace"] = tempOutNames;
+        outputTypes["r_jack"] = tempOutNames;
+        outputTypes["r_shannon"] = tempOutNames;
+        outputTypes["r_shannoneven"] = tempOutNames;
+        outputTypes["r_shannonrange"] = tempOutNames;
+        outputTypes["r_heip"] = tempOutNames;
+        outputTypes["r_smithwilson"] = tempOutNames;
+        outputTypes["r_npshannon"] = tempOutNames;
+        outputTypes["r_simpson"] = tempOutNames;
+        outputTypes["r_simpsoneven"] = tempOutNames;
+        outputTypes["r_invsimpson"] = tempOutNames;
+        outputTypes["r_bootstrap"] = tempOutNames;
+        outputTypes["r_coverage"] = tempOutNames;
+        outputTypes["r_nseqs"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -107,115 +127,17 @@ string RareFactCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-RareFactCommand::RareFactCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["rarefaction"] = tempOutNames;
-		outputTypes["r_chao"] = tempOutNames;
-		outputTypes["r_ace"] = tempOutNames;
-		outputTypes["r_jack"] = tempOutNames;
-		outputTypes["r_shannon"] = tempOutNames;
-		outputTypes["r_shannoneven"] = tempOutNames;
-        outputTypes["r_shannonrange"] = tempOutNames;
-		outputTypes["r_heip"] = tempOutNames;
-		outputTypes["r_smithwilson"] = tempOutNames;
-		outputTypes["r_npshannon"] = tempOutNames;
-		outputTypes["r_simpson"] = tempOutNames;
-		outputTypes["r_simpsoneven"] = tempOutNames;
-		outputTypes["r_invsimpson"] = tempOutNames;
-		outputTypes["r_bootstrap"] = tempOutNames;
-		outputTypes["r_coverage"] = tempOutNames;
-		outputTypes["r_nseqs"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "RareFactCommand", "RareFactCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 RareFactCommand::RareFactCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-		allLines = true;
-						
-		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
-			map<string,string>::iterator it;
 			
 			ValidParameters validParameter;
-		
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["rarefaction"] = tempOutNames;
-			outputTypes["r_chao"] = tempOutNames;
-			outputTypes["r_ace"] = tempOutNames;
-			outputTypes["r_jack"] = tempOutNames;
-			outputTypes["r_shannon"] = tempOutNames;
-			outputTypes["r_shannoneven"] = tempOutNames;
-            outputTypes["r_shannonrange"] = tempOutNames;
-			outputTypes["r_heip"] = tempOutNames;
-			outputTypes["r_smithwilson"] = tempOutNames;
-			outputTypes["r_npshannon"] = tempOutNames;
-			outputTypes["r_simpson"] = tempOutNames;
-			outputTypes["r_simpsoneven"] = tempOutNames;
-			outputTypes["r_invsimpson"] = tempOutNames;
-			outputTypes["r_bootstrap"] = tempOutNames;
-			outputTypes["r_coverage"] = tempOutNames;
-			outputTypes["r_nseqs"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("shared");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("rabund");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["rabund"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("sabund");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["sabund"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("list");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["list"] = inputDir + it->second;		}
-				}
-			}
-			
-			//check for required parameters
 			listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not open") { listfile = ""; abort = true; }
 			else if (listfile == "not found") { listfile = ""; }
@@ -241,18 +163,18 @@ RareFactCommand::RareFactCommand(string option)  {
 				//give priority to shared, then list, then rabund, then sabund
 				//if there is a current shared file, use it
 				sharedfile = current->getSharedFile(); 
-				if (sharedfile != "") { inputfile = sharedfile; format = "sharedfile"; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
+				if (sharedfile != "") { inputfile = sharedfile; format = "sharedfile"; m->mothurOut("Using " + sharedfile + " as input file for the shared parameter.\n");  }
 				else { 
 					listfile = current->getListFile(); 
-					if (listfile != "") { inputfile = listfile; format = "list"; m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
+					if (listfile != "") { inputfile = listfile; format = "list"; m->mothurOut("Using " + listfile + " as input file for the list parameter.\n");  }
 					else { 
 						rabundfile = current->getRabundFile(); 
-						if (rabundfile != "") { inputfile = rabundfile; format = "rabund"; m->mothurOut("Using " + rabundfile + " as input file for the rabund parameter."); m->mothurOutEndLine(); }
+						if (rabundfile != "") { inputfile = rabundfile; format = "rabund"; m->mothurOut("Using " + rabundfile + " as input file for the rabund parameter.\n");  }
 						else { 
 							sabundfile = current->getSabundFile(); 
-							if (sabundfile != "") { inputfile = sabundfile; format = "sabund"; m->mothurOut("Using " + sabundfile + " as input file for the sabund parameter."); m->mothurOutEndLine(); }
+							if (sabundfile != "") { inputfile = sabundfile; format = "sabund"; m->mothurOut("Using " + sabundfile + " as input file for the sabund parameter.\n");  }
 							else { 
-								m->mothurOut("No valid current files. You must provide a list, sabund, rabund or shared file before you can use the collect.single command."); m->mothurOutEndLine(); 
+								m->mothurOut("No valid current files. You must provide a list, sabund, rabund or shared file before you can use the collect.single command.\n");  
 								abort = true;
 							}
 						}
@@ -260,8 +182,8 @@ RareFactCommand::RareFactCommand(string option)  {
 				}
 			}
 			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(inputfile);		}
+			 
+					if (outputdir == ""){    outputdir = util.hasPath(inputfile);		}
 
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
@@ -297,7 +219,7 @@ RareFactCommand::RareFactCommand(string option)  {
             temp = validParameter.valid(parameters, "alpha");		if (temp == "not found") { temp = "1"; }
 			util.mothurConvert(temp, alpha);
             
-            if ((alpha != 0) && (alpha != 1) && (alpha != 2)) { m->mothurOut("[ERROR]: Not a valid alpha value. Valid values are 0, 1 and 2."); m->mothurOutEndLine(); abort=true; }
+            if ((alpha != 0) && (alpha != 1) && (alpha != 2)) { m->mothurOut("[ERROR]: Not a valid alpha value. Valid values are 0, 1 and 2.\n");  abort=true; }
 			
 			temp = validParameter.valid(parameters, "groupmode");		if (temp == "not found") { temp = "T"; }
 			groupMode = util.isTrue(temp);
@@ -336,176 +258,45 @@ int RareFactCommand::execute(){
 		map<int, string> file2Group; //index in outputNames[i] -> group
 		for (int p = 0; p < inputFileNames.size(); p++) {
 			
-			string fileNameRoot = outputDir + util.getRootName(util.getSimpleName(inputFileNames[p]));
+			string fileNameRoot = outputdir + util.getRootName(util.getSimpleName(inputFileNames[p]));
+            map<string, string> variables;
+            variables["[filename]"] = fileNameRoot;
 						
 			if (m->getControl_pressed()) {  outputTypes.clear(); for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	}    return 0; }
 			
-			if (inputFileNames.size() > 1) {
-				m->mothurOutEndLine(); m->mothurOut("Processing group " + Groups[p]); m->mothurOutEndLine(); m->mothurOutEndLine();
-			}
-			int i;
-			ValidCalculators validCalculator;
-			
-            map<string, string> variables; 
-            variables["[filename]"] = fileNameRoot;
-			  
-			for (i=0; i<Estimators.size(); i++) {
-				if (validCalculator.isValidCalculator("rarefaction", Estimators[i]) ) { 
-					if (Estimators[i] == "sobs") { 
-						rDisplays.push_back(new RareDisplay(new Sobs(), new ThreeColumnFile(getOutputFileName("rarefaction",variables))));
-						outputNames.push_back(getOutputFileName("rarefaction",variables)); outputTypes["rarefaction"].push_back(getOutputFileName("rarefaction",variables));
-					}else if (Estimators[i] == "chao") { 
-						rDisplays.push_back(new RareDisplay(new Chao1(), new ThreeColumnFile(getOutputFileName("r_chao",variables))));
-						outputNames.push_back(getOutputFileName("r_chao",variables)); outputTypes["r_chao"].push_back(getOutputFileName("r_chao",variables));
-					}else if (Estimators[i] == "ace") { 
-						if(abund < 5)
-							abund = 10;
-						rDisplays.push_back(new RareDisplay(new Ace(abund), new ThreeColumnFile(getOutputFileName("r_ace",variables))));
-						outputNames.push_back(getOutputFileName("r_ace",variables)); outputTypes["r_ace"].push_back(getOutputFileName("r_ace",variables));
-					}else if (Estimators[i] == "jack") { 
-						rDisplays.push_back(new RareDisplay(new Jackknife(), new ThreeColumnFile(getOutputFileName("r_jack",variables))));
-						outputNames.push_back(getOutputFileName("r_jack",variables)); outputTypes["r_jack"].push_back(getOutputFileName("r_jack",variables));
-					}else if (Estimators[i] == "shannon") { 
-						rDisplays.push_back(new RareDisplay(new Shannon(), new ThreeColumnFile(getOutputFileName("r_shannon",variables))));
-						outputNames.push_back(getOutputFileName("r_shannon",variables)); outputTypes["r_shannon"].push_back(getOutputFileName("r_shannon",variables));
-					}else if (Estimators[i] == "shannoneven") { 
-						rDisplays.push_back(new RareDisplay(new ShannonEven(), new ThreeColumnFile(getOutputFileName("r_shannoneven",variables))));
-						outputNames.push_back(getOutputFileName("r_shannoneven",variables)); outputTypes["r_shannoneven"].push_back(getOutputFileName("r_shannoneven",variables));
-					}else if (Estimators[i] == "heip") { 
-						rDisplays.push_back(new RareDisplay(new Heip(), new ThreeColumnFile(getOutputFileName("r_heip",variables))));
-						outputNames.push_back(getOutputFileName("r_heip",variables)); outputTypes["r_heip"].push_back(getOutputFileName("r_heip",variables));
-                    }else if (Estimators[i] == "r_shannonrange") {
-                        rDisplays.push_back(new RareDisplay(new RangeShannon(alpha), new ThreeColumnFile(getOutputFileName("r_shannonrange", variables))));
-                        outputNames.push_back(getOutputFileName("r_shannonrange", variables)); outputTypes["r_shannoneven"].push_back(getOutputFileName("r_shannonrange", variables));
-					}else if (Estimators[i] == "smithwilson") {
-						rDisplays.push_back(new RareDisplay(new SmithWilson(), new ThreeColumnFile(getOutputFileName("r_smithwilson",variables))));
-						outputNames.push_back(getOutputFileName("r_smithwilson",variables)); outputTypes["r_smithwilson"].push_back(getOutputFileName("r_smithwilson",variables));
-					}else if (Estimators[i] == "npshannon") { 
-						rDisplays.push_back(new RareDisplay(new NPShannon(), new ThreeColumnFile(getOutputFileName("r_npshannon",variables))));
-						outputNames.push_back(getOutputFileName("r_npshannon",variables)); outputTypes["r_npshannon"].push_back(getOutputFileName("r_npshannon",variables));
-					}else if (Estimators[i] == "simpson") { 
-						rDisplays.push_back(new RareDisplay(new Simpson(), new ThreeColumnFile(getOutputFileName("r_simpson",variables))));
-						outputNames.push_back(getOutputFileName("r_simpson",variables)); outputTypes["r_simpson"].push_back(getOutputFileName("r_simpson",variables));
-					}else if (Estimators[i] == "simpsoneven") { 
-						rDisplays.push_back(new RareDisplay(new SimpsonEven(), new ThreeColumnFile(getOutputFileName("r_simpsoneven",variables))));
-						outputNames.push_back(getOutputFileName("r_simpsoneven",variables)); outputTypes["r_simpsoneven"].push_back(getOutputFileName("r_simpsoneven",variables));
-					}else if (Estimators[i] == "invsimpson") { 
-						rDisplays.push_back(new RareDisplay(new InvSimpson(), new ThreeColumnFile(getOutputFileName("r_invsimpson",variables))));
-						outputNames.push_back(getOutputFileName("r_invsimpson",variables)); outputTypes["r_invsimpson"].push_back(getOutputFileName("r_invsimpson",variables));
-					}else if (Estimators[i] == "bootstrap") { 
-						rDisplays.push_back(new RareDisplay(new Bootstrap(), new ThreeColumnFile(getOutputFileName("r_bootstrap",variables))));
-						outputNames.push_back(getOutputFileName("r_bootstrap",variables)); outputTypes["r_bootstrap"].push_back(getOutputFileName("r_bootstrap",variables));
-					}else if (Estimators[i] == "coverage") { 
-						rDisplays.push_back(new RareDisplay(new Coverage(), new ThreeColumnFile(getOutputFileName("r_coverage",variables))));
-						outputNames.push_back(getOutputFileName("r_coverage",variables)); outputTypes["r_coverage"].push_back(getOutputFileName("r_coverage",variables));
-					}else if (Estimators[i] == "nseqs") { 
-						rDisplays.push_back(new RareDisplay(new NSeqs(), new ThreeColumnFile(getOutputFileName("r_nseqs",variables))));
-						outputNames.push_back(getOutputFileName("r_nseqs",variables)); outputTypes["r_nseqs"].push_back(getOutputFileName("r_nseqs",variables));
-					}
-                    if (inputFileNames.size() > 1) { file2Group[outputNames.size()-1] = Groups[p]; }
-				}
-			}
+			if (inputFileNames.size() > 1) { m->mothurOut("\nProcessing group " + Groups[p] + "\n\n");  }
 			
+            fillRDisplays(variables, file2Group, p);
 			
 			//if the users entered no valid calculators don't execute command
 			if (rDisplays.size() == 0) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}  return 0; }
 			
-			InputData input(inputFileNames[p], format, nullVector);
-			OrderVector* order = input.getOrderVector();
-			string lastLabel = order->getLabel();
-			
-			//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
-			set<string> processedLabels;
-			set<string> userLabels = labels;
-			
-			if (m->getControl_pressed()) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}    delete order;  for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
-			
-			//as long as you are not at the end of the file or done wih the lines you want
-			while((order != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-				
-				if (m->getControl_pressed()) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}    delete order;  for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
-
-				
-				if(allLines == 1 || labels.count(order->getLabel()) == 1){
-					
-					m->mothurOut(order->getLabel()); m->mothurOutEndLine();
-                    map<string, set<int> >::iterator itEndings = labelToEnds.find(order->getLabel());
-                    set<int> ends;
-                    if (itEndings != labelToEnds.end()) { ends = itEndings->second; }
-					rCurve = new Rarefact(*order, rDisplays, ends, processors);
-					rCurve->getCurve(freq, nIters);
-					delete rCurve;
-					
-					processedLabels.insert(order->getLabel());
-					userLabels.erase(order->getLabel());
-				}
-				
-				if ((util.anyLabelsToProcess(order->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-					string saveLabel = order->getLabel();
-					
-					delete order;
-					order = (input.getOrderVector(lastLabel));
-					
-					m->mothurOut(order->getLabel()); m->mothurOutEndLine();
-					map<string, set<int> >::iterator itEndings = labelToEnds.find(order->getLabel());
-                    set<int> ends;
-                    if (itEndings != labelToEnds.end()) { ends = itEndings->second; }
-					rCurve = new Rarefact(*order, rDisplays, ends, processors);
-
-					rCurve->getCurve(freq, nIters);
-					delete rCurve;
-					
-					processedLabels.insert(order->getLabel());
-					userLabels.erase(order->getLabel());
-					
-					//restore real lastlabel to save below
-					order->setLabel(saveLabel);
-				}
-				
-				lastLabel = order->getLabel();		
-				
-				delete order;
-				order = (input.getOrderVector());
-			}
-			
-			if (m->getControl_pressed()) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}    for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
-
-			//output error messages about any remaining user labels
-			set<string>::iterator it;
-			bool needToRun = false;
-			for (it = userLabels.begin(); it != userLabels.end(); it++) {  
-				m->mothurOut("Your file does not include the label " + *it);
-				if (processedLabels.count(lastLabel) != 1) {
-					m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-					needToRun = true;
-				}else {
-					m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-				}
-			}
-			
-			if (m->getControl_pressed()) { for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}    for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
-
-			//run last label if you need to
-			if (needToRun )  {
-				if (order != NULL) {	delete order;	}
-				order = (input.getOrderVector(lastLabel));
-				
-				m->mothurOut(order->getLabel()); m->mothurOutEndLine();
-				map<string, set<int> >::iterator itEndings = labelToEnds.find(order->getLabel());
+            InputData input(inputFileNames[p], format, nullVector);
+            set<string> processedLabels;
+            set<string> userLabels = labels;
+            string lastLabel = "";
+            
+            OrderVector* order = util.getNextOrder(input, allLines, userLabels, processedLabels, lastLabel);
+                   
+            while (order != NULL) {
+                
+                if (m->getControl_pressed()) { delete order; break; }
+                
+                map<string, set<int> >::iterator itEndings = labelToEnds.find(order->getLabel());
                 set<int> ends;
                 if (itEndings != labelToEnds.end()) { ends = itEndings->second; }
-                rCurve = new Rarefact(*order, rDisplays, ends, processors);
-
-				rCurve->getCurve(freq, nIters);
-				delete rCurve;
-				
-				delete order;
-			}
-			
-			for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}	
-			rDisplays.clear();
+                Rarefact* rCurve = new Rarefact(*order, rDisplays, ends, processors);
+                rCurve->getCurve(freq, nIters);
+                delete rCurve; delete order;
+                
+                order = util.getNextOrder(input, allLines, userLabels, processedLabels, lastLabel);
+            }
+            
+            //delete displays
+            for(int i=0;i<rDisplays.size();i++){    delete rDisplays[i];    } rDisplays.clear();
 		}
-		
+    
+        if (inputFileNames.size() > 1) { for (int p = 0; p < inputFileNames.size(); p++) { util.mothurRemove(inputFileNames[p]); } }
 		
 		if (m->getControl_pressed()) {  for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
 
@@ -527,6 +318,75 @@ int RareFactCommand::execute(){
 	}
 }
 //**********************************************************************************************************************
+void RareFactCommand::fillRDisplays(map<string, string> variables, map<int, string>& file2Group, int thisGroup) {
+    try {
+        
+        ValidCalculators validCalculator;
+        
+        for (int i=0; i<Estimators.size(); i++) {
+            if (validCalculator.isValidCalculator("rarefaction", Estimators[i]) ) {
+                if (Estimators[i] == "sobs") {
+                    rDisplays.push_back(new RareDisplay(new Sobs(), new ThreeColumnFile(getOutputFileName("rarefaction",variables))));
+                    outputNames.push_back(getOutputFileName("rarefaction",variables)); outputTypes["rarefaction"].push_back(getOutputFileName("rarefaction",variables));
+                }else if (Estimators[i] == "chao") {
+                    rDisplays.push_back(new RareDisplay(new Chao1(), new ThreeColumnFile(getOutputFileName("r_chao",variables))));
+                    outputNames.push_back(getOutputFileName("r_chao",variables)); outputTypes["r_chao"].push_back(getOutputFileName("r_chao",variables));
+                }else if (Estimators[i] == "ace") {
+                    if(abund < 5)
+                        abund = 10;
+                    rDisplays.push_back(new RareDisplay(new Ace(abund), new ThreeColumnFile(getOutputFileName("r_ace",variables))));
+                    outputNames.push_back(getOutputFileName("r_ace",variables)); outputTypes["r_ace"].push_back(getOutputFileName("r_ace",variables));
+                }else if (Estimators[i] == "jack") {
+                    rDisplays.push_back(new RareDisplay(new Jackknife(), new ThreeColumnFile(getOutputFileName("r_jack",variables))));
+                    outputNames.push_back(getOutputFileName("r_jack",variables)); outputTypes["r_jack"].push_back(getOutputFileName("r_jack",variables));
+                }else if (Estimators[i] == "shannon") {
+                    rDisplays.push_back(new RareDisplay(new Shannon(), new ThreeColumnFile(getOutputFileName("r_shannon",variables))));
+                    outputNames.push_back(getOutputFileName("r_shannon",variables)); outputTypes["r_shannon"].push_back(getOutputFileName("r_shannon",variables));
+                }else if (Estimators[i] == "shannoneven") {
+                    rDisplays.push_back(new RareDisplay(new ShannonEven(), new ThreeColumnFile(getOutputFileName("r_shannoneven",variables))));
+                    outputNames.push_back(getOutputFileName("r_shannoneven",variables)); outputTypes["r_shannoneven"].push_back(getOutputFileName("r_shannoneven",variables));
+                }else if (Estimators[i] == "heip") {
+                    rDisplays.push_back(new RareDisplay(new Heip(), new ThreeColumnFile(getOutputFileName("r_heip",variables))));
+                    outputNames.push_back(getOutputFileName("r_heip",variables)); outputTypes["r_heip"].push_back(getOutputFileName("r_heip",variables));
+                }else if (Estimators[i] == "r_shannonrange") {
+                    rDisplays.push_back(new RareDisplay(new RangeShannon(alpha), new ThreeColumnFile(getOutputFileName("r_shannonrange", variables))));
+                    outputNames.push_back(getOutputFileName("r_shannonrange", variables)); outputTypes["r_shannoneven"].push_back(getOutputFileName("r_shannonrange", variables));
+                }else if (Estimators[i] == "smithwilson") {
+                    rDisplays.push_back(new RareDisplay(new SmithWilson(), new ThreeColumnFile(getOutputFileName("r_smithwilson",variables))));
+                    outputNames.push_back(getOutputFileName("r_smithwilson",variables)); outputTypes["r_smithwilson"].push_back(getOutputFileName("r_smithwilson",variables));
+                }else if (Estimators[i] == "npshannon") {
+                    rDisplays.push_back(new RareDisplay(new NPShannon(), new ThreeColumnFile(getOutputFileName("r_npshannon",variables))));
+                    outputNames.push_back(getOutputFileName("r_npshannon",variables)); outputTypes["r_npshannon"].push_back(getOutputFileName("r_npshannon",variables));
+                }else if (Estimators[i] == "simpson") {
+                    rDisplays.push_back(new RareDisplay(new Simpson(), new ThreeColumnFile(getOutputFileName("r_simpson",variables))));
+                    outputNames.push_back(getOutputFileName("r_simpson",variables)); outputTypes["r_simpson"].push_back(getOutputFileName("r_simpson",variables));
+                }else if (Estimators[i] == "simpsoneven") {
+                    rDisplays.push_back(new RareDisplay(new SimpsonEven(), new ThreeColumnFile(getOutputFileName("r_simpsoneven",variables))));
+                    outputNames.push_back(getOutputFileName("r_simpsoneven",variables)); outputTypes["r_simpsoneven"].push_back(getOutputFileName("r_simpsoneven",variables));
+                }else if (Estimators[i] == "invsimpson") {
+                    rDisplays.push_back(new RareDisplay(new InvSimpson(), new ThreeColumnFile(getOutputFileName("r_invsimpson",variables))));
+                    outputNames.push_back(getOutputFileName("r_invsimpson",variables)); outputTypes["r_invsimpson"].push_back(getOutputFileName("r_invsimpson",variables));
+                }else if (Estimators[i] == "bootstrap") {
+                    rDisplays.push_back(new RareDisplay(new Bootstrap(), new ThreeColumnFile(getOutputFileName("r_bootstrap",variables))));
+                    outputNames.push_back(getOutputFileName("r_bootstrap",variables)); outputTypes["r_bootstrap"].push_back(getOutputFileName("r_bootstrap",variables));
+                }else if (Estimators[i] == "coverage") {
+                    rDisplays.push_back(new RareDisplay(new Coverage(), new ThreeColumnFile(getOutputFileName("r_coverage",variables))));
+                    outputNames.push_back(getOutputFileName("r_coverage",variables)); outputTypes["r_coverage"].push_back(getOutputFileName("r_coverage",variables));
+                }else if (Estimators[i] == "nseqs") {
+                    rDisplays.push_back(new RareDisplay(new NSeqs(), new ThreeColumnFile(getOutputFileName("r_nseqs",variables))));
+                    outputNames.push_back(getOutputFileName("r_nseqs",variables)); outputTypes["r_nseqs"].push_back(getOutputFileName("r_nseqs",variables));
+                }
+                if (inputFileNames.size() > 1) { file2Group[outputNames.size()-1] = Groups[thisGroup]; }
+            }
+        }
+        
+        
+    }catch(exception& e) {
+        m->errorOut(e, "RareFactCommand", "fillCDisplays");
+        exit(1);
+    }
+}
+//**********************************************************************************************************************
 vector<string> RareFactCommand::createGroupFile(vector<string>& outputNames, map<int, string> file2Group) {
 	try {
 		vector<string> newFileNames;
@@ -538,7 +398,7 @@ vector<string> RareFactCommand::createGroupFile(vector<string>& outputNames, map
 		for (int i = 0; i < outputNames.size(); i++) {
             
 			string extension = util.getExtension(outputNames[i]);
-            string combineFileName = outputDir + util.getRootName(util.getSimpleName(sharedfile)) + "groups" + extension;
+            string combineFileName = outputdir + util.getRootName(util.getSimpleName(sharedfile)) + "groups" + extension;
 			util.mothurRemove(combineFileName); //remove old file
             
 			ifstream in;
@@ -580,7 +440,7 @@ vector<string> RareFactCommand::createGroupFile(vector<string>& outputNames, map
 		for (map<string, map<string, string> >::iterator it = typesFiles.begin(); it != typesFiles.end(); it++) {
 			
 			ofstream out;
-			string combineFileName = outputDir + util.getRootName(util.getSimpleName(sharedfile)) + "groups" + it->first;
+			string combineFileName = outputdir + util.getRootName(util.getSimpleName(sharedfile)) + "groups" + it->first;
 			util.openOutputFileAppend(combineFileName, out);
             out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
             
