@@ -34,6 +34,12 @@ vector<string> RareFactSharedCommand::setParameters(){
         CommandParameter pprocessors("processors", "Number", "", "1", "", "", "","",false,false,true); parameters.push_back(pprocessors);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;    allLines = true;
+        
+        vector<string> tempOutNames;
+        outputTypes["sharedrarefaction"] = tempOutNames;
+        outputTypes["sharedr_nseqs"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -88,80 +94,24 @@ string RareFactSharedCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-RareFactSharedCommand::RareFactSharedCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["sharedrarefaction"] = tempOutNames;
-		outputTypes["sharedr_nseqs"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "RareFactSharedCommand", "RareFactSharedCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
-
 RareFactSharedCommand::RareFactSharedCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-		allLines = true;
-				
-		//allow user to run help
-		if(option == "help") {  help(); abort = true; calledHelp = true; }
+        if(option == "help") {  help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
-			map<string,string>::iterator it;
 			
 			ValidParameters validParameter;
-			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["sharedrarefaction"] = tempOutNames;
-			outputTypes["sharedr_nseqs"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("shared");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("design");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["design"] = inputDir + it->second;		}
-				}
-
-			}
-			
-			//get shared file
 			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }	
 			else if (sharedfile == "not found") { 
 				//if there is a current shared file, use it
 				sharedfile = current->getSharedFile(); 
-				if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current sharedfile and the shared parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter.\n");  }
+				else { 	m->mothurOut("You have no current sharedfile and the shared parameter is required.\n");  abort = true; }
 			}else { current->setSharedFile(sharedfile); }
             
             designfile = validParameter.validFile(parameters, "design");
@@ -170,8 +120,8 @@ RareFactSharedCommand::RareFactSharedCommand(string option)  {
 			else { current->setDesignFile(designfile); }
 			
 			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(sharedfile);		}
+			 
+					if (outputdir == ""){    outputdir = util.hasPath(sharedfile);		}
 			
 			
 			//check for optional parameter and set defaults
@@ -290,14 +240,15 @@ int RareFactSharedCommand::process(DesignMap& designMap, string thisSet){
         vector<Display*> rDisplays;
         
         InputData input(sharedfile, "sharedfile", Groups);
-		SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
-        if (lookup->size() < 2) {
-			m->mothurOut("I cannot run the command without at least 2 valid groups."); 
-            delete lookup;
-            return 0;
-        }
+        set<string> processedLabels;
+        set<string> userLabels = labels;
+        string lastLabel = "";
         
-        string fileNameRoot = outputDir + util.getRootName(util.getSimpleName(sharedfile));
+		SharedRAbundVectors* lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel, thisSet);
+        Groups = lookup->getNamesGroups();
+        if (lookup->size() < 2) { m->mothurOut("[ERROR]: I cannot run the command without at least 2 valid groups.");  delete lookup; return 0; }
+        
+        string fileNameRoot = outputdir + util.getRootName(util.getSimpleName(sharedfile));
         
         vector<string> newGroups = lookup->getNamesGroups();
         if (thisSet != "") {  //make groups only filled with groups from this set so that's all inputdata will read
@@ -315,7 +266,6 @@ int RareFactSharedCommand::process(DesignMap& designMap, string thisSet){
             subset->eliminateZeroOTUS();
         }else { for (int i = 0; i < data.size(); i++) {  subset->push_back(data[i]); } }
         
-
         /******************************************************/
         if (subsample) {
             //user has not set size, set size = smallest samples size
@@ -337,10 +287,10 @@ int RareFactSharedCommand::process(DesignMap& designMap, string thisSet){
 		for (int i=0; i<Estimators.size(); i++) {
 			if (validCalculator.isValidCalculator("sharedrarefaction", Estimators[i]) ) { 
 				if (Estimators[i] == "sharedobserved") { 
-					rDisplays.push_back(new RareDisplay(new SharedSobs(), new SharedThreeColumnFile(getOutputFileName("sharedrarefaction",variables), "")));
+					rDisplays.push_back(new RareDisplay(new SharedSobs(), new SharedThreeColumnFile(getOutputFileName("sharedrarefaction",variables), thisSet)));
 					outputNames.push_back(getOutputFileName("sharedrarefaction",variables)); outputTypes["sharedrarefaction"].push_back(getOutputFileName("sharedrarefaction",variables));
 				}else if (Estimators[i] == "sharednseqs") { 
-					rDisplays.push_back(new RareDisplay(new SharedNSeqs(), new SharedThreeColumnFile(getOutputFileName("sharedr_nseqs",variables), "")));
+					rDisplays.push_back(new RareDisplay(new SharedNSeqs(), new SharedThreeColumnFile(getOutputFileName("sharedr_nseqs",variables), thisSet)));
 					outputNames.push_back(getOutputFileName("sharedr_nseqs",variables)); outputTypes["sharedr_nseqs"].push_back(getOutputFileName("sharedr_nseqs",variables));
 				}
 			}
@@ -353,127 +303,35 @@ int RareFactSharedCommand::process(DesignMap& designMap, string thisSet){
 		if (m->getControl_pressed()) { 
 			for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}
 			for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	}
-			delete lookup; delete subset;
-			return 0;
+			delete lookup; delete subset; return 0;
 		}
         
-        
-		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
-        string lastLabel = subset->getLabel();
-		set<string> processedLabels;
-		set<string> userLabels = labels;
-        
-		//as long as you are not at the end of the file or done wih the lines you want
-		while((subset != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-			if (m->getControl_pressed()) { 
-				for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}
-				for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	}
-                delete lookup; delete subset;
-				return 0;
-			}
-			
-			if(allLines == 1 || labels.count(subset->getLabel()) == 1){
-				m->mothurOut(subset->getLabel() + '\t' + thisSet); m->mothurOutEndLine();
-                
-				rCurve = new Rarefact(subset, rDisplays, jumble, processors);
-				rCurve->getSharedCurve(freq, nIters);
-				delete rCurve;
-                
-                if (subsample) { subsampleLookup(subset, fileNameRoot);  }
-                    
-				processedLabels.insert(subset->getLabel());
-				userLabels.erase(subset->getLabel());
-			}
-			
-			if ((util.anyLabelsToProcess(subset->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-                string saveLabel = subset->getLabel();
-                
-                delete subset;
-                lookup = input.getSharedRAbundVectors(lastLabel);
-                
-                subset = new SharedRAbundVectors();
-                vector<SharedRAbundVector*> data = lookup->getSharedRAbundVectors();
-                if (thisSet != "") {//remove unwanted groups
-                    for (int i = 0; i < data.size(); i++) { if (util.inUsersGroups(data[i]->getGroup(), newGroups)) { subset->push_back(data[i]); } }
-                    subset->eliminateZeroOTUS();
-                }else { for (int i = 0; i < data.size(); i++) {  subset->push_back(data[i]); } }
-                
-                m->mothurOut(subset->getLabel() + '\t' + thisSet); m->mothurOutEndLine();
-                
-                rCurve = new Rarefact(subset, rDisplays, jumble, processors);
-                rCurve->getSharedCurve(freq, nIters);
-                delete rCurve;
-                
-                if (subsample) { subsampleLookup(subset, fileNameRoot);  }
-                
-                processedLabels.insert(subset->getLabel());
-                userLabels.erase(subset->getLabel());
-                
-                //restore real lastlabel to save below
-                subset->setLabels(saveLabel);
-			}
+        while (subset != NULL) {
             
-			
-			lastLabel = subset->getLabel();
-			
-			//get next line to process
-            delete lookup; delete subset;
-			lookup = input.getSharedRAbundVectors();
+            if (m->getControl_pressed()) { delete subset; delete lookup; break; }
             
-            if (lookup != NULL) {
-                if (thisSet != "") {//remove unwanted groups
-                    for (int i = 0; i < data.size(); i++) { if (util.inUsersGroups(data[i]->getGroup(), newGroups)) { subset->push_back(data[i]); } }
-                    subset->eliminateZeroOTUS();
-                }else { for (int i = 0; i < data.size(); i++) {  subset->push_back(data[i]); } }
-            }else {  subset = NULL; }
-
-		}
-		
-		if (m->getControl_pressed()) { 
-			for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}
-			for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	}
-			return 0;
-		}
-		
-		//output error messages about any remaining user labels
-		bool needToRun = false;
-		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
-			m->mothurOut("Your file does not include the label " + *it); 
-            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
-			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
-		}
-		
-		if (m->getControl_pressed()) { 
-			for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}
-			for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); 	}
-			return 0;
-		}
-		
-		//run last label if you need to
-		if (needToRun )  {
-            delete lookup; delete subset;
-            lookup = input.getSharedRAbundVectors();
-            
-            if (lookup != NULL) {
-                if (thisSet != "") {//remove unwanted groups
-                    for (int i = 0; i < data.size(); i++) { if (util.inUsersGroups(data[i]->getGroup(), newGroups)) { subset->push_back(data[i]); } }
-                    subset->eliminateZeroOTUS();
-                }else { for (int i = 0; i < data.size(); i++) {  subset->push_back(data[i]); } }
-            }else {  subset = NULL; }
-            
-			m->mothurOut(subset->getLabel() + '\t' + thisSet); m->mothurOutEndLine();
-            
-			rCurve = new Rarefact(subset, rDisplays, jumble, processors);
-			rCurve->getSharedCurve(freq, nIters);
-			delete rCurve;
+            rCurve = new Rarefact(subset, rDisplays, jumble, processors);
+            rCurve->getSharedCurve(freq, nIters);
+            delete rCurve;
             
             if (subsample) { subsampleLookup(subset, fileNameRoot);  }
-                
-			delete lookup; delete subset;
-		}
-		
-		for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}	
-
+            
+           delete lookup; delete subset;
+           lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel, thisSet);
+           
+           if (lookup != NULL) {
+               subset = new SharedRAbundVectors();
+               data = lookup->getSharedRAbundVectors();
+               if (thisSet != "") {//remove unwanted groups
+                   for (int i = 0; i < data.size(); i++) { if (util.inUsersGroups(data[i]->getGroup(), newGroups)) { subset->push_back(data[i]); } }
+                   subset->eliminateZeroOTUS();
+               }else { for (int i = 0; i < data.size(); i++) {  subset->push_back(data[i]); } }
+           }else {  subset = NULL; }
+        }
+        
+		for(int i=0;i<rDisplays.size();i++){	delete rDisplays[i];	}
+        
+        if (m->getControl_pressed()) {  for (int i = 0; i < outputNames.size(); i++) {    util.mothurRemove(outputNames[i]);     } }
         
         return 0;
     }
@@ -504,10 +362,10 @@ int RareFactSharedCommand::subsampleLookup(SharedRAbundVectors*& thisLookup, str
             for (int i=0; i<Estimators.size(); i++) {
                 if (validCalculator.isValidCalculator("sharedrarefaction", Estimators[i]) ) { 
                     if (Estimators[i] == "sharedobserved") { 
-                        rDisplays.push_back(new RareDisplay(new SharedSobs(), new SharedThreeColumnFile(getOutputFileName("sharedrarefaction",variables), "")));
+                        rDisplays.push_back(new RareDisplay(new SharedSobs(), new SharedOneColumnFile(getOutputFileName("sharedrarefaction",variables))));
                         filenames["sharedrarefaction"].push_back(getOutputFileName("sharedrarefaction",variables));
                     }else if (Estimators[i] == "sharednseqs") { 
-                        rDisplays.push_back(new RareDisplay(new SharedNSeqs(), new SharedThreeColumnFile(getOutputFileName("sharedr_nseqs",variables), "")));
+                        rDisplays.push_back(new RareDisplay(new SharedNSeqs(), new SharedOneColumnFile(getOutputFileName("sharedr_nseqs",variables))));
                         filenames["sharedr_nseqs"].push_back(getOutputFileName("sharedr_nseqs",variables));
                     }
                 }
@@ -630,7 +488,7 @@ vector<string> RareFactSharedCommand::createGroupFile(vector<string>& outputName
 		for (int i = 0; i < outputNames.size(); i++) {
             
 			string extension = util.getExtension(outputNames[i]);
-            string combineFileName = outputDir + util.getRootName(util.getSimpleName(sharedfile)) + "groups" + extension;
+            string combineFileName = outputdir + util.getRootName(util.getSimpleName(sharedfile)) + "groups" + extension;
 			util.mothurRemove(combineFileName); //remove old file
             
 			ifstream in;
@@ -642,14 +500,11 @@ vector<string> RareFactSharedCommand::createGroupFile(vector<string>& outputName
             vector< vector<string> > allLabels;
             vector<string> thisSet; thisSet.push_back(theseLabels[0]); allLabels.push_back(thisSet); thisSet.clear(); //makes "numSampled" its own grouping
             for (int j = 1; j < theseLabels.size()-1; j++) {
-                if (theseLabels[j+1] == "lci") {
-                    thisSet.push_back(theseLabels[j]); 
-                    thisSet.push_back(theseLabels[j+1]); 
-                    thisSet.push_back(theseLabels[j+2]);
-                    j++; j++;
-                }else{ //no lci or hci for this calc.
-                    thisSet.push_back(theseLabels[j]); 
-                }
+                
+                thisSet.push_back(theseLabels[j]);  j++; //j+1
+                thisSet.push_back(theseLabels[j]);  j++; //j+2
+                thisSet.push_back(theseLabels[j]);
+                
                 allLabels.push_back(thisSet); 
                 thisSet.clear();
             }
@@ -667,11 +522,10 @@ vector<string> RareFactSharedCommand::createGroupFile(vector<string>& outputName
 		}
 		
 		//for each type create a combo file
-		
 		for (map<string, map<string, string> >::iterator it = typesFiles.begin(); it != typesFiles.end(); it++) {
 			
 			ofstream out;
-			string combineFileName = outputDir + util.getRootName(util.getSimpleName(sharedfile)) + "groups" + it->first;
+			string combineFileName = outputdir + util.getRootName(util.getSimpleName(sharedfile)) + "groups" + it->first;
 			util.openOutputFileAppend(combineFileName, out);
 			newFileNames.push_back(combineFileName);
 			map<string, string> thisTypesFiles = it->second; //it->second maps filename to group
@@ -736,7 +590,7 @@ vector<string> RareFactSharedCommand::createGroupFile(vector<string>& outputName
             for (int k = 1; k < fileLabels[combineFileName].size(); k++) { //output thing like 0.03-A lci-A hci-A
                 for (int n = 0; n < groupNames.size(); n++) { // for each group
                     for (int l = 0; l < fileLabels[combineFileName][k].size(); l++) { //output modified labels
-                        out  << '\t' << fileLabels[combineFileName][k][l] << '-' << groupNames[n];
+                        out  << '\t' << fileLabels[combineFileName][k][l]; // << '-' << groupNames[n];
                     }
                 }
             }
