@@ -29,6 +29,16 @@ vector<string> RemoveRareCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;    allLines = true;
+        
+        vector<string> tempOutNames;
+        outputTypes["rabund"] = tempOutNames;
+        outputTypes["sabund"] = tempOutNames;
+        outputTypes["list"] = tempOutNames;
+        outputTypes["group"] = tempOutNames;
+        outputTypes["shared"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -80,112 +90,17 @@ string RemoveRareCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-RemoveRareCommand::RemoveRareCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["rabund"] = tempOutNames;
-		outputTypes["sabund"] = tempOutNames;
-		outputTypes["list"] = tempOutNames;
-		outputTypes["group"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-		outputTypes["shared"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "RemoveRareCommand", "RemoveRareCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 RemoveRareCommand::RemoveRareCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-		allLines = true;
-		
-		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string,string>::iterator it;
-			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["rabund"] = tempOutNames;
-			outputTypes["sabund"] = tempOutNames;
-			outputTypes["list"] = tempOutNames;
-			outputTypes["group"] = tempOutNames;
-			outputTypes["shared"] = tempOutNames;	
-            outputTypes["count"] = tempOutNames;
-			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("list");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["list"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("sabund");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["sabund"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("rabund");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["rabund"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("shared");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-			}
 			
 			
 			//check for file parameters
@@ -220,7 +135,7 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
 			else { current->setCountFile(countfile); }
             			
             if ((groupfile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: group or count."); m->mothurOutEndLine(); abort=true;
+                m->mothurOut("[ERROR]: you may only use one of the following: group or count.\n"); abort=true;
             }
 			
 			if ((sharedfile == "") && (listfile == "") && (rabundfile == "") && (sabundfile == "")) { 
@@ -228,19 +143,18 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
 				//give priority to shared, then list, then rabund, then sabund
 				//if there is a current shared file, use it
 				sharedfile = current->getSharedFile(); 
-				if (sharedfile != "") {  m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
+				if (sharedfile != "") {  m->mothurOut("Using " + sharedfile + " as input file for the shared parameter.\n");  }
 				else { 
 					listfile = current->getListFile(); 
-					if (listfile != "") {  m->mothurOut("Using " + listfile + " as input file for the list parameter."); m->mothurOutEndLine(); }
+					if (listfile != "") {  m->mothurOut("Using " + listfile + " as input file for the list parameter.\n");  }
 					else { 
 						rabundfile = current->getRabundFile(); 
-						if (rabundfile != "") {  m->mothurOut("Using " + rabundfile + " as input file for the rabund parameter."); m->mothurOutEndLine(); }
+						if (rabundfile != "") {  m->mothurOut("Using " + rabundfile + " as input file for the rabund parameter.\n");  }
 						else { 
 							sabundfile = current->getSabundFile(); 
-							if (sabundfile != "") {  m->mothurOut("Using " + sabundfile + " as input file for the sabund parameter."); m->mothurOutEndLine(); }
+							if (sabundfile != "") {  m->mothurOut("Using " + sabundfile + " as input file for the sabund parameter.\n");  }
 							else { 
-								m->mothurOut("No valid current files. You must provide a list, sabund, rabund or shared file."); m->mothurOutEndLine(); 
-								abort = true;
+								m->mothurOut("[ERROR]: No valid current files. You must provide a list, sabund, rabund or shared file.\n");  abort = true;
 							}
 						}
 					}
@@ -260,15 +174,15 @@ RemoveRareCommand::RemoveRareCommand(string option)  {
 			}
 			
 			string temp = validParameter.valid(parameters, "nseqs");
-			if (temp == "not found") { m->mothurOut("nseqs is a required parameter."); m->mothurOutEndLine(); abort = true; }
+			if (temp == "not found") { m->mothurOut("[ERROR]: nseqs is a required parameter, quitting.\n");  abort = true; }
 			else { util.mothurConvert(temp, nseqs); }
 			
 			temp = validParameter.valid(parameters, "bygroup");	 if (temp == "not found") { temp = "f"; }
 			byGroup = util.isTrue(temp);
 			
-			if (byGroup && (sharedfile == "")) { m->mothurOut("The byGroup parameter is only valid with a shared file."); m->mothurOutEndLine(); }
+			if (byGroup && (sharedfile == "")) { m->mothurOut("The byGroup parameter is only valid with a shared file.\n"); }
 			
-			if (((groupfile != "") || (countfile != "")) && (listfile == "")) { m->mothurOut("A group or count file is only valid with a list file."); m->mothurOutEndLine(); groupfile = ""; countfile = ""; }
+			if (((groupfile != "") || (countfile != "")) && (listfile == "")) { m->mothurOut("A group or count file is only valid with a list file.\n");  groupfile = ""; countfile = ""; }
 		}
 		
 	}
@@ -295,9 +209,8 @@ int RemoveRareCommand::execute(){
 		if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
 			
 		if (outputNames.size() != 0) {
-			m->mothurOutEndLine();
-			m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-			for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
+			m->mothurOut("\nOutput File Names:\n");
+			for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]+"\n"); 	}
 			m->mothurOutEndLine();
 			
 			//set rabund file as new current rabundfile
@@ -348,8 +261,8 @@ int RemoveRareCommand::processList(){
 				
 		//you must provide a label because the names in the listfile need to be consistent
 		string thisLabel = "";
-		if (allLines) { m->mothurOut("For the listfile you must select one label, using first label in your listfile."); m->mothurOutEndLine(); }
-		else if (labels.size() > 1) { m->mothurOut("For the listfile you must select one label, using " + (*labels.begin()) + "."); m->mothurOutEndLine(); thisLabel = *labels.begin(); }
+		if (allLines) { m->mothurOut("For the listfile you must select one label, using first label in your listfile.\n"); }
+		else if (labels.size() > 1) { m->mothurOut("For the listfile you must select one label, using " + (*labels.begin()) + ".\n");  thisLabel = *labels.begin(); }
 		else { thisLabel = *labels.begin(); }
 		
 		InputData input(listfile, "list", nullVector);
@@ -385,8 +298,8 @@ int RemoveRareCommand::processList(){
 			}
 		}
         
-        string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(listfile);  }
+        string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(listfile);  }
         map<string, string> variables;
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(listfile));
         variables["[extension]"] = util.getExtension(listfile);
@@ -408,18 +321,21 @@ int RemoveRareCommand::processList(){
 		//if groupfile is given then use it
 		GroupMap* groupMap;
         CountTable ct;
+        CountTable newCountTable; //instead of removing rare, fill new count table with "good" seqs
+        bool selectedGroups = true;
 		if (groupfile != "") { 
 			groupMap = new GroupMap(groupfile); groupMap->readMap(); 
-            if (Groups.size() == 0) { Groups = groupMap->getNamesOfGroups(); }
+            if (Groups.size() == 0) { Groups = groupMap->getNamesOfGroups(); selectedGroups = false; }
 			util.openOutputFile(outputGroupFileName, outGroup);
 		}else if (countfile != "") {
             ct.readTable(countfile, true, false);
             if (ct.hasGroupInfo()) {
                 vector<string> namesGroups = ct.getNamesOfGroups();
-                if (Groups.size() == 0) { Groups = ct.getNamesOfGroups(); }            }
+                if (Groups.size() == 0) { Groups = ct.getNamesOfGroups(); selectedGroups = false; }
+                for (int i = 0; i < namesGroups.size(); i++) { newCountTable.addGroup(namesGroups[i]); }
+            }
         }
-		
-		
+        
 		if (list != NULL) {
             
             vector<string> binLabels = list->getLabels();
@@ -428,65 +344,80 @@ int RemoveRareCommand::processList(){
 			//make a new list vector
 			ListVector newList;
 			newList.setLabel(list->getLabel());
-			
+
 			//for each bin
 			for (int i = 0; i < list->getNumBins(); i++) {
 				if (m->getControl_pressed()) {  if (groupfile != "") { delete groupMap; outGroup.close(); util.mothurRemove(outputGroupFileName); } out.close();  util.mothurRemove(outputFileName);  return 0; }
-				
+                
 				//parse out names that are in accnos file
 				string binnames = list->get(i);
 				vector<string> names;
-				string saveBinNames = binnames;
+                vector<string> newNames;
 				util.splitAtComma(binnames, names);
                 int binsize = names.size();
 				
 				vector<string> newGroupFile;
 				if (groupfile != "") {
-					vector<string> newNames;
-					saveBinNames = "";
 					for(int k = 0; k < names.size(); k++) {
 						string group = groupMap->getGroup(names[k]);
 						
-						if (util.inUsersGroups(group, Groups)) {
-							newGroupFile.push_back(names[k] + "\t" + group); 
-								
-							newNames.push_back(names[k]);	
-							saveBinNames += names[k] + ",";
-						}
+                        if (selectedGroups) {
+                            if (util.inUsersGroups(group, Groups)) {
+                                newGroupFile.push_back(names[k] + "\t" + group);
+                                newNames.push_back(names[k]);
+                            }
+                        }else {
+                            newGroupFile.push_back(names[k] + "\t" + group);
+                            newNames.push_back(names[k]);
+                        }
 					}
 					names = newNames; binsize = names.size();
-					saveBinNames = saveBinNames.substr(0, saveBinNames.length()-1);
 				}else if (countfile != "") {
-					saveBinNames = "";
                     binsize = 0;
 					for(int k = 0; k < names.size(); k++) {
                         if (ct.hasGroupInfo()) {
-                            vector<string> thisSeqsGroups = ct.getGroups(names[k]);
+                            if (selectedGroups) {
+                                vector<string> thisSeqsGroups = ct.getGroups(names[k]);
+                                vector<int> thisGroupCounts = ct.getGroupCounts(names[k]);
                             
-                            int thisSeqsCount = 0;
-                            for (int n = 0; n < thisSeqsGroups.size(); n++) {
-                                if (util.inUsersGroups(thisSeqsGroups[n], Groups)) {
-                                    thisSeqsCount += ct.getGroupCount(names[k], thisSeqsGroups[n]);
+                                int thisSeqsCount = 0;
+                                for (int n = 0; n < thisSeqsGroups.size(); n++) {
+                                    if (util.inUsersGroups(thisSeqsGroups[n], Groups)) {
+                                        thisSeqsCount += thisGroupCounts[n];
+                                    }
                                 }
+                                binsize += thisSeqsCount;
+                                //if you don't have any seqs from the groups the user wants, then remove you.
+                                if (thisSeqsCount == 0) { newGroupFile.push_back(names[k]); }
+                                else { newNames.push_back(names[k]); }
+                            }else { //all groups
+                                binsize += ct.getNumSeqs(names[k]);
+                                newNames.push_back(names[k]);
                             }
-                            binsize += thisSeqsCount;
-                            //if you don't have any seqs from the groups the user wants, then remove you.
-                            if (thisSeqsCount == 0) { newGroupFile.push_back(names[k]); }
-                            else { saveBinNames += names[k] + ","; }
                         }else {
                             binsize += ct.getNumSeqs(names[k]); 
-                            saveBinNames += names[k] + ",";
+                            newNames.push_back(names[k]);
                         }
 					}
-					saveBinNames = saveBinNames.substr(0, saveBinNames.length()-1);
-                }
+                }else { newNames = names; }
 
 				if (binsize > nseqs) { //keep bin
+                    string saveBinNames = util.getStringFromVector(newNames, ",");
 					newList.push_back(saveBinNames);
                     newLabels.push_back(binLabels[i]);
 					if (groupfile != "") {  for(int k = 0; k < newGroupFile.size(); k++) { outGroup << newGroupFile[k] << endl; }  }
-                    else if (countfile != "") { for(int k = 0; k < newGroupFile.size(); k++) {  ct.remove(newGroupFile[k]); } }
-				}else {  if (countfile != "") {  for(int k = 0; k < names.size(); k++) {  ct.remove(names[k]); } }  }
+                    else if (countfile != "") {
+                        for(int k = 0; k < newNames.size(); k++) {
+                            if (ct.hasGroupInfo()) {
+                                vector<int> groupCounts = ct.getGroupCounts(newNames[k]);
+                                newCountTable.push_back(newNames[k], groupCounts);
+                            }else {
+                                int reps = ct.getNumSeqs(newNames[k]);
+                                newCountTable.push_back(newNames[k], reps);
+                            }
+                        }
+                    }
+                }
 			}
 			
 			//print new listvector
@@ -500,18 +431,17 @@ int RemoveRareCommand::processList(){
 		out.close();
 		if (groupfile != "") { outGroup.close(); outputTypes["group"].push_back(outputGroupFileName); outputNames.push_back(outputGroupFileName); }
         if (countfile != "") { 
-            if (ct.hasGroupInfo()) {
-                vector<string> allGroups = ct.getNamesOfGroups();
+            if (newCountTable.hasGroupInfo()) {
+                vector<string> allGroups = newCountTable.getNamesOfGroups();
                 for (int i = 0; i < allGroups.size(); i++) {
-                    if (!util.inUsersGroups(allGroups[i], Groups)) { ct.removeGroup(allGroups[i]); }
+                    if (!util.inUsersGroups(allGroups[i], Groups)) { newCountTable.removeGroup(allGroups[i]); }
                 }
-
             }
-            ct.printTable(outputCountFileName);
+            newCountTable.printTable(outputCountFileName, true);
             outputTypes["count"].push_back(outputCountFileName); outputNames.push_back(outputCountFileName); 
         }
 		
-		if (wroteSomething == false) {  m->mothurOut("Your file contains only rare sequences."); m->mothurOutEndLine();  }
+		if (wroteSomething == false) {  m->mothurOut("Your file contains only rare sequences.\n");   }
 		outputTypes["list"].push_back(outputFileName); outputNames.push_back(outputFileName);
 		
 		return 0;
@@ -522,10 +452,10 @@ int RemoveRareCommand::processList(){
 	}
 }
 //**********************************************************************************************************************
-int RemoveRareCommand::processSabund(){
+void RemoveRareCommand::processSabund(){
 	try {
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(sabundfile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(sabundfile);  }
         map<string, string> variables; 
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(sabundfile));
         variables["[extension]"] = util.getExtension(sabundfile);
@@ -537,81 +467,26 @@ int RemoveRareCommand::processSabund(){
 		
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
 		InputData input(sabundfile, "sabund", nullVector);
-		SAbundVector* sabund = input.getSAbundVector();
-		string lastLabel = sabund->getLabel();
-		set<string> processedLabels;
-		set<string> userLabels = labels;
-		
-		while((sabund != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-			
-			if (m->getControl_pressed()) { delete sabund; out.close(); return 0; }
-			
-			if(allLines == 1 || labels.count(sabund->getLabel()) == 1){			
-				
-				m->mothurOut(sabund->getLabel()); m->mothurOutEndLine();
-				processedLabels.insert(sabund->getLabel());
-				userLabels.erase(sabund->getLabel());
-				
-				if (sabund->getMaxRank() > nseqs) {
-					for(int i = 1; i <=nseqs; i++) {  sabund->set(i, 0); }
-				}else {	sabund->clear(); }
-				
-				if (sabund->getNumBins() > 0) { sabund->print(out); }
-			}
-			
-			if ((util.anyLabelsToProcess(sabund->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = sabund->getLabel();
-				
-				delete sabund;
-				sabund = input.getSAbundVector(lastLabel);
-				
-				m->mothurOut(sabund->getLabel()); m->mothurOutEndLine();
-				processedLabels.insert(sabund->getLabel());
-				userLabels.erase(sabund->getLabel());
-				
-				if (sabund->getMaxRank() > nseqs) {
-					for(int i = 1; i <=nseqs; i++) {  sabund->set(i, 0); }
-				}else {	sabund->clear(); }
-				
-				if (sabund->getNumBins() > 0) { sabund->print(out); }
-								
-				//restore real lastlabel to save below
-				sabund->setLabel(saveLabel);
-			}		
-			
-			lastLabel = sabund->getLabel();			
-			
-			delete sabund;
-			sabund = input.getSAbundVector();
-		}
-		
-		if (m->getControl_pressed()) {  out.close(); return 0; }	
-		
-		//output error messages about any remaining user labels
-		bool needToRun = false;
-		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
-			m->mothurOut("Your file does not include the label " + *it); 
-            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
-			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
-		}
-		
-		//run last label if you need to
-		if (needToRun )  {
-			if (sabund != NULL) {	delete sabund;	}
-			sabund = input.getSAbundVector(lastLabel);
-			
-			m->mothurOut(sabund->getLabel()); m->mothurOutEndLine();
-			
-			if (sabund->getMaxRank() > nseqs) {
-				for(int i = 1; i <=nseqs; i++) {  sabund->set(i, 0); }
-			}else {	sabund->clear(); }
-			
-			if (sabund->getNumBins() > 0) { sabund->print(out); }
-			
-			delete sabund;
-		}
-		
-		return 0;
+        set<string> processedLabels;
+        set<string> userLabels = labels;
+        string lastLabel = "";
+        
+        SAbundVector* sabund = util.getNextSAbund(input, allLines, userLabels, processedLabels, lastLabel);
+        
+        while (sabund != NULL) {
+                   
+            if (m->getControl_pressed()) { delete sabund; break; }
+                   
+            if (sabund->getMaxRank() > nseqs) {
+                for(int i = 1; i <=nseqs; i++) {  sabund->set(i, 0); }
+            }else {    sabund->clear(); }
+            
+            if (sabund->getNumBins() > 0) { sabund->print(out); }
+            delete sabund;
+                  
+            sabund = util.getNextSAbund(input, allLines, userLabels, processedLabels, lastLabel);
+        }
+        out.close();
 	}
 	catch(exception& e) {
 		m->errorOut(e, "RemoveRareCommand", "processSabund");
@@ -619,10 +494,10 @@ int RemoveRareCommand::processSabund(){
 	}
 }
 //**********************************************************************************************************************
-int RemoveRareCommand::processRabund(){
+void RemoveRareCommand::processRabund(){
 	try {
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(rabundfile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(rabundfile);  }
         map<string, string> variables; 
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(rabundfile));
         variables["[extension]"] = util.getExtension(rabundfile);
@@ -634,87 +509,29 @@ int RemoveRareCommand::processRabund(){
 		
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
 		InputData input(rabundfile, "rabund", nullVector);
-		RAbundVector* rabund = input.getRAbundVector();
-		string lastLabel = rabund->getLabel();
-		set<string> processedLabels;
-		set<string> userLabels = labels;
-		
-		while((rabund != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-			
-			if (m->getControl_pressed()) { delete rabund; out.close(); return 0; }
-			
-			if(allLines == 1 || labels.count(rabund->getLabel()) == 1){			
-				
-				m->mothurOut(rabund->getLabel()); m->mothurOutEndLine();
-				processedLabels.insert(rabund->getLabel());
-				userLabels.erase(rabund->getLabel());
-				
-				RAbundVector newRabund; newRabund.setLabel(rabund->getLabel());
-				for (int i = 0; i < rabund->getNumBins(); i++) {
-					if (rabund->get(i) > nseqs) {
-						newRabund.push_back(rabund->get(i));
-					}
-				}
-				if (newRabund.getNumBins() > 0) { newRabund.print(out); }
-			}
-			
-			if ((util.anyLabelsToProcess(rabund->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = rabund->getLabel();
-				
-				delete rabund;
-				rabund = input.getRAbundVector(lastLabel);
-				
-				m->mothurOut(rabund->getLabel()); m->mothurOutEndLine();
-				processedLabels.insert(rabund->getLabel());
-				userLabels.erase(rabund->getLabel());
-				
-				RAbundVector newRabund; newRabund.setLabel(rabund->getLabel());
-				for (int i = 0; i < rabund->getNumBins(); i++) {
-					if (rabund->get(i) > nseqs) {
-						newRabund.push_back(rabund->get(i));
-					}
-				}
-				if (newRabund.getNumBins() > 0) { newRabund.print(out); }				
-				
-				//restore real lastlabel to save below
-				rabund->setLabel(saveLabel);
-			}		
-			
-			lastLabel = rabund->getLabel();			
-			
-			delete rabund;
-			rabund = input.getRAbundVector();
-		}
-		
-		if (m->getControl_pressed()) {  out.close(); return 0; }	
-		
-		//output error messages about any remaining user labels
-		bool needToRun = false;
-		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
-			m->mothurOut("Your file does not include the label " + *it); 
-            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
-			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
-		}
-		
-		//run last label if you need to
-		if (needToRun )  {
-			if (rabund != NULL) {	delete rabund;	}
-			rabund = input.getRAbundVector(lastLabel);
-			
-			m->mothurOut(rabund->getLabel()); m->mothurOutEndLine();
-			
-			RAbundVector newRabund; newRabund.setLabel(rabund->getLabel());
-			for (int i = 0; i < rabund->getNumBins(); i++) {
-				if (rabund->get(i) > nseqs) {
-					newRabund.push_back(rabund->get(i));
-				}
-			}
-			if (newRabund.getNumBins() > 0) { newRabund.print(out); }	
-			
-			delete rabund;
-		}
-		
-		return 0;
+        set<string> processedLabels;
+        set<string> userLabels = labels;
+        string lastLabel = "";
+        
+        RAbundVector* rabund = util.getNextRAbund(input, allLines, userLabels, processedLabels, lastLabel);
+        
+        while (rabund != NULL) {
+            
+            if (m->getControl_pressed()) { delete rabund; break; }
+            
+            RAbundVector newRabund; newRabund.setLabel(rabund->getLabel());
+            for (int i = 0; i < rabund->getNumBins(); i++) {
+                if (rabund->get(i) > nseqs) {
+                    newRabund.push_back(rabund->get(i));
+                }
+            }
+            if (newRabund.getNumBins() > 0) { newRabund.print(out); }
+            delete rabund;
+            
+            rabund = util.getNextRAbund(input, allLines, userLabels, processedLabels, lastLabel);
+        }
+        out.close();
+       
 	}
 	catch(exception& e) {
 		m->errorOut(e, "RemoveRareCommand", "processRabund");
@@ -722,82 +539,37 @@ int RemoveRareCommand::processRabund(){
 	}
 }
 //**********************************************************************************************************************
-int RemoveRareCommand::processShared(){
+void RemoveRareCommand::processShared(){
 	try {
 		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
 		InputData input(sharedfile, "sharedfile", Groups);
-		SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
-		string lastLabel = lookup->getLabel();
 		set<string> processedLabels;
-		set<string> userLabels = labels;
-		
-		while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-			
-            if (m->getControl_pressed()) { delete lookup; return 0; }
-			
-			if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
-				
-				m->mothurOut(lookup->getLabel()+"\n"); 
-				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
-				
-				processLookup(lookup);
-			}
-			
-			if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-				string saveLabel = lookup->getLabel();
-				
-				delete lookup;
-				lookup = input.getSharedRAbundVectors(lastLabel);
-				
-				m->mothurOut(lookup->getLabel()+"\n"); 
-				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
-				
-				processLookup(lookup);			
-				
-				//restore real lastlabel to save below
-				lookup->setLabels(saveLabel);
-			}		
-			
-			lastLabel = lookup->getLabel();
-			
-			delete lookup;
-			lookup = input.getSharedRAbundVectors();
-		}
-		
-		if (m->getControl_pressed()) {  return 0; }	
-		
-		//output error messages about any remaining user labels
-		bool needToRun = false;
-		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
-			m->mothurOut("Your file does not include the label " + *it); 
-            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
-			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
-		}
-		
-		//run last label if you need to
-		if (needToRun )  {
-			delete lookup;
-			lookup = input.getSharedRAbundVectors(lastLabel);
-			
-			m->mothurOut(lookup->getLabel()+"\n"); 
-			processLookup(lookup);	
-			
-			delete lookup;
-		}
-		
-		return 0;
+        set<string> userLabels = labels;
+        string lastLabel = "";
+        
+        SharedRAbundVectors* lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
+        Groups = lookup->getNamesGroups();
+        
+        while (lookup != NULL) {
+            
+            if (m->getControl_pressed()) { delete lookup; break; }
+            
+            processLookup(lookup); delete lookup;
+            
+            lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
+        }
 	}
 	catch(exception& e) {
-		m->errorOut(e, "RemoveRareCommand", "processSabund");
+		m->errorOut(e, "RemoveRareCommand", "processShared");
 		exit(1);
 	}
 }
 //**********************************************************************************************************************
-int RemoveRareCommand::processLookup(SharedRAbundVectors*& lookup){
+void RemoveRareCommand::processLookup(SharedRAbundVectors*& lookup){
 	try {
 		
-        string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(sharedfile);  }
+        string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(sharedfile);  }
         map<string, string> variables;
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(sharedfile));
         variables["[extension]"] = util.getExtension(sharedfile);
@@ -805,8 +577,7 @@ int RemoveRareCommand::processLookup(SharedRAbundVectors*& lookup){
 		string outputFileName = getOutputFileName("shared", variables);
 		outputTypes["shared"].push_back(outputFileName); outputNames.push_back(outputFileName);
 		
-		ofstream out;
-		util.openOutputFile(outputFileName, out);
+		ofstream out; util.openOutputFile(outputFileName, out);
         
 		vector<SharedRAbundVector> newRabunds;  newRabunds.resize(lookup->size());
         vector<string> headers;
@@ -824,7 +595,7 @@ int RemoveRareCommand::processLookup(SharedRAbundVectors*& lookup){
 			for (int i = 0; i < lookup->getNumBins(); i++) {
 				bool allZero = true;
 				
-				if (m->getControl_pressed()) { out.close(); return 0; }
+				if (m->getControl_pressed()) { out.close(); return; }
 				
 				//for each group
                 vector<int> abunds = lookup->getOTU(i);
@@ -846,7 +617,7 @@ int RemoveRareCommand::processLookup(SharedRAbundVectors*& lookup){
 			//for each otu
 			for (int i = 0; i < lookup->getNumBins(); i++) {
 				
-				if (m->getControl_pressed()) { out.close(); return 0; }
+				if (m->getControl_pressed()) { out.close(); return; }
 				
                 int totalAbund = lookup->getOTUTotal(i);
 				
@@ -868,8 +639,6 @@ int RemoveRareCommand::processLookup(SharedRAbundVectors*& lookup){
 		}
 		
         out.close();
-        
-		return 0;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "RemoveRareCommand", "processLookup");
