@@ -25,6 +25,7 @@ vector<string> RemoveSeqsCommand::setParameters(){
 		CommandParameter plist("list", "InputTypes", "", "", "none", "FNGLT", "none","list",false,false,true); parameters.push_back(plist);
 		CommandParameter ptaxonomy("taxonomy", "InputTypes", "", "", "none", "FNGLT", "none","taxonomy",false,false,true); parameters.push_back(ptaxonomy);
 		CommandParameter palignreport("alignreport", "InputTypes", "", "", "none", "FNGLT", "none","alignreport",false,false); parameters.push_back(palignreport);
+        CommandParameter pcontigsreport("contigsreport", "InputTypes", "", "", "FNGLT", "FNGLT", "none","contigsreport",false,false); parameters.push_back(pcontigsreport);
 		CommandParameter pqfile("qfile", "InputTypes", "", "", "none", "FNGLT", "none","qfile",false,false); parameters.push_back(pqfile);
 		CommandParameter paccnos("accnos", "InputTypes", "", "", "none", "none", "none","",false,true,true); parameters.push_back(paccnos);
 		CommandParameter pdups("dups", "Boolean", "", "T", "", "", "","",false,false); parameters.push_back(pdups);
@@ -32,6 +33,20 @@ vector<string> RemoveSeqsCommand::setParameters(){
         CommandParameter pformat("format", "Multiple", "sanger-illumina-solexa-illumina1.8+", "illumina1.8+", "", "", "","",false,false,true); parameters.push_back(pformat);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["fastq"] = tempOutNames;
+        outputTypes["taxonomy"] = tempOutNames;
+        outputTypes["name"] = tempOutNames;
+        outputTypes["group"] = tempOutNames;
+        outputTypes["alignreport"] = tempOutNames;
+        outputTypes["contigsreport"] = tempOutNames;
+        outputTypes["list"] = tempOutNames;
+        outputTypes["qfile"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -46,9 +61,9 @@ vector<string> RemoveSeqsCommand::setParameters(){
 string RemoveSeqsCommand::getHelpString(){	
 	try {
 		string helpString = "";
-		helpString += "The remove.seqs command reads an .accnos file and at least one of the following file types: fasta, name, group, count, list, taxonomy, quality, fastq or alignreport file.\n";
+		helpString += "The remove.seqs command reads an .accnos file and at least one of the following file types: fasta, name, group, count, list, taxonomy, quality, fastq, contigsreport or alignreport file.\n";
 		helpString += "It outputs a file containing the sequences NOT in the .accnos file.\n";
-		helpString += "The remove.seqs command parameters are accnos, fasta, name, group, count, list, taxonomy, qfile, alignreport, fastq and dups.  You must provide accnos and at least one of the file parameters.\n";
+		helpString += "The remove.seqs command parameters are accnos, fasta, name, group, count, list, taxonomy, qfile, alignreport, contigsreport, fastq and dups.  You must provide accnos and at least one of the file parameters.\n";
         helpString += "The format parameter is used to indicate whether your sequences are sanger, solexa, illumina1.8+ or illumina, default=illumina1.8+.\n";
 		helpString += "The dups parameter allows you to remove the entire line from a name file if you remove any name from the line. default=true. \n";
 		helpString += "The remove.seqs command should be in the following format: remove.seqs(accnos=yourAccnos, fasta=yourFasta).\n";
@@ -75,6 +90,7 @@ string RemoveSeqsCommand::getOutputPattern(string type) {
         else if (type == "list")        {   pattern = "[filename],[distance],pick,[extension]";    }
         else if (type == "qfile")       {   pattern = "[filename],pick,[extension]";    }
         else if (type == "alignreport")      {   pattern = "[filename],pick.align.report";    }
+        else if (type == "contigsreport")    {   pattern = "[filename],pick.contigs.report";  }
         else { m->mothurOut("[ERROR]: No definition for type " + type + " output pattern.\n"); m->setControl_pressed(true);  }
         
         return pattern;
@@ -85,160 +101,27 @@ string RemoveSeqsCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-RemoveSeqsCommand::RemoveSeqsCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-        outputTypes["fastq"] = tempOutNames;
-		outputTypes["taxonomy"] = tempOutNames;
-		outputTypes["name"] = tempOutNames;
-		outputTypes["group"] = tempOutNames;
-		outputTypes["alignreport"] = tempOutNames;
-		outputTypes["list"] = tempOutNames;
-		outputTypes["qfile"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "RemoveSeqsCommand", "RemoveSeqsCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-		
-		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string,string>::iterator it;
 			
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-            outputTypes["fastq"] = tempOutNames;
-			outputTypes["taxonomy"] = tempOutNames;
-			outputTypes["name"] = tempOutNames;
-			outputTypes["group"] = tempOutNames;
-			outputTypes["alignreport"] = tempOutNames;
-			outputTypes["list"] = tempOutNames;
-			outputTypes["qfile"] = tempOutNames;
-            outputTypes["count"] = tempOutNames;
-			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";		}
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("alignreport");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["alignreport"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("accnos");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["accnos"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("list");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["list"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("taxonomy");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["taxonomy"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("qfile");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["qfile"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("fastq");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fastq"] = inputDir + it->second;		}
-				}
-			}
-
 			
 			//check for required parameters
 			accnosfile = validParameter.validFile(parameters, "accnos");
 			if (accnosfile == "not open") { abort = true; }
 			else if (accnosfile == "not found") {  
 				accnosfile = current->getAccnosFile();
-				if (accnosfile != "") {  m->mothurOut("Using " + accnosfile + " as input file for the accnos parameter."); m->mothurOutEndLine(); }
+				if (accnosfile != "") {  m->mothurOut("Using " + accnosfile + " as input file for the accnos parameter.\n");  }
 				else { 
-					m->mothurOut("You have no valid accnos file and accnos is required."); m->mothurOutEndLine(); 
-					abort = true;
+					m->mothurOut("[ERROR]: You have no valid accnos file and accnos is required.\n"); abort = true;
 				}  
 			}else { current->setAccnosFile(accnosfile); }	
 			
@@ -260,6 +143,10 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
 			alignfile = validParameter.validFile(parameters, "alignreport");
 			if (alignfile == "not open") { abort = true; }
 			else if (alignfile == "not found") {  alignfile = "";  }
+            
+            contigsreportfile = validParameter.validFile(parameters, "contigsreport");
+            if (contigsreportfile == "not open") { abort = true; }
+            else if (contigsreportfile == "not found") {  contigsreportfile = "";  }
 			
 			listfile = validParameter.validFile(parameters, "list");
 			if (listfile == "not open") { abort = true; }
@@ -294,14 +181,14 @@ RemoveSeqsCommand::RemoveSeqsCommand(string option)  {
             else { current->setCountFile(countfile); }
             
             if ((namefile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: name or count."); m->mothurOutEndLine(); abort = true;
+                m->mothurOut("[ERROR]: you may only use one of the following: name or count.\n");  abort = true;
             }
             
             if ((groupfile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: group or count."); m->mothurOutEndLine(); abort=true;
+                m->mothurOut("[ERROR]: you may only use one of the following: group or count.\n");  abort=true;
             }
 			
-			if ((fastqfile == "") && (countfile == "") && (fastafile == "") && (namefile == "") && (groupfile == "") && (alignfile == "") && (listfile == "") && (taxfile == "") && (qualfile == ""))  { m->mothurOut("You must provide at least one of the following: fasta, name, group, taxonomy, quality, alignreport, fastq or list."); m->mothurOutEndLine(); abort = true; }
+			if ((fastqfile == "") && (countfile == "") && (fastafile == "") && (namefile == "") && (groupfile == "") && (alignfile == "") && (listfile == "") && (taxfile == "") && (qualfile == "") && (contigsreportfile == ""))  { m->mothurOut("You must provide at least one of the following: fasta, name, group, count, taxonomy, quality, alignreport, contigsreport, fastq or list.\n");  abort = true; }
 			
             if (countfile == "") {
                 if ((fastafile != "") && (namefile == "")) {
@@ -338,27 +225,28 @@ int RemoveSeqsCommand::execute(){
         
         if (countfile != "") {
             if ((fastafile != "") || (listfile != "") || (taxfile != "")) { 
-                m->mothurOut("\n[NOTE]: The count file should contain only unique names, so mothur assumes your fasta, list and taxonomy files also contain only uniques.\n\n");
+                //m->mothurOut("\n[NOTE]: The count file should contain only unique names, so mothur assumes your fasta, list and taxonomy files also contain only uniques.\n\n");
             }
         }
 		
 		//read through the correct file and output lines you want to keep
-		if (namefile != "")			{		readName();		}
-		if (fastafile != "")		{		readFasta();	}
+		if (namefile != "")			{		readName();		    }
+		if (fastafile != "")		{		readFasta();	    }
         if (fastqfile != "")		{		readFastq();		}
-		if (groupfile != "")		{		readGroup();	}
-		if (alignfile != "")		{		readAlign();	}
-		if (listfile != "")			{		readList();		}
-		if (taxfile != "")			{		readTax();		}
-		if (qualfile != "")			{		readQual();		}
+		if (groupfile != "")		{		readGroup();	    }
+		if (alignfile != "")		{		readAlign();	    }
+        if (contigsreportfile != ""){       readContigs();      }
+		if (listfile != "")			{		readList();		    }
+		if (taxfile != "")			{		readTax();		    }
+		if (qualfile != "")			{		readQual();		    }
         if (countfile != "")		{		readCount();		}
 		
 		if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) {	util.mothurRemove(outputNames[i]); } return 0; }
 	
 		if (outputNames.size() != 0) {
 			m->mothurOutEndLine();
-			m->mothurOut("Output File Names: "); m->mothurOutEndLine();
-			for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]); m->mothurOutEndLine();	}
+			m->mothurOut("Output File Names:\n");
+			for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]+"\n"); 	}
 			m->mothurOutEndLine();
 			
 			//set fasta file as new current fastafile
@@ -409,10 +297,10 @@ int RemoveSeqsCommand::execute(){
 }
 
 //**********************************************************************************************************************
-int RemoveSeqsCommand::readFasta(){
+void RemoveSeqsCommand::readFasta(){
 	try {
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(fastafile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(fastafile);  }
 		map<string, string> variables; 
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(fastafile));
         variables["[extension]"] = util.getExtension(fastafile);
@@ -430,7 +318,7 @@ int RemoveSeqsCommand::readFasta(){
 		
         set<string> uniqueNames;
 		while(!in.eof()){
-			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
+            if (m->getControl_pressed()) { in.close(); out.close(); util.mothurRemove(outputFileName); return; }
 			
 			Sequence currSeq(in);
             
@@ -459,13 +347,12 @@ int RemoveSeqsCommand::readFasta(){
 		in.close();	
 		out.close();
 		
-		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
+		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file.\n");  }
 		outputTypes["fasta"].push_back(outputFileName);  outputNames.push_back(outputFileName);
 		
-		m->mothurOut("Removed " + toString(removedCount) + " sequences from your fasta file."); m->mothurOutEndLine();
-		
-		return 0;
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your fasta file.\n");
 		
+		return;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "RemoveSeqsCommand", "readFasta");
@@ -473,7 +360,7 @@ int RemoveSeqsCommand::readFasta(){
 	}
 }
 //**********************************************************************************************************************
-int RemoveSeqsCommand::readFastq(){
+void RemoveSeqsCommand::readFastq(){
 	try {
 		bool wroteSomething = false;
 		int removedCount = 0;
@@ -481,8 +368,8 @@ int RemoveSeqsCommand::readFastq(){
 		ifstream in;
 		util.openInputFile(fastqfile, in);
 		
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(fastqfile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(fastqfile);  }
 		map<string, string> variables;
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(fastqfile));
         variables["[extension]"] = util.getExtension(fastqfile);
@@ -493,7 +380,7 @@ int RemoveSeqsCommand::readFastq(){
 		set<string> uniqueNames;
 		while(!in.eof()){
 			
-			if (m->getControl_pressed()) { in.close(); out.close(); util.mothurRemove(outputFileName); return 0; }
+			if (m->getControl_pressed()) { in.close(); out.close(); util.mothurRemove(outputFileName); return; }
 			
             //read sequence name
             bool ignore;
@@ -519,15 +406,12 @@ int RemoveSeqsCommand::readFastq(){
 		in.close();
 		out.close();
 		
-		
-		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
+		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file.\n");   }
 		outputTypes["fasta"].push_back(outputFileName);  outputNames.push_back(outputFileName);
 		
-		m->mothurOut("Removed " + toString(removedCount) + " sequences from your fastq file."); m->mothurOutEndLine();
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your fastq file.\n");
 
-		
-		return 0;
-        
+		return;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "RemoveSeqsCommand", "readFastq");
@@ -535,10 +419,10 @@ int RemoveSeqsCommand::readFastq(){
 	}
 }
 //**********************************************************************************************************************
-int RemoveSeqsCommand::readQual(){
+void RemoveSeqsCommand::readQual(){
 	try {
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(qualfile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(qualfile);  }
 		map<string, string> variables; 
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(qualfile));
         variables["[extension]"] = util.getExtension(qualfile);
@@ -556,43 +440,23 @@ int RemoveSeqsCommand::readQual(){
 		
 		set<string> uniqueNames;
 		while(!in.eof()){	
-			string saveName = "";
-			string name = "";
-			string scores = "";
 			
-			in >> name; 
-			
-			if (name.length() != 0) { 
-				saveName = name.substr(1);
-				while (!in.eof())	{	
-					char c = in.get(); 
-					if (c == 10 || c == 13 || c == -1){	break;	}
-					else { name += c; }	
-				} 
-				util.gobble(in);
-			}
-			
-			while(in){
-				char letter= in.get();
-				if(letter == '>'){	in.putback(letter);	break;	}
-				else{ scores += letter; }
-			}
-			
-			util.gobble(in);
+            QualityScores qual(in); util.gobble(in);
 			
             if (!dups) {//adjust name if needed
-                map<string, string>::iterator it = uniqueMap.find(saveName);
-                if (it != uniqueMap.end()) { name = ">" + it->second; saveName = it->second; }
+                map<string, string>::iterator it = uniqueMap.find(qual.getName());
+                if (it != uniqueMap.end()) { qual.setName(it->second); }
             }
             
-			if (names.count(saveName) == 0) {
-                if (uniqueNames.count(saveName) == 0) { //this name hasn't been seen yet
-                    uniqueNames.insert(saveName);
+            string name = qual.getName();
+			if (names.count(name) == 0) {
+                if (uniqueNames.count(name) == 0) { //this name hasn't been seen yet
+                    uniqueNames.insert(name);
                     wroteSomething = true;
 				
-                    out << name << endl << scores;
+                    qual.printQScores(out);
                 }else {
-                    m->mothurOut("[WARNING]: " + saveName + " is in your qfile more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
+                    m->mothurOut("[WARNING]: " + name + " is in your qfile more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
                 }
 			}else {  removedCount++;  }
 			
@@ -601,14 +465,12 @@ int RemoveSeqsCommand::readQual(){
 		in.close();
 		out.close();
 		
-		
-		if (wroteSomething == false) { m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
+		if (wroteSomething == false) { m->mothurOut("Your file contains only sequences from the .accnos file.\n");   }
 		outputNames.push_back(outputFileName);  outputTypes["qfile"].push_back(outputFileName); 
 		
-		m->mothurOut("Removed " + toString(removedCount) + " sequences from your quality file."); m->mothurOutEndLine();
-		
-		return 0;
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your quality file.\n");
 		
+		return;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "RemoveSeqsCommand", "readQual");
@@ -616,11 +478,11 @@ int RemoveSeqsCommand::readQual(){
 	}
 }
 //**********************************************************************************************************************
-int RemoveSeqsCommand::readCount(){
+void RemoveSeqsCommand::readCount(){
 	try {
         
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(countfile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(countfile);  }
 		map<string, string> variables; 
 		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(countfile));
         variables["[extension]"] = util.getExtension(countfile);
@@ -629,12 +491,10 @@ int RemoveSeqsCommand::readCount(){
         CountTable ct; ct.readTable(countfile, true, false); int originalCount = ct.getNumSeqs();
         
         for (set<string>::iterator it = names.begin(); it != names.end(); it++) {
-            ct.setNumSeqs(*it, 0);
-            if (m->getControl_pressed()) {  return 0; }
+            ct.zeroOutSeq(*it);
+            if (m->getControl_pressed()) {  return; }
         }
         
-        if (ct.getNumSeqs() == 0) {  m->mothurOut("Your file contains only sequences from the .accnos file.\n");   return 0; }
-        
         ct.printTable(outputFileName);
         
         int removedCount = originalCount - ct.getNumSeqs();
@@ -643,7 +503,9 @@ int RemoveSeqsCommand::readCount(){
 		
 		m->mothurOut("Removed " + toString(removedCount) + " sequences from your count file.\n");
         
-		return 0;
+        if (ct.getNumSeqs() == 0) {  m->mothurOut("Your file contains only sequences from the .accnos file.\n");  }
+        
+		return;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "RemoveSeqsCommand", "readCount");
@@ -651,10 +513,10 @@ int RemoveSeqsCommand::readCount(){
 	}
 }
 //**********************************************************************************************************************
-int RemoveSeqsCommand::readList(){
+void RemoveSeqsCommand::readList(){
 	try {
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(listfile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(listfile);  }
 		map<string, string> variables; 
 		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(listfile));
         variables["[extension]"] = util.getExtension(listfile);
@@ -683,11 +545,11 @@ int RemoveSeqsCommand::readList(){
             vector<string> binLabels = list->getLabels();
             vector<string> newBinLabels;
             
-            if (m->getControl_pressed()) { out.close();  return 0; }
+            if (m->getControl_pressed()) { out.close();  return; }
 
 			//for each bin
 			for (int i = 0; i < list->getNumBins(); i++) {
-				if (m->getControl_pressed()) {  out.close();  util.mothurRemove(outputFileName);  return 0; }
+				if (m->getControl_pressed()) {  out.close();  util.mothurRemove(outputFileName);  return; }
 			
 				//parse out names that are in accnos file
 				string bin = list->get(i);
@@ -731,13 +593,11 @@ int RemoveSeqsCommand::readList(){
             list = input.getListVector();
 		}
 		
+		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file.\n");  }
 		
-		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your list file.\n");
 		
-		m->mothurOut("Removed " + toString(removedCount) + " sequences from your list file."); m->mothurOutEndLine();
-		
-		return 0;
-
+		return;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "RemoveSeqsCommand", "readList");
@@ -745,10 +605,10 @@ int RemoveSeqsCommand::readList(){
 	}
 }
 //**********************************************************************************************************************
-int RemoveSeqsCommand::readName(){
+void RemoveSeqsCommand::readName(){
 	try {
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(namefile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(namefile);  }
 		map<string, string> variables; 
 		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(namefile));
         variables["[extension]"] = util.getExtension(namefile);
@@ -765,10 +625,10 @@ int RemoveSeqsCommand::readName(){
 		
         set<string> uniqueNames;
 		while(!in.eof()){
-			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
+			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return; }
 			
 			in >> firstCol;		util.gobble(in);		
-			in >> secondCol;			
+			in >> secondCol;	util.gobble(in);
 			
 			vector<string> parsedNames;
 			util.splitAtComma(secondCol, parsedNames);
@@ -826,17 +686,16 @@ int RemoveSeqsCommand::readName(){
                     }
                 }
 			}
-			util.gobble(in);
 		}
 		in.close();
 		out.close();
 		
-		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
+		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file.\n"); }
 		outputTypes["name"].push_back(outputFileName); outputNames.push_back(outputFileName);
 		
-		m->mothurOut("Removed " + toString(removedCount) + " sequences from your name file."); m->mothurOutEndLine();
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your name file.\n");
 		
-		return 0;
+		return;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "RemoveSeqsCommand", "readName");
@@ -845,10 +704,10 @@ int RemoveSeqsCommand::readName(){
 }
 
 //**********************************************************************************************************************
-int RemoveSeqsCommand::readGroup(){
+void RemoveSeqsCommand::readGroup(){
 	try {
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(groupfile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(groupfile);  }
 		map<string, string> variables; 
 		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(groupfile));
         variables["[extension]"] = util.getExtension(groupfile);
@@ -865,7 +724,7 @@ int RemoveSeqsCommand::readGroup(){
 		
         set<string> uniqueNames;
 		while(!in.eof()){
-			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
+			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return; }
 			
 			in >> name;			util.gobble(in);		//read from first column
 			in >> group;			//read from second column
@@ -886,13 +745,12 @@ int RemoveSeqsCommand::readGroup(){
 		in.close();
 		out.close();
 		
-		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
+		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file.\n");   }
 		outputTypes["group"].push_back(outputFileName); outputNames.push_back(outputFileName);
 		
-		m->mothurOut("Removed " + toString(removedCount) + " sequences from your group file."); m->mothurOutEndLine();
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your group file.\n"); 
 
-		
-		return 0;
+		return;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "RemoveSeqsCommand", "readGroup");
@@ -900,10 +758,10 @@ int RemoveSeqsCommand::readGroup(){
 	}
 }
 //**********************************************************************************************************************
-int RemoveSeqsCommand::readTax(){
+void RemoveSeqsCommand::readTax(){
 	try {
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(taxfile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(taxfile);  }
 		map<string, string> variables; 
 		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(taxfile));
         variables["[extension]"] = util.getExtension(taxfile);
@@ -920,7 +778,7 @@ int RemoveSeqsCommand::readTax(){
 		
         set<string> uniqueNames;
 		while(!in.eof()){
-			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
+			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return; }
 			
             in >> name; util.gobble(in);
             tax = util.getline(in); util.gobble(in);
@@ -945,12 +803,12 @@ int RemoveSeqsCommand::readTax(){
 		in.close();
 		out.close();
 		
-		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
+		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file.\n");   }
 		outputTypes["taxonomy"].push_back(outputFileName); outputNames.push_back(outputFileName);
 		
-		m->mothurOut("Removed " + toString(removedCount) + " sequences from your taxonomy file."); m->mothurOutEndLine();
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your taxonomy file.\n"); 
 		
-		return 0;
+		return;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "RemoveSeqsCommand", "readTax");
@@ -959,10 +817,10 @@ int RemoveSeqsCommand::readTax(){
 }
 //**********************************************************************************************************************
 //alignreport file has a column header line then all other lines contain 16 columns.  we just want the first column since that contains the name
-int RemoveSeqsCommand::readAlign(){
+void RemoveSeqsCommand::readAlign(){
 	try {
-		string thisOutputDir = outputDir;
-		if (outputDir == "") {  thisOutputDir += util.hasPath(alignfile);  }
+		string thisOutputDir = outputdir;
+		if (outputdir == "") {  thisOutputDir += util.hasPath(alignfile);  }
 		map<string, string> variables; 
 		variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(alignfile));
 		string outputFileName = getOutputFileName("alignreport", variables);
@@ -977,18 +835,15 @@ int RemoveSeqsCommand::readAlign(){
 		bool wroteSomething = false;
 		int removedCount = 0;
 		
-		//read column headers
-		for (int i = 0; i < 16; i++) {  
-			if (!in.eof())	{	in >> junk;	 out << junk << '\t';	}
-			else			{	break;			}
-		}
-		out << endl;
+        //read and write headers
+		out << util.getline(in) << endl;  util.gobble(in);
 		
         set<string> uniqueNames;
 		while(!in.eof()){
-			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return 0; }
+			if (m->getControl_pressed()) { in.close();  out.close();  util.mothurRemove(outputFileName);  return; }
 			
-			in >> name;				//read from first column
+			in >> name;   util.gobble(in);              //read from first column
+            junk = util.getline(in); util.gobble(in);
             
             if (!dups) {//adjust name if needed
                 map<string, string>::iterator it = uniqueMap.find(name);
@@ -1001,40 +856,22 @@ int RemoveSeqsCommand::readAlign(){
                     uniqueNames.insert(name);
                     wroteSomething = true;
                     
-                    out << name << '\t';
+                    out << name << '\t' << junk << endl;
                     
-                    //read rest
-                    for (int i = 0; i < 15; i++) {
-                        if (!in.eof())	{	in >> junk;	 out << junk << '\t';	}
-                        else			{	break;			}
-                    }
-                    out << endl;
                 }else {
                     m->mothurOut("[WARNING]: " + name + " is in your alignreport file more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
                 }
-			}else {//still read just don't do anything with it
-				removedCount++;  
-				
-				//read rest
-				for (int i = 0; i < 15; i++) {  
-					if (!in.eof())	{	in >> junk;		}
-					else			{	break;			}
-				}
-			}
-			
-			util.gobble(in);
+			}else { removedCount++;   }
 		}
 		in.close();
 		out.close();
 		
-		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file."); m->mothurOutEndLine();  }
+		if (wroteSomething == false) {  m->mothurOut("Your file contains only sequences from the .accnos file.\n");  ofstream out1; util.openOutputFile(outputFileName, out1); out1.close(); }
 		outputTypes["alignreport"].push_back(outputFileName); outputNames.push_back(outputFileName);
 		
-		m->mothurOut("Removed " + toString(removedCount) + " sequences from your alignreport file."); m->mothurOutEndLine();
+		m->mothurOut("Removed " + toString(removedCount) + " sequences from your alignreport file.\n"); 
 
-		
-		return 0;
-		
+		return;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "RemoveSeqsCommand", "readAlign");
@@ -1042,5 +879,64 @@ int RemoveSeqsCommand::readAlign(){
 	}
 }
 //**********************************************************************************************************************
+//contigsreport file has a column header line then all other lines contain 8 columns.  we just want the first column since that contains the name
+void RemoveSeqsCommand::readContigs(){
+    try {
+        string thisOutputDir = outputdir;
+        if (outputdir == "") {  thisOutputDir += util.hasPath(contigsreportfile);  }
+        map<string, string> variables;
+        variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(contigsreportfile));
+        string outputFileName = getOutputFileName("contigsreport", variables);
+        ofstream out; util.openOutputFile(outputFileName, out);
+        
+        bool wroteSomething = false;
+        int removedCount = 0;
+        
+        set<string> uniqueNames;
+        ifstream in;
+        util.openInputFile(contigsreportfile, in);
+        string name, junk;
+        
+        out << util.getline(in) << endl;  util.gobble(in);
+        
+        while(!in.eof()){
+        
+            if (m->getControl_pressed()) { break; }
+
+            in >> name;   util.gobble(in);              //read from first column
+            junk = util.getline(in); util.gobble(in);
+            
+            if (!dups) {//adjust name if needed
+                map<string, string>::iterator it = uniqueMap.find(name);
+                if (it != uniqueMap.end()) { name = it->second; }
+            }
+            
+            if (names.count(name) == 0) {
+                if (uniqueNames.count(name) == 0) { //this name hasn't been seen yet
+                    uniqueNames.insert(name);
+                    wroteSomething = true;
+                
+                    out << name << '\t' << junk << endl;
+                }else {
+                    m->mothurOut("[WARNING]: " + name + " is in your contigsreport file more than once.  Mothur requires sequence names to be unique. I will only add it once.\n");
+                }
+            }else { removedCount++; }
+        }
+        in.close();
+        out.close();
+        
+        if (wroteSomething == false) { m->mothurOut("Your file does not contain any sequence from the .accnos file.\n");  ofstream out1; util.openOutputFile(outputFileName, out1); out1.close(); } //reopening file clears header line
+        outputNames.push_back(outputFileName);  outputTypes["contigsreport"].push_back(outputFileName);
+        
+        m->mothurOut("Removed " + toString(removedCount) + " sequences from your contigsreport file.\n");
+        
+        return;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "RemoveSeqsCommand", "readContigs");
+        exit(1);
+    }
+}
+//**********************************************************************************************************************
 
 
