@@ -29,6 +29,18 @@ vector<string> RenameSeqsCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["name"] = tempOutNames;
+        outputTypes["group"] = tempOutNames;
+        outputTypes["count"] = tempOutNames;
+        outputTypes["map"] = tempOutNames;
+        outputTypes["qfile"] = tempOutNames;
+        outputTypes["contigsreport"] = tempOutNames;
+        outputTypes["taxonomy"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -85,139 +97,19 @@ string RenameSeqsCommand::getOutputPattern(string type) {
         exit(1);
     }
 }
-//**********************************************************************************************************************
-RenameSeqsCommand::RenameSeqsCommand(){
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-		vector<string> tempOutNames;
-        outputTypes["fasta"] = tempOutNames;
-        outputTypes["name"] = tempOutNames;
-        outputTypes["group"] = tempOutNames;
-        outputTypes["count"] = tempOutNames;
-        outputTypes["map"] = tempOutNames;
-        outputTypes["qfile"] = tempOutNames;
-        outputTypes["contigsreport"] = tempOutNames;
-        outputTypes["taxonomy"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "RenameSeqsCommand", "RenameSeqsCommand");
-		exit(1);
-	}
-}
 /**************************************************************************************/
 RenameSeqsCommand::RenameSeqsCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;
-		
-		//allow user to run help
+
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string, string>::iterator it;
-            
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) {
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			vector<string> tempOutNames;
-            outputTypes["fasta"] = tempOutNames;
-            outputTypes["name"] = tempOutNames;
-            outputTypes["group"] = tempOutNames;
-            outputTypes["count"] = tempOutNames;
-            outputTypes["map"] = tempOutNames;
-            outputTypes["qfile"] = tempOutNames;
-            outputTypes["contigsreport"] = tempOutNames;
-            outputTypes["taxonomy"] = tempOutNames;
-            
-			//if the user changes the input directory command factory will send this info to us in the output parameter
-			string inputDir = validParameter.valid(parameters, "inputdir");
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["count"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("qfile");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["qfile"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("contigsreport");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["contigsreport"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("taxonomy");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["taxonomy"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("map");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["map"] = inputDir + it->second;		}
-                }
-                
-                it = parameters.find("file");
-                //user has given a template file
-                if(it != parameters.end()){
-                    path = util.hasPath(it->second);
-                    //if the user has not given a path then, add inputdir. else leave path alone.
-                    if (path == "") {	parameters["file"] = inputDir + it->second;		}
-                }
-			}
-            
-            //if the user changes the output directory command factory will send this info to us in the output parameter
-            outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){ outputDir = ""; }
 			
 			//check for required parameters
 			fastaFile = validParameter.validFile(parameters, "fasta");
@@ -316,8 +208,8 @@ int RenameSeqsCommand::execute() {
         else {
             
             //prepare filenames and open files
-            string thisOutputDir = outputDir;
-            if (outputDir == "") {  thisOutputDir += util.hasPath(fastaFile);  }
+            string thisOutputDir = outputdir;
+            if (outputdir == "") {  thisOutputDir += util.hasPath(fastaFile);  }
             string outFastaFile = thisOutputDir + util.getRootName(util.getSimpleName(fastaFile));
             map<string, string> variables;
             variables["[filename]"] = outFastaFile;
@@ -334,8 +226,8 @@ int RenameSeqsCommand::execute() {
             ofstream outName;
             map<string, vector<string> > nameMap;
             if (nameFile != "") {
-                thisOutputDir = outputDir;
-                if (outputDir == "") {  thisOutputDir += util.hasPath(nameFile);  }
+                thisOutputDir = outputdir;
+                if (outputdir == "") {  thisOutputDir += util.hasPath(nameFile);  }
                 string outNameFile = thisOutputDir + util.getRootName(util.getSimpleName(nameFile));
                 variables["[filename]"] = outNameFile;
                 variables["[extension]"] = util.getExtension(nameFile);
@@ -348,8 +240,8 @@ int RenameSeqsCommand::execute() {
             
             ofstream outGroup;
             if (groupfile != "") {
-                thisOutputDir = outputDir;
-                if (outputDir == "") {  thisOutputDir += util.hasPath(groupfile);  }
+                thisOutputDir = outputdir;
+                if (outputdir == "") {  thisOutputDir += util.hasPath(groupfile);  }
                 string outGroupFile = thisOutputDir + util.getRootName(util.getSimpleName(groupfile));
                 variables["[filename]"] = outGroupFile;
                 variables["[extension]"] = util.getExtension(groupfile);
@@ -457,8 +349,8 @@ int RenameSeqsCommand::execute() {
             
             if (groupfile != "") {   outGroup.close(); }
             else if (countfile != "") {
-                thisOutputDir = outputDir;
-                if (outputDir == "") {  thisOutputDir += util.hasPath(countfile);  }
+                thisOutputDir = outputdir;
+                if (outputdir == "") {  thisOutputDir += util.hasPath(countfile);  }
                 string outCountFile = thisOutputDir + util.getRootName(util.getSimpleName(countfile));
                 variables["[filename]"] = outCountFile;
                 variables["[extension]"] = util.getExtension(countfile);
@@ -518,8 +410,8 @@ int RenameSeqsCommand::execute() {
 //**********************************************************************************************************************
 int RenameSeqsCommand::readQual(map<string, string>& oldMap){
     try {
-        string thisOutputDir = outputDir;
-        if (outputDir == "") {  thisOutputDir += util.hasPath(qualfile);  }
+        string thisOutputDir = outputdir;
+        if (outputdir == "") {  thisOutputDir += util.hasPath(qualfile);  }
         map<string, string> variables;
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(qualfile));
         variables["[extension]"] = util.getExtension(qualfile);
@@ -561,8 +453,8 @@ int RenameSeqsCommand::readQual(map<string, string>& oldMap){
 //**********************************************************************************************************************
 int RenameSeqsCommand::readTax(map<string, string>& oldMap){
     try {
-        string thisOutputDir = outputDir;
-        if (outputDir == "") {  thisOutputDir += util.hasPath(taxfile);  }
+        string thisOutputDir = outputdir;
+        if (outputdir == "") {  thisOutputDir += util.hasPath(taxfile);  }
         map<string, string> variables;
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(taxfile));
         variables["[extension]"] = util.getExtension(taxfile);
@@ -606,8 +498,8 @@ int RenameSeqsCommand::readTax(map<string, string>& oldMap){
 //**********************************************************************************************************************
 int RenameSeqsCommand::readContigs(map<string, string>& oldMap){
     try {
-        string thisOutputDir = outputDir;
-        if (outputDir == "") {  thisOutputDir += util.hasPath(contigsfile);  }
+        string thisOutputDir = outputdir;
+        if (outputdir == "") {  thisOutputDir += util.hasPath(contigsfile);  }
         map<string, string> variables;
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(contigsfile));
         variables["[extension]"] = util.getExtension(contigsfile);
@@ -655,8 +547,8 @@ int RenameSeqsCommand::readContigs(map<string, string>& oldMap){
 //**********************************************************************************************************************
 int RenameSeqsCommand::readFasta(string thisFastaFile, map<string, string>& oldMap){
     try {
-        string thisOutputDir = outputDir;
-        if (outputDir == "") {  thisOutputDir += util.hasPath(thisFastaFile);  }
+        string thisOutputDir = outputdir;
+        if (outputdir == "") {  thisOutputDir += util.hasPath(thisFastaFile);  }
         map<string, string> variables;
         variables["[filename]"] = thisOutputDir + util.getRootName(util.getSimpleName(thisFastaFile));
         variables["[extension]"] = util.getExtension(thisFastaFile);
@@ -746,8 +638,8 @@ int RenameSeqsCommand::processFile(map<string, string>& readMap){
                 thisFile = temp.substr(pos+1);
             }
             
-            string thisOutputDir = outputDir;
-            if (outputDir == "") {  thisOutputDir += util.hasPath(thisFile);  }
+            string thisOutputDir = outputdir;
+            if (outputdir == "") {  thisOutputDir += util.hasPath(thisFile);  }
             string outMapFile = thisOutputDir + util.getSimpleName(thisFile);
             map<string, string> variables;
             variables["[filename]"] = outMapFile + ".";
