@@ -19,7 +19,6 @@
 class SeqSummaryCommand : public Command {
 public:
 	SeqSummaryCommand(string);
-	SeqSummaryCommand();
 	~SeqSummaryCommand(){}
 	
 	vector<string> setParameters();
@@ -35,7 +34,7 @@ public:
 	void help() { m->mothurOut(getHelpString()); }		
 private:
 	bool abort;
-	string fastafile, outputDir, namefile, countfile, summaryfile, contigsfile, alignfile;
+	string fastafile,  namefile, countfile, summaryfile, contigsfile, alignfile;
 	int processors;
 	vector<string> outputNames;
 };
