@@ -19,7 +19,6 @@ class SetDirectoryCommand : public Command {
 	
 public:
 	SetDirectoryCommand(string);
-	SetDirectoryCommand() { abort = true; calledHelp = true; setParameters(); }
 	~SetDirectoryCommand(){}
 	
 	vector<string> setParameters();
@@ -29,13 +28,13 @@ public:
 	string getHelpString();	
     string getOutputPattern(string){ return ""; }	
 	string getCitation() { return "http://www.mothur.org/wiki/Set.dir"; }
-	string getDescription()		{ return "set input, output and default directories"; }
+	string getDescription()		{ return "set various directories"; }
 
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }	
 	
 private:
-	string output, input, tempdefault, blastLocation;
+	string output, input, tempdefault, blastLocation, toolsLocation;
 	bool abort, debugorSeedOnly, modifyNames;
     int random;
 	vector<string> outputNames;
