@@ -22,6 +22,13 @@ vector<string> ShhhSeqsCommand::setParameters(){
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
 		CommandParameter psigma("sigma", "Number", "", "0.01", "", "", "","",false,false); parameters.push_back(psigma);
+        
+        abort = false; calledHelp = false;
+        
+        vector<string> tempOutNames;
+        outputTypes["fasta"] = tempOutNames;
+        outputTypes["name"] = tempOutNames;
+        outputTypes["map"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -72,103 +79,38 @@ string ShhhSeqsCommand::getOutputPattern(string type) {
         exit(1);
     }
 }
-
-//**********************************************************************************************************************
-
-ShhhSeqsCommand::ShhhSeqsCommand(){	
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["fasta"] = tempOutNames;
-		outputTypes["name"] = tempOutNames;
-		outputTypes["map"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ShhhSeqsCommand", "ShhhSeqsCommand");
-		exit(1);
-	}
-}
-
 //**********************************************************************************************************************
 ShhhSeqsCommand::ShhhSeqsCommand(string option) {
 	try {
-		abort = false; calledHelp = false;   
-		
-		//allow user to run help
+
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters();
 			
 			ValidParameters validParameter;
-			map<string, string>::iterator it;
-			
-			//check to make sure all parameters are valid for command
-			for (map<string, string>::iterator it2 = parameters.begin(); it2 != parameters.end(); it2++) { 
-				if (validParameter.isValidParameter(it2->first, myArray, it2->second) != true) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["fasta"] = tempOutNames;
-			outputTypes["name"] = tempOutNames;
-			outputTypes["map"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("fasta");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["fasta"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-			}
-			
-			//check for required parameters
 			fastafile = validParameter.validFile(parameters, "fasta");
 			if (fastafile == "not found") { 				
 				fastafile = current->getFastaFile(); 
-				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (fastafile != "") { m->mothurOut("Using " + fastafile + " as input file for the fasta parameter.\n");  }
+				else { 	m->mothurOut("You have no current fastafile and the fasta parameter is required.\n");  abort = true; }
 			}
 			else if (fastafile == "not open") { abort = true; }	
 			else { current->setFastaFile(fastafile); }
 			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = "";	}
+			 
+			
 			
 			//check for optional parameter and set defaults
 			// ...at some point should added some additional type checking...
 			namefile = validParameter.validFile(parameters, "name");
 			if (namefile == "not found") { 			
 				namefile = current->getNameFile(); 
-				if (namefile != "") { m->mothurOut("Using " + namefile + " as input file for the name parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current namefile and the name parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (namefile != "") { m->mothurOut("Using " + namefile + " as input file for the name parameter.\n");  }
+				else { 	m->mothurOut("You have no current namefile and the name parameter is required.\n");  abort = true; }
 			}
 			else if (namefile == "not open") { namefile =  ""; abort = true; }	
 			else {  current->setNameFile(namefile); }
@@ -349,16 +291,16 @@ int ShhhSeqsCommand::execute() {
 		
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
 		
-		if (outputDir == "") { outputDir = util.hasPath(fastafile);  }//if user entered a file with a path then preserve it		
+		if (outputdir == "") { outputdir = util.hasPath(fastafile);  }	
 		
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(fastafile));
+		variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(fastafile));
 		string outputFileName = getOutputFileName("fasta",variables);
 		string nameFileName = getOutputFileName("name",variables);
 		string mapFileName = getOutputFileName("map",variables);
 		
 		if (groupfile != "") {
-            mapFileName = outputDir + util.getRootName(util.getSimpleName(fastafile))  + "shhh.";
+            mapFileName = outputdir + util.getRootName(util.getSimpleName(fastafile))  + "shhh.";
 			vector<string> mapFileNames = createProcessesGroups(outputFileName, nameFileName, mapFileName);
 
 			if (m->getControl_pressed()) {    return 0;	}	
@@ -381,10 +323,10 @@ int ShhhSeqsCommand::execute() {
 			
 			//reads fasta and name file and loads them in order
 			readData(correct, noise, sequences, uniqueNames, redundantNames, seqFreq);
-			if (m->getControl_pressed()) { return 0; }
+            if (m->getControl_pressed()) { delete correct; return 0; }
 			
 			//calc distances for cluster
-			string distFileName = outputDir + util.getRootName(util.getSimpleName(fastafile)) + "shhh.dist";
+			string distFileName = outputdir + util.getRootName(util.getSimpleName(fastafile)) + "shhh.dist";
 			correct->execute(distFileName);
 			delete correct;
 			
@@ -505,7 +447,7 @@ struct shhhseqsData {
     string fastafile;
     string namefile;
     string groupfile;
-    string newFFile, newNFile, newMFile, outputDir, extension;
+    string newFFile, newNFile, newMFile,  extension, outputDir;
     MothurOut* m;
     int sigma, count;
     vector<string> groups;
@@ -624,22 +566,22 @@ vector<string> ShhhSeqsCommand::createProcessesGroups(string newFName, string ne
             remainingPairs = remainingPairs - numPairs;
         }
         
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<shhhseqsData*> data;
         for (int i = 0; i < processors-1; i++) {
             string extension = toString(i+1) + ".temp";
             util.mothurRemove(newFName+extension);
             util.mothurRemove(newNName+extension);
-            shhhseqsData* dataBundle = new shhhseqsData(outputDir, fastafile, namefile, groupfile, newFName, newNName, newMName, dividedGroupNames[i+1], sigma, extension);
+            shhhseqsData* dataBundle = new shhhseqsData(outputdir, fastafile, namefile, groupfile, newFName, newNName, newMName, dividedGroupNames[i+1], sigma, extension);
             data.push_back(dataBundle);
             
-            thread* thisThread = new thread(driverShhSeqsGroups, dataBundle);
+            std::thread* thisThread = new std::thread(driverShhSeqsGroups, dataBundle);
             workerThreads.push_back(thisThread);
         }
         
         util.mothurRemove(newFName);
         util.mothurRemove(newNName);
-        shhhseqsData* dataBundle = new shhhseqsData(outputDir, fastafile, namefile, groupfile, newFName, newNName, newMName, dividedGroupNames[0], sigma, "");
+        shhhseqsData* dataBundle = new shhhseqsData(outputdir, fastafile, namefile, groupfile, newFName, newNName, newMName, dividedGroupNames[0], sigma, "");
         driverShhSeqsGroups(dataBundle);
         vector<string> mapFileNames = dataBundle->mapfileNames;
         delete dataBundle;
@@ -665,12 +607,12 @@ vector<string> ShhhSeqsCommand::createProcessesGroups(string newFName, string ne
 //**********************************************************************************************************************
 int ShhhSeqsCommand::deconvoluteResults(string fastaFile, string nameFile){
 	try {
-		m->mothurOutEndLine(); m->mothurOut("Deconvoluting results:"); m->mothurOutEndLine(); m->mothurOutEndLine();
+		m->mothurOutEndLine(); m->mothurOut("Deconvoluting results:\n");  m->mothurOutEndLine();
 		
 		//use unique.seqs to create new name and fastafile
 		string inputString = "fasta=" + fastaFile + ", name=" + nameFile;
-		m->mothurOut("/******************************************/"); m->mothurOutEndLine(); 
-		m->mothurOut("Running command: unique.seqs(" + inputString + ")"); m->mothurOutEndLine(); 
+		m->mothurOut("/******************************************/\n");  
+		m->mothurOut("Running command: unique.seqs(" + inputString + ")\n");  
 		current->setMothurCalling(true);
         
 		Command* uniqueCommand = new DeconvoluteCommand(inputString);
@@ -680,7 +622,7 @@ int ShhhSeqsCommand::deconvoluteResults(string fastaFile, string nameFile){
 		
 		delete uniqueCommand;
 		current->setMothurCalling(false);
-		m->mothurOut("/******************************************/"); m->mothurOutEndLine(); 
+		m->mothurOut("/******************************************/\n");  
 		
 		string newnameFile = filenames["name"][0];
 		string newfastaFile = filenames["fasta"][0];
