@@ -24,6 +24,14 @@ vector<string> SparccCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false; allLines = true;
+        
+        vector<string> tempOutNames;
+        outputTypes["corr"] = tempOutNames; //filetypes should be things like: shared, fasta, accnos...
+        outputTypes["pvalue"] = tempOutNames;
+        outputTypes["sparccrelabund"] = tempOutNames;
+
 
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -73,84 +81,32 @@ string SparccCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-SparccCommand::SparccCommand(){
-	try {
-		abort = true; calledHelp = true;
-		setParameters();
-        vector<string> tempOutNames;
-		outputTypes["corr"] = tempOutNames;
-		outputTypes["pvalue"] = tempOutNames;
-		outputTypes["sparccrelabund"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "SparccCommand", "SparccCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
 SparccCommand::SparccCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;
-        allLines = true;
-
-		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 
 		else {
-			//valid paramters for this command
-			vector<string> myArray = setParameters();
-
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters = parser.getParameters();
 
 			ValidParameters validParameter;
-			map<string,string>::iterator it;
-			//check to make sure all parameters are valid for command
-			for (it = parameters.begin(); it != parameters.end(); it++) {
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-
-            vector<string> tempOutNames;
-            outputTypes["corr"] = tempOutNames; //filetypes should be things like: shared, fasta, accnos...
-            outputTypes["pvalue"] = tempOutNames;
-            outputTypes["sparccrelabund"] = tempOutNames;
-
-			//if the user changes the input directory command factory will send this info to us in the output parameter
-			string inputDir = validParameter.valid(parameters, "inputdir");
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-
-				string path;
-                it = parameters.find("shared");
-				//user has given a template file
-				if(it != parameters.end()){
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
-				}
-            }
-
-			//check for parameters
-            //get shared file, it is required
 			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }
 			else if (sharedfile == "not found") {
 				//if there is a current shared file, use it
 				sharedfile = current->getSharedFile();
-				if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current sharedfile and the shared parameter is required."); m->mothurOutEndLine(); abort = true; }
+				if (sharedfile != "") { m->mothurOut("Using " + sharedfile + " as input file for the shared parameter.\n");  }
+				else { 	m->mothurOut("You have no current sharedfile and the shared parameter is required.\n");  abort = true; }
 			}else { current->setSharedFile(sharedfile); }
 
-            //if the user changes the output directory command factory will send this info to us in the output parameter
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){
-				outputDir = util.hasPath(sharedfile); //if user entered a file with a path then preserve it
-			}
+            if (outputdir == ""){ outputdir = util.hasPath(sharedfile);  }
 
 			normalizeMethod = validParameter.valid(parameters, "method");
 			if (normalizeMethod == "not found") { normalizeMethod = "dirichlet"; }
 			if ((normalizeMethod == "dirichlet") || (normalizeMethod == "relabund")) { }
-			else { m->mothurOut(normalizeMethod + " is not a valid method.  Valid methods are dirichlet and relabund."); m->mothurOutEndLine(); abort = true; }
+			else { m->mothurOut(normalizeMethod + " is not a valid method.  Valid methods are dirichlet and relabund.\n");  abort = true; }
 
 
             string temp = validParameter.valid(parameters, "samplings");	if (temp == "not found"){	temp = "20";	}
@@ -195,80 +151,20 @@ int SparccCommand::execute(){
         long start = time(NULL);
 
         InputData input(sharedfile, "sharedfile", Groups);
-        SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
-        string lastLabel = lookup->getLabel();
-        Groups = lookup->getNamesGroups();
-
-        //if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
         set<string> processedLabels;
         set<string> userLabels = labels;
-
-        //as long as you are not at the end of the file or done wih the lines you want
-        while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-
-            if (m->getControl_pressed()) { delete lookup;  for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); }return 0; }
-
-            if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
-
-                m->mothurOut(lookup->getLabel()+"\n");
-
-                process(lookup);
-
-                processedLabels.insert(lookup->getLabel());
-                userLabels.erase(lookup->getLabel());
-            }
-
-            if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-                string saveLabel = lookup->getLabel();
-
-                delete lookup;
-                lookup = input.getSharedRAbundVectors(lastLabel);
-                m->mothurOut(lookup->getLabel()+"\n");
-
-                process(lookup);
-
-                processedLabels.insert(lookup->getLabel());
-                userLabels.erase(lookup->getLabel());
-
-                //restore real lastlabel to save below
-                lookup->setLabels(saveLabel);
-            }
-
-            lastLabel = lookup->getLabel();
-            //prevent memory leak
-            delete lookup;
-
-            if (m->getControl_pressed()) { return 0; }
-
-            //get next line to process
-            lookup = input.getSharedRAbundVectors();
-        }
-
-        if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); } return 0; }
-
-        //output error messages about any remaining user labels
-        set<string>::iterator it;
-        bool needToRun = false;
-        for (it = userLabels.begin(); it != userLabels.end(); it++) {
-            m->mothurOut("Your file does not include the label " + *it);
-            if (processedLabels.count(lastLabel) != 1) {
-                m->mothurOut(". I will use " + lastLabel + "."); m->mothurOutEndLine();
-                needToRun = true;
-            }else {
-                m->mothurOut(". Please refer to " + lastLabel + "."); m->mothurOutEndLine();
-            }
-        }
-
-        //run last label if you need to
-        if (needToRun )  {
-            delete lookup;
-            lookup = input.getSharedRAbundVectors(lastLabel);
-
-            m->mothurOut(lookup->getLabel()+"\n");
-
-            process(lookup);
-
-            delete lookup;
+        string lastLabel = "";
+        
+        SharedRAbundVectors* lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
+        Groups = lookup->getNamesGroups();
+        
+        while (lookup != NULL) {
+            
+            if (m->getControl_pressed()) { delete lookup; break; }
+            
+            process(lookup); delete lookup;
+            
+            lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
         }
 
         if (m->getControl_pressed()) { for (int i = 0; i < outputNames.size(); i++) { util.mothurRemove(outputNames[i]); } return 0; }
@@ -307,7 +203,7 @@ int SparccCommand::process(SharedRAbundVectors*& shared){
         int numGroups = data.size();
 
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile));
+        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(sharedfile));
         variables["[distance]"] = shared->getLabel();
 
 
@@ -468,7 +364,7 @@ vector<vector<float> > SparccCommand::createProcesses(vector<vector<float> >& sh
         }
 
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<sparccData*> data;
 
         //Lauch worker threads
@@ -477,7 +373,7 @@ vector<vector<float> > SparccCommand::createProcesses(vector<vector<float> >& sh
             sparccData* dataBundle = new sparccData(sharedVector, origCorrMatrix, numSamplings, maxIterations, lines[i+1], normalizeMethod);
             data.push_back(dataBundle);
 
-            workerThreads.push_back(new thread(driverSparcc, dataBundle));
+            workerThreads.push_back(new std::thread(driverSparcc, dataBundle));
         }
 
         int numOTUs = sharedVector[0].size();
