@@ -24,7 +24,6 @@ class SubSampleCommand : public Command {
 
 public:
 	SubSampleCommand(string);
-	SubSampleCommand();
 	~SubSampleCommand() {}
 	
 	vector<string> setParameters();
@@ -43,7 +42,7 @@ private:
 	bool abort, pickedGroups, allLines, persample, withReplacement;
 	string listfile, groupfile, countfile, sharedfile, rabundfile, sabundfile, fastafile, namefile, taxonomyfile, treefile, constaxonomyfile;
 	set<string> labels; //holds labels to be used
-	string groups, label, outputDir;
+	string groups, label;
 	vector<string> Groups, outputNames;
 	int size;
 	//vector<string> names;
@@ -52,8 +51,8 @@ private:
 	
 	int getSubSampleShared();
 	int getSubSampleList();
-	int getSubSampleRabund();
-	int getSubSampleSabund();
+	void getSubSampleRabund();
+	void getSubSampleSabund();
 	int getSubSampleFasta();
     int getSubSampleTree();
 	int processShared(SharedRAbundVectors*&);
