@@ -27,6 +27,12 @@ vector<string> SummarySharedCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        abort = false; calledHelp = false;  allLines = true;
+        
+        vector<string> tempOutNames;
+        outputTypes["summary"] = tempOutNames;
+        outputTypes["phylip"] = tempOutNames;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -82,64 +88,18 @@ string SummarySharedCommand::getOutputPattern(string type) {
     }
 }
 //**********************************************************************************************************************
-SummarySharedCommand::SummarySharedCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["summary"] = tempOutNames;
-        outputTypes["phylip"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "SummarySharedCommand", "SummarySharedCommand");
-		exit(1);
-	}
-}
-//**********************************************************************************************************************
-
 SummarySharedCommand::SummarySharedCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-		allLines = true;
-				
-		//allow user to run help
+
 		if(option == "help") {  help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters();
-			map<string, string>::iterator it;
 			
 			ValidParameters validParameter;
-		
-			//check to make sure all parameters are valid for command
-			for (map<string, string>::iterator it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["summary"] = tempOutNames;
-            outputTypes["phylip"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("shared");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["shared"] = inputDir + it->second;		}
-				}
-			}
-			
-			//get shared file
 			sharedfile = validParameter.validFile(parameters, "shared");
 			if (sharedfile == "not open") { sharedfile = ""; abort = true; }	
 			else if (sharedfile == "not found") { 
@@ -150,8 +110,8 @@ SummarySharedCommand::SummarySharedCommand(string option)  {
 			}else { current->setSharedFile(sharedfile); }
 			
 			
-			//if the user changes the output directory command factory will send this info to us in the output parameter 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(sharedfile);		}
+			 
+					if (outputdir == ""){    outputdir = util.hasPath(sharedfile);		}
 			
 
 			//check for optional parameter and set defaults
@@ -199,7 +159,7 @@ SummarySharedCommand::SummarySharedCommand(string option)  {
                 else { subsample = false; }
             }
             
-            if (!subsample) { iters = 0; }
+            if (!subsample) { iters = 1; }
             
             temp = validParameter.valid(parameters, "withreplacement");		if (temp == "not found"){	temp = "f";		}
             withReplacement = util.isTrue(temp);
@@ -319,7 +279,7 @@ int SummarySharedCommand::execute(){
 		
 		ofstream outputFileHandle, outAll;
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile));
+		variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(sharedfile));
 		string outputFileName = getOutputFileName("summary",variables);
 		
 		//if the users entered no valid calculators don't execute command
@@ -328,43 +288,51 @@ int SummarySharedCommand::execute(){
 		else{ if (all){  for (int i = 0; i < sumCalculators.size(); i++) { if (sumCalculators[i]->getMultiple() ) { mult = true; } } } }
 			
 		InputData input(sharedfile, "sharedfile", Groups);
-		SharedRAbundVectors* lookup = input.getSharedRAbundVectors();
+		set<string> processedLabels;
+        set<string> userLabels = labels;
+        string lastLabel = "";
+        
+        SharedRAbundVectors* lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
         Groups = lookup->getNamesGroups();
-		string lastLabel = lookup->getLabel();
-	
+
 		/******************************************************/
 		//output headings for files
 		/******************************************************/
 		//output estimator names as column headers
-		util.openOutputFile(outputFileName, outputFileHandle);
-		outputFileHandle << "label" <<'\t' << "comparison" << '\t'; 
-		for(int i=0;i<sumCalculators.size();i++){
-			outputFileHandle << '\t' << sumCalculators[i]->getName();
-			if (sumCalculators[i]->getCols() == 3) {   outputFileHandle << "\t" << sumCalculators[i]->getName() << "_lci\t" << sumCalculators[i]->getName() << "_hci";  }
-		}
-		outputFileHandle << endl;
-		outputFileHandle.close();
-		
+        if (!subsample) {
+            util.openOutputFile(outputFileName, outputFileHandle);
+            outputFileHandle << "label" <<'\t' << "comparison" << '\t';
+            for(int i=0;i<sumCalculators.size();i++){
+                outputFileHandle << '\t' << sumCalculators[i]->getName();
+                if (sumCalculators[i]->getCols() == 3) {   outputFileHandle << "\t" << sumCalculators[i]->getName() << "_lci\t" << sumCalculators[i]->getName() << "_hci";  }
+            }
+            outputFileHandle << endl;
+            outputFileHandle.close();
+        }
 		//create file and put column headers for multiple groups file
         variables["[tag]"]= "multiple";
 		string outAllFileName = getOutputFileName("summary",variables);
 		if (mult ) {
-			util.openOutputFile(outAllFileName, outAll);
-			outputNames.push_back(outAllFileName);
-			
-			outAll << "label" <<'\t' << "comparison" << '\t'; 
-			for(int i=0;i<sumCalculators.size();i++){ if (sumCalculators[i]->getMultiple() ) {  outAll << '\t' << sumCalculators[i]->getName(); } }
-			outAll << endl;
-			outAll.close();
+            if (!subsample) {
+                util.openOutputFile(outAllFileName, outAll);
+                outputNames.push_back(outAllFileName);
+                
+                outAll << "label" <<'\t' << "comparison" << '\t';
+                for(int i=0;i<sumCalculators.size();i++){ if (sumCalculators[i]->getMultiple() ) {  outAll << '\t' << sumCalculators[i]->getName(); } }
+                outAll << endl;
+                outAll.close();
+            }
 		}
 		
 		if (lookup->size() < 2) {
 			m->mothurOut("I cannot run the command without at least 2 valid groups."); 
 			delete lookup;
 			
-			//close files and clean up
-			util.mothurRemove(outputFileName);
-			if (mult ) { util.mothurRemove(outAllFileName);  }
+            if (!subsample) {
+                //close files and clean up
+                util.mothurRemove(outputFileName);
+                if (mult ) { util.mothurRemove(outAllFileName);  }
+            }
 			return 0;
 		//if you only have 2 groups you don't need a .sharedmultiple file
 		}else if ((lookup->size() == 2) && (mult )) {
@@ -400,74 +368,27 @@ int SummarySharedCommand::execute(){
 		}		
 		/******************************************************/
 		
-		//if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
-		set<string> processedLabels;
-		set<string> userLabels = labels;
         vector<string> currentLabels = lookup->getOTUNames();
-			
-		//as long as you are not at the end of the file or done wih the lines you want
-		while((lookup != NULL) && ((allLines == 1) || (userLabels.size() != 0))) {
-			if (m->getControl_pressed()) { if (mult) {  util.mothurRemove(outAllFileName);  } util.mothurRemove(outputFileName);  delete lookup; for(int i=0;i<sumCalculators.size();i++){  delete sumCalculators[i]; }   return 0; }
+        
+        while (lookup != NULL) {
+            
+            if (m->getControl_pressed()) { delete lookup; break; }
+            
+            process(lookup, outputFileName, outAllFileName, currentLabels); delete lookup;
+            
+            lookup = util.getNextShared(input, allLines, userLabels, processedLabels, lastLabel);
+        }
 
-		
-			if(allLines == 1 || labels.count(lookup->getLabel()) == 1){
-				m->mothurOut(lookup->getLabel()+"\n");
-                process(lookup, outputFileName, outAllFileName, currentLabels);
-				processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
-			}
-			
-			if ((util.anyLabelsToProcess(lookup->getLabel(), userLabels, "") ) && (processedLabels.count(lastLabel) != 1)) {
-					string saveLabel = lookup->getLabel();
-					
-					delete lookup;
-					lookup = input.getSharedRAbundVectors(lastLabel);
-
-					m->mothurOut(lookup->getLabel()+"\n");
-                    process(lookup, outputFileName, outAllFileName, currentLabels);
-					processedLabels.insert(lookup->getLabel()); userLabels.erase(lookup->getLabel());
-					
-					//restore real lastlabel to save below
-					lookup->setLabels(saveLabel);
-			}
-			
-			lastLabel = lookup->getLabel();
-				
-			//get next line to process
-			//prevent memory leak
-			delete lookup;
-			lookup = input.getSharedRAbundVectors();
-		}
-		
-		if (m->getControl_pressed()) { if (mult) { util.mothurRemove(outAllFileName);  } util.mothurRemove(outputFileName); for(int i=0;i<sumCalculators.size();i++){  delete sumCalculators[i]; }   return 0; }
-
-		//output error messages about any remaining user labels
-		bool needToRun = false;
-		for (set<string>::iterator it = userLabels.begin(); it != userLabels.end(); it++) {
-			m->mothurOut("Your file does not include the label " + *it); 
-            if (processedLabels.count(lastLabel) != 1)  { m->mothurOut(". I will use " + lastLabel + ".\n"); needToRun = true;  }
-			else                                        { m->mothurOut(". Please refer to " + lastLabel + ".\n");               }
-		}
-		
-		//run last label if you need to
-		if (needToRun )  {
-            delete lookup;
-            lookup = input.getSharedRAbundVectors(lastLabel);
-
-            m->mothurOut(lookup->getLabel()+"\n");
-            process(lookup, outputFileName, outAllFileName, currentLabels);
-            delete lookup;
-		}
-		
-		
 		for(int i=0;i<sumCalculators.size();i++){  delete sumCalculators[i]; }
 		
 		if (m->getControl_pressed()) { util.mothurRemove(outAllFileName);   util.mothurRemove(outputFileName);  return 0; }
 		
 		m->mothurOut("\nOutput File Names:\n");
-		m->mothurOut(outputFileName+"\n");
-		if (mult) { m->mothurOut(outAllFileName+"\n"); outputTypes["summary"].push_back(outAllFileName); }
-		for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]+"\n"); 	} outputTypes["summary"].push_back(outputFileName);
-		m->mothurOutEndLine();
+        if (!subsample) {
+            m->mothurOut(outputFileName+"\n");
+            if (mult) { m->mothurOut(outAllFileName+"\n"); outputTypes["summary"].push_back(outAllFileName); }
+            outputTypes["summary"].push_back(outputFileName);
+        }else { for (int i = 0; i < outputNames.size(); i++) {	m->mothurOut(outputNames[i]+"\n"); 	} } m->mothurOutEndLine();
 
 		return 0;
 	}
@@ -611,18 +532,18 @@ void driverSummaryShared(summarySharedData* params) {
         //loop through calculators and add to file all for all calcs that can do mutiple groups
         if (params->mult && params->main) {
             ofstream outAll;
-            params->util.openOutputFile(params->sumAllFile, outAll);
             
-            //output label
-            outAll << params->thisLookup[0]->getLabel() << '\t';
+            if (!params->subsample) { //print names
+                params->util.openOutputFile(params->sumAllFile, outAll);
+                outAll << params->thisLookup[0]->getLabel() << '\t'; //output label
             
-            //output groups names
-            string outNames = "";
-            for (int j = 0; j < params->thisLookup.size(); j++) {
-                outNames += params->thisLookup[j]->getGroup() +  "-";
+                //output groups names
+                string outNames = "";
+                for (int j = 0; j < params->thisLookup.size(); j++) { outNames += params->thisLookup[j]->getGroup() +  "-"; }
+                
+                outNames = outNames.substr(0, outNames.length()-1); //rip off extra '-';
+                outAll << outNames << '\t';
             }
-            outNames = outNames.substr(0, outNames.length()-1); //rip off extra '-';
-            outAll << outNames << '\t';
             
             for(int i=0;i<sumCalculators.size();i++){
                 if (sumCalculators[i]->getMultiple() ) {
@@ -630,16 +551,17 @@ void driverSummaryShared(summarySharedData* params) {
                     
                     if (params->m->getControl_pressed()) { break; }
                     
-                    outAll << '\t';
-                    sumCalculators[i]->print(outAll);
+                    if (!params->subsample) {
+                        outAll << '\t';
+                        sumCalculators[i]->print(outAll);
+                    }
                 }
             }
-            outAll << endl;
-            outAll.close();
+            if (!params->subsample) { outAll << endl; outAll.close(); }
         }
         
         ofstream outputFileHandle;
-        params->util.openOutputFile(params->sumFile, outputFileHandle);
+        if (!params->subsample) {  params->util.openOutputFile(params->sumFile, outputFileHandle); }
         
         vector<SharedRAbundVector*> subset;
         for (int k = params->start; k < params->end; k++) { // pass cdd each set of groups to compare
@@ -648,17 +570,18 @@ void driverSummaryShared(summarySharedData* params) {
             
             for (int l = 0; l < k; l++) {
                 
-                outputFileHandle << params->thisLookup[0]->getLabel() << '\t';
-                
                 subset.clear(); //clear out old pair of sharedrabunds
                 //add new pair of sharedrabunds
                 subset.push_back(params->thisLookup[k]); subset.push_back(params->thisLookup[l]);
                 
-                //sort groups to be alphanumeric
-                if (params->thisLookup[k]->getGroup() > params->thisLookup[l]->getGroup()) {
-                    outputFileHandle << (params->thisLookup[l]->getGroup() +'\t' + params->thisLookup[k]->getGroup()) << '\t'; //print out groups
-                }else{
-                    outputFileHandle << (params->thisLookup[k]->getGroup() +'\t' + params->thisLookup[l]->getGroup()) << '\t'; //print out groups
+                if (!params->subsample) {
+                    outputFileHandle << params->thisLookup[0]->getLabel() << '\t';
+                    //sort groups to be alphanumeric
+                    if (params->thisLookup[k]->getGroup() > params->thisLookup[l]->getGroup()) {
+                        outputFileHandle << (params->thisLookup[l]->getGroup() +'\t' + params->thisLookup[k]->getGroup()) << '\t'; //print out groups
+                    }else{
+                        outputFileHandle << (params->thisLookup[k]->getGroup() +'\t' + params->thisLookup[l]->getGroup()) << '\t'; //print out groups
+                    }
                 }
                 
                 for(int i=0;i<sumCalculators.size();i++) {
@@ -675,17 +598,18 @@ void driverSummaryShared(summarySharedData* params) {
                     
                     if (params->m->getControl_pressed()) { break; }
                     
-                    outputFileHandle << '\t';
-                    sumCalculators[i]->print(outputFileHandle);
-                    
+                    if (!params->subsample) {
+                        outputFileHandle << '\t';
+                        sumCalculators[i]->print(outputFileHandle);
+                    }
                     seqDist temp(l, k, tempdata[0]);
                     params->calcDists[i].push_back(temp);
                 }
-                outputFileHandle << endl;
+                if (!params->subsample) { outputFileHandle << endl; }
             }
         }
         
-        outputFileHandle.close();
+        if (!params->subsample) {  outputFileHandle.close(); }
         for(int i=0;i<sumCalculators.size();i++){  delete sumCalculators[i]; }
         
     }
@@ -699,23 +623,23 @@ void driverSummaryShared(summarySharedData* params) {
 int SummarySharedCommand::runCalcs(SharedRAbundVectors*& thisItersLookup, string sumFileName, string sumAllFile, vector< vector<seqDist>  >& calcDists) {
     try{
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<summarySharedData*> data;
         
         //Lauch worker threads
         for (int i = 0; i < processors-1; i++) {
             // Allocate memory for thread data.
             string extension = toString(i+1) + ".temp";
-            summarySharedData* dataBundle = new summarySharedData(sumFileName+extension, sumAllFile+extension, m, lines[i+1].start, lines[i+1].end, Estimators, thisItersLookup, false, mult);
+            summarySharedData* dataBundle = new summarySharedData(sumFileName+extension, sumAllFile+extension, m, lines[i+1].start, lines[i+1].end, Estimators, thisItersLookup, false, mult, subsample);
             
             data.push_back(dataBundle);
-            workerThreads.push_back(new thread(driverSummaryShared, dataBundle));
+            workerThreads.push_back(new std::thread(driverSummaryShared, dataBundle));
         }
         
         //make copy of lookup so we don't get access violations
         //SharedRAbundVectors* newLookup = new SharedRAbundVectors(*thisItersLookup);
         string extension = toString(0) + ".temp";
-        summarySharedData* dataBundle = new summarySharedData(sumFileName+extension, sumAllFile+extension, m, lines[0].start, lines[0].end, Estimators, thisItersLookup, true, mult);
+        summarySharedData* dataBundle = new summarySharedData(sumFileName+extension, sumAllFile+extension, m, lines[0].start, lines[0].end, Estimators, thisItersLookup, true, mult, subsample);
         
         driverSummaryShared(dataBundle);
         for (int k = 0; k < calcDists.size(); k++) {
@@ -723,16 +647,20 @@ int SummarySharedCommand::runCalcs(SharedRAbundVectors*& thisItersLookup, string
             for (int j = 0; j < size; j++) {    calcDists[k].push_back(dataBundle->calcDists[k][j]);    }
         }
         
-        util.appendFiles((sumFileName + extension), sumFileName);
-        util.mothurRemove((sumFileName + extension));
-        if (mult) { util.appendFiles((sumAllFile + extension), sumAllFile); }
+        if (!subsample) {
+            util.appendFiles((sumFileName + extension), sumFileName);
+            util.mothurRemove((sumFileName + extension));
+            if (mult) { util.appendFiles((sumAllFile + extension), sumAllFile);  util.mothurRemove((sumAllFile + extension)); }
+        }
         
         for (int i = 0; i < processors-1; i++) {
             workerThreads[i]->join();
             
-            string extension = toString(i+1) + ".temp";
-            util.appendFiles((sumFileName + extension), sumFileName);
-            util.mothurRemove((sumFileName + extension));
+            if (!subsample) {
+                string extension = toString(i+1) + ".temp";
+                util.appendFiles((sumFileName + extension), sumFileName);
+                util.mothurRemove((sumFileName + extension));
+            }
             
             if (createPhylip) {
                 for (int k = 0; k < calcDists.size(); k++) {
@@ -759,11 +687,11 @@ int SummarySharedCommand::process(SharedRAbundVectors* thisLookup, string sumFil
         vector< vector<seqDist>  > calcDists; calcDists.resize(numCalcs);
         
         SubSample sample;
-        for (int thisIter = 0; thisIter < iters+1; thisIter++) {
+        for (int thisIter = 0; thisIter < iters; thisIter++) {
             
             SharedRAbundVectors* thisItersLookup = new SharedRAbundVectors(*thisLookup);
             
-            if (subsample && (thisIter != 0)) { //we want the summary results for the whole dataset, then the subsampling
+            if (subsample) { //we want the summary results for the whole dataset, then the subsampling
                 //make copy of lookup so we don't get access violations
                 SharedRAbundVectors* newLookup = new SharedRAbundVectors(*thisItersLookup);
                 
@@ -776,7 +704,7 @@ int SummarySharedCommand::process(SharedRAbundVectors* thisLookup, string sumFil
             
             runCalcs(thisItersLookup, sumFileName, sumAllFileName, calcDists);
             
-            if (subsample && (thisIter != 0)) { //we want the summary results for the whole dataset, then the subsampling
+            if (subsample) { //we want the summary results for the whole dataset, then the subsampling
                 calcDistsTotals.push_back(calcDists);
                 delete thisItersLookup;
             }else {
@@ -800,7 +728,7 @@ int SummarySharedCommand::process(SharedRAbundVectors* thisLookup, string sumFil
                         }
                         
                         map<string, string> variables; 
-                        variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile));
+                        variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(sharedfile));
                         variables["[calc]"] = sumCalculatorsNames[i];
                         variables["[distance]"] = thisLookup->getLabel();
                         variables["[outputtag]"] = output;
@@ -820,7 +748,7 @@ int SummarySharedCommand::process(SharedRAbundVectors* thisLookup, string sumFil
             for (int i = 0; i < calcDists.size(); i++) {  calcDists[i].clear(); }
 		}
 
-        if (iters != 0) {
+        if (subsample) {
             //we need to find the average distance and standard deviation for each groups distance
             vector< vector<seqDist>  > calcAverages = util.getAverages(calcDistsTotals);
             
@@ -851,7 +779,7 @@ int SummarySharedCommand::process(SharedRAbundVectors* thisLookup, string sumFil
                 }
                 
                 map<string, string> variables; 
-                variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(sharedfile));
+                variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(sharedfile));
                 variables["[calc]"] = sumCalculatorsNames[i];
                 variables["[distance]"] = thisLookup->getLabel();
                 variables["[outputtag]"] = output;
