@@ -13,6 +13,8 @@
 vector<string> SystemCommand::setParameters(){	
 	try {
 		CommandParameter pcommand("command", "String", "", "", "", "", "","",false,false); parameters.push_back(pcommand);
+        
+        abort = false; calledHelp = false;
 				
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -26,28 +28,21 @@ vector<string> SystemCommand::setParameters(){
 //**********************************************************************************************************************
 SystemCommand::SystemCommand(string option)  {
 	try {
-		abort = false; calledHelp = false;   
-		
-		//allow user to run help
+
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string, string> parameters = parser.getParameters();
-			map<string, string>::iterator it;
 			
 			ValidParameters validParameter;
-			
-			//check for optional parameter and set defaults
-			// ...at some point should added some additional type checking...
 			string commandOption = validParameter.valid(parameters, "command");			
 			if (commandOption == "not found") { commandOption = ""; }
 			else { command = commandOption; }
 			
-			if ((option == "") && (commandOption == "")) { m->mothurOut("You must enter a command to run."); m->mothurOutEndLine(); abort = true; }
+            if ((option == "") && (commandOption == "")) { m->mothurOut("[ERROR]: You must enter a command to run.\n"); abort = true; }
 			else if (commandOption == "") { 
 				//check for outputdir and inputdir parameters
 				int commaPos = option.find_first_of(',');
@@ -90,20 +85,22 @@ int SystemCommand::execute(){
 	try {
 		
 		if (abort) { if (calledHelp) { return 0; }  return 2;	}
-		
+        
+        if (outputdir == "") { outputdir = "./"; }
+        string redirectFileName = outputdir + "commandScreen.output";
+        
 		//if command contains a redirect don't add the redirect
 		bool usedRedirect = false;
 		if ((command.find('>')) == string::npos) {
-			command += " > ./commandScreen.output 2>&1";
+			command += " > " + redirectFileName + " 2>&1";
 			usedRedirect = true;
 		}
-		
+       
 		system(command.c_str());
-		
+  
 		if (usedRedirect) {
 			ifstream in;
-			string filename = "./commandScreen.output";
-			util.openInputFile(filename, in, "no error");
+			util.openInputFile(redirectFileName, in, "no error");
 			
 			string output = "";
 			while(char c = in.get()){
@@ -111,9 +108,10 @@ int SystemCommand::execute(){
 				else				{	output += c;	}
 			}
 			in.close();
-			
+            
 			m->mothurOut(output); m->mothurOutEndLine();
-			util.mothurRemove(filename);
+            //if (output != "") { exit(1); }
+			util.mothurRemove(redirectFileName);
 		}
 		
 		return 0;		
