@@ -22,7 +22,6 @@
 class TrimFlowsCommand : public Command {
 public:
 	TrimFlowsCommand(string);
-	TrimFlowsCommand();
 	~TrimFlowsCommand() {}
 	
 	vector<string> setParameters();
@@ -45,7 +44,7 @@ private:
 	int maxFlows, minFlows, minLength, maxLength, maxHomoP, tdiffs, bdiffs, pdiffs, sdiffs, ldiffs, numLinkers, numSpacers;
 	float signal, noise;
 	bool fasta, pairedOligos, reorient, allFiles, abort, createGroup;
-	string flowOrder, flowFileName, oligoFileName, outputDir;
+	string flowOrder, flowFileName, oligoFileName;
     
     map<int, oligosPair> pairedBarcodes;
     map<int, oligosPair> pairedPrimers;
@@ -58,7 +57,7 @@ private:
     vector<string> revPrimer;
     map<string, string> groupMap;
     
-	vector<unsigned long long> getFlowFileBreaks();
+	vector<double> getFlowFileBreaks();
 	int createProcessesCreateTrim(string, string, string, string);
 	int getOligos();
 	
