@@ -31,6 +31,15 @@ vector<string> UnifracWeightedCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
+        
+        vector<string> tempOutNames;
+        outputTypes["weighted"] = tempOutNames;
+        outputTypes["wsummary"] = tempOutNames;
+        outputTypes["phylip"] = tempOutNames;
+        outputTypes["column"] = tempOutNames;
+        outputTypes["tree"] = tempOutNames;
+        
+        abort = false; calledHelp = false;
 		
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -85,99 +94,25 @@ string UnifracWeightedCommand::getOutputPattern(string type) {
         exit(1);
     }
 }
-//**********************************************************************************************************************
-UnifracWeightedCommand::UnifracWeightedCommand(){	
-	try {
-		abort = true; calledHelp = true; 
-		setParameters();
-		vector<string> tempOutNames;
-		outputTypes["weighted"] = tempOutNames;
-		outputTypes["wsummary"] = tempOutNames;
-		outputTypes["phylip"] = tempOutNames;
-		outputTypes["column"] = tempOutNames;
-        outputTypes["tree"] = tempOutNames;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "UnifracWeightedCommand", "UnifracWeightedCommand");
-		exit(1);
-	}
-}
 /***********************************************************/
 UnifracWeightedCommand::UnifracWeightedCommand(string option) {
 	try {
-		abort = false; calledHelp = false;   
-			
-		//allow user to run help
+
 		if(option == "help") { help(); abort = true; calledHelp = true; }
 		else if(option == "citation") { citation(); abort = true; calledHelp = true;}
+        else if(option == "category") {  abort = true; calledHelp = true;  }
 		
 		else {
-			vector<string> myArray = setParameters();
-			
-			OptionParser parser(option);
+			OptionParser parser(option, setParameters());
 			map<string,string> parameters=parser.getParameters();
-			map<string,string>::iterator it;
 			
 			ValidParameters validParameter;
-		
-			//check to make sure all parameters are valid for command
-			for (map<string,string>::iterator it = parameters.begin(); it != parameters.end(); it++) { 
-				if (!validParameter.isValidParameter(it->first, myArray, it->second)) {  abort = true;  }
-			}
-			
-			//initialize outputTypes
-			vector<string> tempOutNames;
-			outputTypes["weighted"] = tempOutNames;
-			outputTypes["wsummary"] = tempOutNames;
-			outputTypes["phylip"] = tempOutNames;
-			outputTypes["column"] = tempOutNames;
-            outputTypes["tree"] = tempOutNames;
-			
-			//if the user changes the input directory command factory will send this info to us in the output parameter 
-			string inputDir = validParameter.valid(parameters, "inputdir");		
-			if (inputDir == "not found"){	inputDir = "";		}
-			else {
-				string path;
-				it = parameters.find("tree");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["tree"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("group");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["group"] = inputDir + it->second;		}
-				}
-				
-				it = parameters.find("name");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["name"] = inputDir + it->second;		}
-				}
-                
-                it = parameters.find("count");
-				//user has given a template file
-				if(it != parameters.end()){ 
-					path = util.hasPath(it->second);
-					//if the user has not given a path then, add inputdir. else leave path alone.
-					if (path == "") {	parameters["count"] = inputDir + it->second;		}
-				}
-			}
-			
-			//check for required parameters
 			treefile = validParameter.validFile(parameters, "tree");
 			if (treefile == "not open") { treefile = ""; abort = true; }
 			else if (treefile == "not found") { 				//if there is a current design file, use it
 				treefile = current->getTreeFile(); 
-				if (treefile != "") { m->mothurOut("Using " + treefile + " as input file for the tree parameter."); m->mothurOutEndLine(); }
-				else { 	m->mothurOut("You have no current tree file and the tree parameter is required."); m->mothurOutEndLine(); abort = true; }								
+				if (treefile != "") { m->mothurOut("Using " + treefile + " as input file for the tree parameter.\n");  }
+				else { 	m->mothurOut("You have no current tree file and the tree parameter is required.\n");  abort = true; }								
 			}else { current->setTreeFile(treefile); }	
 			
 			//check for required parameters
@@ -197,14 +132,14 @@ UnifracWeightedCommand::UnifracWeightedCommand(string option) {
 			else { current->setCountFile(countfile); }
             
             if ((namefile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: name or count."); m->mothurOutEndLine(); abort = true;
+                m->mothurOut("[ERROR]: you may only use one of the following: name or count.\n");  abort = true;
             }
 			
             if ((groupfile != "") && (countfile != "")) {
-                m->mothurOut("[ERROR]: you may only use one of the following: group or count."); m->mothurOutEndLine(); abort=true;
+                m->mothurOut("[ERROR]: you may only use one of the following: group or count.\n");  abort=true;
             }
 
-			outputDir = validParameter.valid(parameters, "outputdir");		if (outputDir == "not found"){	outputDir = util.hasPath(treefile);	}
+					if (outputdir == ""){    outputdir = util.hasPath(treefile);	}
 			
 																	
 			//check for optional parameter and set defaults
@@ -224,7 +159,7 @@ UnifracWeightedCommand::UnifracWeightedCommand(string option) {
 			else{
                 if (temp=="phylip") { temp = "lt"; }
 				if ((temp == "lt") || (temp == "column") || (temp == "square")) {  phylip = true;  outputForm = temp; }
-				else { m->mothurOut("Options for distance are: lt, square, or column. Using lt."); m->mothurOutEndLine(); phylip = true; outputForm = "lt"; }
+				else { m->mothurOut("Options for distance are: lt, square, or column. Using lt.\n");  phylip = true; outputForm = "lt"; }
 			}
 			
 			temp = validParameter.valid(parameters, "random");				if (temp == "not found") { temp = "F"; }
@@ -334,7 +269,7 @@ int UnifracWeightedCommand::execute() {
             vector<double> userData; userData.resize(numComp,0);  //weighted score info for user tree. data[0] = weightedscore AB, data[1] = weightedscore AC...
             vector<double> randomData; randomData.resize(numComp,0); //weighted score info for random trees. data[0] = weightedscore AB, data[1] = weightedscore AC...
             
-            userData = weighted.getValues(T[i], processors, outputDir); //userData[0] = weightedscore
+            userData = weighted.getValues(T[i], processors, outputdir); //userData[0] = weightedscore
             if (m->getControl_pressed()) { break; }
             
             if (phylip) {	createPhylipFile((i+1), userData);          }
@@ -363,7 +298,7 @@ int UnifracWeightedCommand::execute() {
                 //call new weighted function
                 vector<double> iterData; iterData.resize(numComp,0);
                 Weighted thisWeighted(includeRoot, Groups);
-                iterData = thisWeighted.getValues(subSampleTree, processors, outputDir); //userData[0] = weightedscore
+                iterData = thisWeighted.getValues(subSampleTree, processors, outputdir); //userData[0] = weightedscore
                 
                 //save data to make ave dist, std dist
                 calcDistsTotals.push_back(iterData);
@@ -440,7 +375,7 @@ int UnifracWeightedCommand::getAverageSTDMatrices(vector< vector<double> >& dist
         }
         
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + util.getSimpleName(treefile);
+		variables["[filename]"] = outputdir + util.getSimpleName(treefile);
         variables["[tag]"] = toString(treeNum+1);
         variables["[tag2]"] = "weighted.ave";
         string aveFileName = getOutputFileName("phylip",variables);
@@ -517,7 +452,7 @@ int UnifracWeightedCommand::getConsensusTrees(vector< vector<double> >& dists, i
         
         //create a new filename
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(treefile));
+		variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(treefile));
         variables["[tag]"] = toString(treeNum+1);
         variables["[tag2]"] = "weighted.cons";
         string conFile = getOutputFileName("tree",variables);							
@@ -541,7 +476,7 @@ vector<Tree*> UnifracWeightedCommand::buildTrees(vector< vector<double> >& dists
         
         //create a new filename
         map<string, string> variables; 
-		variables["[filename]"] = outputDir + util.getRootName(util.getSimpleName(treefile));
+		variables["[filename]"] = outputdir + util.getRootName(util.getSimpleName(treefile));
         variables["[tag]"] = toString(treeNum+1);
         variables["[tag2]"] = "weighted.all";
         string outputFile = getOutputFileName("tree",variables);				
@@ -590,7 +525,7 @@ vector<Tree*> UnifracWeightedCommand::buildTrees(vector< vector<double> >& dists
 int UnifracWeightedCommand::runRandomCalcs(Tree* thisTree, CountTable* ct, vector<double> usersScores, int iter, vector<double>& WScoreSig, vector<string> groupComb) {
 	try {
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getSimpleName(treefile);
+        variables["[filename]"] = outputdir + util.getSimpleName(treefile);
         variables["[tag]"] = toString(iter);
         string wFileName = getOutputFileName("weighted", variables); 
         ColumnFile output(wFileName, itersString); ofstream out; util.openOutputFile(wFileName, out); out.close();
@@ -634,7 +569,7 @@ int UnifracWeightedCommand::runRandomCalcs(Tree* thisTree, CountTable* ct, vecto
             //so if you have 1000 random trees the index returned is 100 
             //then there are 900 trees with a score greater then you. 
             //giving you a signifigance of 0.900
-            int index = findIndex(usersScores[f], f, rScores);    if (index == -1) { m->mothurOut("error in UnifracWeightedCommand"); m->mothurOutEndLine(); exit(1); } //error code
+            int index = findIndex(usersScores[f], f, rScores);    if (index == -1) { m->mothurOut("error in UnifracWeightedCommand\n");  exit(1); } //error code
             
             //the signifigance is the number of trees with the users score or higher 
             WScoreSig.push_back((iters-index)/(float)iters);
@@ -748,7 +683,7 @@ vector<double> UnifracWeightedCommand::createProcesses(Tree* t, CountTable* ct,
             remainingPairs = remainingPairs - numPairs;
         }
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<weightedRandomData*> data;
         
         //Lauch worker threads
@@ -761,7 +696,7 @@ vector<double> UnifracWeightedCommand::createProcesses(Tree* t, CountTable* ct,
             
             weightedRandomData* dataBundle = new weightedRandomData(lines[i+1].start, lines[i+1].end, namesOfGroupCombos, copyTree, copyCount, includeRoot, Groups, randomizedTreeNodes);
             data.push_back(dataBundle);
-            workerThreads.push_back(new thread(driverWeightedRandom, dataBundle));
+            workerThreads.push_back(new std::thread(driverWeightedRandom, dataBundle));
         }
         
         weightedRandomData* dataBundle = new weightedRandomData(lines[0].start, lines[0].end, namesOfGroupCombos, t, ct, includeRoot, Groups, randomizedTreeNodes);
@@ -788,7 +723,7 @@ vector<double> UnifracWeightedCommand::createProcesses(Tree* t, CountTable* ct,
 void UnifracWeightedCommand::printWSummaryFile(int treeIndex, vector<double> utreeScores, vector<double> WScoreSig, vector<string> groupComb) {
 	try {
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getSimpleName(treefile);
+        variables["[filename]"] = outputdir + util.getSimpleName(treefile);
         variables["[tag]"] = toString(treeIndex);
         sumFile = getOutputFileName("wsummary",variables);
         outputNames.push_back(sumFile);  outputTypes["wsummary"].push_back(sumFile);
@@ -837,7 +772,7 @@ void UnifracWeightedCommand::createPhylipFile(int treeIndex, vector<double> utre
         
         string phylipFileName;
         map<string, string> variables;
-        variables["[filename]"] = outputDir + util.getSimpleName(treefile);
+        variables["[filename]"] = outputdir + util.getSimpleName(treefile);
         variables["[tag]"] = toString(treeIndex);
         if ((outputForm == "lt") || (outputForm == "square")) {
             variables["[tag2]"] = "weighted.phylip";
