@@ -15,13 +15,12 @@
 
 /**************************************************************************************************/
 
-Alignment::Alignment() {	m = MothurOut::getInstance(); current = CurrentFile::getInstance(); /*	do nothing	*/	}
+Alignment::Alignment() {	m = MothurOut::getInstance();  /*	do nothing	*/	}
 
 /**************************************************************************************************/
 
 Alignment::Alignment(int A) : nCols(A), nRows(A) {
 	try {
-        current = CurrentFile::getInstance();
 		m = MothurOut::getInstance();
 		alignment.resize(nRows);			//	For the Gotoh and Needleman-Wunsch we initialize the dynamic programming
 		for(int i=0;i<nRows;i++){			//	matrix by initializing a matrix that is A x A.  By default we will set A
@@ -37,7 +36,6 @@ Alignment::Alignment(int A) : nCols(A), nRows(A) {
 
 Alignment::Alignment(int A, int nk) : nCols(A), nRows(A) {
     try {
-        current = CurrentFile::getInstance();
         m = MothurOut::getInstance();
         alignment.resize(nRows);			//	For the Gotoh and Needleman-Wunsch we initialize the dynamic programming
         for(int i=0;i<nRows;i++){			//	matrix by initializing a matrix that is A x A.  By default we will set A
@@ -50,6 +48,7 @@ Alignment::Alignment(int A, int nk) : nCols(A), nRows(A) {
     }
 }
 /**************************************************************************************************/
+//only gets bigger
 void Alignment::resize(int A) {
 	try {
 		nCols = A;
@@ -57,8 +56,8 @@ void Alignment::resize(int A) {
 
 		alignment.resize(nRows);			
 		for(int i=0;i<nRows;i++){			
-			alignment[i].resize(nCols);		
-		}	
+			alignment[i].resize(nCols);
+		}
 	}
 	catch(exception& e) {
 		m->errorOut(e, "Alignment", "resize");
@@ -67,7 +66,7 @@ void Alignment::resize(int A) {
 }
 /**************************************************************************************************/
 
-void Alignment::traceBack(){			//	This traceback routine is used by the dynamic programming algorithms
+void Alignment::traceBack(bool createBaseMap){			//	This traceback routine is used by the dynamic programming algorithms
 	try {	
 		BBaseMap.clear();
         ABaseMap.clear(); //	to fill the values of seqAaln and seqBaln
@@ -89,22 +88,29 @@ void Alignment::traceBack(){			//	This traceback routine is used by the dynamic
 				if(currentCell.prevCell == 'u'){			//	if the pointer to the previous cell is 'u', go up in the
 					seqAaln = '-' + seqAaln;				//	matrix.  this indicates that we need to insert a gap in
 					seqBaln = seqB[row] + seqBaln;			//	seqA and a base in seqB
-                    BBaseMap[row] = count;
-					currentCell = alignment[--row][column];
+                    if (createBaseMap) { BBaseMap[row] = count; }
+					//currentCell = alignment[--row][column];
+                    --row;
 				}
 				else if(currentCell.prevCell == 'l'){		//	if the pointer to the previous cell is 'l', go to the left
 					seqBaln = '-' + seqBaln;				//	in the matrix.  this indicates that we need to insert a gap
 					seqAaln = seqA[column] + seqAaln;		//	in seqB and a base in seqA
-                    ABaseMap[column] = count;
-					currentCell = alignment[row][--column];
+                    if (createBaseMap) { ABaseMap[column] = count; }
+					//currentCell = alignment[row][--column];
+                    --column;
 				}
 				else{
 					seqAaln = seqA[column] + seqAaln;		//	otherwise we need to go diagonally up and to the left,
 					seqBaln = seqB[row] + seqBaln;			//	here we add a base to both alignments
-                    BBaseMap[row] = count;
-                    ABaseMap[column] = count;
-					currentCell = alignment[--row][--column];
+                    if (createBaseMap) {
+                        BBaseMap[row] = count;
+                        ABaseMap[column] = count;
+                    }
+					//currentCell = alignment[--row][--column];
+                    --row; --column;
 				}
+                if ((row >= 0) && (column >= 0)) { currentCell = alignment[row][column]; }
+                else { break; }
                 count++;
 			}
 		}
@@ -113,19 +119,22 @@ void Alignment::traceBack(){			//	This traceback routine is used by the dynamic
         pairwiseLength = seqAaln.length();
 		seqAstart = 1;	seqAend = 0;
 		seqBstart = 1;	seqBend = 0;
-        //flip maps since we now know the total length
-        map<int, int> newAMap;
-        for (map<int, int>::iterator it = ABaseMap.begin(); it != ABaseMap.end(); it++) {
-            int spot = it->second;
-            newAMap[pairwiseLength-spot-1] = it->first-1;
+        
+        if (createBaseMap) {
+            //flip maps since we now know the total length
+            map<int, int> newAMap;
+            for (map<int, int>::iterator it = ABaseMap.begin(); it != ABaseMap.end(); it++) {
+                int spot = it->second;
+                newAMap[pairwiseLength-spot-1] = it->first-1;
+            }
+            ABaseMap = newAMap;
+            map<int, int> newBMap;
+            for (map<int, int>::iterator it = BBaseMap.begin(); it != BBaseMap.end(); it++) {
+                int spot = it->second;
+                newBMap[pairwiseLength-spot-1] = it->first-1;
+            }
+            BBaseMap = newBMap;
         }
-        ABaseMap = newAMap;
-        map<int, int> newBMap;
-        for (map<int, int>::iterator it = BBaseMap.begin(); it != BBaseMap.end(); it++) {
-            int spot = it->second;
-            newBMap[pairwiseLength-spot-1] = it->first-1;
-        }
-		BBaseMap = newBMap;
         
 		for(int i=0;i<seqAaln.length();i++){
 			if(seqAaln[i] != '-' && seqBaln[i] == '-')		{	seqAstart++;	}
@@ -157,6 +166,7 @@ Alignment::~Alignment(){
 		for (int i = 0; i < alignment.size(); i++) {
 			for (int j = (alignment[i].size()-1); j >= 0; j--) {  alignment[i].pop_back();  }
 		}
+        alignment.clear();
 	}
 	catch(exception& e) {
 		m->errorOut(e, "Alignment", "~Alignment");
@@ -216,27 +226,3 @@ int Alignment::getPairwiseLength(){
 }
 
 /**************************************************************************************************/
-
-//int Alignment::getLongestTemplateGap(){
-//
-//	int length = seqBaln.length();
-//	int longGap = 0;
-//	int gapLength = 0;
-//	
-//	int start = seqAstart;
-//	if(seqAstart < seqBstart){	start = seqBstart;	}
-//	for(int i=seqAstart;i<length;i++){
-//		if(seqBaln[i] == '-'){
-//			gapLength++;
-//		}
-//		else{
-//			if(gapLength > 0){
-//				if(gapLength > longGap){	longGap = gapLength;	}
-//			}
-//			gapLength = 0;
-//		}
-//	}
-//	return longGap;
-//}
-
-/**************************************************************************************************/
