@@ -26,11 +26,9 @@ public:
     Alignment(int, int);
 	Alignment();
 	virtual ~Alignment();
-	virtual void align(string, string) = 0;
+	virtual void align(string, string, bool createBaseMap=false) = 0;
     virtual void alignPrimer(string, string) {}
 	
-	
-//	float getAlignmentScore();
 	string getSeqAAln();
 	string getSeqBAln();
     map<int, int> getSeqAAlnBaseMap();
@@ -41,12 +39,11 @@ public:
 	int getTemplateEndPos();
 	
 	int getPairwiseLength();
-	void resize(int);
+	virtual void resize(int);
 	int getnRows() { return nRows; }
-//	int getLongestTemplateGap();
 
 protected:
-	void traceBack();
+	void traceBack(bool createBaseMap);
 	string seqA, seqAaln;
 	string seqB, seqBaln;
 	int seqAstart, seqAend;
@@ -57,7 +54,7 @@ protected:
     map<int, int> ABaseMap;
     map<int, int> BBaseMap;
 	MothurOut* m;
-    CurrentFile* current;
+    
 };
 
 /**************************************************************************************************/
