@@ -296,7 +296,7 @@ int CountTable::createTable(string namefile, string groupfile, vector<string> se
         }
         if (groupfile != "") { delete groupMap; }
 
-        return 0;
+        return total;
     }
 	catch(exception& e) {
 		m->errorOut(e, "CountTable", "createTable");
@@ -354,7 +354,21 @@ int CountTable::readTable(string file, string format) {
 /************************************************************/
 int CountTable::readTable(string file, bool readGroups, bool mothurRunning) {
     try {
-        return (readTable(file, readGroups, mothurRunning, nullVector));
+        
+        readTable(file, readGroups, mothurRunning, nullVector);
+       
+        return total;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "CountTable", "readTable");
+        exit(1);
+    }
+}
+/************************************************************/
+int CountTable::readTable(ifstream& in, bool readGroups, bool mothurRunning) {
+    try {
+        readTable(in, readGroups, mothurRunning, nullVector);
+        return total;
     }
     catch(exception& e) {
         m->errorOut(e, "CountTable", "readTable");
@@ -401,11 +415,25 @@ bool CountTable::isCountTable(string file) {
 /************************************************************/
 int CountTable::readTable(string file, bool readGroups, bool mothurRunning, vector<string> selectedGroups) {
     try {
-        if (!readGroups) { selectedGroups.clear(); }
-        
         filename = file;
         ifstream in;
         util.openInputFile(filename, in);
+        
+        readTable(in, readGroups, mothurRunning, selectedGroups);
+        
+        in.close();
+        
+        return 0;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "CountTable", "readTable");
+        exit(1);
+    }
+}
+/************************************************************/
+int CountTable::readTable(ifstream& in, bool readGroups, bool mothurRunning, vector<string> selectedGroups) {
+    try {
+        if (!readGroups) { selectedGroups.clear(); }
 
         string headers = util.getline(in); util.gobble(in);
         
@@ -471,7 +499,7 @@ int CountTable::readTable(string file, bool readGroups, bool mothurRunning, vect
 
         bool error = false;
         string name;
-        int thisTotal;
+        int thisTotal = 0;
         uniques = 0;
         total = 0;
         while (!in.eof()) {
@@ -490,6 +518,7 @@ int CountTable::readTable(string file, bool readGroups, bool mothurRunning, vect
                 if (readGroups) { //user wants to save them
                     if (selectedGroups.size() != 0) {
                         //read this seqs groups abundances
+                        thisTotal = 0;
                         if (isCompressed) {
                             string groupInfo = util.getline(in); util.gobble(in);
                             vector<string> groupNodes = util.splitWhiteSpace(groupInfo);
@@ -507,6 +536,7 @@ int CountTable::readTable(string file, bool readGroups, bool mothurRunning, vect
                                     countTableItem item(a, thisIndex);
                                     abunds.push_back(item);
                                     totalGroups[thisIndex] += a;
+                                    thisTotal += a;
                                 }
                             }
                             
@@ -521,7 +551,7 @@ int CountTable::readTable(string file, bool readGroups, bool mothurRunning, vect
                                     int thisIndex = indexGroupMap[groupName];
                                     groupCounts[thisIndex] = thisGroupAbund;
                                     totalGroups[thisIndex] += thisGroupAbund;
-
+                                    thisTotal += thisGroupAbund;
                                 }
                             }
                         }
@@ -548,7 +578,11 @@ int CountTable::readTable(string file, bool readGroups, bool mothurRunning, vect
                                 groupCounts = expandAbunds(abunds);
                             }
                             else {
-                                for (int i = 0; i < numGroupsInFile; i++) { int thisIndex = indexGroupMap[originalGroupIndexes[i]]; in >> groupCounts[thisIndex]; util.gobble(in); totalGroups[thisIndex] += groupCounts[thisIndex]; }
+                                for (int i = 0; i < numGroupsInFile; i++) {
+                                    int thisIndex = indexGroupMap[originalGroupIndexes[i]];
+                                    in >> groupCounts[thisIndex]; util.gobble(in);
+                                    totalGroups[thisIndex] += groupCounts[thisIndex];
+                                }
                             }
                         
                     }
@@ -576,19 +610,21 @@ int CountTable::readTable(string file, bool readGroups, bool mothurRunning, vect
                 m->mothurOut("[ERROR]: Your count table contains more than 1 sequence named " + name + ", sequence names must be unique. Please correct.\n");
             }
         }
-        in.close();
 
         if (error) { m->setControl_pressed(true); }
         else { //check for zero groups
             if (hasGroups && readGroups) {
                 for (int i = 0; i < totalGroups.size(); i++) {
-                    if (totalGroups[i] == 0) { m->mothurOut("\nRemoving group: " + groups[i] + " because all sequences have been removed.\n"); removeGroup(groups[i]); i--; }
+                    if (totalGroups[i] == 0) { m->mothurOut("\nRemoving group: " + groups[i] + " because all sequences have been removed.\n");
+                        removeGroup(groups[i]);
+                        i--;
+                    }
                 }
             }
         }
         
         //if the file has groups, but we didn't read them
-        hasGroups = readGroups;
+        if (!readGroups) { hasGroups = false; }
 
         return 0;
     }
@@ -735,7 +771,7 @@ int CountTable::readTable(string file, bool readGroups, bool mothurRunning, set<
         }
         
         //if the file has groups, but we didn't read them
-        hasGroups = readGroups;
+         if (!readGroups) { hasGroups = false; }
         
         return 0;
     }
@@ -789,6 +825,12 @@ int CountTable::clearTable() {
 //zeroed reads are not printed
 vector<string> CountTable::printTable(string file) {
     try {
+        
+        //remove group if all reads are removed
+        for (int i = 0; i < totalGroups.size(); i++) {
+            if (totalGroups[i] == 0) { m->mothurOut("\nRemoving group: " + groups[i] + " because all sequences have been removed.\n"); removeGroup(groups[i]); i--; }
+        }
+        
         if (isCompressed) { return printCompressedTable(file); }
         
         ofstream out;
@@ -812,9 +854,9 @@ vector<string> CountTable::printTable(string file) {
                         namesInTable.push_back(itR->second);
                         
                         out << itR->second << '\t' << totals[i];
-                        if (hasGroups) {
-                            printGroupAbunds(out, i);
-                        }
+                        
+                        if (hasGroups) { printGroupAbunds(out, i); }
+                        
                         out << endl;
                     }
                 }
@@ -830,8 +872,53 @@ vector<string> CountTable::printTable(string file) {
 }
 /************************************************************/
 //zeroed reads are not printed
+vector<string> CountTable::printNoGroupsTable(string file) {
+    try {
+        
+        ofstream out;
+        util.openOutputFile(file, out);
+        
+        vector<string> namesInTable;
+        
+        if (total != 0) {
+            vector<string> headers = getHardCodedHeaders();
+            out << headers[0] << '\t' << headers[1] << endl;
+            
+            map<int, string> reverse; //use this to preserve order
+            for (map<string, int>::iterator it = indexNameMap.begin(); it !=indexNameMap.end(); it++) { reverse[it->second] = it->first;  }
+            
+            for (int i = 0; i < totals.size(); i++) {
+                if (totals[i] != 0) {
+
+                    map<int, string>::iterator itR = reverse.find(i);
+                
+                    if (itR != reverse.end()) {
+                        
+                        namesInTable.push_back(itR->second);
+                        
+                        out << itR->second << '\t' << totals[i] << endl;
+                    }
+                }
+            }
+        }
+        out.close();
+        return namesInTable;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "CountTable", "printTable");
+        exit(1);
+    }
+}
+/************************************************************/
+//zeroed reads are not printed
 vector<string> CountTable::printTable(string file, bool compressedFormat) {
     try {
+        
+        //remove group if all reads are removed
+        for (int i = 0; i < totalGroups.size(); i++) {
+            if (totalGroups[i] == 0) { m->mothurOut("\nRemoving group: " + groups[i] + " because all sequences have been removed.\n"); removeGroup(groups[i]); i--; }
+        }
+        
         if (compressedFormat) { return printCompressedTable(file); }
         
         ofstream out;
@@ -855,9 +942,9 @@ vector<string> CountTable::printTable(string file, bool compressedFormat) {
                         namesInTable.push_back(itR->second);
                         
                         out << itR->second << '\t' << totals[i];
-                        if (hasGroups) {
-                            printGroupAbunds(out, i);
-                        }
+                        
+                        if (hasGroups) { printGroupAbunds(out, i); }
+                        
                         out << endl;
                     }
                 }
@@ -886,14 +973,21 @@ vector<string> CountTable::printCompressedTable(string file, vector<string> grou
         
         if (total != 0) {
             if (hasGroups) {
-                out << "#Compressed Format: groupIndex,abundance. For example 1,6 would mean the read has an abundance of 6 for group 1." << endl;
-                out << "#";
                 
                 map<int, string> reverse;
-                for (map<string, int>::iterator it = indexGroupMap.begin(); it !=indexGroupMap.end(); it++) {
-                    reverse[it->second] = it->first;
+                for (map<string, int>::iterator it = indexGroupMap.begin(); it !=indexGroupMap.end(); it++) { reverse[it->second] = it->first; }
+                
+                map<int, string>::iterator it = reverse.begin();
+                string group1Name = it->second;
+                if (pickedGroups) { //find selected groups indicies
+                    for (map<int, string>::iterator it = reverse.begin(); it != reverse.end(); it++) {
+                        if (util.inUsersGroups(it->second, groupsToPrint)) { group1Name = it->second; break; }
+                    }
                 }
                 
+                out << "#Compressed Format: groupIndex,abundance. For example 1,6 would mean the read has an abundance of 6 for group " + group1Name + "." << endl;
+                out << "#";
+                
                 for (map<int, string>::iterator it = reverse.begin(); it != reverse.end(); it++) {
                     if (pickedGroups) { //find selected groups indicies
                         if (util.inUsersGroups(it->second, groupsToPrint)) {
@@ -961,29 +1055,32 @@ vector<string> CountTable::printCompressedTable(string file, vector<string> grou
     }
 }
 /************************************************************/
-//returns index of countTableItem for group passed in. If group is not present in seq, returns -1
-int CountTable::find(int seq, int group) {
+//returns index of countTableItem for group passed in. If group is not present in seq, returns index of next group or -1
+int CountTable::find(int seq, int group, bool returnNext) {
     try {
+        
+        //if (!returnNext) { return find(seq, group); }
         int index = -1;
         
         for (int i = 0; i < counts[seq].size(); i++) {
             if (counts[seq][i].group >= group) { //found it or done looking
-                if (counts[seq][i].group == group) { index = i; }
+                
+                if (counts[seq][i].group == group) { index = i;  }
                 break;
             }
         }
+        
         return index;
     }
     catch(exception& e) {
         m->errorOut(e, "CountTable", "find");
         exit(1);
     }
-}
-/************************************************************/
+}/************************************************************/
 //returns abundance of countTableItem for seq and group passed in. If group is not present in seq, returns 0
 int CountTable::getAbund(int seq, int group) {
     try {
-        int index = find(seq, group);
+        int index = find(seq, group, false);
         
         if (index != -1) { //this seq has a non zero abundance for this group
             return counts[seq][index].abund;
@@ -1017,6 +1114,7 @@ vector<int> CountTable::expandAbunds(int index) {
     try {
         vector<int> abunds; abunds.resize(groups.size(), 0); //prefill with 0's
         
+        
         for (int i = 0; i < counts[index].size(); i++) { //for each non zero entry
             abunds[counts[index][i].group] = counts[index][i].abund; //set abund for group
         }
@@ -1049,7 +1147,7 @@ vector<countTableItem> CountTable::compressAbunds(vector<int> abunds) {
     }
 }
 /************************************************************/
-int CountTable::printGroupAbunds(ofstream& out, int index) {
+void CountTable::printGroupAbunds(ofstream& out, int index) {
     try {
         
         vector<int> abunds = expandAbunds(index);
@@ -1064,6 +1162,11 @@ int CountTable::printGroupAbunds(ofstream& out, int index) {
 /************************************************************/
 vector<string> CountTable::printSortedTable(string file) {
     try {
+        //remove group if all reads are removed
+        for (int i = 0; i < totalGroups.size(); i++) {
+            if (totalGroups[i] == 0) { m->mothurOut("\nRemoving group: " + groups[i] + " because all sequences have been removed.\n"); removeGroup(groups[i]); i--; }
+        }
+        
         ofstream out;
         util.openOutputFile(file, out);
         printHeaders(out);
@@ -1108,6 +1211,11 @@ vector<string> CountTable::getHardCodedHeaders() {
 /************************************************************/
 int CountTable::printHeaders(ofstream& out, vector<string> selectedGroups) {
     try {
+        //remove group if all reads are removed
+        for (int i = 0; i < totalGroups.size(); i++) {
+            if (totalGroups[i] == 0) { m->mothurOut("\nRemoving group: " + groups[i] + " because all sequences have been removed.\n"); removeGroup(groups[i]); i--; }
+        }
+        
         bool pickedGroups = false;
         if (selectedGroups.size() != 0) { pickedGroups = true; }
         
@@ -1222,7 +1330,7 @@ vector<countTableItem> CountTable::getItems(string seqName) {
             if (it == indexNameMap.end()) {
                 //look for it in names of groups to see if the user accidently used the wrong file
                 if (util.inUsersGroups(seqName, groups)) {
-                    m->mothurOut("[WARNING]: Your group or design file contains a group named " + seqName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group."); m->mothurOutEndLine();
+                    m->mothurOut("[WARNING]: Your group or design file contains a group named " + seqName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group.\n"); 
                 }
                 m->mothurOut("[ERROR]: " + seqName + " is not in your count table. Please correct.\n"); m->setControl_pressed(true);
             }else {
@@ -1270,7 +1378,7 @@ int CountTable::getGroupCount(string seqName, string groupName) {
                 if (it2 == indexNameMap.end()) {
                     //look for it in names of groups to see if the user accidently used the wrong file
                     if (util.inUsersGroups(seqName, groups)) {
-                        m->mothurOut("[WARNING]: Your group or design file contains a group named " + seqName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group."); m->mothurOutEndLine();
+                        m->mothurOut("[WARNING]: Your group or design file contains a group named " + seqName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group.\n"); 
                     }
                     m->mothurOut("[ERROR]: seq " + seqName + " is not in your count table. Please correct.\n"); m->setControl_pressed(true);
                 }else {
@@ -1299,11 +1407,11 @@ int CountTable::setAbund(string seqName, string groupName, int num) {
                 if (it2 == indexNameMap.end()) {
                     //look for it in names of groups to see if the user accidently used the wrong file
                     if (util.inUsersGroups(seqName, groups)) {
-                        m->mothurOut("[WARNING]: Your group or design file contains a group named " + seqName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group."); m->mothurOutEndLine();
+                        m->mothurOut("[WARNING]: Your group or design file contains a group named " + seqName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group.\n"); 
                     }
                     m->mothurOut("[ERROR]: " + seqName + " is not in your count table. Please correct.\n"); m->setControl_pressed(true);
                 }else {
-                    int indexOfGroup = find(it2->second, it->second);
+                    int indexOfGroup = find(it2->second, it->second, false);
                     int oldCount = 0;
                     
                     if (indexOfGroup == -1) { //create item for this group
@@ -1338,7 +1446,7 @@ int CountTable::addGroup(string groupName) {
 
         groups.push_back(groupName);
         if (!hasGroups) { counts.resize(uniques);  }
-
+        
         totalGroups.push_back(0);
         indexGroupMap[groupName] = groups.size()-1;
         map<string, int> originalGroupMap = indexGroupMap;
@@ -1372,9 +1480,10 @@ int CountTable::removeGroup(string groupName) {
         if (hasGroups) {
             //save for later in case removing a group means we need to remove a seq.
             map<int, string> reverse;
-            for (map<string, int>::iterator it = indexNameMap.begin(); it !=indexNameMap.end(); it++) { reverse[it->second] = it->first;  }
-
-            map<string, int>::iterator it = indexGroupMap.find(groupName);
+            map<string, int>::iterator it;
+            for (it = indexNameMap.begin(); it !=indexNameMap.end(); it++) { reverse[it->second] = it->first;  }
+            
+            it = indexGroupMap.find(groupName);
             if (it == indexGroupMap.end()) {
                 m->mothurOut("[ERROR]: " + groupName + " is not in your count table. Please correct.\n"); m->setControl_pressed(true);
             }else {
@@ -1390,43 +1499,59 @@ int CountTable::removeGroup(string groupName) {
                 indexGroupMap.erase(groupName);
                 groups = newGroups;
                 totalGroups.erase(totalGroups.begin()+indexOfGroupToRemove);
-
+                
                 int thisIndex = 0;
                 map<string, int> newIndexNameMap;
                 for (int i = 0; i < counts.size(); i++) {
                     
                     if (m->getControl_pressed()) { break; }
                     
-                    int indexOfGroup = find(i, indexOfGroupToRemove);
+                    int indexOfGroup = -1; bool found = false;
+                    for (int j = 0; j < counts[i].size(); j++) {
+                        if (counts[i][j].group >= indexOfGroupToRemove) { //found it or done looking
+                            
+                            indexOfGroup = j;
+                            if (counts[i][j].group == indexOfGroupToRemove) {   found = true; }
+                            break;
+                        }
+                    }
                     
-                    if (indexOfGroup != -1) { //you have an abundance for this group
+                    if (found) { //you have an abundance for this group
                         int num = counts[i][indexOfGroup].abund;
                         counts[i].erase(counts[i].begin()+indexOfGroup);
                         totals[i] -= num;
                         total -= num;
+                        
                         if (totals[i] == 0) { //your sequences are only from the group we want to remove, then remove you.
                             counts.erase(counts.begin()+i);
                             totals.erase(totals.begin()+i);
                             uniques--;
                             i--;
-                        }else { //remove name from table if no seqs left
-                            newIndexNameMap[reverse[thisIndex]] = i;
-                        }
-                    }////you don't have this group, nothing to remove
+                            if (i == -1) { i = 0; }
+                            indexOfGroup = counts[i].size(); //don't adjust the the group indexes because we removed the read
+                        }else { newIndexNameMap[reverse[thisIndex]] = i; }
+                    }else { //you don't have this group, nothing to remove
+                        
+                        if (indexOfGroup == -1) { indexOfGroup = counts[i].size(); }
+                        newIndexNameMap[reverse[thisIndex]] = i;
+                    }
+                    
+                    for (int j = indexOfGroup; j < counts[i].size(); j++) { counts[i][j].group -= 1; }
+                    
                     thisIndex++;
                 }
                 indexNameMap = newIndexNameMap;
-
+                
                 if (groups.size() == 0) { hasGroups = false; }
             }
         }else { m->mothurOut("[ERROR]: your count table does not contain group information, can not remove group " + groupName + ".\n"); m->setControl_pressed(true); }
-
+        
         return 0;
     }
-	catch(exception& e) {
-		m->errorOut(e, "CountTable", "removeGroup");
-		exit(1);
-	}
+    catch(exception& e) {
+        m->errorOut(e, "CountTable", "removeGroup");
+        exit(1);
+    }
 }
 /***********************************************************************/
 int CountTable::removeGroup(int minSize){
@@ -1479,7 +1604,7 @@ int CountTable::renameSeq(string oldSeqName, string newSeqName) {
             if (hasGroupInfo()) {
                 //look for it in names of groups to see if the user accidently used the wrong file
                 if (util.inUsersGroups(oldSeqName, groups)) {
-                    m->mothurOut("[WARNING]: Your group or design file contains a group named " + oldSeqName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group."); m->mothurOutEndLine();
+                    m->mothurOut("[WARNING]: Your group or design file contains a group named " + oldSeqName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group.\n"); 
                 }
             }
             m->mothurOut("[ERROR]: " + oldSeqName + " is not in your count table. Please correct.\n"); m->setControl_pressed(true);
@@ -1507,7 +1632,7 @@ int CountTable::getNumSeqs(string seqName) {
             if (hasGroupInfo()) {
                 //look for it in names of groups to see if the user accidently used the wrong file
                 if (util.inUsersGroups(seqName, groups)) {
-                    m->mothurOut("[WARNING]: Your group or design file contains a group named " + seqName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group."); m->mothurOutEndLine();
+                    m->mothurOut("[WARNING]: Your group or design file contains a group named " + seqName + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group.\n"); 
                 }
             }
             m->mothurOut("[ERROR]: " + seqName + " is not in your count table. Please correct.\n"); m->setControl_pressed(true);
@@ -1543,7 +1668,34 @@ int CountTable::setNumSeqs(string seqName, int abund) {
         exit(1);
     }
 }
+/************************************************************/
+int CountTable::zeroOutSeq(string seqName) {
+    try {
 
+        map<string, int>::iterator it = indexNameMap.find(seqName);
+        if (it == indexNameMap.end()) {
+            m->mothurOut("[ERROR]: " + seqName + " is not in your count table. Please correct.\n"); m->setControl_pressed(true); return -1;
+        }else {
+            int abund = totals[it->second];
+            totals[it->second] = 0;
+            total-=abund;
+            
+            if (hasGroups) {
+                int seqIndexIntoCounts = it->second;
+                for (int i = 0; i < counts[seqIndexIntoCounts].size(); i++) {
+                    totalGroups[counts[seqIndexIntoCounts][i].group] -= counts[seqIndexIntoCounts][i].abund;
+                }
+                counts[seqIndexIntoCounts].clear();
+            }
+        }
+
+        return 0;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "CountTable", "zeroOutSeq");
+        exit(1);
+    }
+}
 /************************************************************/
 //returns unique index for sequence like get in NameAssignment
 int CountTable::get(string seqName) {
@@ -1613,7 +1765,9 @@ int CountTable::remove(string seqName) {
             int seqIndexIntoCounts = it->second;
             uniques--;
             if (hasGroups){ //remove this sequences counts from group totals
-                for (int i = 0; i < counts[seqIndexIntoCounts].size(); i++) { totalGroups[counts[seqIndexIntoCounts][i].group] -= counts[seqIndexIntoCounts][i].abund; }
+                for (int i = 0; i < counts[seqIndexIntoCounts].size(); i++) {
+                    totalGroups[counts[seqIndexIntoCounts][i].group] -= counts[seqIndexIntoCounts][i].abund;
+                }
             }
             
             //save for later in case removing a group means we need to remove a seq.
@@ -1633,6 +1787,11 @@ int CountTable::remove(string seqName) {
             totals.erase(totals.begin()+seqIndexIntoCounts);
             total -= thisTotal;
             
+            //remove group if all reads are removed
+            for (int i = 0; i < totalGroups.size(); i++) {
+                if (totalGroups[i] == 0) { m->mothurOut("\nRemoving group: " + groups[i] + " because all sequences have been removed.\n"); removeGroup(groups[i]); i--; }
+            }
+            
         }else {
             if (hasGroupInfo()) {
                 //look for it in names of groups to see if the user accidently used the wrong file
@@ -1651,35 +1810,6 @@ int CountTable::remove(string seqName) {
 	}
 }
 /************************************************************/
-//remove sequences with zeroed out counts
-void CountTable::eliminateZeroSeqs() {
-    try {
-        //save for later in case removing a group means we need to remove a seq.
-        map<int, string> reverse;
-        for (map<string, int>::iterator it2 = indexNameMap.begin(); it2 !=indexNameMap.end(); it2++) { reverse[it2->second] = it2->first;  }
-        
-        int thisIndex = 0;
-        map<string, int> newIndexNameMap;
-        for (int i = 0; i < totals.size(); i++) {
-            if (totals[i] == 0) { //remove
-                counts.erase(counts.begin()+i);
-                totals.erase(totals.begin()+i);
-                --i;
-                uniques--;
-            }else {
-                string seqName = reverse[thisIndex];
-                newIndexNameMap[seqName] = i;
-            }
-            thisIndex++;
-        }
-        indexNameMap = newIndexNameMap;
-    }
-    catch(exception& e) {
-        m->errorOut(e, "CountTable", "eliminateZeroSeqs");
-        exit(1);
-    }
-}
-/************************************************************/
 //add seqeunce without group info
 int CountTable::push_back(string seqName, int thisTotal) {
     try {
@@ -1908,7 +2038,7 @@ int CountTable::mergeCounts(string seq1, string seq2) {
             if (hasGroupInfo()) {
                 //look for it in names of groups to see if the user accidently used the wrong file
                 if (util.inUsersGroups(seq1, groups)) {
-                    m->mothurOut("[WARNING]: Your group or design file contains a group named " + seq1 + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group."); m->mothurOutEndLine();
+                    m->mothurOut("[WARNING]: Your group or design file contains a group named " + seq1 + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group.\n"); 
                 }
             }
             m->mothurOut("[ERROR]: " + seq1 + " is not in your count table. Please correct.\n"); m->setControl_pressed(true);
@@ -1918,19 +2048,20 @@ int CountTable::mergeCounts(string seq1, string seq2) {
                 if (hasGroupInfo()) {
                     //look for it in names of groups to see if the user accidently used the wrong file
                     if (util.inUsersGroups(seq2, groups)) {
-                        m->mothurOut("[WARNING]: Your group or design file contains a group named " + seq2 + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group."); m->mothurOutEndLine();
+                        m->mothurOut("[WARNING]: Your group or design file contains a group named " + seq2 + ".  Perhaps you are used a group file instead of a design file? A common cause of this is using a tree file that relates your groups (created by the tree.shared command) with a group file that assigns sequences to a group.\n"); 
                     }
                 }
                 m->mothurOut("[ERROR]: " + seq2 + " is not in your count table. Please correct.\n"); m->setControl_pressed(true);
             }else {
-                //merge data
-                vector<int> countsSeq1 = expandAbunds(it->second);
-                vector<int> countsSeq2 = expandAbunds(it2->second);
+                if (hasGroupInfo()) { //if no group data then counts are empty
+                    //merge data
+                    vector<int> countsSeq1 = expandAbunds(it->second);
+                    vector<int> countsSeq2 = expandAbunds(it2->second);
                 
-                for (int i = 0; i < groups.size(); i++) { countsSeq1[i] += countsSeq2[i]; }
-                
-                counts[it->second] = compressAbunds(countsSeq1);
+                    for (int i = 0; i < groups.size(); i++) { countsSeq1[i] += countsSeq2[i]; }
                 
+                    counts[it->second] = compressAbunds(countsSeq1);
+                }
                 totals[it->second] += totals[it2->second];
                 uniques--;
                 indexNameMap.erase(it2);
