@@ -18,6 +18,7 @@
 #include "currentfile.h"
 #include "utils.hpp"
 
+
 /**************************************************************************************************/
 struct seqMatch {  //used to select top n matches
 		int seq;
@@ -46,16 +47,21 @@ inline bool compareSeqMatchesReverse (seqMatch member, seqMatch member2){ //sort
 class Database {
 
 public:
-    Database(){ longest = 0; numSeqs = 0; m = MothurOut::getInstance(); current = CurrentFile::getInstance(); }
+    Database(){ longest = 0; numSeqs = 0; m = MothurOut::getInstance();  }
+    
     virtual ~Database(){};
-	virtual void generateDB() = 0;
-    virtual void readKmerDB(ifstream&){};
-	virtual void addSequence(Sequence) = 0;  //add sequence to search engine
+    virtual void generateDB() = 0;
+    virtual void readDB(ifstream&){};
+    virtual void addSequence(Sequence) = 0;  //add sequence to search engine
+    virtual void addSequences(vector<Sequence> seqs) { for (int i = 0; i < seqs.size(); i++) { addSequence(seqs[i]); } }
+
 	virtual void setNumSeqs(int i) {	numSeqs = i; 	}
     
-    
-	virtual vector<int> findClosestSequences(Sequence*, int, vector<float>&) = 0;  // returns indexes of n closest sequences to query
+	virtual vector<int> findClosestSequences(Sequence*, int, vector<float>&) const = 0;  // returns indexes of n closest sequences to query
 	
+    virtual vector< vector<int> > get(int i, char& s) { s='x'; vector< vector<int> > blank; return blank; }
+    virtual vector<int> getIndicatorColumns() { return nullIntVector; }
+    virtual map<int, int> getFilteredIndicatorColumns(string, vector<int>&) { return nullIntMap; }
     virtual int getLongestBase() {	return longest+1;		}
     virtual vector<int> getSequencesWithKmer(int){ vector<int> filler; return filler; };
 	virtual int getReversed(int) { return 0; } 
@@ -64,10 +70,9 @@ public:
     virtual vector<int> findClosestMegaBlast(Sequence*, int, int){ vector<int> results; return results;}
 	
 protected:
-	MothurOut* m;
-    CurrentFile* current;
+    
+    MothurOut* m;
 	int numSeqs, longest;
-    std::mutex mutex;
     Utils util;
 	
 	
