@@ -9,6 +9,8 @@
 	
 class SharedSAbundVector;
 class SharedRAbundVectors;
+class SharedCLRVector;
+class SharedCLRVectors;
 class RAbundVector;
 class RAbundFloatVector;
 class SAbundVector;
