@@ -19,7 +19,7 @@ DistanceDB::DistanceDB() : Database() {
 	try {
 		templateAligned = true;  
 		templateSeqsLength = 0; 
-		distCalculator = new eachGapIgnoreTermGapDist();
+        distCalculator = new eachGapIgnoreTermGapDist(1.0);
 	}
 	catch(exception& e) {
 		m->errorOut(e, "DistanceDB", "DistanceDB");
@@ -47,7 +47,7 @@ void DistanceDB::addSequence(Sequence seq) {
 }
 /**************************************************************************************************/
 //returns indexes to top matches
-vector<int> DistanceDB::findClosestSequences(Sequence* query, int numWanted, vector<float>& Scores){
+vector<int> DistanceDB::findClosestSequences(Sequence* query, int numWanted, vector<float>& Scores) const{
 	try {
 		vector<int> topMatches;
 		Scores.clear();
