@@ -31,8 +31,8 @@ public:
 	
 	void generateDB();
 	void addSequence(Sequence);
-	vector<int> findClosestSequences(Sequence*, int, vector<float>&);
-	void readKmerDB(ifstream&);
+	vector<int> findClosestSequences(Sequence*, int, vector<float>&) const;
+	void readDB(ifstream&);
 	int getCount(int);  //returns number of sequences with that kmer number
 	vector<int> getSequencesWithKmer(int);  //returns vector of sequences that contain kmer passed in
 	int getReversed(int);  //returns reverse compliment kmerNumber 
@@ -40,6 +40,7 @@ public:
 	
 private:
 	
+    string version;
 	int kmerSize;
 	int maxKmer, count;
 	string kmerDBName;
