@@ -258,7 +258,7 @@ int Oligos::readOligos(){
 					
 					//check for repeat barcodes
 					map<string, int>::iterator itPrime = primers.find(oligo);
-					if (itPrime != primers.end()) { m->mothurOut("[WARNING]: primer " + oligo + " is in your oligos file already, disregarding."); m->mothurOutEndLine();  }
+					if (itPrime != primers.end()) { m->mothurOut("[WARNING]: primer " + oligo + " is in your oligos file already, disregarding.\n");   }
                     else {
                         if (m->getDebug()) {  if (group != "") { m->mothurOut("[DEBUG]: reading group " + group + ".\n"); }else{ m->mothurOut("[DEBUG]: no group for primer " + oligo + ".\n"); }  }
                     
@@ -298,7 +298,7 @@ int Oligos::readOligos(){
 					
 					//check for repeat barcodes
                     string tempPair = oligo+roligo;
-                    if (uniquePrimers.count(tempPair) != 0) { m->mothurOut("primer pair " + newPrimer.forward + " " + newPrimer.reverse + " is in your oligos file already, disregarding."); m->mothurOutEndLine();  }
+                    if (uniquePrimers.count(tempPair) != 0) { m->mothurOut("primer pair " + newPrimer.forward + " " + newPrimer.reverse + " is in your oligos file already, disregarding.\n");   }
                     else { uniquePrimers.insert(tempPair);
 					
                         if (m->getDebug()) {  if (group != "") { m->mothurOut("[DEBUG]: reading group " + group + ".\n"); }else{ m->mothurOut("[DEBUG]: no group for primer pair " + newPrimer.forward + " " + newPrimer.reverse + ".\n"); }  }
@@ -349,7 +349,7 @@ int Oligos::readOligos(){
                         
                         //check for repeat barcodes
                         string tempPair = oligo+reverseBarcode;
-                        if (uniqueBarcodes.count(tempPair) != 0) { m->mothurOut("barcode pair " + newPair.forward + " " + newPair.reverse +  " is in your oligos file already, disregarding."); m->mothurOutEndLine();  }
+                        if (uniqueBarcodes.count(tempPair) != 0) { m->mothurOut("barcode pair " + newPair.forward + " " + newPair.reverse +  " is in your oligos file already, disregarding.\n");  }
                         else {
                             uniqueBarcodes.insert(tempPair);
                             pairedBarcodes[indexPairedBarcode]=newPair; indexPairedBarcode++;
@@ -358,7 +358,7 @@ int Oligos::readOligos(){
                     }else {
                         //check for repeat barcodes
                         map<string, int>::iterator itBar = barcodes.find(oligo);
-                        if (itBar != barcodes.end()) { m->mothurOut("[WARNING]: barcode " + oligo + " is in your oligos file already, disregarding."); m->mothurOutEndLine();  }
+                        if (itBar != barcodes.end()) { m->mothurOut("[WARNING]: barcode " + oligo + " is in your oligos file already, disregarding.\n");   }
                         else {
                             barcodes[oligo]=indexBarcode; indexBarcode++;
                             barcodeNameVector.push_back(group);
@@ -369,7 +369,7 @@ int Oligos::readOligos(){
 				}else if(type == "SPACER"){
 					spacer.push_back(oligo);
 				}
-				else{	m->mothurOut("[WARNING]: " + type + " is not recognized as a valid type. Choices are forward, reverse, and barcode. Ignoring " + oligo + "."); m->mothurOutEndLine(); }
+				else{	m->mothurOut("[WARNING]: " + type + " is not recognized as a valid type. Choices are forward, reverse, and barcode. Ignoring " + oligo + ".\n");  }
 			}
 			util.gobble(inOligos);
 		}
@@ -392,7 +392,7 @@ int Oligos::readOligos(){
                     }
                 }
                 if (!allNONE) {
-                    m->setControl_pressed(true);  m->mothurOut("[ERROR]: cannot mix forwardBarcode=NONE and forwardBarcode=barcodeString in same file. Mothur assumes all sequences have forward barcodes or all do not, quitting."); m->mothurOutEndLine();  return 0;
+                    m->setControl_pressed(true);  m->mothurOut("[ERROR]: cannot mix forwardBarcode=NONE and forwardBarcode=barcodeString in same file. Mothur assumes all sequences have forward barcodes or all do not, quitting.\n");   return 0;
                 }
             }
             
@@ -405,7 +405,7 @@ int Oligos::readOligos(){
                     }
                 }
                 if (!allNONE) {
-                    m->setControl_pressed(true);  m->mothurOut("[ERROR]: cannot mix reverseBarcode=NONE and reverseBarcode=barcodeString in same file. Mothur assumes all sequences have reverse barcodes or all do not, quitting."); m->mothurOutEndLine();  return 0;
+                    m->setControl_pressed(true);  m->mothurOut("[ERROR]: cannot mix reverseBarcode=NONE and reverseBarcode=barcodeString in same file. Mothur assumes all sequences have reverse barcodes or all do not, quitting.\n");   return 0;
                 }
             }
             
@@ -418,7 +418,7 @@ int Oligos::readOligos(){
                     }
                 }
                 if (!allNONE) {
-                    m->setControl_pressed(true);  m->mothurOut("[ERROR]: cannot mix forwardPrimer=NONE and forwardPrimer=primerString in same file. Mothur assumes all sequences have forward primers or all do not, quitting."); m->mothurOutEndLine();  return 0;
+                    m->setControl_pressed(true);  m->mothurOut("[ERROR]: cannot mix forwardPrimer=NONE and forwardPrimer=primerString in same file. Mothur assumes all sequences have forward primers or all do not, quitting.\n");   return 0;
                 }
             }
             
@@ -431,7 +431,7 @@ int Oligos::readOligos(){
                     }
                 }
                 if (!allNONE) {
-                    m->setControl_pressed(true);  m->mothurOut("[ERROR]: cannot mix reversePrimer=NONE and reversePrimer=primerString in same file. Mothur assumes all sequences have reverse primers or all do not, quitting."); m->mothurOutEndLine();  return 0;
+                    m->setControl_pressed(true);  m->mothurOut("[ERROR]: cannot mix reversePrimer=NONE and reversePrimer=primerString in same file. Mothur assumes all sequences have reverse primers or all do not, quitting.\n");   return 0;
                 }
             }
         }
@@ -602,6 +602,47 @@ vector<string> Oligos::getPrimers(string groupName){
 }
 //********************************************************************/
 //can't have paired and unpaired so this function will either run the paired map or the unpaired
+map<int, oligosPair> Oligos::getReversedPairedPrimers(){
+    try {
+        map<int, oligosPair> rpairedPrimers;
+        
+        for (map<int, oligosPair>::iterator it = pairedPrimers.begin(); it != pairedPrimers.end(); it++) {
+            //add reverse compliment barcodes
+            string forward = reverseOligo((it->second).forward);
+            string reverse = reverseOligo((it->second).reverse);
+            
+            string temp = forward+reverse;
+            if (uniquePrimers.count(temp) != 0) { } //already have this pair assigned to a sample, ignore reversed version
+            else {
+                uniquePrimers.insert(temp);
+                oligosPair tempPair(forward, reverse); //reverseforward, reverseReverse
+                rpairedPrimers[it->first] = tempPair;
+            }
+        }
+        
+        for (map<string, int>::iterator it = primers.begin(); it != primers.end(); it++) {
+            //add reverse compliment barcodes
+            string forward = reverseOligo(it->first);
+            string reverse = "";
+            
+            string temp = forward+reverse;
+            if (uniquePrimers.count(temp) != 0) { } //already have this pair assigned to a sample, ignore reversed version
+            else {
+                uniquePrimers.insert(temp);
+                oligosPair tempPair(forward, reverse); //reverseforward, reverseReverse
+                rpairedPrimers[it->second] = tempPair;
+            }
+        }
+
+        return rpairedPrimers;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "Oligos", "getReversedPairedPrimers");
+        exit(1);
+    }
+}
+//********************************************************************/
+//can't have paired and unpaired so this function will either run the paired map or the unpaired
 map<int, oligosPair> Oligos::getReorientedPairedPrimers(){
 	try {
         map<int, oligosPair> rpairedPrimers;
@@ -630,22 +671,76 @@ map<int, oligosPair> Oligos::getReorientedPairedPrimers(){
 }
 //********************************************************************/
 //can't have paired and unpaired so this function will either run the paired map or the unpaired
+map<int, oligosPair> Oligos::getReversedPairedBarcodes(){
+    try {
+        map<int, oligosPair> rpairedBarcodes;
+        
+        for (map<int, oligosPair>::iterator it = pairedBarcodes.begin(); it != pairedBarcodes.end(); it++) {
+            //add reverse compliment barcodes
+            string forward = reverseOligo((it->second).forward);
+            string reverse = reverseOligo((it->second).reverse);
+            
+            string temp = forward+reverse;
+            if (uniqueBarcodes.count(temp) != 0) { } //already have this pair assigned to a sample, ignore reversed version
+            else {
+                uniqueBarcodes.insert(temp);
+                oligosPair tempPair(forward, reverse); //reverseforward, reverseReverse
+                rpairedBarcodes[it->first] = tempPair;
+            }
+        }
+        
+        for (map<string, int>::iterator it = barcodes.begin(); it != barcodes.end(); it++) {
+            //add reverse compliment barcodes
+            string forward = reverseOligo(it->first);
+            string reverse = "";
+            
+            string temp = forward+reverse;
+            if (uniqueBarcodes.count(temp) != 0) { } //already have this pair assigned to a sample, ignore reversed version
+            else {
+                uniqueBarcodes.insert(temp);
+                oligosPair tempPair(forward, reverse); //reverseforward, reverseReverse
+                rpairedBarcodes[it->second] = tempPair;
+            }
+        }
+
+        return rpairedBarcodes;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "Oligos", "getReversedPairedBarcodes");
+        exit(1);
+    }
+}
+//********************************************************************/
+//can't have paired and unpaired so this function will either run the paired map or the unpaired
 map<int, oligosPair> Oligos::getReorientedPairedBarcodes(){
 	try {
         map<int, oligosPair> rpairedBarcodes;
         
         for (map<int, oligosPair>::iterator it = pairedBarcodes.begin(); it != pairedBarcodes.end(); it++) {
             string forward = (it->second).reverse;
-            if (reversePairs) { forward = reverseOligo(forward); }
+            if (reversePairs) { forward = reverseOligo(forward); } //forward is now the reverse of reverse
             string reverse = (it->second).forward;
-            if (reversePairs) { reverse = reverseOligo(reverse); }
-            oligosPair tempPair(forward, reverse); //reversePrimer, rc ForwardPrimer
-            rpairedBarcodes[it->first] = tempPair;
+            if (reversePairs) { reverse = reverseOligo(reverse); } //reverse is now the reverse of forward
+            
+            //check for repeat barcodes
+            string temp = forward+reverse;
+            if (uniqueBarcodes.count(temp) != 0) { } //already have this pair assigned to a sample, ignore reoriented version
+            else {
+                uniqueBarcodes.insert(temp);
+                oligosPair tempPair(forward, reverse); //(reverse, forward) or if reversePairs (rc_reverse, rc_forward)
+                rpairedBarcodes[it->first] = tempPair;
+            }
         }
-        
+       
         for (map<string, int>::iterator it = barcodes.begin(); it != barcodes.end(); it++) {
-            oligosPair tempPair("", reverseOligo((it->first))); //reverseBarcode, rc ForwardBarcode
-            rpairedBarcodes[it->second] = tempPair;
+            string forward = ""; string reverse = reverseOligo((it->first));
+            string temp = forward+reverse;
+            
+            if (uniqueBarcodes.count(temp) != 0) { } //already have this pair assigned to a sample, ignore reoriented version
+            else { uniqueBarcodes.insert(temp);
+                oligosPair tempPair(forward, reverse); //reversePrimer, rc ForwardPrimer
+                rpairedBarcodes[it->second] = tempPair;
+            }
         }
 
         return rpairedBarcodes;
@@ -655,7 +750,6 @@ map<int, oligosPair> Oligos::getReorientedPairedBarcodes(){
 		exit(1);
 	}
 }
-
 //********************************************************************/
 string Oligos::reverseOligo(string oligo){
 	try {
