@@ -22,14 +22,14 @@ SequenceCountParser::SequenceCountParser(string countfile, string fastafile, vec
             ct.testGroups(countfile, groupsSelected); //fills groupsSelected with groups in count table
         }
         
-        inputString += "groups=" + util.getStringFromVector(groupsSelected, "-");
+        inputString += "groups=" + util.getStringFromVector(groupsSelected, "-"); //split.groups is paraplellized, we don't want the thread spinning up threads.
         inputString += ", fasta=" + fastafile;
         inputString += ", count=" + countfile;
         
         m->mothurOut("\n/******************************************/\n");
         m->mothurOut("Running command: split.groups(" + inputString + ")\n");
         
-        Command* splitCommand = new SplitGroupCommand(inputString);
+        SplitGroupCommand* splitCommand = new SplitGroupCommand(inputString);
         splitCommand->execute();
         
         //type -> files in groups order. fasta -> vector<string>. fastaFileForGroup1 stored in filenames["fasta"][1]
