@@ -30,7 +30,7 @@ SequenceParser::SequenceParser(string groupFile, string fastaFile, string nameFi
         if (groupsSelected.size() != 0) { sort(groupsSelected.begin(), groupsSelected.end());   }
         else                            { groupsSelected = namesOfGroups;                       }
         
-        inputString += "groups=" + util.getStringFromVector(groupsSelected, "-");
+        inputString += "processors=1, groups=" + util.getStringFromVector(groupsSelected, "-"); //split.groups is paraplellized, we don't want the thread spinning up threads.
         inputString += ", fasta=" + fastaFile;
         inputString += ", name=" + nameFile;
         inputString += ", group=" + groupFile;
@@ -160,89 +160,6 @@ vector<string> SequenceParser::getFiles(string group){
         exit(1);
     }
 }
-/************************************************************
-int SequenceParser::getSeqs(string g, string filename, string tag, string tag2, long long& numSeqs, string optionalGroupFileName, bool uchimeFormat=false){
-	try {
-		map<string, int>::iterator it;
-		vector<Sequence> seqForThisGroup;
-		vector<seqPriorityNode> nameVector;
-		
-        it = groupIndexMap.find(g);
-        if(it == groupIndexMap.end()) {
-            m->mothurOut("[ERROR]: No sequences available for group " + g + ", please correct.\n");
-        }else {
-
-			ofstream out;
-			util.openOutputFile(filename, out);
-			
-			seqForThisGroup = getSeqs(g);
-            
-            numSeqs = seqForThisGroup.size();
-
-			if (uchimeFormat) {
-				// format should look like 
-				//>seqName /ab=numRedundantSeqs/
-				//sequence
-				
-				map<string, string> nameMapForThisGroup = getNameMap(g);
-				map<string, string>::iterator itNameMap;
-				int error = 0;
-				
-				for (int i = 0; i < seqForThisGroup.size(); i++) {
-					itNameMap = nameMapForThisGroup.find(seqForThisGroup[i].getName());
-					
-					if (itNameMap == nameMapForThisGroup.end()){
-						error = 1;
-						m->mothurOut("[ERROR]: " + seqForThisGroup[i].getName() + " is in your fastafile, but is not in your namesfile, please correct."); m->mothurOutEndLine();
-					}else {
-						int num = util.getNumNames(itNameMap->second);
-						
-						seqPriorityNode temp(num, seqForThisGroup[i].getUnaligned(), seqForThisGroup[i].getName());
-						nameVector.push_back(temp);
-					}
-				}
-				
-				if (error == 1) { out.close(); util.mothurRemove(filename); return 1; }
-				
-				//sort by num represented
-				sort(nameVector.begin(), nameVector.end(), compareSeqPriorityNodes);
-
-				//print new file in order of
-				for (int i = 0; i < nameVector.size(); i++) {
-					
-					if(m->getControl_pressed()) { out.close(); util.mothurRemove(filename); return 1; }
-					
-					out << ">" <<  nameVector[i].name << tag << nameVector[i].numIdentical << tag2 << endl << nameVector[i].seq << endl; //
-				}
-				
-			}else {
-                
-                ofstream outGroup;
-                if (optionalGroupFileName != "") { util.openOutputFile(optionalGroupFileName, outGroup); }
-                
-				for (int i = 0; i < seqForThisGroup.size(); i++) {
-					
-					if(m->getControl_pressed()) { out.close(); util.mothurRemove(filename); return 1; }
-					
-					seqForThisGroup[i].printSequence(out);
-                    
-                    if (optionalGroupFileName != "") {  outGroup << seqForThisGroup[i].getName() << '\t' << g << endl;  }
-				}
-                
-                if (optionalGroupFileName != "") {  outGroup.close();  }
-			}
-			out.close();
-            
-		}
-		
-		return 0; 
-	}
-	catch(exception& e) {
-		m->errorOut(e, "SequenceParser", "getSeqs");
-		exit(1);
-	}
-}
 /************************************************************/
 
 
-
