@@ -531,7 +531,7 @@ int SharedRAbundFloatVectors::removeGroups(int minSize, bool silent){
         bool remove = false;
         for (vector<SharedRAbundFloatVector*>::iterator it = lookup.begin(); it != lookup.end();) {
             if ((*it)->getNumSeqs() < minSize) {
-                if (!silent) { m->mothurOut((*it)->getGroup() + " contains " + toString((*it)->getNumSeqs()) + ". Eliminating."); m->mothurOutEndLine(); }
+                if (!silent) { m->mothurOut((*it)->getGroup() + " contains " + toString((*it)->getNumSeqs()) + ". Eliminating.\n");  }
                 delete (*it); (*it) = NULL;
                 it = lookup.erase(it);
             }else {
@@ -555,6 +555,7 @@ int SharedRAbundFloatVectors::removeGroups(int minSize, bool silent){
 /**********************************************************************************************************************/
 void SharedRAbundFloatVectors::eliminateZeroOTUS() {
     try {
+        if (currentLabels.size() != numBins) { currentLabels = getOTUNames(); }
         if (lookup.size() > 1) {
             vector<int> otusToRemove;
             for (int i = 0; i < lookup[0]->getNumBins(); i++) {
