@@ -52,6 +52,12 @@ SharedRAbundVectors::SharedRAbundVectors(ifstream& f, vector<string>& userGroups
                 }
                 
                 f >> label >> groupN >> num;
+                
+                if (currentLabels.size() != 0) {
+                    if (currentLabels.size() != num) {
+                        m->mothurOut("[ERROR]: your shared file contains " + toString(currentLabels.size()) + " OTU labels, but your numOtus column indicates " + toString(num) + ". Cannot continue, please correct. This can be caused by editing your file incorrectly outside of mothur.\n"); m->setControl_pressed(true);
+                    }
+                }
             }else {
                 //read in first row since you know there is at least 1 group.
                 f >> groupN >> num;
@@ -101,7 +107,9 @@ SharedRAbundVectors::SharedRAbundVectors(ifstream& f, vector<string>& userGroups
         util.gobble(f);
 
         
-        if (!(f.eof())) { f >> nextLabel; }
+        if (!(f.eof())) {
+            f >> nextLabel;
+        }
         
         //read the rest of the groups info in
         while ((nextLabel == holdLabel) && (f.eof() != true)) {
@@ -153,6 +161,34 @@ void SharedRAbundVectors::print(ostream& output, bool& printOTUHeaders){
     }
 }
 /***********************************************************************/
+void SharedRAbundVectors::printTidy(ostream& output, bool& printOTUHeaders, bool keepZero){
+    try {
+        vector<string> otuLabels = getOTUNames();
+        
+        if (printOTUHeaders) {  output << "label\tsample\tOTU\tabundance\n"; printOTUHeaders = false;  }
+        
+        sort(lookup.begin(), lookup.end(), compareRAbunds);
+        
+        for (int i = 0; i < lookup.size(); i++) {
+            if (m->getControl_pressed()) { break; }
+            
+            vector<int> data = lookup[i]->get();
+            string thisGroup = lookup[i]->getGroup();
+            
+            //if keepzero=false, zeroed otus are not outputted
+            for (int j = 0; j < data.size(); j++) {
+                if ((data[j] != 0) || (keepZero)) {
+                    output << label << '\t' << thisGroup << '\t' << otuLabels[j] << '\t' << data[j] << endl;
+                }
+            }
+        }
+    }
+    catch(exception& e) {
+        m->errorOut(e, "SharedRAbundVectors", "printTidy");
+        exit(1);
+    }
+}
+/***********************************************************************/
 void SharedRAbundVectors::setOTUNames(vector<string> names){
     try {
         currentLabels.clear();
@@ -472,7 +508,7 @@ SharedOrderVector SharedRAbundVectors::getSharedOrderVector(){
             for (int j = 0; j < lookup[i]->getNumBins(); j++) {
                 int abund = lookup[i]->get(j);
                 if (abund != 0) {
-                    for (int k = 0; k < abund; k++) {  order.push_back(j, j, lookup[i]->getGroup());  }
+                    for (int k = 0; k < abund; k++) {  order.push_back(j, lookup[i]->getGroup());  }
                 }
             }
         }
@@ -561,9 +597,6 @@ vector<SharedRAbundVector*> SharedRAbundVectors::getSharedRAbundVectors(){
             if (m->getControl_pressed()) { return newLookup; }
             SharedRAbundVector* temp = new SharedRAbundVector(*lookup[i]);
             newLookup.push_back(temp);
-            if (temp->getNumBins() != numBins) {
-                cout << temp->getGroup() << '\t' << temp->getNumBins() << '\t' << lookup[i]->getNumBins() << '\t' << numBins << endl;
-            }
         }
         
         return newLookup;
@@ -640,13 +673,25 @@ SAbundVector SharedRAbundVectors::getSAbundVector(){
         return rav.getSAbundVector();
     }
     catch(exception& e) {
-        m->errorOut(e, "SharedRAbundVector", "getSharedRAbundVectors");
+        m->errorOut(e, "SharedRAbundVector", "getSAbundVector");
+        exit(1);
+    }
+}
+/***********************************************************************/
+SAbundVector SharedRAbundVectors::getSAbundVector(string group){
+    try {
+        RAbundVector rav = getRAbundVector(group);
+        return rav.getSAbundVector();
+    }
+    catch(exception& e) {
+        m->errorOut(e, "SharedRAbundVector", "getSAbundVector");
         exit(1);
     }
 }
 /**********************************************************************************************************************/
 void SharedRAbundVectors::eliminateZeroOTUS() {
     try {
+        if (currentLabels.size() != numBins) { currentLabels = getOTUNames(); }
         if (lookup.size() > 1) {
             vector<int> otusToRemove;
             for (int i = 0; i < lookup[0]->getNumBins(); i++) {
