@@ -358,7 +358,7 @@ void Tree::getSubTree(Tree* Ctree, vector<string> seqs) {
 	}
 }
 /*****************************************************************/
-int Tree::pruneNewTree(Tree* copy, vector<string> namesToInclude) {
+void Tree::pruneNewTree(Tree* copy, vector<string> namesToInclude) {
     try {
         
         Utils util;
@@ -964,7 +964,7 @@ try {
                     outputString += ":" + toString(tree[node].getBranchLength());
                 }
                 
-                m->mothurOut("[ERROR]: " + tree[node].getName() + " is not in your namefile, please correct."); m->mothurOutEndLine(); 
+                m->mothurOut("[ERROR]: " + tree[node].getName() + " is not in your namefile, please correct.\n");  
             }
                 
             out << outputString;
