@@ -12,6 +12,7 @@
 #include "listvector.hpp"
 #include "rabundvector.hpp"
 #include "sharedrabundvectors.hpp"
+#include "sharedclrvectors.hpp"
 
 /***********************************************************************/
 
@@ -663,6 +664,74 @@ SharedRAbundFloatVectors* InputData::getSharedRAbundFloatVectors(string label){
 	}
 }
 /***********************************************************************/
+//this is used when you don't need the order vector
+SharedCLRVectors* InputData::getSharedCLRVectors(){
+    try {
+        if(fileHandle){
+            if (format == "clrfile")  {
+                SharedCLRVectors* SharedCLR = new SharedCLRVectors(fileHandle, groups, nextDistanceLabel, otuTag);
+                if (SharedCLR->getNumBins() == 0) { delete SharedCLR; SharedCLR = NULL;  } //no valid groups
+                else { //pass labels to others distances in file
+                    if (currentLabels.size() == 0) { currentLabels = SharedCLR->getOTUNames(); }
+                    else { SharedCLR->setOTUNames(currentLabels);  }
+                }
+                return SharedCLR;
+            }
+            util.gobble(fileHandle);
+        }
+                
+        //this is created to signal to calling function that the input file is at eof
+        SharedCLRVectors* null;  null = (NULL);
+        return null;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "InputData", "getSharedCLRVectors");
+        exit(1);
+    }
+}
+/***********************************************************************/
+SharedCLRVectors* InputData::getSharedCLRVectors(string label){
+    try {
+        ifstream in;
+        string  thisLabel;
+        
+        util.openInputFile(filename, in);
+        nextDistanceLabel = "";
+        
+        if(in){
+            if (format == "clrfile")  {
+                while (!in.eof()) {
+                    
+                    SharedCLRVectors* SharedCLR = new SharedCLRVectors(in, groups, nextDistanceLabel, otuTag);
+                    if (SharedCLR != NULL) {
+                        thisLabel = SharedCLR->getLabel();
+                        
+                        if (SharedCLR->getNumBins() == 0) { delete SharedCLR; SharedCLR = NULL; break;  } //no valid groups
+                        
+                        //pass labels to others distances in file
+                        if (currentLabels.size() == 0) { currentLabels = SharedCLR->getOTUNames(); }
+                        else { SharedCLR->setOTUNames(currentLabels);  }
+                        //if you are at the last label
+                        if (thisLabel == label) {  in.close(); return SharedCLR;  }
+                        else { delete SharedCLR; }
+                    }else{  break;  }
+                    util.gobble(in);
+                }
+            }
+        }
+        
+        //this is created to signal to calling function that the input file is at eof
+        SharedCLRVectors* null;  null = (NULL);
+        in.close();
+        return null;
+    
+    }
+    catch(exception& e) {
+        m->errorOut(e, "InputData", "getSharedCLRVectors");
+        exit(1);
+    }
+}
+/***********************************************************************/
 
 SAbundVector* InputData::getSAbundVector(){
 	try {
