@@ -27,37 +27,38 @@ MothurMetastats::MothurMetastats(double t, int n) {
 MothurMetastats::~MothurMetastats() {}
 /***********************************************************/
  //main metastats function
-int MothurMetastats::runMetastats(string outputFileName, vector< vector<double> >& data, int secGroupingStart, vector<string> currentLabels) {
+int MothurMetastats::runMetastats(string outputFileName, vector< vector<double> >& data, int secGroupingStart, vector<string> currentLabels, bool fillProps) {
     try {
          
-        row = data.size();		 //numBins
-		column = data[0].size(); //numGroups in subset
+        numOTUs = data.size();		 //numBins
+		numSamples = data[0].size(); //numGroups in subset
         secondGroupingStart = secGroupingStart; //g number of samples in group 1
          
-        vector< vector<double> > Pmatrix; Pmatrix.resize(row);
-        for (int i = 0; i < row; i++) { Pmatrix[i].resize(column, 0.0);  } // the relative proportion matrix
-        vector< vector<double> > C1; C1.resize(row);
-        for (int i = 0; i < row; i++) { C1[i].resize(3, 0.0);  } // statistic profiles for class1 and class 2
-        vector< vector<double> > C2; C2.resize(row);            // mean[1], variance[2], standard error[3] 
-        for (int i = 0; i < row; i++) { C2[i].resize(3, 0.0);  } 
-        vector<double> T_statistics; T_statistics.resize(row, 1); // a place to store the true t-statistics 
-        vector<double> pvalues; pvalues.resize(row, 1); // place to store pvalues
+        vector< vector<double> > Pmatrix; Pmatrix.resize(numOTUs);
+        for (int i = 0; i < numOTUs; i++) { Pmatrix[i].resize(numSamples, 0.0);  } // the relative proportion matrix
+        vector< vector<double> > C1; C1.resize(numOTUs);
+        for (int i = 0; i < numOTUs; i++) { C1[i].resize(3, 0.0);  } // statistic profiles for class1 and class 2
+        vector< vector<double> > C2; C2.resize(numOTUs);            // mean[1], variance[2], standard error[3]
+        for (int i = 0; i < numOTUs; i++) { C2[i].resize(3, 0.0);  }
+        vector<double> T_statistics; T_statistics.resize(numOTUs, 1); // a place to store the true t-statistics
+        vector<double> pvalues; pvalues.resize(numOTUs, 1); // place to store pvalues
        
         //*************************************
         //      convert to proportions
         //      generate Pmatrix
         //*************************************
-        vector<double> totals; totals.resize(column, 0); // sum of columns
+        vector<double> totals; totals.resize(numSamples, 0); // sum of numSampless / samples -> numSeqs for each sample
         //total[i] = total abundance for group[i]
-		for (int i = 0; i < column; i++) {
-			for (int j = 0; j < row; j++) {
+		for (int i = 0; i < numSamples; i++) { //each sample
+			for (int j = 0; j < numOTUs; j++) { //each otu
 				totals[i] += data[j][i];
 			}
         }
         
-        for (int i = 0; i < column; i++) {
-			for (int j = 0; j < row; j++) {
-				Pmatrix[j][i] = data[j][i]/totals[i];
+        for (int i = 0; i < numSamples; i++) {  //sample
+			for (int j = 0; j < numOTUs; j++) { //otu
+                if (fillProps) {  Pmatrix[j][i] = data[j][i]/totals[i]; }
+                else           {  Pmatrix[j][i] = data[j][i];           }
 			}
         }
         
@@ -65,7 +66,7 @@ int MothurMetastats::runMetastats(string outputFileName, vector< vector<double>
         //# ************************** STATISTICAL TESTING ********************************
         //#********************************************************************************
         
-        if (column == 2){  //# then we have a two sample comparison
+        if (numSamples == 2){  //# then we have a two sample comparison
             //#************************************************************
             //#  generate p values fisher's exact test
             //#************************************************************
@@ -74,21 +75,22 @@ int MothurMetastats::runMetastats(string outputFileName, vector< vector<double>
             for (int i = 0; i < secondGroupingStart; i++) { total1 += totals[i]; }
             
             //total for second grouping
-            for (int i = secondGroupingStart; i < column; i++) { total2 += totals[i]; }
+            for (int i = secondGroupingStart; i < numSamples; i++) { total2 += totals[i]; }
             
-            vector<double> fish;	fish.resize(row, 0.0);
-			vector<double> fish2;	fish2.resize(row, 0.0);
+            vector<double> fish;	fish.resize(numOTUs, 0.0);
+			vector<double> fish2;	fish2.resize(numOTUs, 0.0);
             //vector<string> currentLabels = m->getCurrentSharedBinLabels();
-			for(int i = 0; i < row; i++){
+			for(int i = 0; i < numOTUs; i++){ //numBins
 				
 				for(int j = 0; j < secondGroupingStart; j++)		{ fish[i] += data[i][j];	}
-				for(int j = secondGroupingStart; j < column; j++)	{ fish2[i] += data[i][j];	}
+				for(int j = secondGroupingStart; j < numSamples; j++)	{ fish2[i] += data[i][j];	}
 				
 				double f11, f12, f21, f22;
-				f11 = fish[i];
-				f12 = fish2[i];
-				f21 = total1 - fish[i];
-				f22 = total2 - fish2[i];
+                f11 = fish[i];
+                f12 = fish2[i];
+                f21 = total1 - fish[i];
+                f22 = total2 - fish2[i];
+                if (fillProps) {   f11 = floor(f11);  f12 = floor(f12); f21 = floor(f21); f22 = floor(f22); }
 				
 				MothurFisher fisher;
 				double pre = fisher.fexact(f11, f12, f21, f22, currentLabels[i]);
@@ -104,37 +106,37 @@ int MothurMetastats::runMetastats(string outputFileName, vector< vector<double>
             //#*************************************
             //#  generate statistics mean, var, stderr    
             //#*************************************
-            for(int i = 0; i < row; i++){ // for each taxa
+            for(int i = 0; i < numOTUs; i++){ // for each taxa
                 //# find the mean of each group
                 double g1Total = 0.0; double g2Total = 0.0;
                 for (int j = 0; j < secondGroupingStart; j++)       {     g1Total += Pmatrix[i][j]; }
                 C1[i][0] = g1Total/(double)(secondGroupingStart);
-                for (int j = secondGroupingStart; j < column; j++)  {     g2Total += Pmatrix[i][j]; }
-                C2[i][0] = g2Total/(double)(column-secondGroupingStart);
+                for (int j = secondGroupingStart; j < numSamples; j++)  {     g2Total += Pmatrix[i][j]; }
+                C2[i][0] = g2Total/(double)(numSamples-secondGroupingStart);
                 
                  //# find the variance of each group
                 double g1Var = 0.0; double g2Var = 0.0;
                 for (int j = 0; j < secondGroupingStart; j++)       {     g1Var += pow((Pmatrix[i][j]-C1[i][0]), 2);  }
                 C1[i][1] = g1Var/(double)(secondGroupingStart-1);
-                for (int j = secondGroupingStart; j < column; j++)  {     g2Var += pow((Pmatrix[i][j]-C2[i][0]), 2);  }
-                C2[i][1] = g2Var/(double)(column-secondGroupingStart-1);
+                for (int j = secondGroupingStart; j < numSamples; j++)  {     g2Var += pow((Pmatrix[i][j]-C2[i][0]), 2);  }
+                C2[i][1] = g2Var/(double)(numSamples-secondGroupingStart-1);
                 
                 //# find the std error of each group -std err^2 (will change to std err at end)
                 C1[i][2] = C1[i][1]/(double)(secondGroupingStart);    
-                C2[i][2] = C2[i][1]/(double)(column-secondGroupingStart);
+                C2[i][2] = C2[i][1]/(double)(numSamples-secondGroupingStart);
             }
             
             //#*************************************
             //#  two sample t-statistics
             //#*************************************
-            for(int i = 0; i < row; i++){                  // # for each taxa
+            for(int i = 0; i < numOTUs; i++){                  // # for each taxa
                 double xbar_diff = C1[i][0] - C2[i][0]; 
                 double denom = sqrt(C1[i][2] + C2[i][2]);
                 T_statistics[i] = xbar_diff/denom;  // calculate two sample t-statistic
             }
             
             if (m->getDebug()) {
-                for (int i = 0; i < row; i++) {
+                for (int i = 0; i < numOTUs; i++) {
                     for (int j = 0; j < 3; j++) {
                         cout << "C1[" << i+1 << "," << j+1 << "]=" << C1[i][j] << ";" << endl;
                         cout << "C2[" << i+1 << "," << j+1 << "]=" << C2[i][j] << ";" << endl;
@@ -142,8 +144,8 @@ int MothurMetastats::runMetastats(string outputFileName, vector< vector<double>
                     cout << "T_statistics[" << i+1 << "]=" << T_statistics[i] << ";" << endl;
                 }
                 
-                for (int i = 0; i < row; i++) {
-                    for (int j = 0; j < column; j++) {
+                for (int i = 0; i < numOTUs; i++) {
+                    for (int j = 0; j < numSamples; j++) {
                         cout << "Fmatrix[" << i+1 << "," << j+1 << "]=" << data[i][j] << ";" << endl;
                     }
                 }
@@ -153,7 +155,7 @@ int MothurMetastats::runMetastats(string outputFileName, vector< vector<double>
             //#*************************************
             pvalues = permuted_pvalues(Pmatrix, T_statistics, data);
             
-            if (m->getDebug()) {   for (int i = 0; i < row; i++) { m->mothurOut("[DEBUG]: " + currentLabels[i] + " pvalue = " + toString(pvalues[i]) + "\n"); } }
+            if (m->getDebug()) {   for (int i = 0; i < numOTUs; i++) { m->mothurOut("[DEBUG]: " + currentLabels[i] + " pvalue = " + toString(pvalues[i]) + "\n"); } }
             
             //#*************************************
             //#  generate p values for sparse data 
@@ -161,27 +163,28 @@ int MothurMetastats::runMetastats(string outputFileName, vector< vector<double>
             //#*************************************
             double total1, total2; total1 = 0; total2 = 0;
 			//total for first grouping
-            for (int i = 0; i < secondGroupingStart; i++) { total1 += totals[i];  }
+            for (int i = 0; i < secondGroupingStart; i++) { total1 += totals[i];  } //total all seqs in first set
             
             //total for second grouping
-            for (int i = secondGroupingStart; i < column; i++) { total2 += totals[i];  }
+            for (int i = secondGroupingStart; i < numSamples; i++) { total2 += totals[i];  } //total all seqs in second set
             
-            vector<double> fish;	fish.resize(row, 0.0);
-			vector<double> fish2;	fish2.resize(row, 0.0);
+            vector<double> fish;	fish.resize(numOTUs, 0.0);
+			vector<double> fish2;	fish2.resize(numOTUs, 0.0);
             
-			for(int i = 0; i < row; i++){
+			for(int i = 0; i < numOTUs; i++){ //numBins
 				
 				for(int j = 0; j < secondGroupingStart; j++)		{ fish[i] += data[i][j];	}
-				for(int j = secondGroupingStart; j < column; j++)	{ fish2[i] += data[i][j];	}
+				for(int j = secondGroupingStart; j < numSamples; j++)	{ fish2[i] += data[i][j];	}
                 
-                if ((fish[i] < secondGroupingStart) && (fish2[i] < (column-secondGroupingStart))) {
+                if ((fish[i] < secondGroupingStart) && (fish2[i] < (numSamples-secondGroupingStart))) {
     
                     double f11, f12, f21, f22;
-                    f11 = fish[i];
-                    f12 = fish2[i];
-                    f21 = total1 - fish[i];
-                    f22 = total2 - fish2[i];
-				
+                    f11 = fish[i];  if (f11 < 0) { f11 *= -1.0; } f11 = floor(f11);
+                    f12 = fish2[i]; if (f12 < 0) { f12 *= -1.0; } f12 = floor(f11);
+                    f21 = total1 - fish[i]; if (f21 < 0) { f21 *= -1.0; } f21 = floor(f21);
+                    f22 = total2 - fish2[i]; if (f22 < 0) { f22 *= -1.0; } f22 = floor(f22);
+                    if (fillProps) {   f11 = floor(f11);  f12 = floor(f12); f21 = floor(f21); f22 = floor(f22); }
+                    
                     MothurFisher fisher;
                     if (m->getDebug()) {    m->mothurOut("[DEBUG]: about to run fisher for Otu " + currentLabels[i] + " F11, F12, F21, F22 = " + toString(f11) + " " + toString(f12) + " " + toString(f21) + " " + toString(f22) + " " + "\n"); }
                     
@@ -199,7 +202,7 @@ int MothurMetastats::runMetastats(string outputFileName, vector< vector<double>
             //#*************************************
             //#  convert stderr^2 to std error
             //#*************************************
-            for(int i = 0; i < row; i++){
+            for(int i = 0; i < numOTUs; i++){
                 C1[i][2] = sqrt(C1[i][2]);
                 C2[i][2] = sqrt(C2[i][2]);
             }
@@ -215,13 +218,13 @@ int MothurMetastats::runMetastats(string outputFileName, vector< vector<double>
 		out.setf(ios::fixed, ios::floatfield); out.setf(ios::showpoint);
         
 		out << "Local time and date of test: " << asctime(local) << endl;
-		out << "# rows = " << row << ", # col = " << column << ", g = " << secondGroupingStart << endl << endl;
+		out << "# numOTUss = " << numOTUs << ", # col = " << numSamples << ", g = " << secondGroupingStart << endl << endl;
 		out << numPermutations << " permutations" << endl << endl;	
 		
-		//output column headings - not really sure... documentation labels 9 columns, there are 10 in the output file
+		//output numSamples headings - not really sure... documentation labels 9 numSampless, there are 10 in the output file
 		//storage 0 = meanGroup1 - line 529, 1 = varGroup1 - line 532, 2 = err rate1 - line 534, 3 = mean of counts group1?? - line 291, 4 = meanGroup2 - line 536, 5 = varGroup2 - line 539, 6 = err rate2 - line 541, 7 = mean of counts group2?? - line 292, 8 = pvalues - line 293
 		out << "OTU\tmean(group1)\tvariance(group1)\tstderr(group1)\tmean(group2)\tvariance(group2)\tstderr(group2)\tp-value\n";
-		for(int i = 0; i < row; i++){
+		for(int i = 0; i < numOTUs; i++){
 			if (m->getControl_pressed()) { out.close(); return 0; }
 			
             //if there are binlabels use them otherwise count.
@@ -229,13 +232,12 @@ int MothurMetastats::runMetastats(string outputFileName, vector< vector<double>
             else { out << (i+1) << '\t'; }
             
             out << C1[i][0] << '\t' << C1[i][1] << '\t' << C1[i][2] << '\t' << C2[i][0] << '\t' << C2[i][1] << '\t' << C2[i][2] << '\t' << pvalues[i] <<  endl;
+            
+            //if (pvalues[i] < 0.05) { cout << currentLabels[i] << endl; }
 		}  
 		
-		out << endl << endl;
-		out.close();
+		out << endl << endl; out.close();
 		
-
-
         return 0;
         
     }catch(exception& e) {
@@ -246,10 +248,10 @@ int MothurMetastats::runMetastats(string outputFileName, vector< vector<double>
 /***********************************************************/
 vector<double> MothurMetastats::permuted_pvalues(vector< vector<double> >& Imatrix, vector<double>& tstats, vector< vector<double> >& Fmatrix) {
 	try {
-        //# matrix stores tstats for each taxa(row) for each permuted trial(column)
-        vector<double> ps;  ps.resize(row, 0.0); //# to store the pvalues
+        //# matrix stores tstats for each taxa(numOTUs) for each permuted trial(numSamples)
+        vector<double> ps;  ps.resize(numOTUs, 0.0); //# to store the pvalues
         vector< vector<double> > permuted_ttests; permuted_ttests.resize(numPermutations);            
-        for (int i = 0; i < numPermutations; i++) { permuted_ttests[i].resize(row, 0.0);  } 
+        for (int i = 0; i < numPermutations; i++) { permuted_ttests[i].resize(numOTUs, 0.0);  }
  
         //# calculate null version of tstats using B permutations.
         for (int i = 0; i < numPermutations; i++) {   
@@ -257,24 +259,24 @@ vector<double> MothurMetastats::permuted_pvalues(vector< vector<double> >& Imatr
         }
         
         //# calculate each pvalue using the null ts
-        if ((secondGroupingStart) < 8 || (column-secondGroupingStart) < 8){
+        if ((secondGroupingStart) < 8 || (numSamples-secondGroupingStart) < 8){
             vector< vector<double> > cleanedpermuted_ttests; cleanedpermuted_ttests.resize(numPermutations);  //# the array pooling just the frequently observed ts
             //# then pool the t's together!
             //# count how many high freq taxa there are
             int hfc = 1;
-            for (int i = 0; i < row; i++) {                 // # for each taxa
+            for (int i = 0; i < numOTUs; i++) {                 // # for each taxa
                 double group1Total = 0.0; double group2Total = 0.0;
                 for(int j = 0; j < secondGroupingStart; j++)		{ group1Total += Fmatrix[i][j];	}
-				for(int j = secondGroupingStart; j < column; j++)	{ group2Total += Fmatrix[i][j];	}
+				for(int j = secondGroupingStart; j < numSamples; j++)	{ group2Total += Fmatrix[i][j];	}
                 
-                if (group1Total >= secondGroupingStart || group2Total >= (column-secondGroupingStart)){ 
+                if (group1Total >= secondGroupingStart || group2Total >= (numSamples-secondGroupingStart)){
                     hfc++;
                     for (int j = 0; j < numPermutations; j++) {   cleanedpermuted_ttests[j].push_back(permuted_ttests[j][i]); }
                 }
             }
             
             //#now for each taxa
-            for (int i = 0; i < row; i++) { 
+            for (int i = 0; i < numOTUs; i++) {
                 //number of cleanedpermuted_ttests greater than tstat[i]
                 int numGreater = 0;
                 for (int j = 0; j < numPermutations; j++) {
@@ -286,7 +288,7 @@ vector<double> MothurMetastats::permuted_pvalues(vector< vector<double> >& Imatr
                 ps[i] = (1/(double)(numPermutations*hfc))*numGreater;
             }
         }else{
-            for (int i = 0; i < row; i++) { 
+            for (int i = 0; i < numOTUs; i++) {
                 //number of permuted_ttests[i] greater than tstat[i] //(sum(permuted_ttests[i,] > abs(tstats[i]))+1)
                 int numGreater = 1;
                 for (int j = 0; j < numPermutations; j++) { if (permuted_ttests[j][i] > abs(tstats[i])) { numGreater++; }   }
@@ -306,41 +308,41 @@ vector<double> MothurMetastats::permute_and_calc_ts(vector< vector<double> >& Im
 	try {
         vector< vector<double> > permutedMatrix = Imatrix;
         
-        //randomize columns, ie group abundances.
+        //randomize numSampless, ie group abundances.
         map<int, int> randomMap;
         vector<int> randoms;
-        for (int i = 0; i < column; i++) { randoms.push_back(i); }
+        for (int i = 0; i < numSamples; i++) { randoms.push_back(i); }
         util.mothurRandomShuffle(randoms);
         for (int i = 0; i < randoms.size(); i++) {   randomMap[i] = randoms[i];   }
         
         //calc ts
-        vector< vector<double> > C1; C1.resize(row);
-        for (int i = 0; i < row; i++) { C1[i].resize(3, 0.0);  } // statistic profiles for class1 and class 2
-        vector< vector<double> > C2; C2.resize(row);            // mean[1], variance[2], standard error[3] 
-        for (int i = 0; i < row; i++) { C2[i].resize(3, 0.0);  } 
-        vector<double> Ts; Ts.resize(row, 0.0); // a place to store the true t-statistics 
+        vector< vector<double> > C1; C1.resize(numOTUs);
+        for (int i = 0; i < numOTUs; i++) { C1[i].resize(3, 0.0);  } // statistic profiles for class1 and class 2
+        vector< vector<double> > C2; C2.resize(numOTUs);            // mean[1], variance[2], standard error[3]
+        for (int i = 0; i < numOTUs; i++) { C2[i].resize(3, 0.0);  }
+        vector<double> Ts; Ts.resize(numOTUs, 0.0); // a place to store the true t-statistics
 
         //#*************************************
         //#  generate statistics mean, var, stderr    
         //#*************************************
-        for(int i = 0; i < row; i++){ // for each taxa
+        for(int i = 0; i < numOTUs; i++){ // for each taxa
             //# find the mean of each group
             double g1Total = 0.0; double g2Total = 0.0;
             for (int j = 0; j < secondGroupingStart; j++)       {     g1Total += permutedMatrix[i][randomMap[j]]; }
             C1[i][0] = g1Total/(double)(secondGroupingStart);
-            for (int j = secondGroupingStart; j < column; j++)  {     g2Total += permutedMatrix[i][randomMap[j]]; }
-            C2[i][0] = g2Total/(double)(column-secondGroupingStart);
+            for (int j = secondGroupingStart; j < numSamples; j++)  {     g2Total += permutedMatrix[i][randomMap[j]]; }
+            C2[i][0] = g2Total/(double)(numSamples-secondGroupingStart);
             
             //# find the variance of each group
             double g1Var = 0.0; double g2Var = 0.0;
             for (int j = 0; j < secondGroupingStart; j++)       {     g1Var += pow((permutedMatrix[i][randomMap[j]]-C1[i][0]), 2);  }
             C1[i][1] = g1Var/(double)(secondGroupingStart-1);
-            for (int j = secondGroupingStart; j < column; j++)  {     g2Var += pow((permutedMatrix[i][randomMap[j]]-C2[i][0]), 2);  }
-            C2[i][1] = g2Var/(double)(column-secondGroupingStart-1);
+            for (int j = secondGroupingStart; j < numSamples; j++)  {     g2Var += pow((permutedMatrix[i][randomMap[j]]-C2[i][0]), 2);  }
+            C2[i][1] = g2Var/(double)(numSamples-secondGroupingStart-1);
             
             //# find the std error of each group -std err^2 (will change to std err at end)
             C1[i][2] = C1[i][1]/(double)(secondGroupingStart);    
-            C2[i][2] = C2[i][1]/(double)(column-secondGroupingStart);
+            C2[i][2] = C2[i][1]/(double)(numSamples-secondGroupingStart);
         }
         
         
@@ -348,7 +350,7 @@ vector<double> MothurMetastats::permute_and_calc_ts(vector< vector<double> >& Im
         //#*************************************
         //#  two sample t-statistics
         //#*************************************
-        for(int i = 0; i < row; i++){                  // # for each taxa
+        for(int i = 0; i < numOTUs; i++){                  // # for each taxa
             double xbar_diff = C1[i][0] - C2[i][0]; 
             double denom = sqrt(C1[i][2] + C2[i][2]);
             Ts[i] = abs(xbar_diff/denom);  // calculate two sample t-statistic
