@@ -1,8 +1,6 @@
 #ifndef MOTHUR_H
 #define MOTHUR_H
 
-
-
 /*
  *  mothur.h
  *  Mothur
@@ -33,13 +31,11 @@
 #include <sstream>
 #include <signal.h>
 
-
 //exception
 #include <stdexcept>
 #include <exception>
 #include <cstdlib> 
 
-
 //containers
 #include <vector>
 #include <set>
@@ -144,23 +140,83 @@ using namespace std;
 #define EXECUTABLE_EXT ".exe"
 #define WINDOWS
 #undef NON_WINDOWS
+#define M_PI 3.14159265358979323846264338327950288
 
 #endif
 
 #define MOTHURMAX 1e6
 
-
 typedef unsigned long ull;
 typedef unsigned short intDist;
 const vector<string> nullVector; //used to pass blank vector
+const vector<int> nullIntVector; //used to pass blank ints
+const vector<char> nullCharVector; //used to pass blank char
+const map<int, int> nullIntMap;
 
+/**************************************************************************************************/
+struct classifierOTU {
+    vector<vector<char> > otuData; //otuData[0] -> vector of first characters from each sequence in the OTU, otuData[1] -> vector of second characters from each sequence in the OTU
+    int numSeqs;
+    
+    /*
+     otuData.size = num columns in seq's alignment
+     otuData[i].size() = numSeqs in otu
+     
+     seq1 > atgcaag
+     seq2 > gacctga
+     seq3 > cctgacg
+     
+     otuData[0] > {a,g,c}
+     otuData[1] > {t,a,c}
+     otuData[2] > {g,c,t}
+     
+     otuData[i] > {charInAllCols} if all chars in otuData[i] are identical. ie, ignore column
+     otuData[i] > {a} all seqs contain 'a' in column i of alignment
+     */
+    classifierOTU(){ numSeqs = 0; }
+    classifierOTU(string aligned) {
+        for (int i = 0; i < aligned.length(); i++) {
+            vector<char> thisSpot;
+            thisSpot.push_back(aligned[i]);
+            
+            otuData.push_back(thisSpot);
+        }
+        numSeqs = 1;
+    }
+    classifierOTU(vector<string> otu) { readSeqs(otu); }
+    classifierOTU(vector<vector<char> > otu, int num) : otuData(otu), numSeqs(num) {}
+    
+    void readSeqs(vector<vector<char> > otu, int num) { otuData = otu; numSeqs = num; } //for shortcut files
+    
+    void readSeqs(vector<string> otu) {
+        int alignedLength = 0;
+        bool error = false;
+        if (otu.size() != 0) { alignedLength = otu[0].length(); }
+        for (int j = 0; j < otu.size(); j++) { if (otu[j].length() != alignedLength) { error = true;} }
+        
+        if (!error) {
+            
+            for (int i = 0; i < alignedLength; i++) {
+                vector<char> thisSpot; set<char> thisChars;
+                for (int j = 0; j < otu.size(); j++) {
+                    thisSpot.push_back(otu[j][i]);
+                    thisChars.insert(otu[j][i]);
+                }
+                if (thisChars.size() == 1) { thisSpot.clear(); thisSpot.push_back(*thisChars.begin()); }// all same, reduce to 1.
+                otuData.push_back(thisSpot);
+            }
+            numSeqs = otu.size();
+        }else {  numSeqs = 0; }
+    }
+};
 //******************************************************
 struct mcmcSample {
-    double alpha, beta;
+    double alpha, beta; //dmDash, dV
+    double dNu;
     int ns;
     
     mcmcSample() {}
-    mcmcSample(double a, double b, int n) : alpha(a), beta(b), ns(n) {}
+    mcmcSample(double a, double b, double d, int n) : alpha(a), beta(b), dNu(d), ns(n) {}
     
 };
 typedef struct s_Params
@@ -209,11 +265,13 @@ typedef struct s_LSParams
     
     double dNu;
     
+    double dC;
+    
     int n;
     
 } t_LSParams;
 
-typedef struct s_IGParams
+typedef struct s_IGParams //s_SIParams
 {
     int    nS;      /*number of species in community*/
     
@@ -221,7 +279,7 @@ typedef struct s_IGParams
     
     double dBeta;
     
-    double dC;
+    double dC; //dGamma
     
     int n;
     
@@ -246,8 +304,7 @@ typedef struct s_MetroInit
 
 #endif
 
-//******************************************************
-
+//***********************************************************************
 struct IntNode {
 	int lvalue;
 	int rvalue;
@@ -322,7 +379,7 @@ struct PCell{
 struct PDistCellMin{
     ull row;
     ull col;
-    //PDistCell* cell;
+    
     PDistCellMin(ull r, ull c) :  col(c), row(r) {}
 };
 /***********************************************************************/
@@ -345,55 +402,12 @@ struct seqPNode {
     seqPNode(string na, string seq, int n, vector<int> nm) : numIdentical(n), name(na), sequence(seq), clusteredIndexes(nm) { diffs = 0; }
     ~seqPNode() {}
 };
-/**********************************************************/
-struct CommonHeader {
-	unsigned int magicNumber;
-	string version;
-	unsigned long long indexOffset;
-	unsigned int indexLength;
-	unsigned int numReads;
-	unsigned short headerLength;
-	unsigned short keyLength;
-	unsigned short numFlowsPerRead;
-	int flogramFormatCode;
-	string flowChars; //length depends on number flow reads
-	string keySequence; //length depends on key length
-	
-	CommonHeader(){ magicNumber=0; indexOffset=0; indexLength=0; numReads=0; headerLength=0; keyLength=0; numFlowsPerRead=0; flogramFormatCode='s'; }
-	~CommonHeader() { }
-};
-/**********************************************************/
-struct Header {
-	unsigned short headerLength;
-	unsigned short nameLength;
-	unsigned int numBases;
-	unsigned short clipQualLeft;
-	unsigned short clipQualRight;
-	unsigned short clipAdapterLeft;
-	unsigned short clipAdapterRight;
-	string name; //length depends on nameLength
-	string timestamp;
-	string region;
-	string xy;
-	
-	Header() { headerLength=0; nameLength=0; numBases=0; clipQualLeft=0; clipQualRight=0; clipAdapterLeft=0; clipAdapterRight=0; }
-	~Header() { }
-};
-/**********************************************************/
-struct seqRead {
-	vector<unsigned short> flowgram;
-	vector<unsigned int> flowIndex;
-	string bases;
-	vector<unsigned int> qualScores;
-	
-	seqRead() { }
-	~seqRead() { }
-};
+
 /**********************************************************/
 struct linePair {
-    unsigned long long start;
-    unsigned long long end;
-    linePair(unsigned long long i, unsigned long long j) : start(i), end(j) {}
+    double start;
+    double end;
+    linePair(double i, double j) : start(i), end(j) {}
     linePair(){ start=0; end=0; }
     ~linePair(){}
 };
@@ -422,18 +436,19 @@ struct listCt{
 };
 /***********************************************************************/
 struct consTax2{
+    string otuName;
     string taxonomy;
     int abundance;
-    string otuName;
 	consTax2() :  otuName("OTUxxx"), taxonomy("unknown"), abundance(0) {};
 	consTax2(string n, string t, int a) :  otuName(n), taxonomy(t), abundance(a) {}
 };
-/************************************************************/
-struct clusterNode {
-	int numSeq;
-	int parent;
-	int smallChild; //used to make linkTable work with list and rabund. represents bin number of this cluster node
-	clusterNode(int num, int par, int kid) : numSeq(num), parent(par), smallChild(kid) {};
+/***********************************************************************/
+struct Taxon {
+    string name;
+    float confidence;
+
+    Taxon(string n, float conf) : name(n), confidence(conf) {}
+    ~Taxon(){}
 };
 /************************************************************/
 struct seqDist {
@@ -445,12 +460,6 @@ struct seqDist {
 	~seqDist() {}
 };
 /************************************************************/
-struct distlinePair {
-	int start;
-	int end;
-	
-};
-/************************************************************/
 struct oligosPair {
 	string forward;
 	string reverse;
@@ -524,14 +533,8 @@ inline bool compareSeqPriorityNodes(seqPriorityNode left, seqPriorityNode right)
         else { return false; }
     }
     return false;	
-} 
- 
-/************************************************************/
-//sorts lowest to highest
-inline bool compareDistLinePairs(distlinePair left, distlinePair right){
-	return (left.end < right.end);	
-} 
-//********************************************************************************************************************
+}
+/********************************************************************************************************************/
 //sorts lowest to highest
 inline bool compareSequenceDistance(seqDist left, seqDist right){
 	return (left.dist < right.dist);	
@@ -563,10 +566,9 @@ void convert(const string& s, T& x, bool failIfLeftoverChars = true){
 			throw BadConversion(s);
 	
 }
-//**********************************************************************************************************************
+//*******************************************************************************
 template <typename T> int sgn(T val){ return (val > T(0)) - (val < T(0)); }
-//**********************************************************************************************************************
-
+//*******************************************************************************
 template<typename T>
 bool convertTestFloat(const string& s, T& x, bool failIfLeftoverChars = true){
 	
@@ -579,9 +581,7 @@ bool convertTestFloat(const string& s, T& x, bool failIfLeftoverChars = true){
 		return true;
 	
 }
-
-//**********************************************************************************************************************
-
+//***********************************************************************
 template<typename T>
 bool convertTest(const string& s, T& x, bool failIfLeftoverChars = true){
 	
@@ -594,7 +594,7 @@ bool convertTest(const string& s, T& x, bool failIfLeftoverChars = true){
 		return true;
 	
 }
-//**********************************************************************************************************************
+//**********************************************************************
 template<typename T>
 string toString(const T&x){
 	
@@ -603,15 +603,14 @@ string toString(const T&x){
 		return output.str();
 	
 }
-//**********************************************************************************************************************
+//***********************************************************************
 template<typename T>
 void mothurSwap(T&x, T&y){
     T temp = y;
     y = x;
     x = temp;
 }
-//**********************************************************************************************************************
-
+//*************************************************************************
 template<typename T>
 string toHex(const T&x){
 	
@@ -622,8 +621,7 @@ string toHex(const T&x){
 		return output.str();
 	
 }
-//**********************************************************************************************************************
-
+//*********************************************************************
 template<typename T>
 string toString(const T&x, int i){
 	
@@ -633,10 +631,8 @@ string toString(const T&x, int i){
 		output << fixed << x;
 		
 		return output.str();
-	
 }
-//**********************************************************************************************************************
-
+//***********************************************************************
 template<class T>
 T fromString(const string& s){
 	istringstream stream (s);
@@ -644,8 +640,6 @@ T fromString(const string& s){
 	stream >> t;
 	return t;
 }
-
-//**********************************************************************************************************************
+//****************************************************************************
 
 #endif
-
