@@ -45,12 +45,17 @@ class MothurOut {
         bool getQuietMode()                             { return quietMode;                             }
         void setQuietMode(bool t)                       { quietMode = t;                                }
         int getNumErrors()                              { return numErrors;                             }
-        void resetCommandErrors()                       { numCommandErrors = 0; numCommandWarnings = 0; }
+        void resetCommandErrors()                       { control_pressed = false; numCommandErrors = 0; numCommandWarnings = 0; silenceWarnings = false;}
         string getLogFileName()                         { return logFileName;                           }
 		void setLogFileName(string f, bool append);
+        void setHomePath(string);
+        string getHomePath()  { return homePath; }
+        void setPaths(vector<string>); //environment variable 'PATH' values
+        vector<string> getPaths() { return paths; }
     
 		void mothurOut(string); //writes to cout and the logfile
 		void mothurOutEndLine(); //writes to cout and the logfile
+        void mothurOutClearBuffer();
 		void mothurOut(string, ofstream&); //writes to the ofstream, cout and the logfile
 		void mothurOutEndLine(ofstream&); //writes to the ofstream, cout and the logfile
         void mothurOutJustToScreen(string); //writes to cout
@@ -78,11 +83,13 @@ class MothurOut {
             quietMode = false;
             changedSeqNames = true;
             silenceLog = false;
+            silenceWarnings = false; //per command
             numErrors = 0; numWarnings = 0;
             numCommandErrors = 0; numCommandWarnings = 0;
             maxCommandErrors = 10; maxCommandWarnings = 10;
             logFileName = "";
             buffer = "";
+            homePath = "";
             seed = std::chrono::system_clock::now().time_since_epoch().count();
 		}
 		~MothurOut();
@@ -90,8 +97,9 @@ class MothurOut {
 		ofstream out;
         unsigned seed;
         int numErrors, numWarnings, numCommandErrors, numCommandWarnings, maxCommandErrors, maxCommandWarnings;
-        string logFileName, buffer;
-        bool changedSeqNames, silenceLog, control_pressed, executing, debug, quietMode;
+        string logFileName, buffer, homePath;
+        vector<string> paths;
+        bool changedSeqNames, silenceLog, silenceWarnings, control_pressed, executing, debug, quietMode;
 };
 /***********************************************/
 
