@@ -22,16 +22,19 @@
 
 class OptionParser {
 public:
-	OptionParser(string);
+	OptionParser(string, vector<string>);
     OptionParser(string, map<string, string>&);
 	~OptionParser() {}
-	map<string, string> getParameters();
+	map<string, string> getParameters(); //adds inputdir to parameters if indicated
 	bool getNameFile(vector<string>);
 private:
 	map<string, string> parameters;
 	MothurOut* m;
     CurrentFile* current;
     Utils util;
+    set<string> fileTypes;
+
+    void fillFileTypes(set<string>&);
 };
 
 /***********************************************************************/
