@@ -17,8 +17,8 @@ public:
 	~RareDisplay()					{	delete estimate; delete output;		}
 	void init(string);
 	void reset();
-	void update(SAbundVector*);
-	void update(vector<SharedRAbundVector*> shared, int numSeqs, int numGroupComb, vector<string>);
+	void update(SAbundVector&);
+	void update(vector<SharedRAbundVector*> shared, int numSeqs);
 	void close();
 	bool isCalcMultiple() { return estimate->getMultiple(); }
 	
@@ -28,7 +28,6 @@ private:
 	string label;
 	map<int, vector<double> > results; //maps seqCount to results for that number of sequences
 	int nIters;
-    vector<string> Groups;
     Utils util;
     std::mutex mutex;
     
