@@ -330,7 +330,7 @@ long long Summary::summarizeFasta(string fastafile, string output) {
     try {
         long long num = 0;
         vector<linePair> lines;
-        vector<unsigned long long> positions;
+        vector<double> positions;
 #if defined NON_WINDOWS
         positions = util.divideFile(fastafile, processors);
         for (int i = 0; i < (positions.size()-1); i++) {	lines.push_back(linePair(positions[i], positions[(i+1)]));	 }
@@ -348,7 +348,7 @@ long long Summary::summarizeFasta(string fastafile, string output) {
 #endif
 
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<seqSumData*> data;
 
         //Lauch worker threads
@@ -361,7 +361,7 @@ long long Summary::summarizeFasta(string fastafile, string output) {
             seqSumData* dataBundle = new seqSumData(fastafile, outputName, lines[i+1].start, lines[i+1].end, hasNameOrCount, nameMap);
             data.push_back(dataBundle);
 
-            workerThreads.push_back(new thread(driverSummarize, dataBundle));
+            workerThreads.push_back(new std::thread(driverSummarize, dataBundle));
         }
 
         seqSumData* dataBundle = new seqSumData(fastafile, output, lines[0].start, lines[0].end, hasNameOrCount, nameMap);
@@ -542,7 +542,7 @@ void driverFastaSummarySummarize(seqSumData* params) {
 long long Summary::summarizeFastaSummary(string summaryfile) {
     try {
         long long num = 0;
-        vector<unsigned long long> positions;
+        vector<double> positions;
         vector<linePair> lines;
 #if defined NON_WINDOWS
         positions = util.divideFilePerLine(summaryfile, processors);
@@ -561,7 +561,7 @@ long long Summary::summarizeFastaSummary(string summaryfile) {
 #endif
 
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<seqSumData*> data;
 
         //Lauch worker threads
@@ -569,7 +569,7 @@ long long Summary::summarizeFastaSummary(string summaryfile) {
             seqSumData* dataBundle = new seqSumData(summaryfile, lines[i+1].start, lines[i+1].end, hasNameOrCount, nameMap);
             data.push_back(dataBundle);
 
-            workerThreads.push_back(new thread(driverFastaSummarySummarize, dataBundle));
+            workerThreads.push_back(new std::thread(driverFastaSummarySummarize, dataBundle));
         }
 
         seqSumData* dataBundle = new seqSumData(summaryfile, lines[0].start, lines[0].end, hasNameOrCount, nameMap);
@@ -735,7 +735,7 @@ void driverContigsSummarySummarize(seqSumData* params) {
 long long Summary::summarizeContigsSummary(string summaryfile) {
     try {
         long long num = 0;
-        vector<unsigned long long> positions;
+        vector<double> positions;
         vector<linePair> lines;
 #if defined NON_WINDOWS
         positions = util.divideFilePerLine(summaryfile, processors);
@@ -754,7 +754,7 @@ long long Summary::summarizeContigsSummary(string summaryfile) {
 #endif
 
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<seqSumData*> data;
 
         //Lauch worker threads
@@ -763,7 +763,7 @@ long long Summary::summarizeContigsSummary(string summaryfile) {
             seqSumData* dataBundle = new seqSumData(summaryfile, lines[i+1].start, lines[i+1].end, hasNameOrCount, nameMap);
             data.push_back(dataBundle);
 
-            workerThreads.push_back(new thread(driverContigsSummarySummarize, dataBundle));
+            workerThreads.push_back(new std::thread(driverContigsSummarySummarize, dataBundle));
         }
 
         seqSumData* dataBundle = new seqSumData(summaryfile, lines[0].start, lines[0].end, hasNameOrCount, nameMap);
@@ -931,7 +931,7 @@ void driverAlignSummarySummarize(seqSumData* params) {
 long long Summary::summarizeAlignSummary(string summaryfile) {
     try {
         long long num = 0;
-        vector<unsigned long long> positions;
+        vector<double> positions;
         vector<linePair> lines;
 #if defined NON_WINDOWS
         positions = util.divideFilePerLine(summaryfile, processors);
@@ -949,7 +949,7 @@ long long Summary::summarizeAlignSummary(string summaryfile) {
         }
 #endif
         //create array of worker threads
-        vector<thread*> workerThreads;
+        vector<std::thread*> workerThreads;
         vector<seqSumData*> data;
 
         //Lauch worker threads
@@ -958,7 +958,7 @@ long long Summary::summarizeAlignSummary(string summaryfile) {
             seqSumData* dataBundle = new seqSumData(summaryfile, lines[i+1].start, lines[i+1].end, hasNameOrCount, nameMap);
             data.push_back(dataBundle);
 
-            workerThreads.push_back(new thread(driverAlignSummarySummarize, dataBundle));
+            workerThreads.push_back(new std::thread(driverAlignSummarySummarize, dataBundle));
         }
 
         seqSumData* dataBundle = new seqSumData(summaryfile, lines[0].start, lines[0].end, hasNameOrCount, nameMap);
