@@ -21,7 +21,7 @@
 #include <string>
 #include <sstream>
 #include "mothurout.h"
-
+#include "utils.hpp"
 
 // For the purpose of training a support vector machine
 // we need to calculate a dot product between two feature
@@ -665,7 +665,7 @@ public:
         k(_k), obs(_obs),
         cache(_obs.size(), NULL) {}
     ~KernelFunctionCache() {
-        //cout << "deleting KernelFunctionCache cache" << endl;
+        
         for (int i = 0; i < cache.size(); i++) {
             if ( !rowNotCached(i) ) {
                 delete cache[i];
