@@ -212,8 +212,8 @@ void ValidCalculators::printCitations(vector<string> Estimators) {
 				}else if (Estimators[i] == "kulczynski") { Calculator* temp = new Kulczynski(); m->mothurOut(temp->getName() + ": "); temp->citation(); delete temp;
                 }else if (Estimators[i] == "jsd") { Calculator* temp = new JSD(); m->mothurOut(temp->getName() + ": "); temp->citation(); delete temp;
                 }else if (Estimators[i] == "rjsd") { Calculator* temp = new RJSD(); m->mothurOut(temp->getName() + ": "); temp->citation(); delete temp;
-				}else { m->mothurOut("[ERROR]: Missing else if for " + Estimators[i] + " in printCitations."); m->mothurOutEndLine(); }
-			}else { m->mothurOut(Estimators[i] + " is not a valid calculator, no citation will be given."); m->mothurOutEndLine(); }
+				}else { m->mothurOut("[ERROR]: Missing else if for " + Estimators[i] + " in printCitations.\n");  }
+			}else { m->mothurOut(Estimators[i] + " is not a valid calculator, no citation will be given.\n");  }
 		}
 			
 	}
@@ -337,14 +337,21 @@ bool ValidCalculators::isValidCalculator(string parameter, string calculator) {
 void ValidCalculators::initialEstimators() {
     try {
         
-        estimators.insert("erarefaction");
-        estimators.insert("metroig");
-        estimators.insert("metroln");
-        estimators.insert("metrols");
-        estimators.insert("metrosichel");
+        estimators.insert("erarefact");
+        estimators.insert("ig");
+        estimators.insert("ln");
+        estimators.insert("ls");
+        estimators.insert("si");
         estimators.insert("igabund");
-        //estimators.insert("lnabund");
-        estimators.insert("igrarefaction");
+        estimators.insert("lnabund");
+        estimators.insert("igrarefact");
+        estimators.insert("lnrarefact");
+        estimators.insert("lnshift");
+        estimators.insert("lsabund");
+        estimators.insert("lsrarefact");
+        estimators.insert("siabund");
+        estimators.insert("sirarefact");
+        estimators.insert("sishift");
         estimators.insert("default");
     }
     catch(exception& e) {
@@ -767,6 +774,7 @@ string ValidCalculators::printCalc(string parameter) {
         else if (parameter == "matrix")             {  output += util.getStringFromSet(matrix, ", ");               }
         else if (parameter == "heat")               {  output += util.getStringFromSet(heat, ", ");                 }
         else if (parameter == "distance")           {  output += util.getStringFromSet(distance, ", ");             }
+        else if (parameter == "estimator")          {  output += util.getStringFromSet(estimators, ", ");             }
 		output += "\n";
 		
 		return output;
