@@ -17,7 +17,6 @@ ValidParameters::ValidParameters() {
         current = CurrentFile::getInstance();
         locations = current->getLocations();
 		initParameterRanges();
-		commandName = "";
 	}
 	catch(exception& e) {
 		m->errorOut(e, "ValidParameters", "ValidParameters");
@@ -26,22 +25,6 @@ ValidParameters::ValidParameters() {
 }
 /***********************************************************************/
 
-ValidParameters::ValidParameters(string c) {
-	try {
-		m = MothurOut::getInstance();
-        current = CurrentFile::getInstance();
-        locations = current->getLocations();
-		initParameterRanges();
-		commandName = c;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ValidParameters", "ValidParameters");
-		exit(1);
-	}
-}
-
-/***********************************************************************/
-
 ValidParameters::~ValidParameters() {}
 
 /***********************************************************************/
@@ -53,11 +36,11 @@ bool ValidParameters::isValidParameter(string parameter, vector<string> cParams,
 		for(int i = 0; i < numParams; i++) {
 			if(cParams.at(i).compare(parameter) == 0) {
 				valid = true;
-				i = numParams;
+                break;
 			}
 		}
 		if(!valid) {
-			m->mothurOut(parameter + " is not a valid parameter."); m->mothurOutEndLine();
+			m->mothurOut("[WARNING]: " + parameter + " is not a valid parameter, ignoring.\n");
 			m->mothurOut("The valid parameters are: ");
 			for(int i = 0; i < numParams-1; i++)
 				m->mothurOut(cParams.at(i) + ", ");
@@ -65,8 +48,7 @@ bool ValidParameters::isValidParameter(string parameter, vector<string> cParams,
 			return false;
 		}
 		
-		if(parameterRanges.count(parameter) != 1)
-			return true;
+        if(parameterRanges.count(parameter) != 1) { return true; }
 	
 		int pVal;
 		double piSentinel = 3.14159;
@@ -230,59 +212,59 @@ string ValidParameters::valid(map<string, string>& container, string parameter)
     }
 }
 /******************************************************/
-string ValidParameters::validFile(map<string, string>& container, string parameter, vector<string> locations) {
-	try {
-		bool ableToOpen;
+vector<string> ValidParameters::validFiles(map<string, string>& container, string parameter) {
+    try {
+        vector<string> vFiles;
         Utils util;
-		
-		map<string, string>::iterator it;
-		
-		it = container.find(parameter);
-		if(it != container.end()){ //no parameter given
-                if ((it->second == "NONE") || (it->second == "none")) {it->second = "NONE";}//ignore
-                else {
+        bool openedAtLeastOne = false;
+
+        map<string, string>::iterator it = container.find(parameter);
+        if(it != container.end()){ //no parameter given
+            if ((it->second == "NONE") || (it->second == "none")) {it->second = "NONE";}//ignore
+            else {
                 
-				int pos = (it->second).find(".tx.");
-				if (pos != string::npos) { current->setSharedHeaderMode("tax"); }
-				else { current->setSharedHeaderMode("otu"); }
-			
-                string filename = it->second;
-                if (util.checkLocations(filename, locations)) { container[parameter] = filename; }
-                else { m->mothurOut("Unable to open " + container[parameter]); m->mothurOutEndLine(); return "not open";  }
-				
-				//check phylip file to make sure its really phylip and not column
-				if ((it->first == "phylip") && (ableToOpen)) {
-					ifstream inPhylip;
-					util.openInputFile(it->second, inPhylip);
-										
-					string numTest, name;
-					inPhylip >> numTest >> name;
-					inPhylip.close();
-					
-					if (!util.isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ". I suspect you entered a column formatted file as a phylip file, aborting."); m->mothurOutEndLine(); return "not found"; }
-				}
+                vector<string> files; util.splitAtDash(it->second, files);
                 
-                //check for blank file
-                if (ableToOpen) {
-                    if (util.isBlank(container[parameter])) {
-                        m->mothurOut("[ERROR]: " + container[parameter] + " is blank, aborting.\n");  return "not found"; 
+                for (int i = 0; i < files.size(); i++) {
+                    files[i] = util.removeQuotes(files[i]);
+                    string filename = files[i];
+                    if (util.checkLocations(filename, current->getLocations())) { vFiles.push_back(filename); container[parameter] = filename; openedAtLeastOne = true; }
+                    else { m->mothurOut("Unable to open " + filename + ", skipping.\n");  }
+                    
+                    //check phylip file to make sure its really phylip and not column
+                    if ((it->first == "phylip") && (openedAtLeastOne)) {
+                        ifstream inPhylip;
+                        util.openInputFile(filename, inPhylip);
+                        
+                        string numTest, name;
+                        inPhylip >> numTest >> name;
+                        inPhylip.close();
+                        
+                        if (!util.isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ". I suspect you entered a column formatted file as a phylip file, aborting.\n"); return nullVector; }
+                    }
+                    
+                    //check for blank file
+                    if (openedAtLeastOne) {
+                        if (util.isBlank(container[parameter])) { m->mothurOut("[ERROR]: " + filename + " is blank, skipping.\n");  }
                     }
                 }
-                }
-		}else { return "not found"; }
-		
-		return it->second;
-	
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ValidParameters", "validFile");
-		exit(1);
-	}
+                
+                if (!openedAtLeastOne) { vFiles.push_back("not open"); }
+            }
+        }else { return vFiles; }
+        
+        return vFiles;
+        
+    }
+    catch(exception& e) {
+        m->errorOut(e, "ValidParameters", "validFile");
+        exit(1);
+    }
 }
 /******************************************************/
 string ValidParameters::validFile(map<string, string>& container, string parameter) {
     try {
-        bool ableToOpen;
+        bool ableToOpen = false;
         Utils util;
         
         map<string, string>::iterator it;
@@ -291,13 +273,9 @@ string ValidParameters::validFile(map<string, string>& container, string paramet
         if(it != container.end()){ //no parameter given
             if ((it->second == "NONE") || (it->second == "none")) {it->second = "NONE";}//ignore
             else {
-                
-                int pos = (it->second).find(".tx.");
-                if (pos != string::npos) { current->setSharedHeaderMode("tax"); }
-                else { current->setSharedHeaderMode("otu"); }
-                
+                it->second = util.removeQuotes(it->second);
                 string filename = it->second;
-                if (util.checkLocations(filename, current->getLocations())) { container[parameter] = filename; }
+                if (util.checkLocations(filename, current->getLocations())) { container[parameter] = filename; ableToOpen = true; }
                 else { m->mothurOut("Unable to open " + container[parameter]); m->mothurOutEndLine(); return "not open";  }
                 
                 //check phylip file to make sure its really phylip and not column
@@ -309,13 +287,13 @@ string ValidParameters::validFile(map<string, string>& container, string paramet
                     inPhylip >> numTest >> name;
                     inPhylip.close();
                     
-                    if (!util.isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ". I suspect you entered a column formatted file as a phylip file, aborting."); m->mothurOutEndLine(); return "not found"; }
+                    if (!util.isContainingOnlyDigits(numTest)) { m->mothurOut("[ERROR]: expected a number and got " + numTest + ". I suspect you entered a column formatted file as a phylip file, aborting.\n");  return "not found"; }
                 }
                 
                 //check for blank file
                 if (ableToOpen) {
                     if (util.isBlank(container[parameter])) {
-                        m->mothurOut("[ERROR]: " + container[parameter] + " is blank, aborting."); m->mothurOutEndLine(); return "not found";
+                        m->mothurOut("[ERROR]: " + container[parameter] + " is blank, aborting.\n");  return "not found";
                     }
                 }
             }
